@@ -1,3 +1,25 @@
+/*
+
+    Copyright (C) 2001 The Kompany
+		  2002-2003	Ilya Konstantinov <kde-devel@future.shiny.co.il>
+		  2002-2003	Marcus Meissner <marcus@jet.franken.de>
+		  2003		Nadeem Hasan <nhasan@nadmm.com>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+*/
 #ifndef __kamera_h__
 #define __kamera_h__
 
@@ -20,6 +42,7 @@ class KSimpleConfig;
 class KIconView;
 class KActionCollection;
 class KToolBar;
+class KPopupMenu;
 
 class KKameraConfig : public KCModule
 {
@@ -57,7 +80,6 @@ private:
 	void displayGPSuccessDialogue(void);
 	void displayCameraAbilities(const CameraAbilities &abilities);
 	void populateDeviceListView(void);
-	void autoDetect(void);
 	void beforeCameraOperation(void);
 	void afterCameraOperation(void);
 	
@@ -80,7 +102,7 @@ private:
 	KActionCollection *m_actions;
 	QPushButton *m_addCamera, *m_removeCamera, *m_testCamera, *m_configureCamera;
 	KToolBar *m_toolbar;
-	QPopupMenu *m_devicePopup;
+	KPopupMenu *m_devicePopup;
 
 	// true if libgphoto2 was initialised successfully in
 	// the constructor
