@@ -1,3 +1,25 @@
+/*
+
+    Copyright (C) 2001 The Kompany
+		  2001-2003	Ilya Konstantinov <kde-devel@future.shiny.co.il>
+		  2001-2003	Marcus Meissner <marcus@jet.franken.de>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+*/
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -27,7 +49,7 @@ using namespace KIO;
 
 extern "C"
 {
-	int kdemain(int argc, char **argv);
+	KDE_EXPORT int kdemain(int argc, char **argv);
 
 	static void frontendCameraStatus(GPContext *context, const char *format, va_list args, void *data);
 	static unsigned int frontendProgressStart(
@@ -65,13 +87,12 @@ m_camera(NULL)
 	m_camera = 0;
 	m_file = NULL;
 	m_config = new KSimpleConfig(KProtocolInfo::config("camera"));
-	autoDetect();
 	m_context = gp_context_new();
 }
 
 KameraProtocol::~KameraProtocol()
 {
-    delete m_config;
+	delete m_config;
 	if(m_camera) {
 		closeCamera();
  		gp_camera_free(m_camera);
@@ -79,45 +100,24 @@ KameraProtocol::~KameraProtocol()
 	}
 }
 
-void KameraProtocol::autoDetect(void)
-{
-	GPContext *glob_context = NULL;
-	QStringList groupList = m_config->groupList();
-
-        int i, count;
-        CameraList list;
-        CameraAbilitiesList *al;
-        GPPortInfoList *il;
-        const char *model, *value;
-
-        gp_abilities_list_new (&al);
-        gp_abilities_list_load (al, glob_context);
-        gp_port_info_list_new (&il);
-        gp_port_info_list_load (il);
-        gp_abilities_list_detect (al, il, &list, glob_context);
-        gp_abilities_list_free (al);
-        gp_port_info_list_free (il);
-
-        count = gp_list_count (&list);
-
-	for (i = 0 ; i<count ; i++) {
-		gp_list_get_name  (&list, i, &model);
-		gp_list_get_value (&list, i, &value);
-
-		if (groupList.contains(model))
-			continue;
-		kdDebug(7123) << "Adding " << model << " at " << value << endl;
-		m_config->setGroup(model);
-		m_config->writeEntry("Model",model);
-		m_config->writeEntry("Path",value);
-	}
-}
-
-
 // initializes the camera for usage - should be done before operations over the wire
 bool KameraProtocol::openCamera(void) {
-	if (!m_camera)
+	if (!m_camera) {
 		reparseConfiguration();
+	} else {
+		int ret, tries = 15;
+		
+		while (tries--) {
+			ret = gp_camera_init(m_camera, m_context);
+			if (	(ret == GP_ERROR_IO_USB_CLAIM) || 
+				(ret == GP_ERROR_IO_LOCK)) {
+				sleep(1);
+				continue;
+			}
+			if (ret == GP_OK) break;
+			return false;
+		}
+	}
 	return true;
 }
 
@@ -160,8 +160,10 @@ void KameraProtocol::get(const KURL &url)
 		return;
 	}
 
-	if(!openCamera())
+	if(!openCamera()) {
+		error(KIO::ERR_DOES_NOT_EXIST, url.path());
 		return;
+	}
 
 	// fprintf(stderr,"get(%s)\n",url.path().latin1());
 
@@ -189,7 +191,7 @@ void KameraProtocol::get(const KURL &url)
 
 #undef GPHOTO_TEXT_FILE
 	// emit info message
-	infoMessage( i18n("Retrieving data from camera <b>%1</b>").arg(m_cfgModel) );
+	infoMessage( i18n("Retrieving data from camera <b>%1</b>").arg(url.user()) );
 
 	// Note: There's no need to re-read directory for each get() anymore
 	gp_file_new(&m_file);
@@ -199,7 +201,7 @@ void KameraProtocol::get(const KURL &url)
 	
 	gpr = gp_camera_file_get_info(m_camera, tocstr(fix_foldername(url.directory(false))), tocstr(url.fileName()), &info, m_context);
 	if (gpr != GP_OK) {
-		kdDebug(7123) << "file " << url.directory(false) << " / " << url.fileName() << " not found, gpr is " << gpr << endl;
+		// fprintf(stderr,"Folder %s / File %s not found, gpr is %d\n",folder.latin1(), url.fileName().latin1(), gpr);
 		gp_file_free(m_file);
 		if ((gpr == GP_ERROR_FILE_NOT_FOUND) || (gpr == GP_ERROR_DIRECTORY_NOT_FOUND))
 			error(KIO::ERR_DOES_NOT_EXIST, url.path());
@@ -226,14 +228,14 @@ void KameraProtocol::get(const KURL &url)
 
 	// fetch the data
 	m_fileSize = 0;
-	gpr = gp_camera_file_get(m_camera, tocstr(fix_foldername(url.directory(false))), tocstr(url.filename()), fileType, m_file, m_context);
+	gpr = gp_camera_file_get(m_camera, tocstr(fix_foldername(url.directory(false))), tocstr(url.fileName()), fileType, m_file, m_context);
 	if (	(gpr == GP_ERROR_NOT_SUPPORTED) &&
 		(fileType == GP_FILE_TYPE_PREVIEW)
 	) {
 		// If we get here, the file info command information 
 		// will either not be used, or still valid.
 		fileType = GP_FILE_TYPE_NORMAL;
-		gpr = gp_camera_file_get(m_camera, tocstr(fix_foldername(url.directory(false))), tocstr(url.filename()), fileType, m_file, m_context);
+		gpr = gp_camera_file_get(m_camera, tocstr(fix_foldername(url.directory(false))), tocstr(url.fileName()), fileType, m_file, m_context);
 	}
 	switch(gpr) {
 		case GP_OK:
@@ -242,7 +244,7 @@ void KameraProtocol::get(const KURL &url)
 		case GP_ERROR_DIRECTORY_NOT_FOUND:
 			gp_file_free(m_file);
 			m_file = NULL;
-			error(KIO::ERR_DOES_NOT_EXIST, url.filename());
+			error(KIO::ERR_DOES_NOT_EXIST, url.fileName());
 			closeCamera();
 			return ;
 		default:
@@ -327,8 +329,10 @@ void KameraProtocol::statRegular(const KURL &url)
 	UDSEntry entry;
 	int gpr;
 
-	if (openCamera() == false)
+	if (openCamera() == false) {
+		error(KIO::ERR_DOES_NOT_EXIST, url.path());
 		return;
+	}
 
 	// fprintf(stderr,"statRegular(%s)\n",url.path().latin1());
 
@@ -350,7 +354,7 @@ void KameraProtocol::statRegular(const KURL &url)
 		CameraText xx;						\
 		gpr = gp_camera_get_about(m_camera,  &xx, m_context);	\
 		if (gpr != GP_OK) {					\
-			error(KIO::ERR_DOES_NOT_EXIST, url.filename());	\
+			error(KIO::ERR_DOES_NOT_EXIST, url.fileName());	\
 			return;						\
 		}							\
 		translateTextToUDS(entry,#xx".txt",xx.text);		\
@@ -367,7 +371,7 @@ void KameraProtocol::statRegular(const KURL &url)
 	const char *name;
 	for(int i = 0; i < gp_list_count(dirList); i++) {
 		gp_list_get_name(dirList, i, &name);
-		if (url.filename().compare(name) == 0) {
+		if (url.fileName().compare(name) == 0) {
 			gp_list_free(dirList);
 			UDSEntry entry;
 			translateDirectoryToUDS(entry, url.fileName());
@@ -399,10 +403,12 @@ void KameraProtocol::del(const KURL &url, bool isFile)
 {
 	kdDebug(7123) << "KameraProtocol::del(" << url.path() << ")" << endl;
 
-	if(!openCamera())
+	if(!openCamera()) {
+		error(KIO::ERR_CANNOT_DELETE, url.fileName());
 		return;
+	}
 	if (!cameraSupportsDel()) {
-		error(KIO::ERR_CANNOT_DELETE, url.filename());
+		error(KIO::ERR_CANNOT_DELETE, url.fileName());
 		return;
 	}
 	if(isFile){
@@ -410,10 +416,10 @@ void KameraProtocol::del(const KURL &url, bool isFile)
 		gp_list_new(&list);
 		int ret;
 
-		ret = gp_camera_file_delete(m_camera, tocstr(fix_foldername(url.directory(false))), tocstr(url.filename()), m_context);
+		ret = gp_camera_file_delete(m_camera, tocstr(fix_foldername(url.directory(false))), tocstr(url.fileName()), m_context);
 
 		if(ret != GP_OK) {
-			error(KIO::ERR_CANNOT_DELETE, url.filename());
+			error(KIO::ERR_CANNOT_DELETE, url.fileName());
 		} else {
 			finished();
 		}
@@ -427,46 +433,139 @@ void KameraProtocol::listDir(const KURL &url)
 	kdDebug(7123) << "KameraProtocol::listDir(" << url.path() << ")" << endl;
 
 	if (url.host().isEmpty()) {
+		KURL xurl;
 		// List the available cameras
 		QStringList groupList = m_config->groupList();
 		kdDebug(7123) << "Found cameras: " << groupList.join(", ") << endl;
 		QStringList::Iterator it;
 		UDSEntry entry;
 		UDSAtom atom;
+
+
+		/*
+		 * What we do:
+		 * - Autodetect cameras and remember them with their ports.
+		 * - List all saved and possible offline cameras.
+		 * - List all autodetected and not yet printed cameras.
+		 */
+		QMap<QString,QString>	ports, names;
+		QMap<QString,int>	modelcnt;
+
+		/* Autodetect USB cameras ... */
+		GPContext *glob_context = NULL;
+		int i, count;
+		CameraList list;
+		CameraAbilitiesList *al;
+		GPPortInfoList *il;
+
+		gp_abilities_list_new (&al);
+		gp_abilities_list_load (al, glob_context);
+		gp_port_info_list_new (&il);
+		gp_port_info_list_load (il);
+		gp_abilities_list_detect (al, il, &list, glob_context);
+		gp_abilities_list_free (al);
+		gp_port_info_list_free (il);
+
+		count = gp_list_count (&list);
+
+		for (i = 0 ; i<count ; i++) {
+			const char *model, *value;
+
+			gp_list_get_name  (&list, i, &model);
+			gp_list_get_value (&list, i, &value);
+	
+			ports[value] = model;
+			// NOTE: We might get different ports than usb: later!
+			if (value != "usb:")
+				names[model] = value;
+
+			/* Save them, even though we can autodetect them for
+			 * offline listing.
+			 */
+			m_config->setGroup(model);
+			m_config->writeEntry("Model",model);
+			m_config->writeEntry("Path",value);
+			modelcnt[model]++;
+		}
+
+		/* Avoid duplicated entry for usb: and usb:001,042 entries. */
+		if (ports.contains("usb:") && names[ports["usb:"]]!="usb:")
+			ports.remove("usb:");
+
 		for (it = groupList.begin(); it != groupList.end(); it++) {
-			if (*it != "<default>") {
-				entry.clear();
-				atom.m_uds = UDS_FILE_TYPE; // UDS type
-				atom.m_long = S_IFDIR; // directory
-				entry.append(atom);
+			QString m_cfgPath;
+			if (*it == "<default>")
+				continue;
 
-				atom.m_uds = UDS_NAME;
-				atom.m_str = *it;
-				entry.append(atom);
+			m_config->setGroup(*it);
+			m_cfgPath = m_config->readEntry("Path");
 
-				atom.m_uds = UDS_ACCESS;
-				atom.m_long = S_IRUSR | S_IRGRP | S_IROTH |
-					S_IWUSR | S_IWGRP | S_IWOTH;
-				entry.append(atom);
+			/* If autodetect by USB autodetect ... skip it here.
+			 * We leave unattached USB cameras in here, because the user
+			 * might plug them in later and does not want to press reload.
+			 * We add them with port "usb:".
+			 */
+			if (modelcnt[*it] > 0)
+				continue;
 
-				atom.m_uds = UDS_URL;
-				KURL xurl;
-				xurl.setProtocol("camera");
-				xurl.setHost(*it);
-				xurl.setPath("/");
-				atom.m_str = xurl.url();
-				entry.append(atom);
+			entry.clear();
+			atom.m_uds = UDS_FILE_TYPE;atom.m_long = S_IFDIR;entry.append(atom);
+			atom.m_uds = UDS_NAME;atom.m_str = *it;entry.append(atom);
+			atom.m_uds = UDS_ACCESS;
+			atom.m_long = S_IRUSR | S_IRGRP | S_IROTH |
+				S_IWUSR | S_IWGRP | S_IWOTH;
+			entry.append(atom);
 
-				listEntry(entry, false);
+			atom.m_uds = UDS_URL;
+
+			xurl.setProtocol("camera");
+			xurl.setUser(*it);
+			/* Avoid setting usb:xxx,yyy. */
+			if (m_cfgPath.contains("usb:")>0) {
+				names[*it] = "usb:";
+				xurl.setHost("usb:");
+			} else {
+				xurl.setHost(m_cfgPath);
 			}
+			xurl.setPath("/");
+			atom.m_str = xurl.url();
+			entry.append(atom);
+
+			listEntry(entry, false);
+		}
+	
+		QMap<QString,QString>::iterator portsit;
+
+		for (portsit = ports.begin(); portsit != ports.end(); portsit++) {
+			entry.clear();
+			atom.m_uds = UDS_FILE_TYPE;atom.m_long = S_IFDIR; entry.append(atom);
+			atom.m_uds = UDS_NAME;atom.m_str = portsit.data();entry.append(atom);
+
+			atom.m_uds = UDS_ACCESS;
+			atom.m_long = S_IRUSR | S_IRGRP | S_IROTH |
+				S_IWUSR | S_IWGRP | S_IWOTH;
+			entry.append(atom);
+
+			atom.m_uds = UDS_URL;
+			xurl.setProtocol("camera");
+			xurl.setHost(portsit.key());
+			xurl.setUser(portsit.data());
+			xurl.setPath("/");
+			atom.m_str = xurl.url();
+			entry.append(atom);
+
+			listEntry(entry, false);
 		}
 		listEntry(entry, true);
+
 		finished();
 		return;
 	}
 
-	if (!openCamera())
+	if (!openCamera()) {
+		error(KIO::ERR_COULD_NOT_READ,url.path());
 		return;
+	}
 
 	CameraList *dirList;
 	CameraList *fileList;
@@ -512,10 +611,8 @@ void KameraProtocol::listDir(const KURL &url)
 
 	for(int i = 0; i < gp_list_count(fileList); ++i) {
 		gp_list_get_name(fileList, i, &name);
-	kdDebug(7123) << "after get name" <<endl;
 		// we want to know more info about files (size, type...)
 		gp_camera_file_get_info(m_camera, tocstr(url.path()), name, &info, m_context);
-	kdDebug(7123) << "after file getinfo" <<endl;
 		translateFileToUDS(entry, info, QString::fromLocal8Bit(name));
 		listEntry(entry, false);
 	}
@@ -551,13 +648,7 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 	int gpr, idx;
 
 	if (!host.isEmpty()) {
-		// Read configuration
-		m_config->setGroup(host);
-		QString m_cfgModel = m_config->readEntry("Model");
-		QString m_cfgPath = m_config->readEntry("Path");
-
-		kdDebug(7123) << "model is " << m_cfgModel << ", port is " << m_cfgPath << endl;
-
+		kdDebug(7123) << "model is " << user << ", port is " << host << endl;
 		if (m_camera) {
 			kdDebug(7123) << "Configuration change detected" << endl;
 			closeCamera();
@@ -572,10 +663,10 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		CameraAbilitiesList *abilities_list;
 		gp_abilities_list_new(&abilities_list);
 		gp_abilities_list_load(abilities_list, m_context);
-		idx = gp_abilities_list_lookup_model(abilities_list, tocstr(m_cfgModel));
+		idx = gp_abilities_list_lookup_model(abilities_list, tocstr(user));
 		if (idx < 0) {
 			gp_abilities_list_free(abilities_list);
-			kdDebug(7123) << "Unable to get abilities for model: " << m_cfgModel << endl;
+			kdDebug(7123) << "Unable to get abilities for model: " << user << endl;
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(idx));
 			return;
 		}
@@ -587,10 +678,10 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		GPPortInfo port_info;
 		gp_port_info_list_new(&port_info_list);
 		gp_port_info_list_load(port_info_list);
-		idx = gp_port_info_list_lookup_path(port_info_list, tocstr(m_cfgPath));
+		idx = gp_port_info_list_lookup_path(port_info_list, tocstr(host));
 		if (idx < 0) {
 			gp_port_info_list_free(port_info_list);
-			kdDebug(7123) << "Unable to get port info for path: " << m_cfgPath << endl;
+			kdDebug(7123) << "Unable to get port info for path: " << host << endl;
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(idx));
 			return;
 		}
@@ -613,14 +704,13 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		gp_camera_set_abilities(m_camera, m_abilities);
 		gp_camera_set_port_info(m_camera, port_info);
 		gp_camera_set_port_speed(m_camera, 0); // TODO: the value needs to be configurable
-		kdDebug(7123) << "Opening camera model " << m_cfgModel << " at " << m_cfgPath << endl;
+		kdDebug(7123) << "Opening camera model " << user << " at " << host << endl;
 #if 0
 		// initialize the camera (might take time on a non-existant or disconnected camera)
 		gpr = gp_camera_init(m_camera, m_context);
 		if(gpr != GP_OK) {
 			gp_camera_unref(m_camera);
 			m_camera = NULL;
-			m_cfgModel = ""; // force a configuration reload (since init didn't complete)
 			kdDebug(7123) << "Unable to init camera: " << gp_result_as_string(gpr) << endl;
 			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 			return;
@@ -766,7 +856,7 @@ int KameraProtocol::readCameraFolder(const QString &folder, CameraList *dirList,
 }
 
 void frontendProgressUpdate(
-	GPContext *context, unsigned int id, float current, void *data
+	GPContext * /*context*/, unsigned int /*id*/, float /*current*/, void *data 
 ) {
 	KameraProtocol *object = (KameraProtocol*)data;
 
@@ -796,7 +886,7 @@ void frontendProgressUpdate(
 }
 
 unsigned int frontendProgressStart(
-	GPContext *context, float totalsize, const char *format, va_list args,
+	GPContext * /*context*/, float totalsize, const char *format, va_list args,
 	void *data
 ) {
 	KameraProtocol *object = (KameraProtocol*)data;
@@ -822,7 +912,7 @@ unsigned int frontendProgressStart(
 # elif HAVE___VA_COPY
 	__va_copy(xvalist, args);
 # endif
-	vsnprintf(status, size, format, xvalist);
+	vsnprintf(status, size+1, format, xvalist);
 #else
 	/* We cannot copy the va_list, so make sure we 
 	 * walk it just _once_.
@@ -838,7 +928,7 @@ unsigned int frontendProgressStart(
 }
 
 // this callback function is activated on every status message from gphoto2
-static void frontendCameraStatus(GPContext *context, const char *format, va_list args, void *data)
+static void frontendCameraStatus(GPContext * /*context*/, const char *format, va_list args, void *data)
 {
 	KameraProtocol *object = (KameraProtocol*)data;
 	char *status;
@@ -863,7 +953,7 @@ static void frontendCameraStatus(GPContext *context, const char *format, va_list
 # elif HAVE___VA_COPY
 	__va_copy(xvalist, args);
 # endif
-	vsnprintf(status, size, format, xvalist);
+	vsnprintf(status, size+1, format, xvalist);
 #else
 	/* We cannot copy the va_list, so make sure we 
 	 * walk it just _once_.
