@@ -1,3 +1,24 @@
+/*
+
+    Copyright (C) 2001 The Kompany
+		  2001-2003	Ilya Konstantinov <kde-devel@future.shiny.co.il>
+		  2001-2003	Marcus Meissner <marcus@jet.franken.de>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+*/
 
 #ifndef __kamera_h__
 #define __kamera_h__
@@ -31,8 +52,6 @@ private:
 
 	GPContext	*m_context;
 
-	void autoDetect(void);
-
 	void reparseConfiguration(void);
 	bool openCamera(void);
 	void closeCamera(void);
