@@ -1,3 +1,11 @@
+//
+// Class: dviFile
+//
+// Class that represents a DVI file. Part of KDVI - A DVI previewing
+// plugin for kviewshell.
+//
+// (C) 2004 Stefan Kebekus. Distributed under the GPL.
+//
 
 #ifndef _DVIFILE_H
 #define _DVIFILE_H
@@ -20,8 +28,8 @@ class dvifile : public bigEndianByteReader
  public:
   /** Makes a deep copy of the old DVI file. */
   dvifile(const dvifile *old, fontPool *fp );
+  dvifile(QString fname, class fontPool *pool);
 
-  dvifile(QString fname, class fontPool *pool, bool sourceSpecialMark=true);
   ~dvifile();
 
   bool           isModified;
@@ -45,11 +53,11 @@ class dvifile : public bigEndianByteReader
       will be modified during the prescan phase (at this time the
       prescan code still resides in the dviwin class) */
   Q_UINT16       numberOfExternalPSFiles;
-
-  /** This field is set to 'false' when the DVI file is constructed,
-      and is set to 'true' after the prescan phase (at this time the
+  
+  /** This field is set to zero when the DVI file is constructed, and
+      will be modified during the prescan phase (at this time the
       prescan code still resides in the dviwin class) */
-  bool           prescan_is_performed;
+  Q_UINT16       numberOfExternalNONPSFiles;
 
   Q_UINT32       beginning_of_postamble;
   
@@ -65,7 +73,11 @@ class dvifile : public bigEndianByteReader
 
   /** Returns the number of centimeters per DVI unit in this DVI
       file. */
-  double         getCmPerDVIunit(void) {return cmPerDVIunit;};
+  double         getCmPerDVIunit(void) const {return cmPerDVIunit;}
+
+  /** Returns the magnification of the DVI file, as described in the
+      DVI Standard. */
+  Q_UINT32        getMagnification() const {return _magnification;}
 
   /** This member is set to zero on construction and can be used by
       other software to count error messages that were printed when
@@ -99,7 +111,7 @@ class dvifile : public bigEndianByteReader
 
   /** Offset in DVI file of last page, set in read_postamble(). */
   Q_UINT32       last_page_offset;
-  Q_UINT32       magnification;
+  Q_UINT32       _magnification;
 
   double         cmPerDVIunit;
 
