@@ -1,10 +1,10 @@
 //
-// Class: dviWindow
+// Class: dviRenderer
 //
-// Widget for displaying TeX DVI files.
+// Class for rendering TeX DVI files.
 // Part of KDVI- A previewer for TeX DVI files.
 //
-// (C) 2001 Stefan Kebekus
+// (C) 2001-2004 Stefan Kebekus
 // Distributed under the GPL
 //
 
@@ -15,8 +15,8 @@
 #include <qcheckbox.h>
 #include <qclipboard.h>
 #include <qcursor.h>
-#include <qfileinfo.h>
 #include <qlabel.h>
+#include <qfileinfo.h>
 #include <qlayout.h>
 #include <qmessagebox.h>
 #include <qpaintdevice.h>
@@ -46,59 +46,43 @@
 #include "fontpool.h"
 #include "fontprogress.h"
 #include "kdvi_multipage.h"
-#include "optiondialog.h"
 #include "performanceMeasurement.h"
 #include "xdvi.h"
 #include "zoomlimits.h"
+#include "dvisourcesplitter.h"
 
 //#define DEBUG_DVIWIN
 
 QPainter foreGroundPaint; // QPainter used for text
 
-//------ now comes the dviWindow class implementation ----------
 
-dviWindow::dviWindow(QWidget *par)
-  : info(new infoDialog(par))
+//------ now comes the dviRenderer class implementation ----------
+
+dviRenderer::dviRenderer(QWidget *par)
+  : documentRenderer(par), info(new infoDialog(par))
 {
 #ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "dviWindow( parent=" << par << " )" << endl;
+  kdDebug(4300) << "dviRenderer( parent=" << par << " )" << endl;
 #endif
 
   // initialize the dvi machinery
   dviFile                = 0;
 
   connect(&font_pool, SIGNAL( setStatusBarText( const QString& ) ), this, SIGNAL( setStatusBarText( const QString& ) ) );
-  connect(&font_pool, SIGNAL(fonts_have_been_loaded(fontPool *)), this, SLOT(all_fonts_loaded(fontPool *)));
-  connect(&font_pool, SIGNAL(MFOutput(QString)), info, SLOT(outputReceiver(QString)));
-  connect(&font_pool, SIGNAL(fonts_have_been_loaded(fontPool *)), info, SLOT(setFontInfo(fontPool *)));
-  connect(&font_pool, SIGNAL(new_kpsewhich_run(QString)), info, SLOT(clear(QString)));
 
   parentWidget = par;
   shrinkfactor = 3;
   current_page = 0;
+  resolutionInDPI = 0.0;
 
   connect( &clearStatusBarTimer, SIGNAL(timeout()), this, SLOT(clearStatusBar()) );
 
   currentlyDrawnPage = 0;
   editorCommand         = "";
 
-  // Calculate the horizontal resolution of the display device.  @@@
-  // We assume implicitly that the horizontal and vertical resolutions
-  // agree. This is probably not a safe assumption.
-  xres                   = QPaintDevice::x11AppDpiX ();
-  // Just to make sure that we are never dividing by zero.
-  if ((xres < 10)||(xres > 1000))
-    xres = 75.0;
-
-  _zoom                  = 1.0;
-  paper_width_in_cm           = 21.0; // set A4 paper as default
-  paper_height_in_cm          = 29.7;
-
   PostScriptOutPutString = NULL;
   HTML_href              = NULL;
   _postscript            = 0;
-  _showHyperLinks        = true;
-  reference              = QString::null;
 
   // Storage used for dvips and friends, i.e. for the "export" functions.
   proc                   = 0;
@@ -108,16 +92,16 @@ dviWindow::dviWindow(QWidget *par)
   export_tmpFileName     = "";
   export_errorString     = "";
 
-  PS_interface           = new ghostscript_interface(0.0, 0, 0);
+  PS_interface           = new ghostscript_interface();
   // pass status bar messages through
   connect(PS_interface, SIGNAL( setStatusBarText( const QString& ) ), this, SIGNAL( setStatusBarText( const QString& ) ) );
 }
 
 
-dviWindow::~dviWindow()
+dviRenderer::~dviRenderer()
 {
 #ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "~dviWindow" << endl;
+  kdDebug(4300) << "~dviRenderer" << endl;
 #endif
 
   delete PS_interface;
@@ -129,184 +113,159 @@ dviWindow::~dviWindow()
 }
 
 
-void dviWindow::setPrefs(bool flag_showPS, bool flag_showHyperLinks, const QString &str_editorCommand, 
-			 unsigned int MetaFontMode, bool makePK, bool useType1Fonts, bool useFontHints )
+void dviRenderer::setPrefs(bool flag_showPS, const QString &str_editorCommand, bool useFontHints )
 {
   _postscript = flag_showPS;
-  _showHyperLinks = flag_showHyperLinks;
   editorCommand = str_editorCommand;
-  font_pool.setParameters(MetaFontMode, makePK, useType1Fonts, useFontHints );
+  font_pool.setParameters( useFontHints );
   emit(needsRepainting());
 }
 
 
-void dviWindow::showInfo(void)
+void dviRenderer::showInfo(void)
 {
   info->setDVIData(dviFile);
-  // Call check_if_fonts_filenames_are_looked_up() to make sure that
-  // the fonts_info is emitted. That way, the infoDialog will know
-  // about the fonts and their status.
-  font_pool.check_if_fonts_filenames_are_looked_up();
   info->show();
 }
 
 
-void dviWindow::setPaper(double width_in_cm, double height_in_cm)
-{
-#ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "dviWindow::setPaper( width_in_cm=" << width_in_cm << ", height_in_cm=" << height_in_cm << " )" << endl;
-#endif
-
-  paper_width_in_cm      = width_in_cm;
-  paper_height_in_cm     = height_in_cm;
-  changePageSize();
-}
-
-
 //------ this function calls the dvi interpreter ----------
 
 
-void dviWindow::drawPage(documentPage *page)
+void dviRenderer::drawPage(double resolution, documentPage *page)
 {
 #ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "dviWindow::drawPage(documentPage *) called" << endl;
+  kdDebug(4300) << "dviRenderer::drawPage(documentPage *) called, page number " << page->getPageNumber() << endl;
 #endif
-
+  
   // Paranoid safety checks
   if (page == 0) {
-    kdError(4300) << "dviWindow::drawPage(documentPage *) called with argument == 0" << endl; 
+    kdError(4300) << "dviRenderer::drawPage(documentPage *) called with argument == 0" << endl; 
     return;
   }
   if (page->getPageNumber() == 0) {
-    kdError(4300) << "dviWindow::drawPage(documentPage *) called for a documentPage with page number 0" << endl;
+    kdError(4300) << "dviRenderer::drawPage(documentPage *) called for a documentPage with page number 0" << endl;
     return;
   }
   if ( dviFile == 0 ) {
-    kdError(4300) << "dviWindow::drawPage(documentPage *) called, but no dviFile class allocated." << endl;
+    kdError(4300) << "dviRenderer::drawPage(documentPage *) called, but no dviFile class allocated." << endl;
     page->clear();
     return;
   }
   if (page->getPageNumber() > dviFile->total_pages) {
-    kdError(4300) << "dviWindow::drawPage(documentPage *) called for a documentPage with page number " << page->getPageNumber() 
+    kdError(4300) << "dviRenderer::drawPage(documentPage *) called for a documentPage with page number " << page->getPageNumber() 
 		  << " but the current dviFile has only " << dviFile->total_pages << " pages." << endl;
     return;
   }
   if ( dviFile->dvi_Data() == 0 ) {
-    kdError(4300) << "dviWindow::drawPage(documentPage *) called, but no dviFile is loaded yet." << endl;
+    kdError(4300) << "dviRenderer::drawPage(documentPage *) called, but no dviFile is loaded yet." << endl;
     page->clear();
     return;
   }
-
-  currentlyDrawnPage     = page;;
-  shrinkfactor           = MFResolutions[font_pool.getMetafontMode()]/(xres*_zoom);
+ 
+  if (resolution != resolutionInDPI)
+    setResolution(resolution);
+  
+  currentlyDrawnPage     = page;
+  shrinkfactor           = 1200/resolutionInDPI;
   current_page           = page->getPageNumber()-1;
-
-  if ( currentlyDrawnPixmap.isNull() ) {
+  
+  
+  // Reset colors
+  colorStack.clear();
+  globalColor = Qt::black;
+  
+  foreGroundPaint.begin( page->getPaintDevice() );
+  QApplication::setOverrideCursor( waitCursor );
+  errorMsg = QString::null;
+  draw_page();
+  foreGroundPaint.drawRect( foreGroundPaint.viewport() );
+  foreGroundPaint.end();
+  QApplication::restoreOverrideCursor();
+  page->isEmpty = false;
+  if (errorMsg.isEmpty() != true) {
+    KMessageBox::detailedError(parentWidget,
+			       i18n("<qt><strong>File corruption!</strong> KDVI had trouble interpreting your DVI file. Most "
+				    "likely this means that the DVI file is broken.</qt>"),
+			       errorMsg, i18n("DVI File Error"));
+    errorMsg = QString::null;
     currentlyDrawnPage = 0;
     return;
   }
-
-
-  if ( !currentlyDrawnPixmap.paintingActive() ) {
-    // Reset colors
-    colorStack.clear();
-    globalColor = Qt::black;
-
-    // Check if all the fonts are loaded. If that is not the case, we
-    // return and do not draw anything. The font_pool will later emit
-    // the signal "fonts_are_loaded" and thus trigger a redraw of the
-    // page.
-    if (font_pool.check_if_fonts_filenames_are_looked_up() == true) {
-      foreGroundPaint.begin( &(currentlyDrawnPixmap) );
-      QApplication::setOverrideCursor( waitCursor );
-      errorMsg = QString::null;
-      draw_page();
-      foreGroundPaint.drawRect(0, 0, currentlyDrawnPixmap.width(), currentlyDrawnPixmap.height());
-      foreGroundPaint.end();
-      QApplication::restoreOverrideCursor();
-      page->isEmpty = false;
-      if (errorMsg.isEmpty() != true) {
-	KMessageBox::detailedError(parentWidget,
-				   i18n("<qt><strong>File corruption!</strong> KDVI had trouble interpreting your DVI file. Most "
-					"likely this means that the DVI file is broken.</qt>"),
-				   errorMsg, i18n("DVI File Error"));
-	errorMsg = QString::null;
-	currentlyDrawnPage = 0;
-	return;
-      }
-    } else {
-      foreGroundPaint.begin( &(currentlyDrawnPixmap) );
-      errorMsg = QString::null;
-      foreGroundPaint.drawRect(0, 0, currentlyDrawnPixmap.width(), currentlyDrawnPixmap.height());
-      foreGroundPaint.end();
-    }
-    
-    // Tell the user (once) if the DVI file contains source specials
-    // ... wo don't want our great feature to go unnoticed. In
-    // principle, we should use a KMessagebox here, but we want to add
-    // a button "Explain in more detail..." which opens the
-    // Helpcenter. Thus, we practically re-implement the KMessagebox
-    // here. Most of the code is stolen from there.
-    if ((dviFile->sourceSpecialMarker == true) && (currentlyDrawnPage->sourceHyperLinkList.size() > 0)) {
-      dviFile->sourceSpecialMarker = false;
-      // Check if the 'Don't show again' feature was used
-      KConfig *config = kapp->config();
-      KConfigGroupSaver saver( config, "Notification Messages" );
-      bool showMsg = config->readBoolEntry( "KDVI-info_on_source_specials", true);
-      
-      if (showMsg) {
-	KDialogBase *dialog= new KDialogBase(i18n("KDVI: Information"), KDialogBase::Yes, KDialogBase::Yes, KDialogBase::Yes,
-					     parentWidget, "information", true, true,KStdGuiItem::ok() );
-	
-	QVBox *topcontents = new QVBox (dialog);
-	topcontents->setSpacing(KDialog::spacingHint()*2);
-	topcontents->setMargin(KDialog::marginHint()*2);
-	
-	QWidget *contents = new QWidget(topcontents);
-	QHBoxLayout * lay = new QHBoxLayout(contents);
-	lay->setSpacing(KDialog::spacingHint()*2);
-	
-	lay->addStretch(1);
-	QLabel *label1 = new QLabel( contents);
-	label1->setPixmap(QMessageBox::standardIcon(QMessageBox::Information));
-	lay->add( label1 );
-	QLabel *label2 = new QLabel( i18n("<qt>This DVI file contains source file information. You may click into the text with the "
-					  "middle mouse button, and an editor will open the TeX-source file immediately.</qt>"),
-				     contents);
-	label2->setMinimumSize(label2->sizeHint());
-	lay->add( label2 );
-	lay->addStretch(1);
-	QSize extraSize = QSize(50,30);
-	QCheckBox *checkbox = new QCheckBox(i18n("Do not show this message again"), topcontents);
-	extraSize = QSize(50,0);
-	dialog->setHelpLinkText(i18n("Explain in more detail..."));
-	dialog->setHelp("inverse-search", "kdvi");
-	dialog->enableLinkedHelp(true);
-	dialog->setMainWidget(topcontents);
-	dialog->enableButtonSeparator(false);
-	dialog->incInitialSize( extraSize );
-	dialog->exec();
-	delete dialog;
-	
-	showMsg = !checkbox->isChecked();
-	if (!showMsg) {
-	  KConfigGroupSaver saver( config, "Notification Messages" );
-	  config->writeEntry( "KDVI-info_on_source_specials", showMsg);
-	}
-	config->sync();
-      }
-    }
+  
+  // Tell the user (once) if the DVI file contains source specials
+  // ... we don't want our great feature to go unnoticed.
+  if ((dviFile->sourceSpecialMarker == true) && (currentlyDrawnPage->sourceHyperLinkList.size() > 0)) {
+    dviFile->sourceSpecialMarker = false;
+    // Show the dialog as soon as event processing is finished, and
+    // the program is idle
+    QTimer::singleShot( 0, this, SLOT(showThatSourceInformationIsPresent()) );
   }
   
-  page->setPixmap(currentlyDrawnPixmap);
   currentlyDrawnPage = 0;
 }
 
 
-void dviWindow::embedPostScript(void)
+void dviRenderer::showThatSourceInformationIsPresent(void)
+{
+  // In principle, we should use a KMessagebox here, but we want to
+  // add a button "Explain in more detail..." which opens the
+  // Helpcenter. Thus, we practically re-implement the KMessagebox
+  // here. Most of the code is stolen from there.
+  
+  // Check if the 'Don't show again' feature was used
+  KConfig *config = kapp->config();
+  KConfigGroupSaver saver( config, "Notification Messages" );
+  bool showMsg = config->readBoolEntry( "KDVI-info_on_source_specials", true);
+  
+  if (showMsg) {
+    KDialogBase *dialog= new KDialogBase(i18n("KDVI: Information"), KDialogBase::Yes, KDialogBase::Yes, KDialogBase::Yes,
+					 parentWidget, "information", true, true,KStdGuiItem::ok() );
+    
+    QVBox *topcontents = new QVBox (dialog);
+    topcontents->setSpacing(KDialog::spacingHint()*2);
+    topcontents->setMargin(KDialog::marginHint()*2);
+    
+    QWidget *contents = new QWidget(topcontents);
+    QHBoxLayout * lay = new QHBoxLayout(contents);
+    lay->setSpacing(KDialog::spacingHint()*2);
+    
+    lay->addStretch(1);
+    QLabel *label1 = new QLabel( contents);
+    label1->setPixmap(QMessageBox::standardIcon(QMessageBox::Information));
+    lay->add( label1 );
+    QLabel *label2 = new QLabel( i18n("<qt>This DVI file contains source file information. You may click into the text with the "
+				      "middle mouse button, and an editor will open the TeX-source file immediately.</qt>"),
+				 contents);
+    label2->setMinimumSize(label2->sizeHint());
+    lay->add( label2 );
+    lay->addStretch(1);
+    QSize extraSize = QSize(50,30);
+    QCheckBox *checkbox = new QCheckBox(i18n("Do not show this message again"), topcontents);
+    extraSize = QSize(50,0);
+    dialog->setHelpLinkText(i18n("Explain in more detail..."));
+    dialog->setHelp("inverse-search", "kdvi");
+    dialog->enableLinkedHelp(true);
+    dialog->setMainWidget(topcontents);
+    dialog->enableButtonSeparator(false);
+    dialog->incInitialSize( extraSize );
+    dialog->exec();
+    delete dialog;
+    
+    showMsg = !checkbox->isChecked();
+    if (!showMsg) {
+      KConfigGroupSaver saver( config, "Notification Messages" );
+      config->writeEntry( "KDVI-info_on_source_specials", showMsg);
+    }
+    config->sync();
+  }
+}
+
+
+void dviRenderer::embedPostScript(void)
 {
 #ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "dviWindow::embedPostScript()" << endl;
+  kdDebug(4300) << "dviRenderer::embedPostScript()" << endl;
 #endif
 
   if (!dviFile)
@@ -337,7 +296,7 @@ void dviWindow::embedPostScript(void)
     memset((char *) &currinf.data, 0, sizeof(currinf.data));
     currinf.fonttable = &(dviFile->tn_table);
     currinf._virtual  = NULL;
-    prescan(&dviWindow::prescan_embedPS);
+    prescan(&dviRenderer::prescan_embedPS);
   }
 
   delete embedPS_progress;
@@ -370,15 +329,13 @@ void dviWindow::embedPostScript(void)
     memset((char *) &currinf.data, 0, sizeof(currinf.data));
     currinf.fonttable = &(dviFile->tn_table);
     currinf._virtual  = NULL;
-    prescan(&dviWindow::prescan_parseSpecials);
+    prescan(&dviRenderer::prescan_parseSpecials);
 
     if (!PostScriptOutPutString->isEmpty())
       PS_interface->setPostScript(current_page, *PostScriptOutPutString);
     delete PostScriptOutPutString;
   }
   PostScriptOutPutString = NULL;
-  emit(prescanDone());
-  dviFile->prescan_is_performed = true;
 
 #ifdef PERFORMANCE_MEASUREMENT
   kdDebug(4300) << "Time required for prescan phase: " << preScanTimer.restart() << "ms" << endl;
@@ -387,8 +344,7 @@ void dviWindow::embedPostScript(void)
 }
 
 
-
-bool dviWindow::correctDVI(const QString &filename)
+bool dviRenderer::isValidFile(const QString filename)
 {
   QFile f(filename);
   if (!f.open(IO_ReadOnly))
@@ -412,34 +368,12 @@ bool dviWindow::correctDVI(const QString &filename)
 }
 
 
-void dviWindow::changePageSize()
+bool dviRenderer::setFile(const QString &fname)
 {
 #ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "dviWindow::changePageSize()" << endl;
+  kdDebug(4300) << "dviRenderer::setFile( fname='" << fname << "', ref='" << ref << "', sourceMarker=" << sourceMarker << " )" << endl;
 #endif
 
-  if ( currentlyDrawnPixmap.paintingActive() )
-    return;
-
-  unsigned int page_width_in_pixel = (unsigned int)(_zoom*paper_width_in_cm/2.54 * xres + 0.5);
-  unsigned int page_height_in_pixel = (unsigned int)(_zoom*paper_height_in_cm/2.54 * xres + 0.5);
-
-  currentlyDrawnPixmap.resize( page_width_in_pixel, page_height_in_pixel );
-  currentlyDrawnPixmap.fill( white );
-
-  PS_interface->setSize( xres*_zoom, page_width_in_pixel, page_height_in_pixel );
-  emit(needsRepainting());
-}
-
-
-bool dviWindow::setFile(const QString &fname, const QString &ref, bool sourceMarker)
-{
-#ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "dviWindow::setFile( fname='" << fname << "', ref='" << ref << "', sourceMarker=" << sourceMarker << " )" << endl;
-#endif
-
-  reference              = QString::null;
-
   QFileInfo fi(fname);
   QString   filename = fi.absFilePath();
 
@@ -451,10 +385,6 @@ bool dviWindow::setFile(const QString &fname, const QString &ref, bool sourceMar
     delete dviFile;
     dviFile = 0;
     
-    currentlyDrawnPixmap.resize(0,0);
-    if (currentlyDrawnPage != 0)
-      currentlyDrawnPage->setPixmap(currentlyDrawnPixmap);
-    emit(prescanDone()); // ####
     return true;
   }
 
@@ -483,7 +413,14 @@ bool dviWindow::setFile(const QString &fname, const QString &ref, bool sourceMar
   }
 
   QApplication::setOverrideCursor( waitCursor );
-  dvifile *dviFile_new = new dvifile(filename, &font_pool, sourceMarker);
+  dvifile *dviFile_new = new dvifile(filename, &font_pool);
+
+  if ((dviFile == 0) || (dviFile->filename != filename))
+    dviFile_new->sourceSpecialMarker = true;
+  else
+    dviFile_new->sourceSpecialMarker = false;
+
+
   if ((dviFile_new->dvi_Data() == NULL)||(dviFile_new->errorMsg.isEmpty() != true)) {
     QApplication::restoreOverrideCursor();
     if (dviFile_new->errorMsg.isEmpty() != true)
@@ -497,6 +434,7 @@ bool dviWindow::setFile(const QString &fname, const QString &ref, bool sourceMar
 
   delete dviFile;
   dviFile = dviFile_new;
+  numPages = dviFile->total_pages;
   info->setDVIData(dviFile);
 
   font_pool.setExtraSearchPath( fi.dirPath(true) );
@@ -535,164 +473,108 @@ bool dviWindow::setFile(const QString &fname, const QString &ref, bool sourceMar
   if (dviFile->page_offset.isEmpty() == true)
     return false;
 
-  // If we are re-loading a document, e.g. because the user TeXed his
-  // document anew, then all fonts required for this document are
-  // probably already there, and we should pre-scan the document now
-  // (to extract embedded, PostScript, Hyperlinks, ets). Otherwise,
-  // the pre-scan will be carried out in the method 'all_fonts_loaded'
-  // after fonts have been loaded, and the fontPool emits the signal
-  // fonts_have_been_loaded().
-  if (font_pool.check_if_fonts_filenames_are_looked_up() == true) {
-    if (dviFile->prescan_is_performed == false) {
-      // Prescan phase starts here
+  // Locate fonts.
+  font_pool.locateFonts();
+  
+  // Update the list of fonts in the info window
+  if (info != 0)
+    info->setFontInfo(&font_pool);
+
+
+  // We should pre-scan the document now (to extract embedded,
+  // PostScript, Hyperlinks, ets).
+  
+  // PRESCAN STARTS HERE
 #ifdef PERFORMANCE_MEASUREMENT
-      kdDebug(4300) << "Time elapsed till prescan phase starts " << performanceTimer.elapsed() << "ms" << endl;
-      QTime preScanTimer;
-      preScanTimer.start();
+  kdDebug(4300) << "Time elapsed till prescan phase starts " << performanceTimer.elapsed() << "ms" << endl;
+  QTime preScanTimer;
+  preScanTimer.start();
 #endif
-      dviFile->numberOfExternalPSFiles = 0;
-      Q_UINT16 currPageSav = current_page;
-
-      for(current_page=0; current_page < dviFile->total_pages; current_page++) {
-	PostScriptOutPutString = new QString();
-
-	if (current_page < dviFile->total_pages) {
-	  command_pointer = dviFile->dvi_Data() + dviFile->page_offset[current_page];
-	  end_pointer     = dviFile->dvi_Data() + dviFile->page_offset[current_page+1];
-	} else
-	  command_pointer = end_pointer = 0;
-
-	memset((char *) &currinf.data, 0, sizeof(currinf.data));
-	currinf.fonttable = &(dviFile->tn_table);
-	currinf._virtual  = NULL;
-	prescan(&dviWindow::prescan_parseSpecials);
-
-	if (!PostScriptOutPutString->isEmpty())
-	  PS_interface->setPostScript(current_page, *PostScriptOutPutString);
-	delete PostScriptOutPutString;
-      }
-      PostScriptOutPutString = NULL;
-      emit(prescanDone());
-      dviFile->prescan_is_performed = true;
-
-#ifdef PERFORMANCE_MEASUREMENT
-      kdDebug(4300) << "Time required for prescan phase: " << preScanTimer.restart() << "ms" << endl;
-#endif
-      current_page = currPageSav;
-    }
-    emit(needsRepainting());
-    if (dviFile->suggestedPageSize != 0)
-      emit( documentSpecifiedPageSize(*(dviFile->suggestedPageSize)) );
+  dviFile->numberOfExternalPSFiles = 0;
+  Q_UINT16 currPageSav = current_page;
+  
+  for(current_page=0; current_page < dviFile->total_pages; current_page++) {
+    PostScriptOutPutString = new QString();
+    
+    if (current_page < dviFile->total_pages) {
+      command_pointer = dviFile->dvi_Data() + dviFile->page_offset[current_page];
+      end_pointer     = dviFile->dvi_Data() + dviFile->page_offset[current_page+1];
+    } else
+      command_pointer = end_pointer = 0;
+    
+    memset((char *) &currinf.data, 0, sizeof(currinf.data));
+    currinf.fonttable = &(dviFile->tn_table);
+    currinf._virtual  = NULL;
+    prescan(&dviRenderer::prescan_parseSpecials);
+    
+    if (!PostScriptOutPutString->isEmpty())
+      PS_interface->setPostScript(current_page, *PostScriptOutPutString);
+    delete PostScriptOutPutString;
   }
+  PostScriptOutPutString = NULL;
+  
+#ifdef PERFORMANCE_MEASUREMENT
+  kdDebug(4300) << "Time required for prescan phase: " << preScanTimer.restart() << "ms" << endl;
+#endif
+  current_page = currPageSav;
+  // PRESCAN ENDS HERE
+  
+ 
+  pageSizes.resize(0);
+  if (dviFile->suggestedPageSize != 0) {
+    // Fill the vector pageSizes with total_pages identical entries
+    pageSizes.resize(dviFile->total_pages, *(dviFile->suggestedPageSize));
+  }
+  emit(needsRepainting());
   
   QApplication::restoreOverrideCursor();
-  reference              = ref;
   return true;
 }
 
 
-void dviWindow::all_fonts_loaded(fontPool *)
+anchor dviRenderer::parseReference(const QString &reference)
 {
 #ifdef DEBUG_DVIWIN
-  kdDebug(4300) << "dviWindow::all_fonts_loaded(...) called" << endl;
+  kdDebug(4300) << "dviRenderer::parseReference( " << reference << " ) called" << endl;
 #endif
   
-  if (!dviFile)
-    return;
-  
-  if (dviFile->prescan_is_performed == false) {
-    // Prescan phase starts here
-#ifdef PERFORMANCE_MEASUREMENT
-    kdDebug(4300) << "Time elapsed till prescan phase starts " << performanceTimer.elapsed() << "ms" << endl;
-    QTime preScanTimer;
-    preScanTimer.start();
-#endif
-    dviFile->numberOfExternalPSFiles = 0;
-    Q_UINT16 currPageSav = current_page;
-
-    for(current_page=0; current_page < dviFile->total_pages; current_page++) {
-      PostScriptOutPutString = new QString();
-
-      if (current_page < dviFile->total_pages) {
-	command_pointer = dviFile->dvi_Data() + dviFile->page_offset[current_page];
-	end_pointer     = dviFile->dvi_Data() + dviFile->page_offset[current_page+1];
-      } else
-	command_pointer = end_pointer = 0;
-
-      memset((char *) &currinf.data, 0, sizeof(currinf.data));
-      currinf.fonttable = &(dviFile->tn_table);
-      currinf._virtual  = NULL;
-      prescan(&dviWindow::prescan_parseSpecials);
-
-      if (!PostScriptOutPutString->isEmpty())
-	PS_interface->setPostScript(current_page, *PostScriptOutPutString);
-      delete PostScriptOutPutString;
-    }
-    PostScriptOutPutString = NULL;
-    emit(prescanDone());
-    dviFile->prescan_is_performed = true;
-
-#ifdef PERFORMANCE_MEASUREMENT
-    kdDebug(4300) << "Time required for prescan phase: " << preScanTimer.restart() << "ms" << endl;
-#endif
-    current_page = currPageSav;
-  }
-
-  // If the document specifies a paper size, we emit
-  // 'documentSpecifiedPageSize' here. Note that emitting
-  // 'documentSpecifiedPageSize' may or may not lead to a call of
-  // 'drawPage'; that depends on the question if the widget size
-  // really changes or not. To be on the safe side, we emit
-  // emit(needsRepainting()) independently. For documents that have a
-  // specified paper format which is NOT the default format, that
-  // means that the document will be drawn twice.
-  if (dviFile->suggestedPageSize != 0)
-    emit( documentSpecifiedPageSize(*(dviFile->suggestedPageSize)) );
-  //@@@@  emit(needsRepainting());
-
-
+  if (dviFile == 0)
+    return anchor();
+    
   // case 1: The reference is a number, which we'll interpret as a
   // page number.
   bool ok;
   int page = reference.toInt ( &ok );
   if (ok == true) {
-    page--;
     if (page < 0)
       page = 0;
-    if (page >= dviFile->total_pages)
-      page = dviFile->total_pages-1;
-    emit(request_goto_page(page, -1000));
-    reference = QString::null;
-    return;
+    if (page > dviFile->total_pages)
+      page = dviFile->total_pages;
+    
+    return anchor(page, 0.0);
   }
-
+  
   // case 2: The reference is of form "src:1111Filename", where "1111"
   // points to line number 1111 in the file "Filename". KDVI then
   // looks for source specials of the form "src:xxxxFilename", and
   // tries to find the special with the biggest xxxx
   if (reference.find("src:",0,false) == 0) {
-    QString ref = reference.mid(4);
+  
     // Extract the file name and the numeral part from the reference string
-    Q_UINT32 i;
-    for(i=0;i<ref.length();i++)
-      if (!ref.at(i).isNumber())
-	break;
-    Q_UINT32 refLineNumber = ref.left(i).toUInt();
-
-    QFileInfo fi1(dviFile->filename);
-    QString  refFileName   = QFileInfo(fi1.dir(), ref.mid(i).stripWhiteSpace()).absFilePath();
-
+    DVI_SourceFileSplitter splitter(reference, dviFile->filename);
+    Q_UINT32 refLineNumber = splitter.line();
+    QString  refFileName   = splitter.filePath();
+    
     if (sourceHyperLinkAnchors.isEmpty()) {
       KMessageBox::sorry(parentWidget, i18n("<qt>You have asked KDVI to locate the place in the DVI file which corresponds to "
 				    "line %1 in the TeX-file <strong>%2</strong>. It seems, however, that the DVI file "
 				    "does not contain the necessary source file information. "
 				    "We refer to the manual of KDVI for a detailed explanation on how to include this "
-				    "information. Press the F1 key to open the manual.</qt>").arg(ref.left(i)).arg(refFileName),
+				    "information. Press the F1 key to open the manual.</qt>").arg(refLineNumber).arg(refFileName),
 			 i18n("Could Not Find Reference"));
-      return;
+      return anchor();
     }
 
-
     // Go through the list of source file anchors, and find the anchor
     // whose line number is the biggest among those that are smaller
     // than the refLineNumber. That way, the position in the DVI file
@@ -707,152 +589,93 @@ void dviWindow::all_fonts_loaded(fontPool *)
     // the LaTeX file. In that case, we jump to the beginning of the
     // document.
     bool anchorForRefFileFound = false; // Flag that is set if source file anchors for the refFileName could be found at all
-
+    
     QValueVector<DVI_SourceFileAnchor>::iterator bestMatch = sourceHyperLinkAnchors.end();
     QValueVector<DVI_SourceFileAnchor>::iterator it;
     for( it = sourceHyperLinkAnchors.begin(); it != sourceHyperLinkAnchors.end(); ++it )
-      if (refFileName.stripWhiteSpace() == it->fileName.stripWhiteSpace()) {
+      if (refFileName.stripWhiteSpace() == it->fileName.stripWhiteSpace()
+      || refFileName.stripWhiteSpace() == it->fileName.stripWhiteSpace() + ".tex"
+      ) {
 	anchorForRefFileFound = true;
-
+	
 	if ( (it->line <= refLineNumber) &&
 	     ( (bestMatch == sourceHyperLinkAnchors.end()) || (it->line > bestMatch->line) ) )
 	  bestMatch = it;
       }
-
-    reference = QString::null;
-
+    
     if (bestMatch != sourceHyperLinkAnchors.end())
-      emit(request_goto_page(bestMatch->page, (Q_INT32)(bestMatch->vertical_coordinate/shrinkfactor+0.5)));
+      return anchor(bestMatch->page, bestMatch->distance_from_top_in_inch);
     else
       if (anchorForRefFileFound == false)
 	KMessageBox::sorry(parentWidget, i18n("<qt>KDVI was not able to locate the place in the DVI file which corresponds to "
-				      "line %1 in the TeX-file <strong>%2</strong>.</qt>").arg(ref.left(i)).arg(refFileName),
+					      "line %1 in the TeX-file <strong>%2</strong>.</qt>").arg(refLineNumber).arg(refFileName),
 			   i18n( "Could Not Find Reference" ));
       else
-	emit(request_goto_page(0, 0));
-
-    return;
+	return anchor();
+    return anchor();
   }
-  reference = QString::null;
+  return anchor();
 }
 
 
-int dviWindow::totalPages()
+void dviRenderer::setResolution(double resolution_in_DPI)
 {
-  if (dviFile != NULL)
-    return dviFile->total_pages;
-  else
-    return 0;
+  // Ignore minute changes. The difference to the current value would
+  // hardly be visible anyway. That saves a lot of re-painting,
+  // e.g. when the user resizes the window, and a flickery mouse
+  // changes the window size by 1 pixel all the time.
+  if (fabs(resolutionInDPI-resolution_in_DPI) < 1)
+    return;
+
+  resolutionInDPI = resolution_in_DPI;
+  
+  // Pass the information on to the font pool. 
+  font_pool.setDisplayResolution( resolutionInDPI );
+  shrinkfactor = 1200/resolutionInDPI;
+  return;
 }
 
 
-double dviWindow::setZoom(double zoom)
-{
-  // Ignore minute changes by less than 1%. The difference to the
-  // current zoom value would hardly be visible anyway. That saves a
-  // lot of re-painting, e.g. when the user resizes the window, and a
-  // flickery mouse changes the window size by 1 pixel all the time.
-  if (fabs(zoom-_zoom) < 0.01)
-    return zoom;
-
-  // In principle, this method should never be called with illegal
-  // values. In principle.
-  if (zoom < ZoomLimits::MinZoom/1000.0)
-    zoom = ZoomLimits::MinZoom/1000.0;
-  if (zoom > ZoomLimits::MaxZoom/1000.0)
-    zoom = ZoomLimits::MaxZoom/1000.0;
-
-  shrinkfactor = MFResolutions[font_pool.getMetafontMode()]/(xres*zoom);
-  _zoom        = zoom;
-
-  font_pool.setDisplayResolution( xres*zoom );
-  changePageSize();
-  return _zoom;
-}
-
-
-void dviWindow::clearStatusBar(void)
+void dviRenderer::clearStatusBar(void)
 {
   emit setStatusBarText( QString::null );
 }
 
 
-void dviWindow::handleLocalLink(const QString &linkText)
-{	  
-#ifdef DEBUG_SPECIAL
-  kdDebug(4300) << "hit: local link to " << linkText << endl;
-#endif
-  QString locallink;
-  if (linkText[0] == '#' )
-    locallink = linkText.mid(1); // Drop the '#' at the beginning
-  else
-    locallink = linkText;
-  QMap<QString,DVI_Anchor>::Iterator it = anchorList.find(locallink);
-  if (it != anchorList.end()) {
-#ifdef DEBUG_SPECIAL
-    kdDebug(4300) << "hit: local link to  y=" << AnchorList_Vert[j] << endl;
-    kdDebug(4300) << "hit: local link to sf=" << shrinkfactor << endl;
-#endif
-    emit(request_goto_page(it.data().page, (int)(it.data().vertical_coordinate/shrinkfactor)));
-  } else {
-    if (linkText[0] != '#' ) {
-#ifdef DEBUG_SPECIAL
-      kdDebug(4300) << "hit: external link to " << currentlyDrawnPage->hyperLinkList[i].linkText << endl;
-#endif
-      // We could in principle use KIO::Netaccess::run() here, but
-      // it is perhaps not a very good idea to allow a DVI-file to
-      // specify arbitrary commands, such as "rm -rvf /". Using
-      // the kfmclient seems to be MUCH safer.
-      QUrl DVI_Url(dviFile->filename);
-      QUrl Link_Url(DVI_Url, linkText, TRUE );
-      
-      QStringList args;
-      args << "openURL";
-      args << Link_Url.toString();
-      kapp->kdeinitExec("kfmclient", args);
-    }
-  }
-}
-
-
-void dviWindow::handleSRCLink(const QString &linkText, QMouseEvent *e, documentWidget *win)
+void dviRenderer::handleSRCLink(const QString &linkText, QMouseEvent *e, documentWidget *win)
 {
 #ifdef DEBUG_SPECIAL
   kdDebug(4300) << "Source hyperlink to " << currentlyDrawnPage->sourceHyperLinkList[i].linkText << endl;
 #endif
   
-  QString cp = linkText;
-  int max = cp.length();
-  int i;
-  for(i=0; i<max; i++)
-    if (cp[i].isDigit() == false)
-      break;
-  
-  // The macro-package srcltx gives a special like "src:99 test.tex"
-  // while MikTeX gives "src:99test.tex". KDVI tries
-  // to understand both.
-  QFileInfo fi1(dviFile->filename);
-  QFileInfo fi2(fi1.dir(),cp.mid(i+1));
+//   QString cp = linkText;
+//   int max = cp.length();
+//   int i;
+//   for(i=0; i<max; i++)
+//     if (cp[i].isDigit() == false)
+//       break;
+//   
+//   // The macro-package srcltx gives a special like "src:99 test.tex"
+//   // while MikTeX gives "src:99test.tex". KDVI tries
+//   // to understand both.
+//   QFileInfo fi1(dviFile->filename);
+//   QFileInfo fi2(fi1.dir(),cp.mid(i+1));
+// 
+//   //Sometimes the filename is passed without the .tex extension,
+//   //better add it when necessary.
+//   if ( !fi2.exists() )
+//     fi2.setFile(fi2.absFilePath() + ".tex");
 
-  //Sometimes the filename is passed without the .tex extension,
-  //better add it when necessary.
-  if ( !fi2.exists() )
-    fi2.setFile(fi2.absFilePath() + ".tex");
-
-  QString TeXfile;
-  if ( fi2.exists() )
-    TeXfile = fi2.absFilePath();
-  else {
-    QFileInfo fi3(fi1.dir(),cp.mid(i));
-    TeXfile = fi3.absFilePath();
-    if ( !fi3.exists() ) {
+  DVI_SourceFileSplitter splitter(linkText, dviFile->filename);
+  QString TeXfile = splitter.filePath();
+  if ( ! splitter.fileExists() )
+  {
       KMessageBox::sorry(parentWidget, QString("<qt>") +
 			 i18n("The DVI-file refers to the TeX-file "
 			      "<strong>%1</strong> which could not be found.").arg(KShellProcess::quote(TeXfile)) +
 			 QString("</qt>"),
 			 i18n( "Could Not Find File" ));
       return;
-    }
   }
   
   QString command = editorCommand;
@@ -870,7 +693,7 @@ void dviWindow::handleSRCLink(const QString &linkText, QMouseEvent *e, documentW
     else
       return;
   }
-  command = command.replace( QRegExp("%l"), cp.left(i) ).replace( QRegExp("%f"), KShellProcess::quote(TeXfile) );
+  command = command.replace( "%l", QString::number(splitter.line()) ).replace( "%f", KShellProcess::quote(TeXfile) );
   
 #ifdef DEBUG_SPECIAL
   kdDebug(4300) << "Calling program: " << command << endl;
