@@ -1,10 +1,10 @@
 //
-// Class: dviWindow
+// Class: dviRenderer
 //
-// Widget for displaying TeX DVI files.
+// Class for rendering TeX DVI files.
 // Part of KDVI- A previewer for TeX DVI files.
 //
-// (C) 2001-2003 Stefan Kebekus. Distributed under the GPL.
+// (C) 2001-2004 Stefan Kebekus. Distributed under the GPL.
 
 
 #ifndef _dviwin_h_
@@ -20,16 +20,19 @@
 #include <qwidget.h> 
 #include <kviewpart.h>
 
+#include "anchor.h"
 #include "bigEndianByteReader.h"
 #include "documentPage.h"
+#include "documentRenderer.h"
 #include "dviFile.h"
 #include "fontpool.h"
 #include "infodialog.h"
+#include "pageSize.h"
 #include "psgs.h"
 
 
 class documentWidget;
-class dviWindow;
+class dviRenderer;
 class fontProgressDialog;
 class infoDialog;
 class KAction;
@@ -42,24 +45,16 @@ class TeXFontDefinition;
 
 extern const int MFResolutions[];
 
-class DVI_Anchor {
- public:
-  DVI_Anchor() {}
-  DVI_Anchor(Q_UINT32 pg, double vc): page(pg), vertical_coordinate(vc) {}
-
-  Q_UINT32   page;
-  double     vertical_coordinate;
-};
-
 class DVI_SourceFileAnchor {
  public:
   DVI_SourceFileAnchor() {}
-  DVI_SourceFileAnchor(QString &name, Q_UINT32 ln, Q_UINT32 pg, double vc): fileName(name), line(ln), page(pg), vertical_coordinate(vc) {}
+  DVI_SourceFileAnchor(QString &name, Q_UINT32 ln, Q_UINT32 pg, double _distance_from_top_in_inch): fileName(name), line(ln), page(pg), 
+    distance_from_top_in_inch(_distance_from_top_in_inch) {}
 
   QString    fileName;
   Q_UINT32   line;
   Q_UINT32   page;
-  double     vertical_coordinate;
+  double     distance_from_top_in_inch;
 };
 
 /** Compound of registers, as defined in section 2.6.2 of the DVI
@@ -79,8 +74,8 @@ struct framedata {
 
 /* this information is saved when using virtual fonts */
 
-typedef	void	(dviWindow::*set_char_proc)(unsigned int, unsigned int);
-typedef void    (dviWindow::*parseSpecials)(char *, Q_UINT8 *);
+typedef	void	(dviRenderer::*set_char_proc)(unsigned int, unsigned int);
+typedef void    (dviRenderer::*parseSpecials)(char *, Q_UINT8 *);
 
 struct drawinf {
   struct framedata            data;
@@ -93,39 +88,34 @@ struct drawinf {
 
 
 
-class dviWindow : public QObject, bigEndianByteReader
+class dviRenderer : public documentRenderer, bigEndianByteReader
 {
   Q_OBJECT
 
 public:
-  dviWindow(QWidget *parent);
-  ~dviWindow();
+  dviRenderer(QWidget *parent);
+  ~dviRenderer();
 
-  documentPage  *currentlyDrawnPage;
-
-  QSize         sizeOfPage(Q_UINT16 page) {return currentlyDrawnPixmap.size();};
+  virtual bool	setFile(const QString &fname);
 
   class dvifile *dviFile;
 
-  void          setPrefs(bool flag_showPS, bool flag_showHyperLinks, const QString &editorCommand, 
-			 unsigned int MetaFontMode, bool makePK, bool useType1Fonts, bool useFontHints );
+  void          setPrefs(bool flag_showPS, const QString &editorCommand, bool useFontHints );
 
-  bool          supportsTextSearch(void) {return true;};
+  virtual bool  supportsTextSearch(void) {return true;};
 
-  void          exportPS(QString fname = QString::null, QString options = QString::null, KPrinter *printer = 0);
-  void          exportPDF();
-
-  void          changePageSize(void);
-  int		totalPages(void);
   bool		showPS(void) { return _postscript; };
   int		curr_page(void) { return current_page+1; };
-  bool		showHyperLinks(void) { return _showHyperLinks; };
-  void		setPaper(double w, double h);
-  static bool   correctDVI(const QString &filename);
-  
-  // for the preview
-  QPixmap      *pix() { if (currentlyDrawnPage) return currentlyDrawnPage->getPixmap(); return 0; };
+  virtual bool  isValidFile(const QString fileName);
 
+
+  /** This method will try to parse the reference part of the DVI
+      file's URL, (either a number, which is supposed to be a page
+      number, or src:<line><filename>) and see if a corresponding
+      section of the DVI file can be found. If so, it returns an
+      anchor to that section. If not, it returns an invalid anchor. */
+  virtual anchor        parseReference(const QString &reference);
+  
   // These should not be public... only for the moment
   void          read_postamble(void);
   void          draw_part(double current_dimconv, bool is_vfmacro);
@@ -142,73 +132,46 @@ public:
   void          html_anchor_end(void);
   void          draw_page(void);
 
-  double        xres;         // horizontal resolution of the display device in dots per inch.
-  double        paper_width_in_cm;  // paper width in centimeters
-  double        paper_height_in_cm; // paper height in centimeters
-
-
- /** Reference part of the URL which describes the filename. */
- QString        reference;
-
-
 public slots:
+  void          exportPS(QString fname = QString::null, QString options = QString::null, KPrinter *printer = 0);
+  void          exportPDF();
+
   void          showInfo(void);
-  void          handleLocalLink(const QString &linkText);
   void          handleSRCLink(const QString &linkText, QMouseEvent *e, documentWidget *widget);
 
   void          embedPostScript(void);
   void          abortExternalProgramm(void);
-  bool		setFile(const QString &fname, const QString &ref = QString::null, bool sourceMarker=true);
 
   /** simply emits "setStatusBarText( QString::null )". This is used
-      in dviWindow::mouseMoveEvent(), see the explanation there. */
+      in dviRenderer::mouseMoveEvent(), see the explanation there. */
   void          clearStatusBar(void);
 
-  double	setZoom(double zoom);
-  double        zoom() { return _zoom; };
-  void		drawPage(documentPage *page);
+
+
+  void		drawPage(double res, documentPage *page);
  
   /** Slots used in conjunction with external programs */
   void          dvips_output_receiver(KProcess *, char *buffer, int buflen);
   void          dvips_terminated(KProcess *);
   void          editorCommand_terminated(KProcess *);
 
-
-  /** This slot is usually called by the fontpool if all fonts are
-      loaded. The method will try to parse the reference part of the
-      DVI file's URL, e.g. src:<line><filename> and see if a
-      corresponding section of the DVI file can be found. If so, it
-      will emit a "requestGotoPage", otherwise it will just call
-      drawpage */
-  void          all_fonts_loaded(fontPool *);
-
 signals:
-  /** Emitted if the status of this class changed internally so that
-      all associated widgets should be repainted, e.g. if a lengthy
-      network download finished. */
-  void          needsRepainting();
-
-  /** Emitted to indicate that the prescan phase has ended */
-  void          prescanDone();
-
-  /** Emitted to indicate that a hyperlink has been clicked on, and
-      that the widget requests that the controlling program goes to the
-      page and the coordinates specified. */
-  void          request_goto_page(int page, int y);
-
   /** Passed through to the top-level kpart. */
   void setStatusBarText( const QString& );
 
-  /** To be passed through to the kmultipage */
-  void documentSpecifiedPageSize(const pageSize &size);
-
+private slots:
+  /** This method shows a dialog that tells the user that source
+      information is present, and gives the opportunity to open the
+      manual and learn more about forward and inverse search */
+  void          showThatSourceInformationIsPresent(void);
 
 private:
+  void  setResolution(double resolution_in_DPI);
+
   fontPool      font_pool;
   infoDialog    *info;
 
-  QWidget       *parentWidget;
-
+  double        resolutionInDPI;
 
   // @@@ explanation
   void          prescan(parseSpecials specialParser);
@@ -230,7 +193,6 @@ private:
   KProgressDialog *embedPS_progress;
   Q_UINT16         embedPS_numOfProgressedFiles;
 
-
   /** Shrink factor. Units are not quite clear */
   double	shrinkfactor;
   
@@ -245,15 +207,13 @@ private:
   void TPIC_addPath_special(QString cp);
   void TPIC_flushPath_special(void);
   
-  /* This timer is used to delay clearing of the statusbar. Clearing
-     the statusbar is delayed to avoid awful flickering when the mouse
-     moves over a block of text that contains source hyperlinks. The
-     signal timeout() is connected to the method clearStatusBar() of
-     *this. */
+  /** This timer is used to delay clearing of the statusbar. Clearing
+      the statusbar is delayed to avoid awful flickering when the
+      mouse moves over a block of text that contains source
+      hyperlinks. The signal timeout() is connected to the method
+      clearStatusBar() of *this. */
   QTimer        clearStatusBarTimer;
   
-  QPixmap       currentlyDrawnPixmap;
-  
   // List of source-hyperlinks on all pages. This vector is generated
   // when the DVI-file is first loaded, i.e. when draw_part is called
   // with PostScriptOutPutString != NULL
@@ -292,23 +252,14 @@ private:
       drawn. */
   bool    	   _postscript;
   
-  /** TRUE, if Hyperlinks should be shown. */
-  bool     	   _showHyperLinks;
-  
   /** This flag is used when rendering a dvi-page. It is set to "true"
       when any dvi-command other than "set" or "put" series of commands
       is encountered. This is considered to mark the end of a word. */
   bool              line_boundary_encountered;
   bool              word_boundary_encountered;
   
-  /** List of anchors in a document */
-  QMap<QString, DVI_Anchor> anchorList;
-  
   unsigned int	   current_page;
   
-  // Zoom factor. 1.0 means "100%"
-  double            _zoom;
-
   /** Used to run and to show the progress of dvips and friends. */
   fontProgressDialog *progress;
   KShellProcess      *proc;
@@ -323,6 +274,7 @@ private:
   Q_UINT16    number_of_elements_in_path;
   
   struct drawinf	currinf;
+  documentPage* currentlyDrawnPage;
 };
 
 
