@@ -54,6 +54,7 @@
 #include "dviwin.h"
 #include "dvi.h"
 #include "fontpool.h"
+#include "kdvi_multipage.h"
 #include "performanceMeasurement.h"
 #include "TeXFont.h"
 #include "xdvi.h"
@@ -73,7 +74,7 @@ extern QPainter foreGroundPaint;
 
 /** Routine to print characters.  */
 
-void dviWindow::set_char(unsigned int cmd, unsigned int ch)
+void dviRenderer::set_char(unsigned int cmd, unsigned int ch)
 {
 #ifdef DEBUG_RENDER
   kdDebug(4300) << "set_char #" << ch << endl;
@@ -98,19 +99,19 @@ void dviWindow::set_char(unsigned int cmd, unsigned int ch)
   
   // Are we drawing text for a hyperlink? And are hyperlinks
   // enabled?
-  if (HTML_href != NULL && _showHyperLinks != 0) {
+  if (HTML_href != NULL) {
     // Now set up a rectangle which is checked against every mouse
     // event.
     if (line_boundary_encountered == true) {
       // Set up hyperlink
-      DVI_Hyperlink dhl;
+      Hyperlink dhl;
       dhl.baseline = currinf.data.pxl_v;
       dhl.box.setRect(x, y, pix.width(), pix.height());
       dhl.linkText = *HTML_href;
-      currentlyDrawnPage.hyperLinkList.push_back(dhl);
+      currentlyDrawnPage->hyperLinkList.push_back(dhl);
     } else {
-      QRect dshunion = currentlyDrawnPage.hyperLinkList[currentlyDrawnPage.hyperLinkList.size()-1].box.unite(QRect(x, y, pix.width(), pix.height())) ;
-      currentlyDrawnPage.hyperLinkList[currentlyDrawnPage.hyperLinkList.size()-1].box = dshunion;
+      QRect dshunion = currentlyDrawnPage->hyperLinkList[currentlyDrawnPage->hyperLinkList.size()-1].box.unite(QRect(x, y, pix.width(), pix.height())) ;
+      currentlyDrawnPage->hyperLinkList[currentlyDrawnPage->hyperLinkList.size()-1].box = dshunion;
     }
   }
   
@@ -121,74 +122,74 @@ void dviWindow::set_char(unsigned int cmd, unsigned int ch)
     // event.
     if (line_boundary_encountered == true) {
       // Set up source hyperlinks
-      DVI_Hyperlink dhl;
+      Hyperlink dhl;
       dhl.baseline = currinf.data.pxl_v;
       dhl.box.setRect(x, y, pix.width(), pix.height());
       if (source_href != NULL) 
 	dhl.linkText = *source_href;
       else
 	dhl.linkText = "";
-      currentlyDrawnPage.sourceHyperLinkList.push_back(dhl);
+      currentlyDrawnPage->sourceHyperLinkList.push_back(dhl);
     } else {
-      QRect dshunion = currentlyDrawnPage.sourceHyperLinkList[currentlyDrawnPage.sourceHyperLinkList.size()-1].box.unite(QRect(x, y, pix.width(), pix.height())) ;
-      currentlyDrawnPage.sourceHyperLinkList[currentlyDrawnPage.sourceHyperLinkList.size()-1].box = dshunion;
+      QRect dshunion = currentlyDrawnPage->sourceHyperLinkList[currentlyDrawnPage->sourceHyperLinkList.size()-1].box.unite(QRect(x, y, pix.width(), pix.height())) ;
+      currentlyDrawnPage->sourceHyperLinkList[currentlyDrawnPage->sourceHyperLinkList.size()-1].box = dshunion;
     }
   }
   
   // Code for DVI -> text functions (e.g. marking of text, full text
-  // search, etc.). Set up the currentlyDrawnPage.textLinkList.
+  // search, etc.). Set up the currentlyDrawnPage->textLinkList.
   if (line_boundary_encountered == true) {
     // Set up source hyperlinks
-    DVI_Hyperlink link;
+    Hyperlink link;
     link.baseline = currinf.data.pxl_v;
     link.box.setRect(x, y, pix.width(), pix.height());
     link.linkText = "";
     
-    currentlyDrawnPage.textLinkList.push_back(link);
+    currentlyDrawnPage->textLinkList.push_back(link);
   } else {
     // line boundary encountered
-    QRect dshunion = currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].box.unite(QRect(x, y, pix.width(), pix.height())) ;
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].box = dshunion;
+    QRect dshunion = currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].box.unite(QRect(x, y, pix.width(), pix.height())) ;
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].box = dshunion;
   }
   
   switch(ch) {
   case 0x0b:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "ff";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "ff";
     break;
   case 0x0c:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "fi";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "fi";
     break;
   case 0x0d:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "fl";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "fl";
     break;
   case 0x0e:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "ffi";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "ffi";
     break;
   case 0x0f:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "ffl";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "ffl";
     break;
     
   case 0x7b:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "-";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "-";
     break;
   case 0x7c:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "---";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "---";
     break;
   case 0x7d:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "\"";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "\"";
     break;
   case 0x7e:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "~";
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "~";
     break;
   case 0x7f:
-    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "@@"; // @@@ check!
+    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "@@"; // @@@ check!
     break;
     
   default:
     if ((ch >= 0x21) && (ch <= 0x7a))
-      currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += QChar(ch);
+      currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += QChar(ch);
     else
-      currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += "?";
+      currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += "?";
     break;
   }
   
@@ -197,21 +198,21 @@ void dviWindow::set_char(unsigned int cmd, unsigned int ch)
     currinf.data.dvi_h = dvi_h_sav;
   else
     currinf.data.dvi_h += (int)(currinf.fontp->scaled_size_in_DVI_units * dviFile->getCmPerDVIunit() * 
-				(MFResolutions[font_pool->getMetafontMode()] / 2.54)/16.0 * g->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
+				(1200.0 / 2.54)/16.0 * g->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
 
   word_boundary_encountered = false;
   line_boundary_encountered = false;
 }
 
-void dviWindow::set_empty_char(unsigned int, unsigned int)
+void dviRenderer::set_empty_char(unsigned int, unsigned int)
 {
   return;
 }
 
-void dviWindow::set_vf_char(unsigned int cmd, unsigned int ch)
+void dviRenderer::set_vf_char(unsigned int cmd, unsigned int ch)
 {
 #ifdef DEBUG_RENDER
-  kdDebug(4300) << "dviWindow::set_vf_char( cmd=" << cmd << ", ch=" << ch << " )" << endl;
+  kdDebug(4300) << "dviRenderer::set_vf_char( cmd=" << cmd << ", ch=" << ch << " )" << endl;
 #endif
 
   static unsigned char   c;
@@ -236,7 +237,7 @@ void dviWindow::set_vf_char(unsigned int cmd, unsigned int ch)
   Q_UINT8 *end_ptr_sav      = end_pointer;
   command_pointer           = m->pos;
   end_pointer               = m->end;
-  draw_part(currinf.fontp->scaled_size_in_DVI_units*(dviFile->getCmPerDVIunit() * MFResolutions[font_pool->getMetafontMode()] / 2.54)/16.0, true);
+  draw_part(currinf.fontp->scaled_size_in_DVI_units*(dviFile->getCmPerDVIunit() * 1200.0 / 2.54)/16.0, true);
   command_pointer           = command_ptr_sav;
   end_pointer               = end_ptr_sav;
   currinf = oldinfo;
@@ -245,14 +246,14 @@ void dviWindow::set_vf_char(unsigned int cmd, unsigned int ch)
     currinf.data.dvi_h = dvi_h_sav;
   else
     currinf.data.dvi_h += (int)(currinf.fontp->scaled_size_in_DVI_units * dviFile->getCmPerDVIunit() * 
-				(MFResolutions[font_pool->getMetafontMode()] / 2.54)/16.0 * m->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
+				(1200.0 / 2.54)/16.0 * m->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
 }
 
 
-void dviWindow::set_no_char(unsigned int cmd, unsigned int ch)
+void dviRenderer::set_no_char(unsigned int cmd, unsigned int ch)
 {
 #ifdef DEBUG_RENDER
-  kdDebug(4300) << "dviWindow::set_no_char( cmd=" << cmd << ", ch =" << ch << " )"  << endl;
+  kdDebug(4300) << "dviRenderer::set_no_char( cmd=" << cmd << ", ch =" << ch << " )"  << endl;
 #endif
   
   if (currinf._virtual) {
@@ -264,12 +265,12 @@ void dviWindow::set_no_char(unsigned int cmd, unsigned int ch)
     }
   }
 
-  errorMsg = i18n("The DVI code set a character of an unknown font");
+  errorMsg = i18n("The DVI code set a character of an unknown font.");
   return;
 }
 
 
-void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
+void dviRenderer::draw_part(double current_dimconv, bool is_vfmacro)
 {
 #ifdef DEBUG_RENDER
   kdDebug(4300) << "draw_part" << endl;
@@ -279,10 +280,11 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
   Q_UINT8 ch;
 
   currinf.fontp        = NULL;
-  currinf.set_char_p   = &dviWindow::set_no_char;
+  currinf.set_char_p   = &dviRenderer::set_no_char;
 
   for (;;) {
     ch = readUINT8();
+
     if (ch <= (unsigned char) (SETCHAR0 + 127)) {
       (this->*currinf.set_char_p)(ch, ch);
     } else
@@ -356,8 +358,8 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	    line_boundary_encountered = true;
 	  }
 	  command_pointer += 11 * 4;
-	  currinf.data.dvi_h = MFResolutions[font_pool->getMetafontMode()] << 16; // Reminder: DVI-coordinates start at (1",1") from top of page
-	  currinf.data.dvi_v = MFResolutions[font_pool->getMetafontMode()];
+	  currinf.data.dvi_h = 1200 << 16; // Reminder: DVI-coordinates start at (1",1") from top of page
+	  currinf.data.dvi_v = 1200;
 	  currinf.data.pxl_v = int(currinf.data.dvi_v/shrinkfactor);
 	  currinf.data.w = currinf.data.x = currinf.data.y = currinf.data.z = 0;
 	  break;
@@ -410,8 +412,8 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	  if ((is_vfmacro == false) &&
 	      (currinf.fontp != 0) &&
 	      ((RRtmp >= currinf.fontp->scaled_size_in_DVI_units/6) || (RRtmp <= -4*(currinf.fontp->scaled_size_in_DVI_units/6))) && 
-	      (currentlyDrawnPage.textLinkList.size() > 0))
-	    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += ' ';
+	      (currentlyDrawnPage->textLinkList.size() > 0))
+	    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += ' ';
 	  currinf.data.dvi_h += ((long) (RRtmp *  current_dimconv));
 	  break;
 	  
@@ -425,8 +427,8 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	  if ((is_vfmacro == false) && 
 	      (currinf.fontp != 0) &&
 	      ((WWtmp >= currinf.fontp->scaled_size_in_DVI_units/6) || (WWtmp <= -4*(currinf.fontp->scaled_size_in_DVI_units/6))) && 
-	      (currentlyDrawnPage.textLinkList.size() > 0) )
-	    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += ' ';
+	      (currentlyDrawnPage->textLinkList.size() > 0) )
+	    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += ' ';
 	  currinf.data.dvi_h += currinf.data.w;
 	  break;
 	  
@@ -440,8 +442,8 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	  if ((is_vfmacro == false)  && 
 	      (currinf.fontp != 0) &&
 	      ((XXtmp >= currinf.fontp->scaled_size_in_DVI_units/6) || (XXtmp <= -4*(currinf.fontp->scaled_size_in_DVI_units/6))) && 
-	      (currentlyDrawnPage.textLinkList.size() > 0))
-	    currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += ' ';
+	      (currentlyDrawnPage->textLinkList.size() > 0))
+	    currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += ' ';
 	  currinf.data.dvi_h += currinf.data.x;
 	  break;
 	  
@@ -454,11 +456,11 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	    if ((is_vfmacro == false) &&
 		(currinf.fontp != 0) &&
 		(abs(DDtmp) >= 5*(currinf.fontp->scaled_size_in_DVI_units/6)) && 
-		(currentlyDrawnPage.textLinkList.size() > 0)) {
+		(currentlyDrawnPage->textLinkList.size() > 0)) {
 	      word_boundary_encountered = true;
 	      line_boundary_encountered = true;
 	      if (abs(DDtmp) >= 10*(currinf.fontp->scaled_size_in_DVI_units/6)) 
-		currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += '\n';
+		currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += '\n';
 	    }
 	    currinf.data.dvi_v += ((long) (DDtmp *  current_dimconv))/65536;
 	    currinf.data.pxl_v  = int(currinf.data.dvi_v/shrinkfactor);
@@ -475,11 +477,11 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	  if ((is_vfmacro == false) &&
 	      (currinf.fontp != 0) &&
 	      (abs(YYtmp) >= 5*(currinf.fontp->scaled_size_in_DVI_units/6)) && 
-	      (currentlyDrawnPage.textLinkList.size() > 0)) {
+	      (currentlyDrawnPage->textLinkList.size() > 0)) {
 	    word_boundary_encountered = true;
 	    line_boundary_encountered = true;
 	    if (abs(YYtmp) >= 10*(currinf.fontp->scaled_size_in_DVI_units/6)) 
-	      currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += '\n';
+	      currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += '\n';
 	  }
 	  currinf.data.dvi_v += currinf.data.y/65536;
 	  currinf.data.pxl_v = int(currinf.data.dvi_v/shrinkfactor);
@@ -495,11 +497,11 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	  if ((is_vfmacro == false) &&
 	      (currinf.fontp != 0) &&
 	      (abs(ZZtmp) >= 5*(currinf.fontp->scaled_size_in_DVI_units/6)) && 
-	      (currentlyDrawnPage.textLinkList.size() > 0)) {
+	      (currentlyDrawnPage->textLinkList.size() > 0)) {
 	    word_boundary_encountered = true;
 	    line_boundary_encountered = true;
 	    if (abs(ZZtmp) >= 10*(currinf.fontp->scaled_size_in_DVI_units/6)) 
-	      currentlyDrawnPage.textLinkList[currentlyDrawnPage.textLinkList.size()-1].linkText += '\n';
+	      currentlyDrawnPage->textLinkList[currentlyDrawnPage->textLinkList.size()-1].linkText += '\n';
 	  }
 	  currinf.data.dvi_v += currinf.data.z/65536;
 	  currinf.data.pxl_v  = int(currinf.data.dvi_v/shrinkfactor);
@@ -549,7 +551,15 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 	case FNTDEF3:
 	case FNTDEF4:
 	  command_pointer += 12 + ch - FNTDEF1 + 1;
-	  command_pointer += readUINT8() + readUINT8();
+	  
+	  // The variables _A_ and _L_, which are not used any
+	  // further, are there as a temporary workaround for a bug in
+	  // the C++ compiler that RedHat uses for Fedora Core 4.
+	  {
+	    Q_UINT8 _A_ = readUINT8();
+	    Q_UINT8 _L_ = readUINT8();
+	    command_pointer += _A_ + _L_ ;
+	  }
 	  break;
 	  
 	case PRE:
@@ -568,27 +578,20 @@ void dviWindow::draw_part(double current_dimconv, bool is_vfmacro)
 }
 
 
-void dviWindow::draw_page(void)
+void dviRenderer::draw_page(void)
 {
   // Reset a couple of variables
   HTML_href         = 0;
   source_href       = 0;
   penWidth_in_mInch = 0.0;
-  currentlyDrawnPage.hyperLinkList.clear();
+  currentlyDrawnPage->hyperLinkList.clear();
 
 
   // Calling resize() here rather than clear() means that the memory
   // taken up by the vector is not freed. This is faster than
   // constantly allocating/freeing memory.
-  currentlyDrawnPage.textLinkList.resize(0);
-  currentlyDrawnPage.sourceHyperLinkList.resize(0);
-
-  // Check if all the fonts are loaded. If that is not the case, we
-  // return and do not draw anything. The font_pool will later emit
-  // the signal "fonts_are_loaded" and thus trigger a redraw of the
-  // page.
-  if (font_pool->check_if_fonts_filenames_are_looked_up() == false)
-    return;
+  currentlyDrawnPage->textLinkList.resize(0);
+  currentlyDrawnPage->sourceHyperLinkList.resize(0);
 
 #ifdef PERFORMANCE_MEASUREMENT
   // If this is the first time a page is drawn, take the time that is
@@ -602,33 +605,31 @@ void dviWindow::draw_page(void)
 
 
 #ifdef DEBUG_RENDER
-  kdDebug() <<"draw_page" << endl;
+  kdDebug(4300) <<"draw_page" << endl;
 #endif
 
-  foreGroundPaint.fillRect(currentlyDrawnPage.pixmap->rect(), PS_interface->getBackgroundColor(current_page) );
+  foreGroundPaint.fillRect( foreGroundPaint.viewport(), PS_interface->getBackgroundColor(current_page) );
 
   // Render the PostScript background, if there is one.
-  if (_postscript) {
-    QPixmap *pxm = PS_interface->graphics(current_page);
-    if (pxm != NULL) {
-      foreGroundPaint.drawPixmap(0, 0, *pxm);
-      delete pxm;
-    }
-  }
-
+  if (_postscript)
+    PS_interface->graphics(current_page, resolutionInDPI, dviFile->getMagnification(), foreGroundPaint);
+  
   // Now really write the text
-  if (dviFile->page_offset == 0)
+  if (dviFile->page_offset.isEmpty() == true)
     return;
   if (current_page < dviFile->total_pages) {
-    command_pointer = dviFile->dvi_Data + dviFile->page_offset[current_page];
-    end_pointer     = dviFile->dvi_Data + dviFile->page_offset[current_page+1];
+    command_pointer = dviFile->dvi_Data() + dviFile->page_offset[current_page];
+    end_pointer     = dviFile->dvi_Data() + dviFile->page_offset[current_page+1];
   } else
     command_pointer = end_pointer = 0;
-
+  
   memset((char *) &currinf.data, 0, sizeof(currinf.data));
   currinf.fonttable      = &(dviFile->tn_table);
   currinf._virtual       = 0;
-  draw_part(65536.0*fontPixelPerDVIunit(), false);
+  
+  double fontPixelPerDVIunit = dviFile->getCmPerDVIunit() * 1200.0/2.54;
+  
+  draw_part(65536.0*fontPixelPerDVIunit, false);
   if (HTML_href != 0) {
     delete HTML_href;
     HTML_href = 0;
@@ -637,16 +638,4 @@ void dviWindow::draw_page(void)
     delete source_href;
     source_href = 0;
   }
-
-  // Mark hyperlinks in blue. We draw a blue line under the
-  // character whose width is equivalent to 0.5 mm, but at least
-  // one pixel.
-  int h = (int)(MFResolutions[font_pool->getMetafontMode()]*0.05/(2.54*shrinkfactor) + 0.5);
-  h = (h < 1) ? 1 : h;
-  for(unsigned int i=0; i<currentlyDrawnPage.hyperLinkList.size(); i++) {
-    int x = currentlyDrawnPage.hyperLinkList[i].box.left();
-    int w = currentlyDrawnPage.hyperLinkList[i].box.width();
-    int y = currentlyDrawnPage.hyperLinkList[i].baseline;
-    foreGroundPaint.fillRect(x, y, w, h, Qt::blue);
-  }
 }
