@@ -2,18 +2,20 @@
 //
 // Part of KDVI - A DVI previewer for the KDE desktop environemt 
 //
-// (C) 2003 Stefan Kebekus
+// (C) 2003--2004 Stefan Kebekus
 // Distributed under the GPL
 
 #include "dviwin.h"
 #include "dvi.h"
 #include "fontpool.h"
+#include "kdvi_multipage.h"
 #include "performanceMeasurement.h"
 #include "TeXFont.h"
 #include "xdvi.h"
 
 #include <kdebug.h>
 #include <klocale.h>
+#include <kmimetype.h>
 #include <kprocess.h>
 #include <kprocio.h>
 #include <kprogress.h>
@@ -36,10 +38,10 @@ extern void parse_special_argument(QString strg, const char *argument_name, int
 
 
 
-void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
+void dviRenderer::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
 {
 #ifdef  DEBUG_PRESCAN
-  kdDebug(4300) << "dviWindow::prescan_embedPS( cp = " << cp << " ) " << endl;
+  kdDebug(4300) << "dviRenderer::prescan_embedPS( cp = " << cp << " ) " << endl;
 #endif
 
   // Encapsulated Postscript File
@@ -62,9 +64,15 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
   // macro packages (but not by others). This probably means that
   // graphic files are no longer found if the filename really does
   // contain quotes, but we don't really care that much.
-  if ((EPSfilename.at(0) == '\"') && (EPSfilename.at(EPSfilename.length()-1) == '\"')) {
+  if ((EPSfilename.at(0) == '\"') && (EPSfilename.at(EPSfilename.length()-1) == '\"'))
     EPSfilename = EPSfilename.mid(1,EPSfilename.length()-2);
-  }
+
+  // If the file name ends in 'png', 'gif', 'jpg' or 'jpeg', we assume
+  // that this is NOT a PostScript file, and we exit here. The graphic
+  // file is later read when the page is rendered.
+  QString ending = EPSfilename.section('.', -1).lower();
+  if ((ending == "png") || (ending == "gif") || (ending == "jpg") || (ending == "jpeg") || (ending == "mng"))
+    return;
 
   QString originalFName = EPSfilename;
 
@@ -77,7 +85,7 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
   
   if (!QFile::exists(EPSfilename)) {
     // Find the number of the page
-    Q_UINT32 currentOffset = beginningOfSpecialCommand-dviFile->dvi_Data;
+    Q_UINT32 currentOffset = beginningOfSpecialCommand - dviFile->dvi_Data();
     Q_UINT16 page;
     for(page=0; page < dviFile->total_pages; page++) 
       if ((dviFile->page_offset[page] <= currentOffset) && (currentOffset <= dviFile->page_offset[page+1]))
@@ -109,6 +117,7 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
   parse_special_argument(include_command, "rhi=", &rhi);
   parse_special_argument(include_command, "angle=", &angle);
 
+  int clip=include_command.find(" clip"); // -1 if clip keyword is not present, >= 0 otherwise
 
   // Generate the PostScript commands to be included
   QString PS = QString("ps: @beginspecial %1 @llx %2 @lly %3 @urx %4 @ury").arg(llx).arg(lly).arg(urx).arg(ury);
@@ -118,6 +127,8 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
     PS.append( QString(" %1 @rhi").arg(rhi) );
   if (angle != 0)
     PS.append( QString(" %1 @angle").arg(angle) );
+  if (clip != -1)
+    PS.append(" @clip");
   PS.append( " @setspecial\n" );
   
   QFile file( EPSfilename );
@@ -137,36 +148,32 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
   Q_UINT32 lengthOfOldSpecial = command_pointer - beginningOfSpecialCommand;
   Q_UINT32 lengthOfNewSpecial = PS.length()+5;
   
-  Q_UINT8 *newDVI = new Q_UINT8[dviFile->size_of_file + lengthOfNewSpecial-lengthOfOldSpecial];
-  if (newDVI == 0) {
-    kdError(4300) << "Out of memory -- could not embed PS file" << endl;
-    return;
-  }
+  QMemArray<Q_UINT8> newDVI(dviFile->size_of_file + lengthOfNewSpecial-lengthOfOldSpecial);
   
   Q_UINT8 *commandPtrSav = command_pointer;
   Q_UINT8 *endPtrSav = end_pointer;
-  end_pointer = newDVI + dviFile->size_of_file + lengthOfNewSpecial-lengthOfOldSpecial;
-  memcpy(newDVI, dviFile->dvi_Data, beginningOfSpecialCommand-dviFile->dvi_Data);
-  command_pointer = newDVI+(beginningOfSpecialCommand-dviFile->dvi_Data);
+  end_pointer = newDVI.data() + dviFile->size_of_file + lengthOfNewSpecial-lengthOfOldSpecial;
+  memcpy(newDVI.data(), dviFile->dvi_Data(), beginningOfSpecialCommand-dviFile->dvi_Data());
+  command_pointer = newDVI.data()+(beginningOfSpecialCommand-dviFile->dvi_Data());
   command_pointer[0] = XXX4;
   command_pointer++;
   writeUINT32(PS.length());
-  memcpy(newDVI+(beginningOfSpecialCommand-dviFile->dvi_Data)+5, PS.latin1(), PS.length() );
-  memcpy(newDVI+(beginningOfSpecialCommand-dviFile->dvi_Data)+lengthOfNewSpecial, beginningOfSpecialCommand+lengthOfOldSpecial,
-	 dviFile->size_of_file-(beginningOfSpecialCommand-dviFile->dvi_Data)-lengthOfOldSpecial );
+  memcpy(newDVI.data()+(beginningOfSpecialCommand-dviFile->dvi_Data())+5, PS.latin1(), PS.length() );
+  memcpy(newDVI.data()+(beginningOfSpecialCommand-dviFile->dvi_Data())+lengthOfNewSpecial, beginningOfSpecialCommand+lengthOfOldSpecial,
+	 dviFile->size_of_file-(beginningOfSpecialCommand-dviFile->dvi_Data())-lengthOfOldSpecial );
   
   // Adjust page pointers in the DVI file
   dviFile->size_of_file = dviFile->size_of_file + lengthOfNewSpecial-lengthOfOldSpecial;
-  end_pointer = newDVI + dviFile->size_of_file;
-  Q_UINT32 currentOffset = beginningOfSpecialCommand-dviFile->dvi_Data;
+  end_pointer = newDVI.data() + dviFile->size_of_file;
+  Q_UINT32 currentOffset = beginningOfSpecialCommand-dviFile->dvi_Data();
   for(Q_UINT16 i=0; i < dviFile->total_pages; i++) {
     if (dviFile->page_offset[i] > currentOffset) {
       dviFile->page_offset[i] = dviFile->page_offset[i] + lengthOfNewSpecial-lengthOfOldSpecial;
-      command_pointer = dviFile->page_offset[i] + newDVI + 4*10 + 1;
+      command_pointer = dviFile->page_offset[i] + newDVI.data() + 4*10 + 1;
       Q_UINT32 a = readUINT32();
       if (a > currentOffset) {
 	a = a + lengthOfNewSpecial-lengthOfOldSpecial;
-	command_pointer = dviFile->page_offset[i] + newDVI + 4*10 + 1;
+	command_pointer = dviFile->page_offset[i] + newDVI.data() + 4*10 + 1;
 	writeUINT32(a);
       }
     }
@@ -176,16 +183,16 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
   dviFile->beginning_of_postamble            = dviFile->beginning_of_postamble + lengthOfNewSpecial - lengthOfOldSpecial;
   dviFile->page_offset[dviFile->total_pages] = dviFile->beginning_of_postamble;
   
-  command_pointer = newDVI + dviFile->beginning_of_postamble + 1;
+  command_pointer = newDVI.data() + dviFile->beginning_of_postamble + 1;
   Q_UINT32 a = readUINT32();
   if (a > currentOffset) {
     a = a + lengthOfNewSpecial - lengthOfOldSpecial;
-    command_pointer = newDVI + dviFile->beginning_of_postamble + 1;
+    command_pointer = newDVI.data() + dviFile->beginning_of_postamble + 1;
     writeUINT32(a);
   }
   
-  command_pointer = newDVI + dviFile->size_of_file - 1;
-  while((*command_pointer == TRAILER) && (command_pointer > newDVI))
+  command_pointer = newDVI.data() + dviFile->size_of_file - 1;
+  while((*command_pointer == TRAILER) && (command_pointer > newDVI.data()))
     command_pointer--;
   command_pointer -= 4;
   writeUINT32(dviFile->beginning_of_postamble);
@@ -195,11 +202,11 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
   end_pointer     = endPtrSav;
   
   // Modify all pointers to point to the newly allocated memory
-  command_pointer = newDVI + (command_pointer - dviFile->dvi_Data) + lengthOfNewSpecial-lengthOfOldSpecial;
-  end_pointer = newDVI + (end_pointer - dviFile->dvi_Data)  + lengthOfNewSpecial-lengthOfOldSpecial;
+  command_pointer = newDVI.data() + (command_pointer - dviFile->dvi_Data()) + lengthOfNewSpecial-lengthOfOldSpecial;
+  end_pointer = newDVI.data() + (end_pointer - dviFile->dvi_Data())  + lengthOfNewSpecial-lengthOfOldSpecial;
   
-  delete [] dviFile->dvi_Data;
-  dviFile->dvi_Data = newDVI;
+  
+  dviFile->setNewData(newDVI);
   
   embedPS_progress->progressBar()->advance(1);
   qApp->processEvents();
@@ -207,9 +214,24 @@ void dviWindow::prescan_embedPS(char *cp, Q_UINT8 *beginningOfSpecialCommand)
 }
 
 
-void dviWindow::prescan_ParsePapersizeSpecial(QString cp)
+void dviRenderer::prescan_removePageSizeInfo(char *cp, Q_UINT8 *beginningOfSpecialCommand)
 {
-#ifdef DEBUG_SPECIAL
+#ifdef  DEBUG_PRESCAN
+  kdDebug(4300) << "dviRenderer::prescan_embedPS( cp = " << cp << " ) " << endl;
+#endif
+  
+  // Encapsulated Postscript File
+  if (strncasecmp(cp, "papersize=", 10) != 0) 
+    return;
+  
+  for (Q_UINT8 *ptr=beginningOfSpecialCommand; ptr<command_pointer; ptr++) 
+    *ptr = NOP;
+}
+
+
+void dviRenderer::prescan_ParsePapersizeSpecial(QString cp)
+{
+#ifdef DEBUG_PRESCAN
   kdDebug(4300) << "Papersize-Special : papersize" << cp << endl;
 #endif
 
@@ -219,9 +241,6 @@ void dviWindow::prescan_ParsePapersizeSpecial(QString cp)
     cp = cp.mid(1);
     dviFile->suggestedPageSize = new pageSize;
     dviFile->suggestedPageSize->setPageSize(cp);
-#ifdef DEBUG_SPECIAL
-    kdDebug(4300) << "Suggested paper size is " << dviFile->suggestedPageSize.serialize() << "." << endl;
-#endif
   } else 
     printErrorMsgForSpecials(i18n("The papersize data '%1' could not be parsed.").arg(cp));
 
@@ -229,7 +248,7 @@ void dviWindow::prescan_ParsePapersizeSpecial(QString cp)
 }
 
 
-void dviWindow::prescan_ParseBackgroundSpecial(QString cp)
+void dviRenderer::prescan_ParseBackgroundSpecial(QString cp)
 {
   QColor col = parseColorSpecification(cp.stripWhiteSpace());
   if (col.isValid())
@@ -239,20 +258,16 @@ void dviWindow::prescan_ParseBackgroundSpecial(QString cp)
 }
 
 
-void dviWindow::prescan_ParseHTMLAnchorSpecial(QString cp)
+void dviRenderer::prescan_ParseHTMLAnchorSpecial(QString cp)
 {
   cp.truncate(cp.find('"'));
-#ifdef DEBUG_SPECIAL
-  kdDebug(4300) << "HTML-special, anchor " << cp.latin1() << endl;
-  kdDebug(4300) << "page " << current_page << endl;
-#endif
-  anchorList[cp] = DVI_Anchor(current_page, currinf.data.dvi_v);
+  anchorList[cp] = anchor(current_page+1, currinf.data.dvi_v/(resolutionInDPI*shrinkfactor));
 }
 
 
-void dviWindow::prescan_ParsePSHeaderSpecial(QString cp)
+void dviRenderer::prescan_ParsePSHeaderSpecial(QString cp)
 {
-#ifdef DEBUG_SPECIAL
+#ifdef DEBUG_PRESCAN
   kdDebug(4300) << "PostScript-special, header " << cp.latin1() << endl;
 #endif
 
@@ -261,9 +276,9 @@ void dviWindow::prescan_ParsePSHeaderSpecial(QString cp)
 }
 
 
-void dviWindow::prescan_ParsePSBangSpecial(QString cp)
+void dviRenderer::prescan_ParsePSBangSpecial(QString cp)
 {
-#ifdef DEBUG_SPECIAL
+#ifdef DEBUG_PRESCAN
   kdDebug(4300) << "PostScript-special, literal header " << cp.latin1() << endl;
 #endif
   
@@ -273,15 +288,15 @@ void dviWindow::prescan_ParsePSBangSpecial(QString cp)
 }
 
 
-void dviWindow::prescan_ParsePSQuoteSpecial(QString cp)
+void dviRenderer::prescan_ParsePSQuoteSpecial(QString cp)
 {
-#ifdef DEBUG_SPECIAL
+#ifdef DEBUG_PRESCAN
   kdError(4300) << "PostScript-special, literal PostScript " << cp.latin1() << endl;
 
 #endif
   
-  double PS_H = (currinf.data.dvi_h*300.0)/(65536*MFResolutions[font_pool->getMetafontMode()])-300;
-  double PS_V = (currinf.data.dvi_v*300.0)/MFResolutions[font_pool->getMetafontMode()] - 300;
+  double PS_H = (currinf.data.dvi_h*300.0)/(65536*1200)-300;
+  double PS_V = (currinf.data.dvi_v*300.0)/1200 - 300;
   PostScriptOutPutString->append( QString(" %1 %2 moveto\n").arg(PS_H).arg(PS_V) );
   PostScriptOutPutString->append( " @beginspecial @setspecial \n" );
   PostScriptOutPutString->append( cp );
@@ -289,9 +304,9 @@ void dviWindow::prescan_ParsePSQuoteSpecial(QString cp)
 }
 
 
-void dviWindow::prescan_ParsePSSpecial(QString cp)
+void dviRenderer::prescan_ParsePSSpecial(QString cp)
 {
-#ifdef DEBUG_SPECIAL
+#ifdef DEBUG_PRESCAN
   kdDebug(4300) << "PostScript-special, direct PostScript " << cp << endl;
 #endif
 
@@ -318,15 +333,15 @@ void dviWindow::prescan_ParsePSSpecial(QString cp)
     if (cp.startsWith("ps:SDict begin [") && cp.endsWith(" pdfmark end")) {  // hyperref definition of link/anchor/bookmark/etc
       if (cp.contains("/DEST")) { // The PostScript code defines an anchor
 	QString anchorName = cp.section('(', 1, 1).section(')', 0, 0);
-	anchorList[anchorName] = DVI_Anchor(current_page, currinf.data.dvi_v);
+	anchorList[anchorName] = anchor(current_page+1, currinf.data.dvi_v/(resolutionInDPI*shrinkfactor));
       }
       return;
     }
   }
   
   
-  double PS_H = (currinf.data.dvi_h*300.0)/(65536*MFResolutions[font_pool->getMetafontMode()])-300;
-  double PS_V = (currinf.data.dvi_v*300.0)/MFResolutions[font_pool->getMetafontMode()] - 300;
+  double PS_H = (currinf.data.dvi_h*300.0)/(65536*1200)-300;
+  double PS_V = (currinf.data.dvi_v*300.0)/1200 - 300;
   
   if (cp.find("ps::[begin]", 0, false) == 0) {
     PostScriptOutPutString->append( QString(" %1 %2 moveto\n").arg(PS_H).arg(PS_V) );
@@ -346,16 +361,14 @@ void dviWindow::prescan_ParsePSSpecial(QString cp)
 }
 
 
-void dviWindow::prescan_ParsePSFileSpecial(QString cp)
+void dviRenderer::prescan_ParsePSFileSpecial(QString cp)
 {
-#ifdef DEBUG_SPECIAL
+#ifdef DEBUG_PRESCAN
   kdDebug(4300) << "epsf-special: psfile=" << cp <<endl;
 #endif
 
   QString include_command = cp.simplifyWhiteSpace();
 
-  dviFile->numberOfExternalPSFiles++;  
-
   // The line is supposed to start with "..ile=", and then comes the
   // filename. Figure out what the filename is and stow it away. Of
   // course, this does not work if the filename contains spaces
@@ -372,6 +385,17 @@ void dviWindow::prescan_ParsePSFileSpecial(QString cp)
     EPSfilename = EPSfilename.mid(1,EPSfilename.length()-2);
   }
 
+  // If the file name ends in 'png', 'gif', 'jpg' or 'jpeg', we assume
+  // that this is NOT a PostScript file, and we exit here.
+  QString ending = EPSfilename.section('.', -1).lower();
+  if ((ending == "png") || (ending == "gif") || (ending == "jpg") || (ending == "jpeg")) {
+    dviFile->numberOfExternalNONPSFiles++;  
+    return;
+  }
+  
+  // Now assume that the graphics file *is* a PostScript file
+  dviFile->numberOfExternalPSFiles++;  
+  
   // Now locate the Gfx file on the hard disk...
   EPSfilename = ghostscript_interface::locateEPSfile(EPSfilename, dviFile);
   
@@ -394,10 +418,11 @@ void dviWindow::prescan_ParsePSFileSpecial(QString cp)
   parse_special_argument(include_command, "rwi=", &rwi);
   parse_special_argument(include_command, "rhi=", &rhi);
   parse_special_argument(include_command, "angle=", &angle);
+  int clip=include_command.find(" clip"); // -1 if clip keyword is not present, >= 0 otherwise
 
   if (QFile::exists(EPSfilename)) {
-    double PS_H = (currinf.data.dvi_h*300.0)/(65536*MFResolutions[font_pool->getMetafontMode()])-300;
-    double PS_V = (currinf.data.dvi_v*300.0)/MFResolutions[font_pool->getMetafontMode()] - 300;
+    double PS_H = (currinf.data.dvi_h*300.0)/(65536*1200)-300;
+    double PS_V = (currinf.data.dvi_v*300.0)/1200 - 300;
     PostScriptOutPutString->append( QString(" %1 %2 moveto\n").arg(PS_H).arg(PS_V) );
     PostScriptOutPutString->append( "@beginspecial " );
     PostScriptOutPutString->append( QString(" %1 @llx").arg(llx) );
@@ -410,6 +435,8 @@ void dviWindow::prescan_ParsePSFileSpecial(QString cp)
       PostScriptOutPutString->append( QString(" %1 @rhi").arg(rhi) );
     if (angle != 0)
       PostScriptOutPutString->append( QString(" %1 @angle").arg(angle) );
+    if (clip != -1)
+      PostScriptOutPutString->append(" @clip");
     PostScriptOutPutString->append( " @setspecial \n" );
     PostScriptOutPutString->append( QString(" (%1) run\n").arg(EPSfilename) );
     PostScriptOutPutString->append( "@endspecial \n" );
@@ -419,7 +446,7 @@ void dviWindow::prescan_ParsePSFileSpecial(QString cp)
 }
 
 
-void dviWindow::prescan_ParseSourceSpecial(QString cp)
+void dviRenderer::prescan_ParseSourceSpecial(QString cp)
 {
   // if no rendering takes place, i.e. when the DVI file is first
   // loaded, generate a DVI_SourceFileAnchor. These anchors are used
@@ -434,12 +461,12 @@ void dviWindow::prescan_ParseSourceSpecial(QString cp)
   Q_UINT32 sourceLineNumber = cp.left(j).toUInt();
   QFileInfo fi1(dviFile->filename);
   QString  sourceFileName   = QFileInfo(fi1.dir(), cp.mid(j).stripWhiteSpace()).absFilePath();
-  DVI_SourceFileAnchor sfa(sourceFileName, sourceLineNumber, current_page, currinf.data.dvi_v);
+  DVI_SourceFileAnchor sfa(sourceFileName, sourceLineNumber, current_page+1, currinf.data.dvi_v/(resolutionInDPI*shrinkfactor));
   sourceHyperLinkAnchors.push_back(sfa);
 }
 
 
-void dviWindow::prescan_parseSpecials(char *cp, Q_UINT8 *)
+void dviRenderer::prescan_parseSpecials(char *cp, Q_UINT8 *)
 {
   QString special_command(cp);
 
@@ -513,45 +540,49 @@ void dviWindow::prescan_parseSpecials(char *cp, Q_UINT8 *)
 }
 
 
-void dviWindow::prescan_setChar(unsigned int ch)
+void dviRenderer::prescan_setChar(unsigned int ch)
 {
   TeXFontDefinition *fontp = currinf.fontp;
   if (fontp == NULL)
     return;
 
-  if (currinf.set_char_p == &dviWindow::set_char) {
+  if (currinf.set_char_p == &dviRenderer::set_char) {
     glyph *g = ((TeXFont *)(currinf.fontp->font))->getGlyph(ch, true, globalColor);
     if (g == NULL)
       return;
     currinf.data.dvi_h += (int)(currinf.fontp->scaled_size_in_DVI_units * dviFile->getCmPerDVIunit() * 
-				(MFResolutions[font_pool->getMetafontMode()] / 2.54)/16.0 * g->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
+				(1200.0 / 2.54)/16.0 * g->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
     return;
   }
  
-  if (currinf.set_char_p == &dviWindow::set_vf_char) {
+  if (currinf.set_char_p == &dviRenderer::set_vf_char) {
     macro *m = &currinf.fontp->macrotable[ch];
     if (m->pos == NULL) 
       return;
     currinf.data.dvi_h += (int)(currinf.fontp->scaled_size_in_DVI_units * dviFile->getCmPerDVIunit() * 
-				(MFResolutions[font_pool->getMetafontMode()] / 2.54)/16.0 * m->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
+				(1200.0 / 2.54)/16.0 * m->dvi_advance_in_units_of_design_size_by_2e20 + 0.5);
     return;
   }
 }
 
 
-void dviWindow::prescan(parseSpecials specialParser)
+void dviRenderer::prescan(parseSpecials specialParser)
 {
 #ifdef DEBUG_PRESCAN
-  kdDebug(4300) << "dviWindow::prescan( ... )" << endl;
+  kdDebug(4300) << "dviRenderer::prescan( ... )" << endl;
 #endif
-  
+
+  if (resolutionInDPI == 0.0)
+    setResolution(100);
+
   Q_INT32 RRtmp=0, WWtmp=0, XXtmp=0, YYtmp=0, ZZtmp=0;
   Q_UINT8 ch;
+  double fontPixelPerDVIunit = dviFile->getCmPerDVIunit() * 1200.0/2.54;
 
   stack.clear();
 
   currinf.fontp        = NULL;
-  currinf.set_char_p   = &dviWindow::set_no_char;
+  currinf.set_char_p   = &dviRenderer::set_no_char;
 
   for (;;) {
     ch = readUINT8();
@@ -584,7 +615,7 @@ void dviWindow::prescan(parseSpecials specialParser)
 	 0x80000000. We don't want any SIGFPE here. */
       a = readUINT32();
       b = readUINT32();
-      b = ((long) (b *  65536.0*fontPixelPerDVIunit()));
+      b = ((long) (b *  65536.0*fontPixelPerDVIunit));
       currinf.data.dvi_h += b;
       break;
       
@@ -599,8 +630,8 @@ void dviWindow::prescan(parseSpecials specialParser)
       
     case BOP:
       command_pointer += 11 * 4;
-      currinf.data.dvi_h = MFResolutions[font_pool->getMetafontMode()] << 16; // Reminder: DVI-coordinates start at (1",1") from top of page
-      currinf.data.dvi_v = MFResolutions[font_pool->getMetafontMode()];
+      currinf.data.dvi_h = 1200 << 16; // Reminder: DVI-coordinates start at (1",1") from top of page
+      currinf.data.dvi_v = 1200;
       currinf.data.pxl_v = int(currinf.data.dvi_v/shrinkfactor);
       currinf.data.w = currinf.data.x = currinf.data.y = currinf.data.z = 0;
       break;
@@ -621,7 +652,7 @@ void dviWindow::prescan(parseSpecials specialParser)
     case RIGHT3:
     case RIGHT4:
       RRtmp = readINT(ch - RIGHT1 + 1);
-      currinf.data.dvi_h += ((long) (RRtmp *  65536.0*fontPixelPerDVIunit()));
+      currinf.data.dvi_h += ((long) (RRtmp *  65536.0*fontPixelPerDVIunit));
       break;
       
     case W1:
@@ -629,7 +660,7 @@ void dviWindow::prescan(parseSpecials specialParser)
     case W3:
     case W4:
       WWtmp = readINT(ch - W0);
-      currinf.data.w = ((long) (WWtmp *  65536.0*fontPixelPerDVIunit()));
+      currinf.data.w = ((long) (WWtmp *  65536.0*fontPixelPerDVIunit));
     case W0:
       currinf.data.dvi_h += currinf.data.w;
       break;
@@ -639,7 +670,7 @@ void dviWindow::prescan(parseSpecials specialParser)
     case X3:
     case X4:
       XXtmp = readINT(ch - X0);
-      currinf.data.x = ((long) (XXtmp *  65536.0*fontPixelPerDVIunit()));
+      currinf.data.x = ((long) (XXtmp *  65536.0*fontPixelPerDVIunit));
     case X0:
       currinf.data.dvi_h += currinf.data.x;
       break;
@@ -650,7 +681,7 @@ void dviWindow::prescan(parseSpecials specialParser)
     case DOWN4:
       {
 	Q_INT32 DDtmp = readINT(ch - DOWN1 + 1);
-	currinf.data.dvi_v += ((long) (DDtmp *  65536.0*fontPixelPerDVIunit()))/65536;
+	currinf.data.dvi_v += ((long) (DDtmp *  65536.0*fontPixelPerDVIunit))/65536;
 	currinf.data.pxl_v  = int(currinf.data.dvi_v/shrinkfactor);
       }
       break;
@@ -660,7 +691,7 @@ void dviWindow::prescan(parseSpecials specialParser)
     case Y3:
     case Y4:
       YYtmp = readINT(ch - Y0);
-      currinf.data.y    = ((long) (YYtmp *  65536.0*fontPixelPerDVIunit()));
+      currinf.data.y    = ((long) (YYtmp *  65536.0*fontPixelPerDVIunit));
     case Y0:
       currinf.data.dvi_v += currinf.data.y/65536;
       currinf.data.pxl_v = int(currinf.data.dvi_v/shrinkfactor);
@@ -671,7 +702,7 @@ void dviWindow::prescan(parseSpecials specialParser)
     case Z3:
     case Z4:
       ZZtmp = readINT(ch - Z0);
-      currinf.data.z    = ((long) (ZZtmp *  65536.0*fontPixelPerDVIunit()));
+      currinf.data.z    = ((long) (ZZtmp *  65536.0*fontPixelPerDVIunit));
     case Z0:
       currinf.data.dvi_v += currinf.data.z/65536;
       currinf.data.pxl_v  = int(currinf.data.dvi_v/shrinkfactor);
