@@ -201,6 +201,9 @@ bool KDVIMultiPage::openFile()
   if (!r)
     emit setStatusBarText(QString::null);
 
+  //############
+  //An dieser Stelle msste der Zoom-Faktor neu berechnet werden?
+
   generateDocumentWidgets();
   emit numberOfPages(DVIRenderer.totalPages());
   enableActions(r);
@@ -522,10 +525,13 @@ void KDVIMultiPage::reload()
 
 void KDVIMultiPage::enableActions(bool b)
 {
+  KMultiPage::enableActions(b);
+
   docInfoAction->setEnabled(b);
   exportPSAction->setEnabled(b);
   exportPDFAction->setEnabled(b);
   exportTextAction->setEnabled(b);
+
   setEmbedPostScriptAction();
 }
 
