@@ -1,24 +1,30 @@
-#include <stdio.h>
+//
+// ghostscript_interface
+//
+// Part of KDVI - A framework for multipage text/gfx viewers
+//
+// (C) 2004 Stefan Kebekus
+// Distributed under the GPL
+
 
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kprocess.h>
 #include <kprocio.h>
 #include <qdir.h>
-#include <qfile.h>
-#include <qfileinfo.h>
+#include <qpainter.h>
+#include <stdio.h>
 
 #include "dviFile.h"
 #include "psgs.h"
 
 extern const char psheader[];
 
+//#define DEBUG_PSGS
 
 
 pageInfo::pageInfo(QString _PostScriptString) {
   PostScriptString = new QString(_PostScriptString);
-  Gfx              = NULL;
   background       = Qt::white;
 }
 
@@ -31,15 +37,10 @@ pageInfo::~pageInfo() {
 
 // ======================================================
 
-ghostscript_interface::ghostscript_interface(double dpi, int pxlw, int pxlh) {
+ghostscript_interface::ghostscript_interface() {
   pageList.setAutoDelete(TRUE);
-  MemoryCache.setAutoDelete(TRUE);
-  DiskCache.setAutoDelete(TRUE);
 
   PostScriptHeaderString = new QString();
-  resolution   = dpi;
-  pixel_page_w = pxlw;
-  pixel_page_h = pxlh;
 
   knownDevices.append("png256");
   knownDevices.append("jpeg");
@@ -54,17 +55,11 @@ ghostscript_interface::~ghostscript_interface() {
 }
 
 
-void ghostscript_interface::setSize(double dpi, int pxlw, int pxlh) {
-  resolution   = dpi;
-  pixel_page_w = pxlw;
-  pixel_page_h = pxlh;
+void ghostscript_interface::setPostScript(PageNumber page, QString PostScript) {
+#ifdef DEBUG_PSGS
+  kdDebug(4300) << "ghostscript_interface::setPostScript( " << page << ", ... )" << endl;
+#endif
 
-  MemoryCache.clear();
-  DiskCache.clear();
-}
-
-
-void ghostscript_interface::setPostScript(int page, QString PostScript) {
   if (pageList.find(page) == 0) {
     pageInfo *info = new pageInfo(PostScript);
     // Check if dict is big enough
@@ -84,7 +79,7 @@ void ghostscript_interface::setIncludePath(const QString &_includePath) {
 }
 
 
-void ghostscript_interface::setColor(int page, QColor background_color) {
+void ghostscript_interface::setColor(PageNumber page, QColor background_color) {
 #ifdef DEBUG_PSGS
   kdDebug(4300) << "ghostscript_interface::setColor( " << page << ", " << background_color << " )" << endl;
 #endif
@@ -104,7 +99,7 @@ void ghostscript_interface::setColor(int page, QColor background_color) {
 // Returns the background color for a certain page. This color is
 // always guaranteed to be valid
 
-QColor ghostscript_interface::getBackgroundColor(int page) {
+QColor ghostscript_interface::getBackgroundColor(PageNumber page) {
 #ifdef DEBUG_PSGS
   kdDebug(4300) << "ghostscript_interface::getBackgroundColor( " << page << " )" << endl;
 #endif
@@ -118,17 +113,21 @@ QColor ghostscript_interface::getBackgroundColor(int page) {
 
 void ghostscript_interface::clear(void) {
   PostScriptHeaderString->truncate(0);
-  MemoryCache.clear();
-  DiskCache.clear();
   
   // Deletes all items, removes temporary files, etc.
   pageList.clear();
 }
 
 
-void ghostscript_interface::gs_generate_graphics_file(int page, const QString &filename) {
-  if (knownDevices.isEmpty())
+void ghostscript_interface::gs_generate_graphics_file(PageNumber page, const QString &filename, long magnification) {
+#ifdef DEBUG_PSGS
+  kdDebug(4300) << "ghostscript_interface::gs_generate_graphics_file( " << page << ", " << filename << " )" << endl;
+#endif
+
+  if (knownDevices.isEmpty()) {
+    kdError(4300) << "No known devices found" << endl;
     return;
+  }
 
   emit(setStatusBarText(i18n("Generating PostScript graphics...")));
   
@@ -155,8 +154,7 @@ void ghostscript_interface::gs_generate_graphics_file(int page, const QString &f
 
   fprintf(f," %ld", (long)(72*65781*(pixel_page_w/resolution)) );  // HSize in (1/(65781.76*72))inch @@@
   fprintf(f," %ld", (long)(72*65781*(pixel_page_h/resolution)) );  // VSize in (1/(65781.76*72))inch 
-
-  fputs(" 1000",f);                           // Magnification
+  fprintf(f," %ld", magnification );  // Magnification
   fputs(" 300 300",f);                        // dpi and vdpi
   fputs(" (test.dvi)",f);                     // Name
   fputs(" @start end\n",f);
@@ -183,15 +181,22 @@ void ghostscript_interface::gs_generate_graphics_file(int page, const QString &f
   // Step 2: Call GS with the File
   QFile::remove(filename.ascii());
   KProcIO proc;
-  proc << "gs";
-  proc << "-dSAFER" << "-dPARANOIDSAFER" << "-dDELAYSAFER" << "-dNOPAUSE" << "-dBATCH";
-  proc << QString("-sDEVICE=%1").arg(*gsDevice);
-  proc << QString("-sOutputFile=%1").arg(filename);
-  proc << QString("-sExtraIncludePath=%1").arg(includePath);
-  proc << QString("-g%1x%2").arg(pixel_page_w).arg(pixel_page_h); // page size in pixels
-  proc << QString("-r%1").arg(resolution);                       // resolution in dpi
-  proc << "-c" << "<< /PermitFileReading [ ExtraIncludePath ] /PermitFileWriting [] /PermitFileControl [] >> setuserparams .locksafe";
-  proc << "-f" << PSfile.name();
+  QStringList argus;
+  argus << "gs";
+  argus << "-dSAFER" << "-dPARANOIDSAFER" << "-dDELAYSAFER" << "-dNOPAUSE" << "-dBATCH";
+  argus << QString("-sDEVICE=%1").arg(*gsDevice);
+  argus << QString("-sOutputFile=%1").arg(filename);
+  argus << QString("-sExtraIncludePath=%1").arg(includePath);
+  argus << QString("-g%1x%2").arg(pixel_page_w).arg(pixel_page_h); // page size in pixels
+  argus << QString("-r%1").arg(resolution);                       // resolution in dpi
+  argus << "-c" << "<< /PermitFileReading [ ExtraIncludePath ] /PermitFileWriting [] /PermitFileControl [] >> setuserparams .locksafe";
+  argus << "-f" << PSfile.name();
+  
+#ifdef DEBUG_PSGS
+  kdDebug(4300) << argus.join(" ") << endl;
+#endif
+
+  proc << argus;
   if (proc.start(KProcess::Block) == false) {
     // Starting ghostscript did not work. 
     // TODO: Issue error message, switch PS support off.
@@ -201,11 +206,12 @@ void ghostscript_interface::gs_generate_graphics_file(int page, const QString &f
 
   // Check if gs has indeed produced a file.
   if (QFile::exists(filename) == false) {
+    kdError(4300) << "GS did not produce output." << endl;
+
     // No. Check is the reason is that the device is not compiled into
     // ghostscript. If so, try again with another device.
     QString GSoutput;
     while(proc.readln(GSoutput) != -1) {
-
       if (GSoutput.contains("Unknown device")) {
 	kdDebug(4300) << QString("The version of ghostview installed on this computer does not support "
 				   "the '%1' ghostview device driver.").arg(*gsDevice) << endl;
@@ -235,51 +241,45 @@ void ghostscript_interface::gs_generate_graphics_file(int page, const QString &f
 					  "</p></qt>"));
 	else {
 	  kdDebug(4300) << QString("KDVI will now try to use the '%1' device driver.").arg(*gsDevice) << endl;
-	  gs_generate_graphics_file(page, filename);
+	  gs_generate_graphics_file(page, filename, magnification);
 	}
 	return;
       }
     }
   }
-
   emit(setStatusBarText(QString::null));
 }
 
 
-QPixmap *ghostscript_interface::graphics(int page) {
+void ghostscript_interface::graphics(PageNumber page, double dpi, long magnification, QPainter &paint) {
+#ifdef DEBUG_PSGS
+  kdDebug(4300) << "ghostscript_interface::graphics( " << page << ", " << dpi << ", ... ) called." << endl;
+#endif
+
+  resolution   = dpi;
+
+  pixel_page_w = paint.viewport().width();
+  pixel_page_h = paint.viewport().height();
+
   pageInfo *info = pageList.find(page);
 
   // No PostScript? Then return immediately.
-  if ((info == 0) || (info->PostScriptString->isEmpty()))
-    return 0;
-
-  // Gfx exists in the MemoryCache?
-  QPixmap *CachedCopy = MemoryCache.find(page);
-  if (CachedCopy != NULL) 
-    return new QPixmap(*CachedCopy);
-
-  // Gfx exists in the DiskCache?
-  KTempFile *CachedCopyFile = DiskCache.find(page);
-  if (CachedCopyFile != NULL) {
-    QPixmap *MemoryCopy = new QPixmap(CachedCopyFile->name());
-    QPixmap *ReturnCopy = new QPixmap(*MemoryCopy);
-    MemoryCache.insert(page, MemoryCopy);
-    return ReturnCopy;
+  if ((info == 0) || (info->PostScriptString->isEmpty())) {
+#ifdef DEBUG_PSGS
+    kdDebug(4300) << "No PostScript found. Not drawing anything." << endl;
+#endif
+    return;
   }
-
-  // Gfx exists neither in Disk- nor in Memorycache. We have to build
-  // it ourselfes.
+  
   KTempFile *GfxFile = new KTempFile(QString::null,".png");
   GfxFile->setAutoDelete(1);
   GfxFile->close(); // we are want the filename, not the file
-
-  gs_generate_graphics_file(page, GfxFile->name());
-
-  QPixmap *MemoryCopy = new QPixmap(GfxFile->name());
-  QPixmap *ReturnCopy = new QPixmap(*MemoryCopy);
-  MemoryCache.insert(page, MemoryCopy);
-  DiskCache.insert(page, GfxFile);
-  return ReturnCopy;
+  
+  gs_generate_graphics_file(page, GfxFile->name(), magnification);
+  
+  QPixmap MemoryCopy(GfxFile->name());
+  paint.drawPixmap(0, 0, MemoryCopy);
+  return;
 }
 
 
