@@ -34,8 +34,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 } while (0)
 #define GetBits(n)	(BitAcc & ((1<<(n))-1))
 #define ClrBits(n) do {							\
-    BitsAvail -= (n);							\
     BitAcc >>= (n);							\
+    BitsAvail -= (n);							\
 } while (0)
 
 #ifdef DEBUG_FAX
@@ -105,7 +105,7 @@ char *StateNames[] = {
 	NeedBits(11);							\
 	if (GetBits(11) == 0)						\
 	    break;							\
-	ClrBits(11);							\
+	ClrBits(1);							\
     }									\
     ClrBits(11);							\
     goto EOL;								\
@@ -143,7 +143,7 @@ char *StateNames[] = {
 		break;							\
 	    }								\
 	}								\
-	done = 0;							\
+	done = a0 >= lastx;						\
 	while (!done) {		/* then black */			\
 	    LOOKUP(13, BlackTable);					\
 	    switch (TabEnt->State) {					\
@@ -311,13 +311,15 @@ char *StateNames[] = {
 	}								\
     }									\
     if (RunLength) {							\
-	/* expect a final V0 */						\
-	NeedBits(1);							\
-	if (!GetBits(1)) {						\
-	    unexpected("MainTable", LineNum);				\
-	    SKIP_EOL;							\
+	if (RunLength + a0 < lastx) {					\
+	    /* expect a final V0 */					\
+	    NeedBits(1);						\
+	    if (!GetBits(1)) {						\
+		unexpected("MainTable", LineNum);			\
+		SKIP_EOL;						\
+	    }								\
+	    ClrBits(1);							\
 	}								\
-	ClrBits(1);							\
 	SETVAL(0);							\
     }									\
  eol2lab ;								\
@@ -362,8 +364,8 @@ MHexpand(struct pagenode *pn, drawfunc df)
 	pa = runs;
 	a0 = 0;
 	EOLcnt = 0;
-	if (BitsAvail & ~8)	/* skip to byte boundary */
-	    ClrBits(BitsAvail & ~8);
+	if (BitsAvail & 7)	/* skip to byte boundary */
+	    ClrBits(BitsAvail & 7);
 	expand1d();
 	if (RunLength)
 	    SETVAL(0);
