@@ -29,6 +29,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #include <qstring.h>
 #include <kapplication.h>
 #include <klocale.h>
+#include <kdebug.h>
 
 void statusbarupdate(char* name,int width,int height,char* res);
 extern void kfaxerror(const QString& title, const QString& error);
@@ -52,11 +53,11 @@ notefile(const char *name, int type)
 	lastpage->next = newnode;
     lastpage = newnode;
 
-    /*printf("Adding new node%ld\n",newnode);*/
+    // kdDebug() << "Adding new node " << newnode << endl;
 
     newnode->pathname = (char*) malloc (strlen(name) +1);
     if(!newnode->pathname){
-      kfaxerror("Sorry","Out of memory\n");
+      kfaxerror(i18n("Sorry"),i18n("Out of memory\n"));
       exit(1);
     }
 
@@ -109,7 +110,7 @@ notetiff(const char *name)
 
     if ((tf = fopen(name, "r")) == NULL) {
         QString mesg = i18n("Unable to open:\n%1\n").arg(name);
-	kfaxerror("Sorry", mesg);
+	kfaxerror(i18n("Sorry"), mesg);
 	return 0;
     }
 
@@ -145,8 +146,8 @@ notetiff(const char *name)
 
 	if (fseek(tf, IFDoff, SEEK_SET) < 0) {
 	realbad:
-	  str.sprintf("             Invalid tiff file:         \n%s\n",name);
-	  kfaxerror("Sorry",str);
+	  str = i18n("Invalid tiff file:\n%1\n").arg(name);
+	  kfaxerror(i18n("Sorry"),str);
 	bad:
 	    if (strips)
 		free(strips);
@@ -246,9 +247,9 @@ notetiff(const char *name)
 		break;
 	    case 279:		/* StripByteCounts */
 		if (count != nstrips) {
-		  str.sprintf("In file %s\nStrpisPerImage tag 273=%ld,tag279=%ld\n",
-			      name, nstrips,(long int) count);
-		  kfaxerror("Message",str);
+		  str = i18n("In file %1\nStripsPerImage tag 273=%2,tag279=%3\n")
+			      .arg(name).arg(nstrips).arg(count);
+		  kfaxerror(i18n("Message"),str);
 		  goto realbad;
 		}
 		if (count == 1 || (count == 2 && ftype == 3)) {
@@ -287,8 +288,14 @@ notetiff(const char *name)
 	IFDoff = get4(dp, endian);
 	free(dir);
 	dir = NULL;
+	if (comp == 5) {
+          // compression type 5 is LZW compression
+	  kfaxerror(i18n("Sorry"),i18n("Due to patent reasons KFax can not handle LZW (Lempel-Ziv & Welch) "
+		    "compressed Fax files.\n"));
+	    goto bad;
+	}
 	if (comp < 2 || comp > 4) {
-	  kfaxerror("Sorry","This version can only handle Fax files\n");
+	  kfaxerror(i18n("Sorry"),i18n("This version can only handle Fax files\n"));
 	    goto bad;
 	}
 	pn = notefile(name,FAX_TIFF);
@@ -322,7 +329,7 @@ badfile(struct pagenode *pn)
 	perror(pn->pathname);
     if (pn == firstpage) {
       if (pn->next == NULL){
-	  kfaxerror("Sorry","             Bad Fax File          ");
+	  kfaxerror(i18n("Sorry"),i18n("Bad Fax File"));
 	  return;
       }
       else{
@@ -411,8 +418,8 @@ getstrip(struct pagenode *pn, int strip)
 	pn->length = pn->strips[strip].size;
     }
     else {
-      str.sprintf("Trying to expand too many strips\n%s\n",pn->pathname);
-      kfaxerror("Warning",str);
+      str = i18n("Trying to expand too many strips\n%1%n").arg(pn->pathname);
+      kfaxerror(i18n("Warning"),str);
       return NULL;
     }
 
@@ -439,10 +446,9 @@ getstrip(struct pagenode *pn, int strip)
     if (pn->strips == NULL && memcmp(Data, FAXMAGIC, sizeof(FAXMAGIC)) == 0) {
 	/* handle ghostscript / PC Research fax file */
       if (Data[24] != 1 || Data[25] != 0){
-	str.sprintf(
-        "Only the first page of the PC Research multipage file\n%s\nwill be shown\n",
-	pn->pathname);
-	kfaxerror("Message",str);
+	str = i18n("Only the first page of the PC Research multipage file\n%1\nwill be shown\n")
+		.arg(pn->pathname);
+	kfaxerror(i18n("Message"),str);
       }
 	pn->length -= 64;
 	pn->vres = Data[29];
@@ -455,8 +461,8 @@ getstrip(struct pagenode *pn, int strip)
 	pn->height = G3count(pn, pn->expander == g32expand);
     if (pn->height == 0) {
 
-      str.sprintf("No fax found in file:\n%s\n",pn->pathname);
-      kfaxerror("Sorry",str);
+      str = i18n("No fax found in file:\n%1\n").arg(pn->pathname);
+      kfaxerror(i18n("Sorry"),str);
       errno = 0;
       badfile(pn);
       free(Data);
@@ -465,9 +471,8 @@ getstrip(struct pagenode *pn, int strip)
     if (pn->strips == NULL)
 	pn->rowsperstrip = pn->height;
     if (verbose && strip == 0)
-	printf("%s:\n\twidth = %d\n\theight = %d\n\tresolution = %s\n",
-	       pn->name, pn->width, pn->height, pn->vres ?
-	       "fine" : "normal");
+	kdWarning() << pn->name << "\n\twidth = " << pn->width << "\n\theight = "
+		<< pn->height << "\n\tresolution = " << (pn->vres ? "fine" : "normal") << endl;
 //    statusbarupdate(pn->name,pn->width,pn->height,pn->vres ? "fine" : "normal");
     return Data;
 }
