@@ -1,6 +1,6 @@
    /*
 
-    $Id: kfax.cpp,v 1.97.2.2 2004/11/09 19:55:50 deller Exp $
+    $Id: kfax.cpp 378907 2005-01-16 00:28:57Z deller $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -68,6 +68,7 @@
 #include "version.h"
 #include "viewfax.h"
 #include "options.h"
+#include "kfax_printsettings.h"
 
 #include <X11/X.h>
 #include <X11/Xlib.h>
@@ -242,7 +243,7 @@ void TopLevel::setupMenuBar()
           actionCollection() );
   actPrint = KStdAction::print( this, SLOT( print() ), actionCollection() );
   KStdAction::quit( this, SLOT( close() ), actionCollection() );
-  actAdd = new KAction( i18n( "&Add..." ), "filenew", KShortcut(), this,
+  actAdd = new KAction( i18n( "A&dd..." ), "filenew", KShortcut(), this,
       SLOT( faxAdd() ), actionCollection(), "file_add_fax" );
 
   actRecent->setMaxItems( 5 );
@@ -494,7 +495,12 @@ void TopLevel::actualSize()
 
 void loadfile(QString filename)
 {
-  QSize dpi(200,200);
+  // Typical FAX resolutions are:
+  // Standard: 203 dpi x 98 dpi
+  // Fine: 203 dpi x 196 lpi
+  // Super Fine: 203 dpi y 392 lpi,  or
+  //             406 dpi x 392 lpi
+  QSize dpi(203,196);
 
   KFileMetaInfo metaInfo(filename);
   if (metaInfo.isValid() && metaInfo.item("Resolution").isValid())
@@ -675,13 +681,16 @@ void TopLevel::print(){
   int pages, currentpage;
   loadAllPages(pages, currentpage);
 
-  KPrinter printer(true, QPrinter::PrinterResolution);
+  KPrinter printer(true, QPrinter::HighResolution);
   printer.setFullPage( true );
   printer.setUsePrinterResolution( true );
-  printer.setDocName( firstpage->name );
+  printer.setCreator( i18n("KFax") + " " KFAXVERSION );
+  printer.setDocName( QString("%1 - %2").arg(firstpage->name).arg(i18n("KFax")));
+  printer.setDocFileName( firstpage->name );
   printer.setPageSelection( KPrinter::ApplicationSide );
   printer.setMinMax( 1, pages ); 
   printer.setCurrentPage( currentpage );
+  printer.addDialogPage(new KFAXPrintSettings());
   if ( !printer.setup( this ) )
 	return;
 
@@ -699,6 +708,10 @@ void TopLevel::printIt( KPrinter &printer, QPainter &painter )
   QApplication::setOverrideCursor( waitCursor );
   kapp->processEvents();
 
+  const bool fullpage = printer.option(APP_KFAX_SCALE_FULLPAGE) == "true";
+  const bool center_h = printer.option(APP_KFAX_CENTER_HORZ) == "true";
+  const bool center_v = printer.option(APP_KFAX_CENTER_VERT) == "true";
+
   int currentpage = 0;
   bool first_page_printed = false;
   struct pagenode *pn;
@@ -732,42 +745,55 @@ void TopLevel::printIt( KPrinter &printer, QPainter &painter )
       }
     }
 
-    QImage qi( (uchar *)bytes.data(), Image->bytes_per_line*8, Image->height, 1, NULL, 2, QImage::LittleEndian);
+    QImage image( (uchar *)bytes.data(), Image->bytes_per_line*8, Image->height, 1, NULL, 2, QImage::LittleEndian);
 
     if (first_page_printed)
 	printer.newPage();
     first_page_printed = true;
 
-    QSize printersize( dm.width(), dm.height() );
+    const QSize printersize( dm.width(), dm.height() );
     kdDebug() << "Printersize = " << printersize << endl;
     // print Image in original size if possible, else scale it.
 
-    QSize size; // logical size of the image
-    size.setWidth ( Image->width  * dm.logicalDpiX() / pn->dpiX );
-    size.setHeight( Image->height * dm.logicalDpiY() / pn->dpiY );
+    const QSize size(  // logical size of the image
+			Image->width  * dm.logicalDpiX() / pn->dpiX,
+			Image->height * dm.logicalDpiY() / pn->dpiY
+		);
 
-    kdDebug() << "Org image size = " << Image->width << "x" << Image->height << endl;
-    kdDebug() << "New image size = " << size << " logical printer res =" << dm.logicalDpiX() << "x" << dm.logicalDpiY() << endl;
+    kdDebug()	<< "Org image size = " << Image->width << "x" << Image->height 
+		<< " logical picture res = " << pn->dpiX << "x" << pn->dpiY << endl;
+    kdDebug()	<< "New image size = " << size 
+		<< " logical printer res = " << dm.logicalDpiX() << "x" << dm.logicalDpiY() << endl;
 
     uint top, left, bottom, right;
-    printer.margins( &top, &left, &bottom, &right );
+    if (fullpage)
+       top = left = bottom = right = 0;
+    else
+       printer.margins( &top, &left, &bottom, &right );
     kdDebug() << "Margins = " << top << " " << left << " " << bottom << " " << right << endl;
 
-    QSize maxSize( printersize.width()-left-right, printersize.height()-top-bottom );
-    QImage scaledImage;
+    const QSize maxSize( printersize.width()-left-right, printersize.height()-top-bottom );
+    QSize scaledImageSize = size;
     if (size.width() > maxSize.width() || size.height() > maxSize.height() ) {
 	// Image does not fit - scale it and print centered
-	scaledImage = qi.scale( maxSize, QImage::ScaleMin );
+	scaledImageSize.scale( maxSize, QSize::ScaleMin );
 	kdDebug() << "Image does not fit - scaling to " << maxSize << endl;
     } else {
 	// Image does fit - print it in original size, but centered
-	scaledImage = qi.scale( size, QImage::ScaleMin );
+	scaledImageSize.scale( size, QSize::ScaleMin );
 	kdDebug() << "Image does fit - scaling to " << size << endl;
     }
-    kdDebug() << "Final image size " << scaledImage.size() << endl;
-    maxSize -= scaledImage.size();
-    maxSize /= 2;
-    painter.drawImage( left+maxSize.width(), top+maxSize.height(), scaledImage );
+    kdDebug() << "Final image size " << scaledImageSize << endl;
+    int x,y;
+    if (center_h)
+	x = (maxSize.width()-scaledImageSize.width())/2 + left;
+    else
+	x = left;
+    if (center_v)
+	y = (maxSize.height()-scaledImageSize.height())/2 + top;
+    else
+	y = top;
+    painter.drawImage( QRect(x,y,scaledImageSize.width(), scaledImageSize.height()), image );
 
   }
 
@@ -1461,6 +1487,7 @@ void TopLevel::uiUpdate(){
     }
 
     QString resolution = i18n("Res: %1").arg(thispage->vres?i18n("Fine"):i18n("Normal"));
+    // TODO: resolution += QString("%1x%2").arg(thispage->dpiX).arg(thispage->dpiY);
     statusbar->changeItem(resolution, ID_GENERAL);
 
     statusbar->changeItem(thispage->name, ID_FNAME);
@@ -1663,6 +1690,8 @@ int main (int argc, char **argv)
   aboutData.addAuthor( "Bernd Johannes Wuebben", 0, "wuebben@kde.org" );
   aboutData.addCredit( "Nadeem Hasan", I18N_NOOP( "UI Rewrite, lots of code "
       "cleanups and fixes" ), "nhasan@kde.org" );
+  aboutData.addCredit( "Helge Deller", I18N_NOOP( "Printing Rewrite, lots of code "
+      "cleanups and fixes"), "deller@kde.org" );
 
   KCmdLineArgs::init(argc, argv, &aboutData);
   KCmdLineArgs::addCmdLineOptions( options );
