@@ -325,7 +325,9 @@ int ExifData::ReadJpegSections (QFile & infile, ReadMode_t ReadMode)
                 // that uses marker 31 for non exif stuff.  Thus make sure
                 // it says 'Exif' in the section before treating it as exif.
                 if ((ReadMode & READ_EXIF) && memcmp(Data+2, "Exif", 4) == 0){
-                    process_EXIF((uchar *)Data, itemlen);
+                    process_EXIF((uchar *)Data, itemlen); // FIXME: This call
+			// requires Data to be array of at least 8 bytes. Code
+			// above only checks for itemlen < 2.
                 }else{
                     // Discard this section.
                     free(Sections[--SectionsRead].Data);
@@ -345,7 +347,9 @@ int ExifData::ReadJpegSections (QFile & infile, ReadMode_t ReadMode)
             case M_SOF13:
             case M_SOF14:
             case M_SOF15:
-                process_SOFn(Data, marker);
+                process_SOFn(Data, marker); //FIXME: This call requires Data to
+		// be array of at least 8 bytes. Code above only checks for 
+		// itemlen < 2.
             default:
                 break;
                 break;
@@ -575,7 +579,7 @@ void ExifData::ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBa
 
             case TAG_FOCALLENGTH:
                 // Nice digital cameras actually save the focal length as a function
-                // of how farthey are zoomed in.
+                // of how far they are zoomed in.
                 ExifData::FocalLength = (float)ConvertAnyFormat(ValuePtr, Format);
                 break;
 
@@ -601,9 +605,7 @@ void ExifData::ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBa
                 break;
 
             case TAG_FLASH:
-                if (ConvertAnyFormat(ValuePtr, Format)){
-                    ExifData::FlashUsed = 1;
-                }
+		ExifData::FlashUsed = (int)ConvertAnyFormat(ValuePtr, Format);
                 break;
 
             case TAG_EXIF_IMAGELENGTH:
@@ -732,14 +734,7 @@ void ExifData::ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBa
 //--------------------------------------------------------------------------
 void ExifData::process_COM (const uchar * Data, int length)
 {
-    QChar ch;
-    int a;
-
-    for (a=2;a<length;a++){
-        ch = Data[a];
-        if (ch == '\000') continue;                     // Remove nulls
-        Comment.append(ch);
-    }
+    Comment = QString::fromUtf8((char *)Data+2, (length-2));
 }
 
 
@@ -822,6 +817,7 @@ void ExifData::process_EXIF(unsigned char * CharBuf, unsigned int length)
 
     // Compute the CCD width, in milimeters.
     if (FocalplaneXRes != 0){
+	kdDebug(7034) << "ExifImageWidth " << ExifImageWidth << " FocalplaneUnits " << FocalplaneUnits << " FocalplaneXRes " << FocalplaneXRes << endl;
         ExifData::CCDWidth = (float)(ExifImageWidth * FocalplaneUnits / FocalplaneXRes);
     }
 }
@@ -857,7 +853,7 @@ ExifData::ExifData()
 {
     ExifData::Whitebalance = -1;
     ExifData::MeteringMode = -1;
-    ExifData::FlashUsed = -1;
+    ExifData::FlashUsed = 0;
     Orientation = 0;
     Height = 0;
     Width = 0;
@@ -882,8 +878,9 @@ bool ExifData::scan(const QString & path)
     int ret;
 
     QFile f(path);
-    f.open(IO_ReadOnly);
- 
+    if ( !f.open(IO_ReadOnly) )
+        return false;
+
     try {
         // Scan the JPEG headers.
         ret = ReadJpegSections(f, READ_EXIF);
@@ -893,7 +890,7 @@ bool ExifData::scan(const QString & path)
         f.close();
         return false;
     }
- 
+
     if (ret == false){
         kdDebug(7034) << "Not JPEG file!\n";
         DiscardData();
