@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_ps.h,v 1.4 2002/03/22 20:15:30 aseigo Exp $
+ *  $Id: kfile_ps.h 293705 2004-03-05 01:29:20Z luis_pedro $
  */
 
 #ifndef __KFILE_PS_H__
@@ -43,7 +43,7 @@ private:
     KFileMetaInfoGroup _group;
     KDSC* _dsc;
     bool _endComments;
-    bool _setData;
+    int _setData;
 };
 
 #endif
