@@ -21,12 +21,9 @@
 #define __KFILE_TIFF_H_
 
 #include <kfilemetainfo.h>
-#include <kurl.h>
 
 #include <qintdict.h>
 
-class QStringList;
-
 class KTiffPlugin: public KFilePlugin
 {
     Q_OBJECT
