@@ -45,13 +45,23 @@
 typedef KGenericFactory<KGamma, QWidget> KGammaFactory;
 K_EXPORT_COMPONENT_FACTORY ( kcm_kgamma, KGammaFactory( "kgamma" ) )
 
+extern "C"
+{
+	bool test_kgamma()
+	{
+		bool retval;
+		(void) new XVidExtWrap(&retval, NULL);
+		return retval;
+	}
+}
+
 KGamma::KGamma(QWidget *parent, const char *name, const QStringList&)
     :KCModule(parent,name)
 {
   bool ok;
   GammaCorrection = true;
   xv = new XVidExtWrap(&ok, NULL);
-  if (ok) {
+  if (ok) { /* KDE 4: Uneccessary test, when all KCM wrappers do conditional loading */
     xv->getGamma(XVidExtWrap::Red, &ok);
     if (ok) {
       ScreenCount = xv->_ScreenCount();
@@ -143,7 +153,7 @@ void KGamma::setupUI() {
     background.load(locate("data", "kgamma/pics/background.png"));
 
     QLabel *pic1 = new QLabel(stack);
-    pic1->setMinimumSize(570, 220);
+    pic1->setMinimumSize(530, 171);
     pic1->setBackgroundPixmap(background);
     pic1->setPixmap(QPixmap(locate("data", "kgamma/pics/greyscale.png")));
     pic1->setAlignment(AlignCenter);
@@ -183,10 +193,10 @@ void KGamma::setupUI() {
 
     //Sliders for gamma correction
     QFrame *frame1 = new QFrame(this);
-    frame1->setFrameStyle ( QFrame::Box | QFrame::Sunken );
+    frame1->setFrameStyle( QFrame::GroupBoxPanel | QFrame::Plain );
 
     QFrame *frame2 = new QFrame(this);
-    frame2->setFrameStyle ( QFrame::Box | QFrame::Sunken );
+    frame2->setFrameStyle( QFrame::GroupBoxPanel | QFrame::Plain );
 
     QLabel *gammalabel = new QLabel(this);
     gammalabel->setText(i18n("Gamma:"));
@@ -203,24 +213,28 @@ void KGamma::setupUI() {
     gctrl = new GammaCtrl(this, xv);
     connect(gctrl, SIGNAL(gammaChanged(int)), SLOT(Changed()));
     connect(gctrl, SIGNAL(gammaChanged(int)), SLOT(SyncScreens()));
+    gammalabel->setBuddy( gctrl );
 
     rgctrl = new GammaCtrl(this, xv, XVidExtWrap::Red);
     connect(rgctrl, SIGNAL(gammaChanged(int)), SLOT(Changed()));
     connect(rgctrl, SIGNAL(gammaChanged(int)), SLOT(SyncScreens()));
     connect(gctrl, SIGNAL(gammaChanged(int)), rgctrl, SLOT(setCtrl(int)));
     connect(rgctrl, SIGNAL(gammaChanged(int)), gctrl, SLOT(suspend()));
+    redlabel->setBuddy( rgctrl );
 
     ggctrl = new GammaCtrl(this, xv, XVidExtWrap::Green);
     connect(ggctrl, SIGNAL(gammaChanged(int)), SLOT(Changed()));
     connect(ggctrl, SIGNAL(gammaChanged(int)), SLOT(SyncScreens()));
     connect(gctrl, SIGNAL(gammaChanged(int)), ggctrl, SLOT(setCtrl(int)));
     connect(ggctrl, SIGNAL(gammaChanged(int)), gctrl, SLOT(suspend()));
+    greenlabel->setBuddy( ggctrl );
 
     bgctrl = new GammaCtrl(this, xv, XVidExtWrap::Blue);
     connect(bgctrl, SIGNAL(gammaChanged(int)), SLOT(Changed()));
     connect(bgctrl, SIGNAL(gammaChanged(int)), SLOT(SyncScreens()));
     connect(gctrl, SIGNAL(gammaChanged(int)), bgctrl, SLOT(setCtrl(int)));
     connect(bgctrl, SIGNAL(gammaChanged(int)), gctrl, SLOT(suspend()));
+    bluelabel->setBuddy( bgctrl );
 
     QGridLayout *grid = new QGridLayout(4, 9);
     grid->setSpacing(8);
