@@ -1,13 +1,13 @@
 /* Copyright (C) 2000-2001, Ghostgum Software Pty Ltd.  All rights reserved.
-  
+    
   This file is part of GSview.
-  
+   
   This file is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
   to anyone for the consequences of using it or for whether it serves any
   particular purpose or works at all, unless he says so in writing.  Refer
   to the GNU General Public Licence for full details.
-  
+   
   Everyone is granted permission to copy, modify and redistribute this
   file, but only under the conditions described in the GNU General
   Public Licence.  A copy of this license is supposed to have been given
@@ -17,6 +17,8 @@
   copies.
 */
 
+/* $Id: dscparse.cpp 420740 2005-06-01 09:16:37Z wgreven $ */
+
 /* dscparse.c - DSC parser  */
 
 /*
@@ -148,15 +150,53 @@ dsc_private const int dsc_severity[] = {
 const CDSCMEDIA dsc_known_media[CDSC_KNOWN_MEDIA] = {
     /* These sizes taken from Ghostscript gs_statd.ps */
     {"11x17", 792, 1224, 0, NULL, NULL, NULL},
+    {"A0", 2380, 3368, 0, NULL, NULL, NULL},
+    {"A1", 1684, 2380, 0, NULL, NULL, NULL}, 
+    {"A2", 1190, 1684, 0, NULL, NULL, NULL}, 
     {"A3", 842, 1190, 0, NULL, NULL, NULL},
     {"A4", 595, 842, 0, NULL, NULL, NULL},
     {"A5", 421, 595, 0, NULL, NULL, NULL},
+    {"A6", 297, 421, 0, NULL, NULL, NULL}, 
+    {"A7", 210, 297, 0, NULL, NULL, NULL}, 
+    {"A8", 148, 210, 0, NULL, NULL, NULL}, 
+    {"A9", 105, 148, 0, NULL, NULL, NULL}, 
+    {"A10", 74, 105, 0, NULL, NULL, NULL}, 
+    {"B0", 2836, 4008, 0, NULL, NULL, NULL}, 
+    {"B1", 2004, 2836, 0, NULL, NULL, NULL}, 
+    {"B2", 1418, 2004, 0, NULL, NULL, NULL}, 
+    {"B3", 1002, 1418, 0, NULL, NULL, NULL}, 
     {"B4", 709, 1002, 0, NULL, NULL, NULL}, /* ISO, but not Adobe standard */
     {"B5", 501, 709, 0, NULL, NULL, NULL},  /* ISO, but not Adobe standard */
+    {"B6", 354, 501, 0, NULL, NULL, NULL}, 
+    {"C0", 2600, 3677, 0, NULL, NULL, NULL}, 
+    {"C1", 1837, 2600, 0, NULL, NULL, NULL},  
+    {"C2", 1298, 1837, 0, NULL, NULL, NULL}, 
+    {"C3", 918, 1298, 0, NULL, NULL, NULL}, 
+    {"C4", 649, 918, 0, NULL, NULL, NULL}, 
+    {"C5", 459, 649, 0, NULL, NULL, NULL}, 
+    {"C6", 323, 459, 0, NULL, NULL, NULL}, 
     {"Ledger", 1224, 792, 0, NULL, NULL, NULL},
     {"Legal", 612, 1008, 0, NULL, NULL, NULL},
     {"Letter", 612, 792, 0, NULL, NULL, NULL},
     {"Note", 612, 792, 0, NULL, NULL, NULL},
+// ISO and JIS B sizes are different....
+    {"jisb0", 2916, 4128, 0, NULL, NULL, NULL},
+    {"jisb1", 2064, 2916, 0, NULL, NULL, NULL}, 
+    {"jisb2", 1458, 2064, 0, NULL, NULL, NULL}, 
+    {"jisb3", 1032, 1458, 0, NULL, NULL, NULL}, 
+    {"jisb4", 729, 1032, 0, NULL, NULL, NULL}, 
+    {"jisb5", 516, 729, 0, NULL, NULL, NULL}, 
+    {"jisb6", 363, 516, 0, NULL, NULL, NULL}, 
+// U.S. CAD standard paper sizes
+    {"archE", 2592, 3456, 0, NULL, NULL, NULL}, 
+    {"archD", 1728, 2592, 0, NULL, NULL, NULL}, 
+    {"archC", 1296, 1728, 0, NULL, NULL, NULL}, 
+    {"archB", 864, 1296, 0, NULL, NULL, NULL}, 
+    {"archA", 648, 864, 0, NULL, NULL, NULL}, 
+// Other paper sizes
+    {"flsa", 612, 936, 0, NULL, NULL, NULL}, /* U.S. foolscap */
+    {"flse", 612, 936, 0, NULL, NULL, NULL}, /* European foolscap */
+    {"halfletter", 396, 612, 0, NULL, NULL, NULL}, 
     {NULL, 0, 0, 0, NULL, NULL, NULL}
 };
 
@@ -3385,3 +3425,5 @@ dsc_error(CDSC *dsc, unsigned int explanation,
     return CDSC_RESPONSE_CANCEL;
 }
 
+
+// vim:sw=4:sts=4:ts=8:noet
