@@ -68,7 +68,6 @@ public:
     KGVPageView*      pageView()      const { return _pageView;      }
     KGVPageDecorator* pageDecorator() const { return _pageDecorator; }
     KGVDocument*      document()      const { return _document;      }
-    const KGVConfigDialog* configDialog()   { return _configDialog;  }
 
 
     /**
@@ -77,7 +76,7 @@ public:
      */
     virtual bool closeURL();
 
-    static KAboutData* createAboutData();
+    KDE_EXPORT static KAboutData* createAboutData();
 
 public slots:
     /**
@@ -102,6 +101,7 @@ public slots:
     void slotScrollUp();
     void slotScrollDown();
     void slotReadDown();
+    void slotFlicker();
     void slotReadUp();
     void slotPrevPage();
     void slotNextPage();
@@ -123,6 +123,7 @@ public slots:
     void slotZoom( const QString& );
 
     void slotConfigure();
+    void slotConfigurationChanged();
 
     /**
      * Sets the display options in a sticky way.
@@ -181,7 +182,6 @@ private:
     MarkList*	      _markList;
     KGVMiniWidget*    _docManager;
 
-    KGVConfigDialog* _configDialog;
     LogWindow*       _logWindow;
 
     QTimer*		_fitTimer;
@@ -202,6 +202,7 @@ private:
     KAction*       _gotoPage;
     KToggleAction* _showScrollBars;
     KToggleAction* _watchFile;
+    KToggleAction* _flick;
     KToggleAction* _showPageList;
     KToggleAction* _showPageLabels;
     KPopupMenu*    _popup;
