@@ -34,6 +34,7 @@
 #include <klocale.h>
 #include <kdebug.h>
 
+#include "configuration.h"
 #include "kdscerrordialog.h"
 #include "kgv_miniwidget.h"
 #include "marklist.h"
@@ -73,9 +74,7 @@ KGVDocument::~KGVDocument()
 
 void KGVDocument::readSettings()
 {
-    _interpreterPath = 
-            KConfigGroup( KGVFactory::instance()->config(), "Ghostscript" )
-                        .readPathEntry( "Interpreter" );
+    _interpreterPath = Configuration::interpreter();
 }
 
 /*- OPENING and READING ---------------------------------------------------*/
