@@ -13,10 +13,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include "kgvmainwidget.h"
+#include <kurl.h>
+#include <kurldrag.h>
 
 KGVMainWidget::KGVMainWidget( QWidget* parent, const char* name )
   : QWidget( parent, name ) {}
@@ -29,4 +31,20 @@ void KGVMainWidget::keyPressEvent( QKeyEvent* event )
     }
 }
 
+void KGVMainWidget::dropEvent( QDropEvent* ev )
+{
+    KURL::List lst;
+    if (  KURLDrag::decode(  ev, lst ) ) {
+	emit urlDropped( lst.first() );
+    }
+}
+
+
+void KGVMainWidget::dragEnterEvent( QDragEnterEvent * ev )
+{
+    ev->accept();
+}
+
 #include "kgvmainwidget.moc"
+
+// vim:sw=4:sts=4:ts=8:noet
