@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KGVMAINWIDGET_H
@@ -21,6 +21,8 @@
 
 #include <qwidget.h>
 
+class KURL;
+
 class KGVMainWidget : public QWidget
 {
     Q_OBJECT
@@ -30,9 +32,14 @@ public:
 
 signals:
     void spacePressed();
+    void urlDropped( const KURL& );
 
 protected:
     virtual void keyPressEvent( QKeyEvent* );
+    virtual void dragEnterEvent( QDragEnterEvent* );
+    virtual void dropEvent( QDropEvent* );
 };
 
 #endif
+
+// vim:sw=4:sts=4:ts=8:noet
