@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -50,8 +50,7 @@ public:
     void enableScrollBars( bool);
     
     /**
-     * Reimplemented from QScrollView. It enables scrolling by dragging the
-     * page with the mouse.
+     * @reimplemented
      */
     bool eventFilter( QObject*, QEvent* );
     
@@ -66,35 +65,41 @@ public slots:
     void scrollTop();
   
 signals:
-    void viewSizeChanged( QSize size );
-    void pageSizeChanged( QSize size );
+    void viewSizeChanged( const QSize& );
+    void pageSizeChanged( const QSize& );
     void nextPage();
     void zoomOut();
     void zoomIn();
     void prevPage();
+    void rightClick();
     void ReadUp();
     void ReadDown();
-    
+
 protected:
     virtual void keyPressEvent( QKeyEvent* );
-    
+
     /**
-     * Reimplemented to from QScrollView to make sure that the page is centered 
+     * Reimplemented to from QScrollView to make sure that the page is centered
      * when it fits in the viewport.
      */
     virtual void viewportResizeEvent( QResizeEvent* );
-    
+
+    virtual void mousePressEvent( QMouseEvent *e );
+    virtual void mouseReleaseEvent( QMouseEvent *e );
+    virtual void mouseMoveEvent( QMouseEvent *e );
     virtual void wheelEvent( QWheelEvent * );
 
     /**
-     * If the viewport is larger than the page, center the page on the 
+     * If the viewport is larger than the page, center the page on the
      * viewport.
      */
     void centerContents();
-    
+
 private:
     QPoint   _dragGrabPos;
     QWidget* _page;
 };
 
 #endif
+
+// vim:sw=4:sts=4:ts=8:noet
