@@ -194,6 +194,22 @@ void
 KGVShell::readSettings()
 {
     recent->loadEntries( KGlobal::config() );
+    QStringList items = recent->items();
+
+// Code copied from kviewshell.cpp:
+// Constant source of annoyance in KDVI < 1.0: the 'recent-files'
+// menu contains lots of files which don't exist (any longer). Thus,
+// we'll sort out the non-existent files here.
+
+    for ( QStringList::Iterator it = items.begin(); it != items.end(); ++it ) {
+        KURL url(*it);
+        if (url.isLocalFile()) {
+            QFileInfo info(url.path());
+            if (!info.exists())
+                recent->removeURL(url);
+        }
+    }
+
     applyMainWindowSettings(KGlobal::config(), "MainWindow");
 
     KGlobal::config()->setDesktopGroup();
