@@ -35,7 +35,7 @@ class KPopupMenu;
 class DisplayOptions;
 class FullScreenFilter;
 
-class KGVShell : public KParts::MainWindow
+class KDE_EXPORT KGVShell : public KParts::MainWindow
 {
     Q_OBJECT
 
@@ -53,14 +53,13 @@ protected slots:
     void slotFileOpen();
     void slotShowMenubar();
     void slotQuit();
-    void slotFitToPage();
-    void slotFitToScreen();
-    void slotDoFitToScreen();
     void slotMaximize();
     void slotResize();
     void slotUpdateFullScreen();
     void slotReset();
     void slotDocumentState();
+    void slotConfigureToolbars();
+    void slotNewToolbarConfig();
 
 protected:
     // session management
@@ -79,8 +78,6 @@ private:
     KGVPart* m_gvpart;
     QString cwd;
 
-    QTimer* mFitTimer;
-
     KAction* openact;
     KToggleAction* _showMenuBarAction;
     KToggleAction* m_fullScreenAction;
