@@ -29,7 +29,7 @@
 #include <kmessagebox.h>
 #include <kprocess.h>
 
-#include "kgvconfigdialog.h"
+#include "configuration.h"
 
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -63,16 +63,16 @@ int orientation2angle( CDSC_ORIENTATION_ENUM orientation )
     return angle;
 }
 
-QCString palette2String( KPSWidget::Palette palette )
+QCString palette2String( Configuration::EnumPalette::type palette )
 {
     QCString str;
 
     switch( palette )
     {
-    case KPSWidget::COLOR:      str = "Color";      break;
-    case KPSWidget::GRAYSCALE:  str = "Grayscale";  break;
-    case KPSWidget::MONOCHROME: str = "Monochrome"; break;
-    default: kdWarning( 4500 ) << "palette2String(): unkown palette" << endl;
+	case Configuration::EnumPalette::Color:      str = "Color";      break;
+	case Configuration::EnumPalette::Grayscale:  str = "Grayscale";  break;
+	case Configuration::EnumPalette::Monochrome: str = "Monochrome"; break;
+	default: kdWarning( 4500 ) << "palette2String(): unkown palette" << endl;
 	     str = "Color";
     }
 
@@ -88,11 +88,10 @@ KPSWidget::KPSWidget( QWidget* parent, const char* name ) :
     _ghostscriptDirty ( false ),
     _orientation      ( CDSC_PORTRAIT ),
     _magnification    ( 1 ),
-    _palette          ( COLOR ),
+    _palette          ( Configuration::EnumPalette::Color ),
     _widgetDirty      ( true ),
     _process          ( 0 ),
-    _currentRecord    ( 0 ),
-    _inputBuffer      ( 0 ),
+    _buffer           ( 0 ),
     _stdinReady       ( false ),
     _interpreterBusy  ( false ),
     _interpreterReady ( false )
@@ -110,8 +109,8 @@ KPSWidget::KPSWidget( QWidget* parent, const char* name ) :
 
 KPSWidget::~KPSWidget()
 {
+    if ( _buffer ) operator delete( _buffer );
     stopInterpreter();
-    if ( _inputBuffer ) free( _inputBuffer );
 }
 
 bool KPSWidget::isInterpreterReady() const
@@ -158,7 +157,7 @@ bool KPSWidget::nextPage()
 
 void KPSWidget::clear()
 {
-    _backgroundPixmap.fill();
+    //_backgroundPixmap.fill();
 }
 
 
@@ -170,12 +169,7 @@ bool KPSWidget::sendPS( FILE* fp, unsigned int begin, unsigned int end )
 	return false;
 
     // Create a new record to add to the queue.
-    Record* ps_new = new Record;
-    ps_new->fp = fp;
-    ps_new->begin = begin;
-    ps_new->len = end - begin;
-
-    _inputQueue.enqueue( ps_new );
+    _inputQueue.push( Record( fp, begin, end - begin ) );
 
     // Start processing the queue.
     if( _stdinReady )
@@ -186,6 +180,7 @@ bool KPSWidget::sendPS( FILE* fp, unsigned int begin, unsigned int end )
 
 void KPSWidget::setGhostscriptPath( const QString& path )
 {
+    kdDebug() << "KPSWidget::setGhostscriptPath( " << path << " )" << endl;
     if( _ghostscriptPath != path )
     {
 	_ghostscriptPath = path;
@@ -245,7 +240,7 @@ void KPSWidget::setMagnification( double magnification )
     }
 }
 
-void KPSWidget::setPalette( Palette palette )
+void KPSWidget::setPalette( Configuration::EnumPalette::type palette )
 {
     if( _palette != palette )
     {
@@ -406,15 +401,7 @@ void KPSWidget::stopInterpreter()
 	_process->kill( SIGHUP );
 
     _process = 0;
-
-    if( _currentRecord != 0 )
-    {
-	delete _currentRecord;
-	_currentRecord = 0;
-    }
-    _inputQueue.setAutoDelete( true );
-    _inputQueue.clear();
-    _inputQueue.setAutoDelete( false );
+    while ( !_inputQueue.empty() ) _inputQueue.pop();
 
     _interpreterBusy = false;
     unsetCursor();
@@ -450,82 +437,67 @@ void KPSWidget::gs_output( KProcess*, char* buffer, int len )
 
 void KPSWidget::gs_input( KProcess* process )
 {
-    kdDebug(4500) << "KPSWidget: gs_input" << endl;
+    kdDebug(4500) << "KPSWidget::gs_input" << endl;
 
     if (process != _process)
     {
       kdDebug(4500) << "KPSWidget::gs_input(): process != _process" << endl;
       return;
     }
-    
     _stdinReady = true;
-    const unsigned bufferSize = 8192;
 
-
-    // Get a Record with size greater than 0 from the queue 
-    while( ( !_currentRecord || _currentRecord->len == 0 ) && !_inputQueue.isEmpty() )
-    {
-	if( _currentRecord != 0 ) 
-	    delete _currentRecord;
-	_currentRecord = _inputQueue.dequeue();
+    while( ! _inputQueue.empty() && _inputQueue.front().len == 0 ) _inputQueue.pop();
+    if( _inputQueue.empty() ) {
+	_interpreterReady = true;
+	return;
     }
-    if( !_currentRecord ) return;
 
-    if ( fseek( _currentRecord->fp, _currentRecord->begin, SEEK_SET ) ) {
+    Record& current = _inputQueue.front();
+
+    if ( fseek( current.fp, current.begin, SEEK_SET ) ) {
 	kdDebug(4500) << "KPSWidget::gs_input(): seek failed!" << endl;
 	interpreterFailed();
 	return;
     }
-    if( _currentRecord && _currentRecord->len > 0 )
-    {
-	if( _inputBuffer == 0 )
-	    _inputBuffer = (char *) malloc(bufferSize);
+    Q_ASSERT( current.len > 0 );
 
-	const int bytesRead = fread( _inputBuffer, sizeof (char), 
-	                       QMIN( bufferSize, _currentRecord->len ), 
-			       _currentRecord->fp );
-	if( bytesRead > 0 ) 
-	{
-	    _currentRecord->begin += bytesRead;
-	    _currentRecord->len -= bytesRead;
-	    if( process && process->writeStdin( _inputBuffer, bytesRead ) )
-		_stdinReady = false;
-	    else
-		interpreterFailed();
-	}
+    const unsigned buffer_size = 4096;
+    if ( !_buffer ) _buffer = static_cast<char*>( operator new( buffer_size ) );
+    const int bytesRead = fread( _buffer, sizeof (char), 
+	    QMIN( buffer_size, current.len ),
+	    current.fp );
+    if( bytesRead > 0 ) 
+    {
+	current.begin += bytesRead;
+	current.len -= bytesRead;
+	if( process && process->writeStdin( _buffer, bytesRead ) )
+	    _stdinReady = false;
 	else
 	    interpreterFailed();
     }
-    else 
-	_interpreterReady = true;
+    else
+	interpreterFailed();
 }
 
-void KPSWidget::readSettings( const KGVConfigDialog* intConfig )
+void KPSWidget::readSettings()
 {
-    setGhostscriptPath( intConfig->interpreterPath() );
+    setGhostscriptPath( Configuration::interpreter() );
 
     QStringList arguments;
 
-    if( intConfig->antiAlias() )
-	arguments = QStringList::split( " ", intConfig->antialiasArgs() );
+    if( Configuration::antialiasing() )
+	arguments = QStringList::split( " ", Configuration::antialiasingArguments() );
     else
-	arguments = QStringList::split( " ", intConfig->nonAntialiasArgs() );
+	arguments = QStringList::split( " ", Configuration::nonAntialiasingArguments() );
 
-    if( !intConfig->platformFonts() )
+    if( !Configuration::platformFonts() )
 	arguments << "-dNOPLATFONTS";
 
     arguments << "-dNOPAUSE" << "-dQUIET" << "-dSAFER" << "-dPARANOIDSAFER";
 
     setGhostscriptArguments( arguments );
 
-    switch( intConfig->paletteType() )
-    {
-    case KGVConfigDialog::COLOR_PALETTE: setPalette( COLOR );      break;
-    case KGVConfigDialog::GRAY_PALETTE:  setPalette( GRAYSCALE );  break;
-    case KGVConfigDialog::MONO_PALETTE:  setPalette( MONOCHROME ); break;
-    default: kdWarning( 4500 ) << "KPSWidget::readSettings(): Unkown palletteType() [ " << intConfig->paletteType() << " ]\n";
-	     setPalette( COLOR );
-    }
+    setPalette( static_cast<Configuration::EnumPalette::type>( Configuration::palette() ) );
 }
 
 bool KPSWidget::x11Event( XEvent* e )
