@@ -19,13 +19,14 @@
 #ifndef __KPSWIDGET_H__
 #define __KPSWIDGET_H__
 
-#include <qptrqueue.h>
+#include <queue>
 #include <qstring.h>
 #include <qstringlist.h>
 #include <qwidget.h>
 #include <qpixmap.h>
 
 #include "dscparse_adapter.h"
+#include "configuration.h"
 #undef min
 
 #include <X11/X.h>
@@ -48,8 +49,6 @@ class KPSWidget : public QWidget
     Q_OBJECT
 
 public:
-    enum Palette { COLOR, GRAYSCALE, MONOCHROME };
-
     KPSWidget( QWidget* parent = 0, const char* name = 0 );
     ~KPSWidget();
 
@@ -131,8 +130,6 @@ public:
      */
     CDSC_ORIENTATION_ENUM orientation() const;
 
-    void readSettings( const KGVConfigDialog* );
-
     /**
      * Double buffering means that all the drawing is done outside the
      * screen and the finished picture is then flashed to the screen.
@@ -146,6 +143,11 @@ public:
 
     void clear();
 
+public slots:
+    /**
+     * Call this when the settings have changed.
+     */
+    void readSettings();
 signals:
     /**
      * This signal gets emited whenever a page is finished, but contains a reference to the pixmap
@@ -171,6 +173,9 @@ signals:
 protected:
     struct Record 
     {
+	Record( FILE* fp_, long begin_, unsigned len_ )
+	    :fp( fp_ ), begin( begin_ ), len( len_ ) { }
+
 	FILE* fp;
 	long begin;
 	unsigned int len;
@@ -193,7 +198,7 @@ protected:
     
     void setGhostscriptPath( const QString& );
     void setGhostscriptArguments( const QStringList& );
-    void setPalette( Palette );
+    void setPalette( Configuration::EnumPalette::type );
 
 protected slots:
     void gs_input( KProcess* );
@@ -233,7 +238,7 @@ private:
     CDSC_ORIENTATION_ENUM _orientation;
     KDSCBBOX              _boundingBox;
     float                 _magnification;
-    Palette               _palette;
+    Configuration::EnumPalette::type _palette;
 
     /**
      * Flag set when one of the properties _orientation, _boundingBox,
@@ -242,10 +247,9 @@ private:
     bool _widgetDirty;
 
     KProcess* _process;
+    char* _buffer;
  
-    QPtrQueue<Record> _inputQueue;
-    Record*           _currentRecord;
-    char*             _inputBuffer;
+    std::queue<Record> _inputQueue;
 
     bool _stdinReady;
     bool _interpreterBusy;
