@@ -245,9 +245,12 @@ KBackgroundConfig::KBackgroundConfig( QWidget* parent )
   QVBoxLayout *mainLayout = new QVBoxLayout( this );
 
   QGroupBox *grp1 = new QGroupBox( i18n( "Select Background" ), this );
+  grp1->setColumnLayout(0, Qt::Vertical );
+  grp1->layout()->setSpacing( KDialog::spacingHint() );
+  grp1->layout()->setMargin( KDialog::marginHint() );
   mainLayout->addWidget( grp1 );
 
-  QGridLayout *grp1Layout = new QGridLayout( grp1, 3, 2, 15 );
+  QGridLayout *grp1Layout = new QGridLayout( grp1->layout(), 3, 2 );
 
   QButtonGroup* btngrp = new QButtonGroup( grp1 );
   btngrp->setExclusive( true );
@@ -376,23 +379,90 @@ KMiscConfig::KMiscConfig(QWidget *parent) : QWidget(parent)
 
   KIconEditProperties* props = KIconEditProperties::self();
 
-  QBoxLayout *ml = new QVBoxLayout( this );
+  QBoxLayout *ml = new QVBoxLayout( this, 0, 5 );
 
-  QGroupBox *grp1 = new QGroupBox( i18n( "Paste Mode" ), this );
-  grp1->setColumnLayout( 0, Qt::Horizontal );
-  ml->addWidget(grp1);
-
-  QBoxLayout *l1 = new  QVBoxLayout(grp1->layout(), KDialog::spacingHint());
-
-  QCheckBox *cbp = new QCheckBox( i18n( "Paste transparent pixels" ), grp1 );
+  QCheckBox *cbp = new QCheckBox( i18n( "Paste &transparent pixels" ), this );
   connect( cbp, SIGNAL( toggled( bool ) ), SLOT( pasteMode( bool ) ) );
-  l1->addWidget(cbp);
+  ml->addWidget(cbp);
 
-  QCheckBox *cbr = new QCheckBox( i18n( "Show rulers" ), grp1 );
+  QCheckBox *cbr = new QCheckBox( i18n( "Show &rulers" ), this );
   connect( cbr, SIGNAL( toggled( bool ) ), SLOT( showRulers( bool ) ) );
-  l1->addWidget(cbr);
+  ml->addWidget(cbr);
 
-  l1->addStretch(1);
+  QButtonGroup* btngrp = new QButtonGroup( i18n( "Transparency Display" ), this);
+  btngrp->setExclusive( true );
+  connect( btngrp, SIGNAL( clicked( int ) ), SLOT( slotTransparencyDisplayType( int ) ) );
+  ml->addWidget( btngrp );
+
+  QVBoxLayout *tgl = new QVBoxLayout( btngrp, KDialog::marginHint(), KDialog::spacingHint() );
+  tgl->insertSpacing(0, 10);
+
+  QHBoxLayout *hl = new QHBoxLayout(tgl);
+
+  QRadioButton *solidColorRButton = new QRadioButton( i18n( "&Solid color:" ), btngrp );
+  btngrp->insert( solidColorRButton, 0 );
+  hl->addWidget( solidColorRButton );
+
+  m_solidColorButton = new KColorButton(props->transparencySolidColor(), btngrp);
+  btngrp->insert( m_solidColorButton, 2 );
+  hl->addWidget(m_solidColorButton);
+  //connect(btcolor, SIGNAL(changed(const QColor &)), 
+    //  SLOT( selectColor(const QColor &)));
+
+  QRadioButton *checkerboardRButton = new QRadioButton( i18n( "Checker&board" ), btngrp );
+  btngrp->insert( checkerboardRButton, 1 );
+  tgl->addWidget( checkerboardRButton );
+
+  QGridLayout *grid = new QGridLayout(tgl, 3, 3);
+  grid->addColSpacing(0, 40);
+  grid->setColStretch(1, 1);
+  grid->setColStretch(2, 1);
+
+  m_checkerboardSizeCombo = new QComboBox(btngrp);
+  m_checkerboardSizeCombo->insertItem( i18n( "Small" ) );
+  m_checkerboardSizeCombo->insertItem( i18n( "Medium" ) );
+  m_checkerboardSizeCombo->insertItem( i18n( "Large" ) );
+  m_checkerboardSizeCombo->setCurrentItem(props->checkerboardSize());
+
+  QLabel *label = new QLabel(m_checkerboardSizeCombo, i18n("Si&ze:"), btngrp);
+
+  grid->addWidget(label, 0, 1);
+  grid->addWidget(m_checkerboardSizeCombo, 0, 2);
+
+  m_checkerboardColor1Button = new KColorButton(props->checkerboardColor1(), btngrp);
+  label = new QLabel(m_checkerboardColor1Button, i18n("Color &1:"), btngrp);
+
+  grid->addWidget(label, 1, 1);
+  grid->addWidget(m_checkerboardColor1Button, 1, 2);
+
+  m_checkerboardColor2Button = new KColorButton(props->checkerboardColor2(), btngrp);
+  label = new QLabel(m_checkerboardColor2Button, i18n("Color &2:"), btngrp);
+
+  grid->addWidget(label, 2, 1);
+  grid->addWidget(m_checkerboardColor2Button, 2, 2);
+
+  if(props->transparencyDisplayType() == KIconEditGrid::TRD_CHECKERBOARD)
+  {
+    checkerboardRButton->setChecked(true);
+    m_checkerboardColor1Button->setEnabled(true);
+    m_checkerboardColor2Button->setEnabled(true);
+    m_checkerboardSizeCombo->setEnabled(true);
+
+    solidColorRButton->setChecked(false);
+    m_solidColorButton->setEnabled(false);
+  }
+  else
+  {
+    checkerboardRButton->setChecked(false);
+    m_checkerboardColor1Button->setEnabled(false);
+    m_checkerboardColor2Button->setEnabled(false);
+    m_checkerboardSizeCombo->setEnabled(false);
+
+    solidColorRButton->setChecked(true);
+    m_solidColorButton->setEnabled(true);
+  }
+
+  ml->addStretch(1);
 
   cbp->setChecked( props->pasteTransparent() );
   cbr->setChecked( props->showRulers() );
@@ -409,6 +479,18 @@ void KMiscConfig::saveSettings()
   KIconEditProperties* props =  KIconEditProperties::self();
   props->setPasteTransparent( pastemode );
   props->setShowRulers( showrulers );
+  if(m_solidColorButton->isEnabled())
+  {
+    props->setTransparencyDisplayType(KIconEditGrid::TRD_SOLIDCOLOR);
+    props->setTransparencySolidColor(m_solidColorButton->color());
+  }
+  else
+  {
+    props->setTransparencyDisplayType(KIconEditGrid::TRD_CHECKERBOARD);
+    props->setCheckerboardColor1(m_checkerboardColor1Button->color());
+    props->setCheckerboardColor2(m_checkerboardColor2Button->color());
+    props->setCheckerboardSize((KIconEditGrid::CheckerboardSize)m_checkerboardSizeCombo->currentItem());
+  }
 }
 
 void KMiscConfig::pasteMode(bool mode)
@@ -421,6 +503,27 @@ void KMiscConfig::showRulers(bool mode)
   showrulers = mode;
 }
 
+void KMiscConfig::slotTransparencyDisplayType(int id)
+{
+  if(id == 0)
+  {
+    m_checkerboardColor1Button->setEnabled(false);
+    m_checkerboardColor2Button->setEnabled(false);
+    m_checkerboardSizeCombo->setEnabled(false);
+
+    m_solidColorButton->setEnabled(true);
+  }
+  else
+  if(id == 1)
+  {
+    m_checkerboardColor1Button->setEnabled(true);
+    m_checkerboardColor2Button->setEnabled(true);
+    m_checkerboardSizeCombo->setEnabled(true);
+
+    m_solidColorButton->setEnabled(false);
+  }
+}
+
 KIconConfig::KIconConfig(QWidget *parent)
   : KDialogBase(KDialogBase::IconList, i18n("Configure"),
                          KDialogBase::Help |
