@@ -24,11 +24,6 @@
 #include <qpixmap.h>
 #include <kdialogbase.h>
 
-class KAccel;
-class KKeyChooser;
-class KColorButton;
-class KURLRequester;
-
 #include "knew.h"
 #include "utils.h"
 #include "properties.h"
@@ -37,24 +32,28 @@ class KURLRequester;
 #include "config.h"
 #endif
 
-class KTemplateEditDlg : public KDialog
+class KAccel;
+class KKeyChooser;
+class KColorButton;
+class KURLRequester;
+class QComboBox;
+
+class KTemplateEditDlg : public KDialogBase
 {
   Q_OBJECT
 public:
   KTemplateEditDlg(QWidget *);
   ~KTemplateEditDlg() {};
 
-  QString getName();
-  QString getPath();
+  QString name();
+  QString path();
   void setName(const QString &);
   void setPath(const QString &);
   
 public slots:
-  void slotTextChanged(const QString &);
-  void slotBrowse();
+  void slotTextChanged();
 
 protected:
-  QPushButton *ok, *cancel;
   QLineEdit *ln_name;
   KURLRequester *ln_path;
 };
@@ -118,12 +117,17 @@ public slots:
   void showRulers(bool);
 
 protected slots:
+  void slotTransparencyDisplayType(int);
 
 signals:
 
 protected:
   bool pastemode, showrulers;
   QRadioButton *rbp;
+  KColorButton *m_solidColorButton;
+  KColorButton *m_checkerboardColor1Button;
+  KColorButton *m_checkerboardColor2Button;
+  QComboBox *m_checkerboardSizeCombo;
 };
 
 class KIconConfig : public KDialogBase
