@@ -52,7 +52,7 @@ KIconEdit::KIconEdit(KURL url, const char *name)
 
 void KIconEdit::init()
 {
-  setMinimumSize( 600, 500 );
+  setMinimumSize( 600, 540 );
 
   windowList.append(this);
   setCaption(kapp->caption());
@@ -151,7 +151,6 @@ void KIconEdit::init()
 
 KIconEdit::~KIconEdit()
 {
-    kdDebug(4640) << "Deleting KIconEdit: " << (int)this << endl;
     windowList.remove(this);
 
     if (windowList.count() < 1)
@@ -240,7 +239,7 @@ void KIconEdit::setupActions()
   KShortcut cut;
 
   // File Menu
-  action = new KAction(i18n("New &Window"), "newwin", cut,
+  action = new KAction(i18n("New &Window"), "window_new", cut,
       this,  SLOT(slotNewWin()), actionCollection(), "file_new_window");
   action->setWhatsThis(i18n("New window\n\nOpens a new icon editor window."));
 
