@@ -60,7 +60,7 @@ class KIconEdit : public KMainWindow
 {
     Q_OBJECT
 public:
-  KIconEdit( KURL url = "", const char *name = "kiconedit");
+  KIconEdit( KURL url = KURL(), const char *name = "kiconedit");
   KIconEdit( const QImage image, const char *name = "kiconedit");
   ~KIconEdit();
 
