@@ -58,6 +58,12 @@ void KIconEdit::updateProperties()
             ->setBackgroundColor(props->bgColor());
         m_paletteToolBar->setPreviewBackground(props->bgColor());
     }
+    grid->setTransparencyDisplayType(props->transparencyDisplayType());
+    grid->setTransparencySolidColor(props->transparencySolidColor());
+    grid->setCheckerboardColor1(props->checkerboardColor1());
+    grid->setCheckerboardColor2(props->checkerboardColor2());
+    grid->setCheckerboardSize(props->checkerboardSize());
+    grid->update();
 }
 
 void KIconEdit::slotNewWin(const QString & url)
@@ -114,7 +120,7 @@ void KIconEdit::slotNew()
             else if(r == KNewIcon::Template)
             {
                 QString str = newicon.templatePath();
-                icon->open(&grid->image(), str);
+                icon->open(&grid->image(), KURL( str ));
             }
             icon->setUrl("");
             emit newname(i18n("Untitled"));
@@ -299,7 +305,7 @@ void KIconEdit::slotOpenRecent(const KURL& iconFile)
 
     if( !cancel )
     {
-        if(icon->open(&grid->image(), iconFile.url()))
+        if(icon->open(&grid->image(), iconFile))
         {
             grid->setModified(false);
         }
