@@ -28,6 +28,7 @@
 #include <qscrollview.h>
 #include <qbitmap.h>
 #include <qclipboard.h>
+#include <qdatetime.h>
 
 #include <kiconloader.h>
 #include <kruler.h>
@@ -44,6 +45,8 @@
 #define PICS_INCLUDED
 #endif
 
+#include <X11/Xos.h>
+
 void DrawCommand::execute()
 {
 	oldcolor = *((uint*)image->scanLine(y) + x);
@@ -308,6 +311,7 @@ KIconEditGrid::KIconEditGrid(QImage *image, KCommandHistory* h, QWidget *parent,
     clearImage(img);
 
     currentcolor = qRgb(0,0,0)|OPAQUE_MASK;
+    emit colorSelected(currentcolor);
 
     setMouseTracking(true);
 
@@ -318,6 +322,14 @@ KIconEditGrid::KIconEditGrid(QImage *image, KCommandHistory* h, QWidget *parent,
     connect( kapp->clipboard(), SIGNAL(dataChanged()), SLOT(checkClipboard()));
     connect( h, SIGNAL(commandExecuted()), this, SLOT(updatePreviewPixmap() ));    
     createCursors();
+
+    KIconEditProperties *props = KIconEditProperties::self();
+
+    setTransparencyDisplayType(props->transparencyDisplayType());
+    setTransparencySolidColor(props->transparencySolidColor());
+    setCheckerboardColor1(props->checkerboardColor1());
+    setCheckerboardColor2(props->checkerboardColor2());
+    setCheckerboardSize(props->checkerboardSize());
 }
 
 KIconEditGrid::~KIconEditGrid()
@@ -327,15 +339,359 @@ KIconEditGrid::~KIconEditGrid()
 
 void KIconEditGrid::paintEvent(QPaintEvent *e)
 {
-    //kdDebug(4640) << "KIconGrid::paintEvent" << endl;
-    KColorGrid::paintEvent(e);
-    //kdDebug() << "KIconGrid::paintEvent - done" << endl;
+  const QRect cellsRect(0, 0, numCols() * cellSize(), numRows() * cellSize());
+  const QRect paintCellsRect = cellsRect.intersect(e->rect());
+
+  if(!paintCellsRect.isEmpty())
+  {
+    //QTime time;
+
+    //time.start();
+
+    QRgb *imageBuffer = new QRgb[paintCellsRect.width() * paintCellsRect.height()];
+    const int cellsize = cellSize();
+    const int firstCellPixelsRemaining = cellsize - paintCellsRect.left() % cellsize;
+
+    if(transparencyDisplayType() == TRD_SOLIDCOLOR)
+    {
+      const QRgb backgroundColor = transparencySolidColor().rgb();
+      const int backgroundRed = transparencySolidColor().red();
+      const int backgroundGreen = transparencySolidColor().green();
+      const int backgroundBlue = transparencySolidColor().blue();
+      const int firstCellX = paintCellsRect.left() / cellsize;
+
+      for(int y = paintCellsRect.top(); y <= paintCellsRect.bottom(); y++)
+      {
+        QRgb *dest = imageBuffer + (y - paintCellsRect.top()) * paintCellsRect.width();
+        
+        if(y % cellsize == 0 || dest == imageBuffer)
+        {
+          // Paint the first scanline in each block of cellSize() identical lines.
+          // The remaineder can just be copied from this one.
+          const int cellY = y / cellsize;
+          QRgb *src = gridcolors.data() + cellY * numCols() + firstCellX;
+
+          QRgb sourcePixel = *src++;
+          int sourceAlpha = qAlpha(sourcePixel);
+          
+          QRgb c;
+
+          if(sourceAlpha == 255)
+          {
+            c = sourcePixel;
+          }
+          else
+          if(sourceAlpha == 0)
+          {
+            c = backgroundColor;
+          }
+          else
+          {
+            const int sourceRed = qRed(sourcePixel);
+            const int sourceGreen = qGreen(sourcePixel);
+            const int sourceBlue = qBlue(sourcePixel);
+
+            int r = (sourceAlpha * (sourceRed - backgroundRed)) + 0x80;
+            r = backgroundRed + ((r + (r >> 8)) >> 8);
+
+            int g = (sourceAlpha * (sourceGreen - backgroundGreen)) + 0x80;
+            g = backgroundGreen + ((g + (g >> 8)) >> 8);
+
+            int b = (sourceAlpha * (sourceBlue - backgroundBlue)) + 0x80;
+            b = backgroundBlue + ((b + (b >> 8)) >> 8);
+
+            c = qRgb(r, g, b);
+          }
+
+          int cellPixelsRemaining = firstCellPixelsRemaining;
+
+          for(int x = paintCellsRect.left(); x <= paintCellsRect.right(); x++)
+          {
+            if(cellPixelsRemaining == 0)
+            {
+              cellPixelsRemaining = cellsize;
+
+              // Fetch the next source pixel
+              sourcePixel = *src++;
+              sourceAlpha = qAlpha(sourcePixel);
+
+              if(sourceAlpha == 255)
+              {
+                c = sourcePixel;
+              }
+              else
+              if(sourceAlpha == 0)
+              {
+                c = backgroundColor;
+              }
+              else
+              {
+                const int sourceRed = qRed(sourcePixel);
+                const int sourceGreen = qGreen(sourcePixel);
+                const int sourceBlue = qBlue(sourcePixel);
+
+                //int r = backgroundRed + (sourceAlpha * (sourceRed - backgroundRed)) / 255;
+                //int g = backgroundGreen + (sourceAlpha * (sourceGreen - backgroundGreen)) / 255;
+                //int b = backgroundBlue + (sourceAlpha * (sourceBlue - backgroundBlue)) / 255;
+
+                int r = (sourceAlpha * (sourceRed - backgroundRed)) + 0x80;
+                r = backgroundRed + ((r + (r >> 8)) >> 8);
+
+                int g = (sourceAlpha * (sourceGreen - backgroundGreen)) + 0x80;
+                g = backgroundGreen + ((g + (g >> 8)) >> 8);
+
+                int b = (sourceAlpha * (sourceBlue - backgroundBlue)) + 0x80;
+                b = backgroundBlue + ((b + (b >> 8)) >> 8);
+
+                c = qRgb(r, g, b);
+              }
+            }
+
+            cellPixelsRemaining--;
+
+            *dest++ = c;
+          }
+        }
+        else
+        {
+          // Copy the scanline above.
+          memcpy(dest, dest - paintCellsRect.width(), paintCellsRect.width() * sizeof(QRgb));
+        }
+      }
+    }
+    else
+    {
+      int squareSize;
+      const int fixedPointMultiplier = 4;
+
+      if(checkerboardSize() == CHK_SMALL)
+      {
+        squareSize = (cellSize() * fixedPointMultiplier) / 4;
+      }
+      else
+      if(checkerboardSize() == CHK_MEDIUM)
+      {
+        squareSize = (cellSize() * fixedPointMultiplier) / 2;
+      }
+      else
+      {
+        squareSize = (2 * cellSize() * fixedPointMultiplier) / 2;
+      }
+
+      QRgb *color1ScanLine = new QRgb[paintCellsRect.width()];
+      QRgb *color2ScanLine = new QRgb[paintCellsRect.width()];
+      QRgb *color1Buffer = color1ScanLine;
+      QRgb *color2Buffer = color2ScanLine;
+
+      for(int x = paintCellsRect.left(); x <= paintCellsRect.right(); x++)
+      {
+        if((((x * fixedPointMultiplier) / squareSize) & 1) == 0)
+        {
+          *color1Buffer++ = checkerboardColor1().rgb();
+          *color2Buffer++ = checkerboardColor2().rgb();
+        }
+        else
+        {
+          *color1Buffer++ = checkerboardColor2().rgb();
+          *color2Buffer++ = checkerboardColor1().rgb();
+        }
+      }
+
+      const int firstCellX = paintCellsRect.left() / cellsize;
+      const int firstCellPixelsRemaining = cellsize - paintCellsRect.left() % cellsize;
+      int lastCellY = -1;
+      int lastLineFirstSquareColour = 0;
+
+      for(int y = paintCellsRect.top(); y <= paintCellsRect.bottom(); y++)
+      {
+        QRgb *dest = imageBuffer + (y - paintCellsRect.top()) * paintCellsRect.width();
+        const int cellY = y / cellsize;
+
+        int firstSquareColour;
+        const QRgb *checkerboardSrc;
+
+        if((((y * fixedPointMultiplier) / squareSize) & 1) == 0)
+        {
+          firstSquareColour = 1;
+          checkerboardSrc = color1ScanLine;
+        }
+        else
+        {
+          firstSquareColour = 2;
+          checkerboardSrc = color2ScanLine;
+        }
+
+        if(cellY == lastCellY && firstSquareColour == lastLineFirstSquareColour)
+        {
+          // Copy the scanline above.
+          memcpy(dest, dest - paintCellsRect.width(), paintCellsRect.width() * sizeof(QRgb));
+        }
+        else
+        {
+          QRgb *src = gridcolors.data() + cellY * numCols() + firstCellX;
+
+          QRgb sourcePixel = *src++;
+          int sourceRed = qRed(sourcePixel);
+          int sourceGreen = qGreen(sourcePixel);
+          int sourceBlue = qBlue(sourcePixel);
+          int sourceAlpha = qAlpha(sourcePixel);
+
+          int cellPixelsRemaining = firstCellPixelsRemaining;
+
+          for(int x = paintCellsRect.left(); x <= paintCellsRect.right(); x++)
+          {
+            if(cellPixelsRemaining == 0)
+            {
+              cellPixelsRemaining = cellsize;
+
+              // Fetch the next source pixel
+              sourcePixel = *src++;
+              sourceRed = qRed(sourcePixel);
+              sourceGreen = qGreen(sourcePixel);
+              sourceBlue = qBlue(sourcePixel);
+              sourceAlpha = qAlpha(sourcePixel);
+            }
+
+            cellPixelsRemaining--;
+
+            QRgb c;
+
+            if(sourceAlpha == 255)
+            {
+              c = sourcePixel;
+            }
+            else
+            if(sourceAlpha == 0)
+            {
+              c = *checkerboardSrc;
+            }
+            else
+            {
+              const int backgroundColor = *checkerboardSrc;
+              const int backgroundRed = qRed(backgroundColor);
+              const int backgroundGreen = qGreen(backgroundColor);
+              const int backgroundBlue = qBlue(backgroundColor);
+
+              //int r = backgroundRed + (sourceAlpha * (sourceRed - backgroundRed)) / 255;
+              //int g = backgroundGreen + (sourceAlpha * (sourceGreen - backgroundGreen)) / 255;
+              //int b = backgroundBlue + (sourceAlpha * (sourceBlue - backgroundBlue)) / 255;
+
+              int r = (sourceAlpha * (sourceRed - backgroundRed)) + 0x80;
+              r = backgroundRed + ((r + (r >> 8)) >> 8);
+
+              int g = (sourceAlpha * (sourceGreen - backgroundGreen)) + 0x80;
+              g = backgroundGreen + ((g + (g >> 8)) >> 8);
+
+              int b = (sourceAlpha * (sourceBlue - backgroundBlue)) + 0x80;
+              b = backgroundBlue + ((b + (b >> 8)) >> 8);
+
+              c = qRgb(r, g, b);
+            }
+
+            *dest++ = c;
+            checkerboardSrc++;
+          }
+        }
+
+        lastCellY = cellY;
+        lastLineFirstSquareColour = firstSquareColour;
+      }
+
+      delete [] color1ScanLine;
+      delete [] color2ScanLine;
+    }
+
+    QImage image((uchar *)(imageBuffer), paintCellsRect.width(), paintCellsRect.height(), 32, 0, 0,
+#if X_BYTE_ORDER == X_LITTLE_ENDIAN
+      QImage::LittleEndian);
+#else
+      QImage::BigEndian);
+#endif
+    Q_ASSERT(!image.isNull());
+
+    QPixmap _pixmap;
+    _pixmap.convertFromImage(image);
+
+    QPainter p;
+    p.begin(&_pixmap);
+    paintForeground(&p, e);
+    p.end();
+
+    bitBlt(this, paintCellsRect.left(), paintCellsRect.top(), &_pixmap);
+
+    //kdDebug(4640) << "Image render elapsed: " << time.elapsed() << endl;
+
+    delete [] imageBuffer;
+  }
 }
 
 void KIconEditGrid::paintForeground(QPainter* p, QPaintEvent* e)
 {
+    QWMatrix matrix;
+
+    matrix.translate(-e->rect().x(), -e->rect().y());
+    p->setWorldMatrix( matrix );
+
+    QRect cellsRect(0, 0, numCols() * cellSize(), numRows() * cellSize());
+    QRect paintCellsRect = cellsRect.intersect(e->rect());
+
+    if(!paintCellsRect.isEmpty())
+    {
+      int firstColumn = paintCellsRect.left() / cellSize();
+      int lastColumn = paintCellsRect.right() / cellSize();
+
+      int firstRow = paintCellsRect.top() / cellSize();
+      int lastRow = paintCellsRect.bottom() / cellSize();
+
+      p->setPen(QColor(0, 0, 0));
+      p->setBrush(QColor(0, 0, 0));
+
+      for(int column = firstColumn; column <= lastColumn; column++)
+      {
+        for(int row = firstRow; row <= lastRow; row++)
+        {
+          int x = column * cellSize();
+          int y = row * cellSize();
+
+          if((ispasting || isselecting) && isMarked(column, row))
+          {
+            p->drawWinFocusRect(x + 1, y + 1, cellSize() - 2, cellSize() - 2);
+          }
+          else
+          {
+            switch( tool )
+            {
+              case FilledRect:
+              case Rect:
+              case Ellipse:
+              case Circle:
+              case FilledEllipse:
+              case FilledCircle:
+              case Line:
+                if(btndown && isMarked(column, row))
+                {
+                  if(cellSize() > 1)
+                  {
+                    p->drawWinFocusRect( x + 1, y + 1, cellSize() - 2, cellSize() - 2);
+                  }
+                  else
+                  {
+                    p->drawPoint(x, y);
+                  }
+                }
+                break;
+
+              default:
+                break;
+            }
+          }
+        }
+      }
+    }
+
     if(hasGrid()&& !(cellSize()==1))
     {
+        p->setPen(QColor(0, 0, 0));
         int x = e->rect().x() - ((e->rect().x() % cellSize()) + cellSize());
         if(x < 0) x = 0;
         int y = e->rect().y() - ((e->rect().y() % cellSize()) + cellSize());
@@ -350,83 +706,6 @@ void KIconEditGrid::paintForeground(QPainter* p, QPaintEvent* e)
         for(int i = y; i < cy; i += cellSize())
             p->drawLine(x, i, cx, i);
     }
-    //kdDebug(4640) << "KIconGrid::paintEvent - done" << endl;
-}
-
-
-void KIconEditGrid::paintCell( QPainter *painter, int row, int col )
-{
-  int sel = row * numCols() + col;
-  int s = cellSize();
-  uint sourcePixel = colorAt(sel);
-  uint backgroundColour = eraseColor().rgb();
-
-  double alpha = qAlpha(sourcePixel) / 255.0;
-
-  int r = (int) (((qRed(backgroundColour) * (1 - alpha)) + (qRed(sourcePixel) * alpha)) + 0.5);
-  int g = (int) (((qGreen(backgroundColour) * (1 - alpha)) + (qGreen(sourcePixel) * alpha)) + 0.5);
-  int b = (int) (((qBlue(backgroundColour) * (1 - alpha)) + (qBlue(sourcePixel) * alpha)) + 0.5);
-
-  uint c = qRgb(r, g, b);
-
-  if(s == 1)
-  {
-    if((ispasting || isselecting) && isMarked(col, row))
-    {
-      painter->drawPoint(0, 0);
-      return;
-    }
-    else
-    {
-      painter->setPen(c);
-      painter->drawPoint(0, 0);
-    }
-  }
-  else
-  {
-    painter->fillRect(0, 0, s, s, (QBrush)c);
-    if((ispasting || isselecting) && isMarked(col, row))
-    {
-      painter->drawWinFocusRect( 1, 1, s-1, s-1);
-      return;
-    }
-  }
-
-  switch( tool )
-  {
-    case Find:
-    case Spray:
-    case Eraser:
-    case Freehand:
-      if ( sel == selected)
-      {
-        if(cellSize() > 1)
-          painter->drawWinFocusRect( 1, 1, s-1, s-1 );
-        else
-          painter->drawPoint(0, 0);
-      }
-      break;
-
-    case FilledRect:
-    case Rect:
-    case Ellipse:
-    case Circle:
-    case FilledEllipse:
-    case FilledCircle:
-    case Line:
-      if(btndown && isMarked(col, row))
-      {
-        if(cellSize() > 1)
-          painter->drawWinFocusRect( 1, 1, s-1, s-1);
-        else
-          painter->drawPoint(0, 0);
-      }
-      break;
-
-    default:
-      break;
-  }
-  //kdDebug(4640) << "KIconEditGrid::paintCell() - done" << endl;
 }
 
 void KIconEditGrid::mousePressEvent( QMouseEvent *e )
@@ -568,6 +847,7 @@ void KIconEditGrid::mouseMoveEvent( QMouseEvent *e )
                 selected = cell;
                 update((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize);
                 update(col*cellsize,row*cellsize, cellsize, cellsize);
+                emit colorSelected(colorAt(selected));
             }
             break;
         }
@@ -692,6 +972,7 @@ void KIconEditGrid::mouseReleaseEvent( QMouseEvent *e )
         selected = cell;
         update((prevSel%numCols())*cellsize,(prevSel/numCols())*cellsize, cellsize, cellsize);
         update(col*cellsize,row*cellsize, cellsize, cellsize);
+        emit colorSelected(currentcolor);
         //updateCell( prevSel/numCols(), prevSel%numCols(), FALSE );
         //updateCell( row, col, FALSE );
       }
@@ -710,6 +991,7 @@ void KIconEditGrid::mouseReleaseEvent( QMouseEvent *e )
 void KIconEditGrid::setColorSelection( uint c )
 {
   currentcolor = c;
+  emit colorSelected(currentcolor);
 }
 
 void KIconEditGrid::loadBlank( int w, int h )
