@@ -24,18 +24,17 @@
 #include <qwidget.h>
 #include <qpixmap.h>
 #include <qimage.h>
-#include <qbitmap.h>
-#include <qfiledialog.h> 
-#include <qbuttongroup.h>
-#include <qbutton.h>
-#include <qradiobutton.h>
 #include <qlistbox.h>
 
-#include "kresize.h"
 #include <kwizard.h>
 
+#include "kresize.h"
+
 class KIconListBox;
 class KIconTemplateContainer;
+class QButtonGroup;
+class QRadioButton;
+class QGroupBox;
 
 struct KIconTemplate
 {
@@ -44,8 +43,8 @@ struct KIconTemplate
 };
 
 class KIconListBoxItem : public QListBoxItem    
-{    
-public:      
+{
+public:
   KIconListBoxItem( KIconTemplate ); 
 
 
@@ -53,23 +52,23 @@ public:
   KIconTemplate& iconTemplate() { return icontemplate; }
   void reloadIcon();
 
-protected:      
+protected:
   virtual void paint( QPainter * );      
   virtual int height( const QListBox * ) const;      
   virtual int width( const QListBox * ) const;      
-private:      
-  QPixmap pm;    
+private:
+  QPixmap pm;
   KIconTemplate icontemplate;
 };
 
 class KIconListBox : public QListBox    
-{    
+{
   Q_OBJECT
-public:      
+public:
   KIconListBox( QWidget *parent ) : QListBox(parent) {} ;
   const QString path(int idx) { return ((KIconListBoxItem*)item(idx))->path(); }
   KIconTemplate& iconTemplate(int idx) { return ((KIconListBoxItem*)item(idx))->iconTemplate(); }
-  
+
 };
 
 class KIconTemplateContainer : public QValueList<KIconTemplate>
@@ -81,15 +80,15 @@ public:
          instance = new KIconTemplateContainer;
       return instance;
    }
-   
+
    void save();
-   
+
 private:
    static KIconTemplateContainer* instance;
-  
+
   const KIconTemplateContainer operator = (const KIconTemplateContainer&);
   KIconTemplateContainer(const KIconTemplateContainer&);
-  
+
   KIconTemplateContainer();  
   ~KIconTemplateContainer();
 };
