@@ -1,6 +1,7 @@
 /*
     KDE Draw - a small graphics drawing program for the KDE.
     Copyright (C) 1998  Thomas Tanghus (tanghus@kde.org)
+    Copyright ( C ) 2002  Nadeem Hasan (  nhasan@kde.org )
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public
@@ -21,17 +22,7 @@
 #ifndef __KRESIZE_H__
 #define __KRESIZE_H__
 
-//#include <qwidget.h>
-#include <qpixmap.h>
-#include <qimage.h>
-#include <qbitmap.h>
-#include <qfiledialog.h> 
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qlistbox.h>
-
-#include <kiconloader.h>
-#include <kapplication.h>
+#include <kdialogbase.h>
 
 class KIntSpinBox;
 
@@ -46,21 +37,13 @@ public:
 
   const QSize getSize();
 
-signals:
-
-  void validSize( bool );
-
-public slots:
-
-  void checkValue( int );
-
 private:
 
-  KIntSpinBox *x_line;
-  KIntSpinBox *y_line;
+  KIntSpinBox *m_width;
+  KIntSpinBox *m_height;
 };
 
-class KResizeDialog : public QDialog
+class KResizeDialog : public KDialogBase
 {
   Q_OBJECT
   
@@ -71,19 +54,9 @@ public:
 
   const QSize getSize();
 
-public slots:
-
-  void validSize( bool );
-  void checkValue( int );
-
-protected:
-
-  bool eventFilter( QObject*, QEvent* );
-
 private:
 
-  KResizeWidget* rw;
-  QPushButton *ok, *cancel;
+  KResizeWidget* m_resize;
 };
 
 #endif //__KRESIZE_H__
