@@ -31,7 +31,7 @@
 #include "config.h"
 #include "properties.h"
 
-static const char *description =
+static const char description[] =
 	I18N_NOOP("KDE Icon Editor");
 
 static KCmdLineOptions options[] =
@@ -50,8 +50,8 @@ int main(int argc, char **argv)
   aboutData.addAuthor("John Califf",0, "jcaliff@compuzone.net");
   aboutData.addAuthor("Laurent Montel",0, "lmontel@mandrakesoft.com");
   aboutData.addAuthor("Aaron J. Seigo",0, "aseigo@olympusproject.org");
-  aboutData.addCredit( "Nadeem Hasan", I18N_NOOP("Rewrote UI to use XMLGUI\n"
-      "Lots of fixes and cleanup"), "nhasan@nadmm.com" );
+  aboutData.addCredit( "Nadeem Hasan", "Rewrote UI to use XMLGUI\n"
+      "Lots of fixes and cleanup", "nhasan@nadmm.com" );
   aboutData.addCredit( "Adrian Page", I18N_NOOP("Bug fixes and GUI tidy up"),
       "Adrian.Page@tesco.net" );
   KCmdLineArgs::init( argc, argv, &aboutData );
