@@ -19,6 +19,7 @@
 #ifndef MRML_VIEW_H
 #define MRML_VIEW_H
 
+#include <qevent.h>
 #include <qframe.h>
 #include <qptrlist.h>
 #include <qpixmap.h>
@@ -41,7 +42,7 @@ class MrmlViewItemList : public QPtrList<MrmlViewItem>
 {
 protected:
     // sort by similarity
-    virtual int compareItems( QCollection::Item, QCollection::Item );
+    virtual int compareItems( QPtrCollection::Item, QPtrCollection::Item );
 
 };
 
@@ -51,7 +52,7 @@ class MrmlView : public QScrollView
     friend class MrmlViewItem;
 
     Q_OBJECT
-	
+
 public:
     MrmlView( QWidget *parent = 0L, const char *name = 0L );
     ~MrmlView();
@@ -95,7 +96,7 @@ private:
     QPixmapCache m_pixmapCache;
     QPixmap m_unavailablePixmap;
 
-	
+
 };
 
 
@@ -122,7 +123,7 @@ public:
     double similarity() const { return m_similarity; }
 
     void setSimilarity( double value );
-	
+
     virtual QSize sizeHint() const;
 
     const KURL& url() const { return m_url; }
@@ -140,7 +141,7 @@ protected:
     virtual void mousePressEvent( QMouseEvent * );
     virtual void mouseMoveEvent( QMouseEvent * );
     virtual void mouseReleaseEvent( QMouseEvent * );
-	
+
 private:
     bool hitsPixmap( const QPoint& ) const;
     MrmlView * view() const { return m_view; }
@@ -151,7 +152,7 @@ private:
     inline int pixmapY() const {
         return m_combo->y() - similarityHeight - m_pixmap.height() - margin;
     }
-	
+
     KComboBox *m_combo; // for relevance
     MrmlView *m_view;
 
@@ -161,11 +162,11 @@ private:
     QPixmap m_pixmap;
 
     double m_similarity;
-    const double similarityFullWidth;
+    const int similarityFullWidth;
     bool m_hasRemotePixmap;
 
     QPoint pressedPos;
-	
+
     static const int spacing = 3;
     static const int margin = 5;
     static const int similarityHeight = 4;
