@@ -148,7 +148,7 @@ void kpTool::createAction ()
     }
 
 
-    m_action = new kpToolAction (text (), iconSet (), shortcutForKey (m_key),
+    m_action = new kpToolAction (text (), iconName (), shortcutForKey (m_key),
                                  this, SLOT (slotActionActivated ()),
                                  m_mainWindow->actionCollection (), name ());
     m_action->setExclusiveGroup (QString::fromLatin1 ("Tool Box Actions"));
@@ -613,6 +613,12 @@ QIconSet kpTool::iconSet (int forceSize) const
         return BarIcon (name ());
 }
 
+// public
+QString kpTool::iconName () const
+{
+    return name ();
+}
+
 // public
 kpToolAction *kpTool::action ()
 {
@@ -1135,7 +1141,7 @@ void kpTool::mouseReleaseEvent (QMouseEvent *e)
 void kpTool::keyPressEvent (QKeyEvent *e)
 {
 #if DEBUG_KP_TOOL && 0
-    kdDebug () << "kpTool::keyPressEvent()" << endl;
+    kdDebug () << "kpTool::keyPressEvent() e->key=" << e->key () << endl;
 #endif
 
     int dx = 0, dy = 0;
@@ -1178,10 +1184,11 @@ void kpTool::keyPressEvent (QKeyEvent *e)
     case Qt::Key_PageDown: dx = +1, dy = +1;    break;
 
     case Qt::Key_Enter:
+    case Qt::Key_Return:
     case Qt::Key_Insert:
+    case Qt::Key_Clear:
     {
         kpView *view = viewUnderCursor (); // TODO: wrong for dragging lines outside of view (for e.g.)
-    // TODO: what's the 5 key called?
         if (view)
         {
             // TODO: what about the modifiers
@@ -1275,10 +1282,11 @@ void kpTool::keyReleaseEvent (QKeyEvent *e)
         break;
 
     case Qt::Key_Enter:
+    case Qt::Key_Return:
     case Qt::Key_Insert:
+    case Qt::Key_Clear:
     {
         kpView *view = viewUnderCursor ();
-    // TODO: what's the 5 key called?
         if (view)
         {
             QMouseEvent me (QEvent::MouseButtonRelease,
