@@ -1,6 +1,6 @@
 
 /*
-   Copyright (c) 2003-2004 Clarence Dang <dang@kde.org>
+   Copyright (c) 2003,2004,2005 Clarence Dang <dang@kde.org>
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -53,6 +53,7 @@
 #include <kpmainwindow.h>
 #include <kppixmapfx.h>
 #include <kptool.h>
+#include <kpview.h>
 
 
 /*
@@ -298,10 +299,10 @@ void kpDualColorButton::drawContents (QPainter *p)
 
     if (isEnabled () && m_mainWindow)
     {
-        m_mainWindow->drawTransparentBackground (&backBufferPainter,
-                                                 m_backBuffer->width (), m_backBuffer->height (),
-                                                 m_backBuffer->rect (),
-                                                 true/*preview*/);
+        kpView::drawTransparentBackground (&backBufferPainter,
+                                           m_backBuffer->width (), m_backBuffer->height (),
+                                           m_backBuffer->rect (),
+                                           true/*preview*/);
     }
     else
     {
