@@ -43,6 +43,8 @@
 #include <kio/job.h>
 #include <kio/netaccess.h>
 #include <ktempfile.h>
+#include <kinputdialog.h>
+
 #include <qdir.h>
 #include <qlayout.h>
 #include <qfileinfo.h>
@@ -273,14 +275,14 @@ void ImgSaver::createDir( const QString& dir )
       // if( mkdir( QFile::encodeName( dir ), S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH ) != 0 )
       if( KIO::mkdir( KURL(dir)))
       {
-        KMessageBox::sorry(0, i18n("The folder\n%1\n does not exist and could not be created !\n"
-                        "Please check the permissions.").arg(dir));
+        KMessageBox::sorry(0, i18n("The folder\n%1\n does not exist and could not be created;\n"
+                        "please check the permissions.").arg(dir));
       }
    }
 #if 0
    if( ! fi.isWritable() )
    {
-        KMessageBox::sorry(0, i18n("The directory\n%1\n is not writeable.\nPlease check the permissions.")
+        KMessageBox::sorry(0, i18n("The directory\n%1\n is not writeable;\nplease check the permissions.")
                 .arg(dir));
    }
 #endif
@@ -331,10 +333,37 @@ ImgSaveStat ImgSaver::saveImage( QImage *image )
    }
 
    kdDebug(28000) << "saveImage: Directory is " << directory << endl;
-   QString fi = directory + "/" + createFilename( format );
+   QString filename = createFilename( format );
+
+   KConfig *konf = KGlobal::config ();
+   konf->setGroup( OP_FILE_GROUP );
+
+   if( konf->readBoolEntry( OP_ASK_FILENAME, false ) )
+   {
+       bool ok;
+       QString text = KInputDialog::getText( i18n( "Filename" ), i18n("Enter filename:"),
+					     filename, &ok );
+
+       if(ok)
+       {
+	   filename = text;
+       }
+   }
+       
+   QString fi = directory + "/" + filename;
+
+   if( extension(fi).isEmpty() )
+   {
+       if( ! fi.endsWith( "." )  )
+       {
+	   fi+= ".";
+       }
+       fi+=format.lower();
+   }
+
+
    kdDebug(28000) << "saveImage: saving file <" << fi << ">" << endl;
-   stat = save( image, fi,
-		format, subformat );
+   stat = save( image, fi, format, subformat );
 
    return( stat );
 
@@ -390,39 +419,6 @@ ImgSaveStat ImgSaver::saveImage( QImage *image, const KURL& filename, const QStr
 }
 
 
-
-
-
-ImgSaveStat ImgSaver::savePreview( QImage *image, const QCString& scannerName )
-{
-   if( !image ||  image->isNull() )
-      return( ISS_ERR_PARAM );
-
-   QString format = findFormat( PT_PREVIEW );
-
-   ImgSaveStat stat = ISS_ERR_FORMAT_NO_WRITE;
-
-   QString previewfile = Previewer::previewFile( scannerName );
-   if( ! format.isEmpty() )
-   {
-      // Previewfile always comes absolute
-      stat = save( image, previewfile, format, "" );
-   }
-#if 0  /* preview file name is not longer needed in config file */
-   if( stat == ISS_OK )
-   {
-      KConfig *konf = KGlobal::config ();
-      konf->setGroup( scannerName );
-
-      konf->writeEntry( OP_PREVIEW_FILE,   previewfile );
-      konf->writeEntry( OP_PREVIEW_FORMAT, format );
-      konf->sync();
-   }
-#endif
-
-   return( stat );
-}
-
 /*
  * findFormat does all the stuff with the dialog.
  */
@@ -772,7 +768,7 @@ bool ImgSaver::renameImage( const KURL& fromUrl, KURL& toUrl, bool askExt,  QWid
 	 s = i18n("The filename you supplied has no file extension.\nShould the correct one be added automatically? ");
 	 s += i18n( "That would result in the new filename: %1" ).arg( fName);
 
-	 result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension missing"),
+	 result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension Missing"),
 					     KStdGuiItem::yes(), KStdGuiItem::no(),
 					     "AutoAddExtensions" );
       }
@@ -842,7 +838,7 @@ QString ImgSaver::tempSaveImage( KookaImage *img, const QString& format, int col
     {
 	name = tmpFile->name();
 
-	img->save( name, format.latin1() );
+	if( ! img->save( name, format.latin1() ) ) name = QString();
     }
     delete tmpFile;
     return name;
@@ -869,7 +865,7 @@ bool ImgSaver::copyImage( const KURL& fromUrl, const KURL& toUrl, QWidget *overW
       s = i18n("The filename you supplied has no file extension.\nShould the correct one be added automatically? ");
       s += i18n( "That would result in the new filename: %1" ).arg( fName);
 
-      result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension missing"),
+      result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension Missing"),
 					  KStdGuiItem::yes(), KStdGuiItem::no(),
 					  "AutoAddExtensions" );
 
@@ -886,8 +882,8 @@ bool ImgSaver::copyImage( const KURL& fromUrl, const KURL& toUrl, QWidget *overW
        {
 	   KMessageBox::error( overWidget, i18n("Format changes of images are currently not supported."),
 			       i18n("Wrong Extension Found" ));
+	   return(false);
        }
-      return(false);
    }
 
    KIO::Job *copyjob = KIO::copy( fromUrl, targetUrl, false );
