@@ -392,9 +392,9 @@ QString PDFGenerator::getMetaData( const QString & key, const QString & option )
 
 bool PDFGenerator::reparseConfig()
 {
-    // load paper color from Settings or use the white default color
-    QColor color = ( (Settings::renderMode() == Settings::EnumRenderMode::Paper ) &&
-                     Settings::changeColors() ) ? Settings::paperColor() : Qt::white;
+    // load paper color from KpdfSettings or use the white default color
+    QColor color = ( (KpdfSettings::renderMode() == KpdfSettings::EnumRenderMode::Paper ) &&
+                     KpdfSettings::changeColors() ) ? KpdfSettings::paperColor() : Qt::white;
     // if paper color is changed we have to rebuild every visible pixmap in addition
     // to the outputDevice. it's the 'heaviest' case, other effect are just recoloring
     // over the page rendered on 'standard' white background.
@@ -575,6 +575,17 @@ void PDFGenerator::addSynopsisChildren( QDomNode * parent, GList * items )
                 item.setAttribute( "Viewport", DocumentViewport( pageNumber ).toString() );
             }
         }
+	else if ( a && a->getKind() == actionGoToR )
+        {
+            LinkGoToR * g = static_cast< LinkGoToR * >( a );
+            LinkDest * destination = g->getDest();
+            if ( !destination && g->getNamedDest() )
+            {
+                item.setAttribute( "ViewportName", g->getNamedDest()->getCString() );
+            }
+
+            item.setAttribute( "ExternalFileName", g->getFileName()->getCString() );
+        }
 
         // 3. recursively descend over children
         outlineItem->open();
