@@ -66,7 +66,7 @@ public:
     QValueVector< PageViewItem * > items;
     QValueList< PageViewItem * > visibleItems;
 
-    // view layout (columns and continuous in Settings), zoom and mouse
+    // view layout (columns and continuous in KpdfSettings), zoom and mouse
     PageView::ZoomMode zoomMode;
     float zoomFactor;
     PageView::MouseMode mouseMode;
@@ -197,11 +197,11 @@ void PageView::setupActions( KActionCollection * ac )
     // View-Layout actions
     d->aViewTwoPages = new KToggleAction( i18n("&Two Pages"), "view_left_right", 0, ac, "view_twopages" );
     connect( d->aViewTwoPages, SIGNAL( toggled( bool ) ), SLOT( slotTwoPagesToggled( bool ) ) );
-    d->aViewTwoPages->setChecked( Settings::viewColumns() > 1 );
+    d->aViewTwoPages->setChecked( KpdfSettings::viewColumns() > 1 );
 
     d->aViewContinuous = new KToggleAction( i18n("&Continuous"), "view_text", 0, ac, "view_continuous" );
     connect( d->aViewContinuous, SIGNAL( toggled( bool ) ), SLOT( slotContinuousToggled( bool ) ) );
-    d->aViewContinuous->setChecked( Settings::viewContinuous() );
+    d->aViewContinuous->setChecked( KpdfSettings::viewContinuous() );
 
     // Mouse-Mode actions
     d->aMouseNormal = new KRadioAction( i18n("&Normal"), "mouse", 0, this, SLOT( slotSetMouseNormal() ), ac, "mouse_drag" );
@@ -263,14 +263,18 @@ void PageView::notifySetup( const QValueVector< KPDFPage * > & pageSet, bool doc
     for ( ; setIt != setEnd; ++setIt )
         d->items.push_back( new PageViewItem( *setIt ) );
 
-    // invalidate layout so relayout/repaint will happen on next viewport change
     if ( pageSet.count() > 0 )
-        d->dirtyLayout = true;
+        // TODO for Enrico: Check if doing always the slotRelayoutPages() is not
+        // suboptimal in some cases, i'd say it is not but a recheck will not hurt
+        // Need slotRelayoutPages() here instead of d->dirtyLayout = true
+        // because opening a pdf from another pdf will not trigger a viewportchange
+        // so pages are never relayouted
+        slotRelayoutPages();
     else
         resizeContents( 0, 0 );
 
     // OSD to display pages
-    if ( documentChanged && pageSet.count() > 0 && Settings::showOSD() )
+    if ( documentChanged && pageSet.count() > 0 && KpdfSettings::showOSD() )
         d->messageWindow->display(
             i18n(" Loaded a one-page document.",
                  " Loaded a %n-page document.",
@@ -305,7 +309,7 @@ void PageView::notifyViewportChanged( bool smoothMove )
 
     // relayout in "Single Pages" mode or if a relayout is pending
     d->blockPixmapsRequest = true;
-    if ( !Settings::viewContinuous() || d->dirtyLayout )
+    if ( !KpdfSettings::viewContinuous() || d->dirtyLayout )
         slotRelayoutPages();
 
     // restore viewport center or use default {x-center,v-top} alignment
@@ -465,7 +469,7 @@ void PageView::viewportPaintEvent( QPaintEvent * pe )
         // note: this check will take care of all things requiring alpha blending (not only selection)
         bool wantCompositing = !selectionRect.isNull() && contentsRect.intersects( selectionRect );
 
-        if ( wantCompositing && Settings::enableCompositing() )
+        if ( wantCompositing && KpdfSettings::enableCompositing() )
         {
             // create pixmap and open a painter over it (contents{left,top} becomes pixmap {0,0})
             QPixmap doubleBuffer( contentsRect.size() );
@@ -499,7 +503,7 @@ void PageView::viewportPaintEvent( QPaintEvent * pe )
                 pixmapPainter.drawRect( selectionRect );
             }
             // 4) Layer 3: overlays
-            if ( Settings::debugDrawBoundaries() )
+            if ( KpdfSettings::debugDrawBoundaries() )
             {
                 pixmapPainter.setPen( Qt::blue );
                 pixmapPainter.drawRect( contentsRect );
@@ -522,7 +526,7 @@ void PageView::viewportPaintEvent( QPaintEvent * pe )
                 screenPainter.drawRect( selectionRect );
             }
             // 4) Layer 3: overlays
-            if ( Settings::debugDrawBoundaries() )
+            if ( KpdfSettings::debugDrawBoundaries() )
             {
                 screenPainter.setPen( Qt::red );
                 screenPainter.drawRect( contentsRect );
@@ -577,11 +581,17 @@ void PageView::keyPressEvent( QKeyEvent * e )
         {
             // part doesn't get this key event because of the keyboard grab
             d->findTimeoutTimer->stop(); // restore normal operation during possible messagebox is displayed
+            // it is needed to grab the keyboard becase people may have Space assigned to a 
+            // accel and without grabbing the keyboard you can not vim-search for space
+            // because it activates the accel
             releaseKeyboard();
             if ( d->document->continueSearch( PAGEVIEW_SEARCH_ID ) )
                 d->messageWindow->display( i18n("Text found: \"%1\".").arg(d->typeAheadString.lower()),
                                            PageViewMessage::Find, 3000 );
             d->findTimeoutTimer->start( 3000, true );
+            // it is needed to grab the keyboard becase people may have Space assigned to a 
+            // accel and without grabbing the keyboard you can not vim-search for space
+            // because it activates the accel
             grabKeyboard();
         }
         // esc and return: end search
@@ -621,6 +631,9 @@ void PageView::keyPressEvent( QKeyEvent * e )
             connect( d->findTimeoutTimer, SIGNAL( timeout() ), this, SLOT( findAheadStop() ) );
         }
         d->findTimeoutTimer->start( 3000, true );
+        // it is needed to grab the keyboard becase people may have Space assigned to a 
+        // accel and without grabbing the keyboard you can not vim-search for space
+        // because it activates the accel
         grabKeyboard();
         return;
     }
@@ -635,7 +648,7 @@ void PageView::keyPressEvent( QKeyEvent * e )
         case Key_Up:
         case Key_PageUp:
             // if in single page mode and at the top of the screen, go to previous page
-            if ( Settings::viewContinuous() || verticalScrollBar()->value() > verticalScrollBar()->minValue() )
+            if ( KpdfSettings::viewContinuous() || verticalScrollBar()->value() > verticalScrollBar()->minValue() )
             {
                 if ( e->key() == Key_Up )
                     verticalScrollBar()->subtractLine();
@@ -655,7 +668,7 @@ void PageView::keyPressEvent( QKeyEvent * e )
         case Key_Down:
         case Key_PageDown:
             // if in single page mode and at the bottom of the screen, go to next page
-            if ( Settings::viewContinuous() || verticalScrollBar()->value() < verticalScrollBar()->maxValue() )
+            if ( KpdfSettings::viewContinuous() || verticalScrollBar()->value() < verticalScrollBar()->maxValue() )
             {
                 if ( e->key() == Key_Down )
                     verticalScrollBar()->addLine();
@@ -884,17 +897,19 @@ void PageView::contentsMouseReleaseEvent( QMouseEvent * e )
                     const KPDFLink * link = static_cast< const KPDFLink * >( linkRect->pointer() );
                     d->document->processLink( link );
                 }
-
-                imageRect = pageItem->page()->hasObject( ObjectRect::Image, nX, nY );
-                if ( imageRect )
+                else
                 {
-                    // handle click over a image
-                }
-
-                if (!linkRect && !imageRect)
-                {
-                    // if not on a rect, the click selects the page
-                    d->document->setViewportPage( pageItem->pageNumber(), PAGEVIEW_ID );
+                    // a link can move us to another page or even to another document, there's no point in trying to process the click on the image once we have processes the click on the link
+                    imageRect = pageItem->page()->hasObject( ObjectRect::Image, nX, nY );
+                    if ( imageRect )
+                    {
+                        // handle click over a image
+                    }
+                    else
+                    {
+                        // if not on a rect, the click selects the page
+                        d->document->setViewportPage( pageItem->pageNumber(), PAGEVIEW_ID );
+                    }
                 }
             }
             else if ( rightButton )
@@ -986,7 +1001,7 @@ void PageView::contentsMouseReleaseEvent( QMouseEvent * e )
                 menu.insertItem( SmallIcon("editcopy"), i18n( "Copy to Clipboard" ), 1 );
                 if ( !d->document->isAllowed( KPDFDocument::AllowCopy ) )
                     menu.setItemEnabled( 1, false );
-                if ( Settings::useKTTSD() )
+                if ( KpdfSettings::useKTTSD() )
                     menu.insertItem( SmallIcon("kttsd"), i18n( "Speak Text" ), 2 );
             }
             menu.insertTitle( i18n( "Image (%1 by %2 pixels)" ).arg( selectionRect.width() ).arg( selectionRect.height() ) );
@@ -1057,10 +1072,10 @@ void PageView::contentsMouseReleaseEvent( QMouseEvent * e )
                             // Use kdebug for now.
                             // d->messageWindow->display( i18n( "Starting KTTSD Failed") )
                             kdDebug() << "Starting KTTSD Failed" << endl;
-                            Settings::setUseKTTSD(false);
+                            KpdfSettings::setUseKTTSD(false);
                         }
                     }
-                    if ( Settings::useKTTSD() )
+                    if ( KpdfSettings::useKTTSD() )
                     {
                         // serialize the text to speech (selectedText) and the
                         // preferred reader ("" is the default voice) ...
@@ -1116,7 +1131,7 @@ void PageView::wheelEvent( QWheelEvent *e )
         else
             slotZoomIn();
     }
-    else if ( delta <= -120 && !Settings::viewContinuous() && vScroll == verticalScrollBar()->maxValue() )
+    else if ( delta <= -120 && !KpdfSettings::viewContinuous() && vScroll == verticalScrollBar()->maxValue() )
     {
         // go to next page
         if ( d->document->currentPage() < d->items.count() - 1 )
@@ -1129,7 +1144,7 @@ void PageView::wheelEvent( QWheelEvent *e )
             d->document->setViewport( newViewport );
         }
     }
-    else if ( delta >= 120 && !Settings::viewContinuous() && vScroll == verticalScrollBar()->minValue() )
+    else if ( delta >= 120 && !KpdfSettings::viewContinuous() && vScroll == verticalScrollBar()->minValue() )
     {
         // go to prev page
         if ( d->document->currentPage() > 0 )
@@ -1502,11 +1517,11 @@ void PageView::slotRelayoutPages()
     QRect viewportRect( contentsX(), contentsY(), viewportWidth, viewportHeight );
 
     // set all items geometry and resize contents. handle 'continuous' and 'single' modes separately
-    if ( Settings::viewContinuous() )
+    if ( KpdfSettings::viewContinuous() )
     {
         // Here we find out column's width and row's height to compute a table
         // so we can place widgets 'centered in virtual cells'.
-        int nCols = Settings::viewColumns(),
+        int nCols = KpdfSettings::viewColumns(),
             nRows = (int)ceil( (float)pageCount / (float)nCols ),
             * colWidth = new int[ nCols ],
             * rowHeight = new int[ nRows ],
@@ -1573,7 +1588,7 @@ void PageView::slotRelayoutPages()
         PageViewItem * currentItem = d->items[ QMAX( 0, (int)d->document->currentPage() ) ];
 
         // setup varialbles for a 1(row) x N(columns) grid
-        int nCols = Settings::viewColumns(),
+        int nCols = KpdfSettings::viewColumns(),
             * colWidth = new int[ nCols ],
             cIdx = 0;
         fullHeight = viewportHeight;
@@ -1727,8 +1742,8 @@ void PageView::slotRequestVisiblePixmaps( int newLeft, int newTop )
 
     // if preloading is enabled, add the pages before and after in preloading
     if ( !d->visibleItems.isEmpty() &&
-         Settings::memoryLevel() != Settings::EnumMemoryLevel::Low &&
-         Settings::enableThreading() )
+         KpdfSettings::memoryLevel() != KpdfSettings::EnumMemoryLevel::Low &&
+         KpdfSettings::enableThreading() )
     {
         // add the page before the 'visible series' in preload
         int headRequest = d->visibleItems.first()->pageNumber() - 1;
@@ -1825,6 +1840,9 @@ void PageView::findAheadStop()
     d->typeAheadActive = false;
     d->typeAheadString = "";
     d->messageWindow->display( i18n("Find stopped."), PageViewMessage::Find, 1000 );
+    // it is needed to grab the keyboard becase people may have Space assigned to a 
+    // accel and without grabbing the keyboard you can not vim-search for space
+    // because it activates the accel
     releaseKeyboard();
 }
 
@@ -1862,9 +1880,9 @@ void PageView::slotFitToTextToggled( bool on )
 void PageView::slotTwoPagesToggled( bool on )
 {
     uint newColumns = on ? 2 : 1;
-    if ( Settings::viewColumns() != newColumns )
+    if ( KpdfSettings::viewColumns() != newColumns )
     {
-        Settings::setViewColumns( newColumns );
+        KpdfSettings::setViewColumns( newColumns );
         if ( d->document->pages() > 0 )
             slotRelayoutPages();
     }
@@ -1872,9 +1890,9 @@ void PageView::slotTwoPagesToggled( bool on )
 
 void PageView::slotContinuousToggled( bool on )
 {
-    if ( Settings::viewContinuous() != on )
+    if ( KpdfSettings::viewContinuous() != on )
     {
-        Settings::setViewContinuous( on );
+        KpdfSettings::setViewContinuous( on );
         if ( d->document->pages() > 0 )
             slotRelayoutPages();
     }
