@@ -66,12 +66,12 @@ PresentationWidget::PresentationWidget( KPDFDocument * doc )
     connect( m_overlayHideTimer, SIGNAL( timeout() ), this, SLOT( slotHideOverlay() ) );
 
     // handle cursor appearance as specified in configuration
-    if ( Settings::slidesCursor() == Settings::EnumSlidesCursor::HiddenDelay )
+    if ( KpdfSettings::slidesCursor() == KpdfSettings::EnumSlidesCursor::HiddenDelay )
     {
         KCursor::setAutoHideCursor( this, true );
         KCursor::setHideCursorDelay( 3000 );
     }
-    else if ( Settings::slidesCursor() == Settings::EnumSlidesCursor::Hidden )
+    else if ( KpdfSettings::slidesCursor() == KpdfSettings::EnumSlidesCursor::Hidden )
     {
         setCursor( KCursor::blankCursor() );
     }
@@ -142,15 +142,15 @@ void PresentationWidget::notifySetup( const QValueVector< KPDFPage * > & pageSet
 void PresentationWidget::notifyViewportChanged( bool /*smoothMove*/ )
 {
     // discard notifications if displaying the summary
-    if ( m_frameIndex == -1 && Settings::slidesShowSummary() )
+    if ( m_frameIndex == -1 && KpdfSettings::slidesShowSummary() )
         return;
 
     // display the current page
     changePage( m_document->viewport().pageNumber );
 
     // auto advance to the next page if set
-    if ( Settings::slidesAdvance() )
-        QTimer::singleShot( Settings::slidesAdvanceTime() * 1000, this, SLOT( slotNextPage() ) );
+    if ( KpdfSettings::slidesAdvance() )
+        QTimer::singleShot( KpdfSettings::slidesAdvanceTime() * 1000, this, SLOT( slotNextPage() ) );
 }
 
 void PresentationWidget::notifyPageChanged( int pageNumber, int changedFlags )
@@ -266,7 +266,7 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
         m_document->addObserver( this );
 
         // show summary if requested
-        if ( Settings::slidesShowSummary() )
+        if ( KpdfSettings::slidesShowSummary() )
             generatePage();
     }
 
@@ -284,7 +284,7 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
         if ( !r.isValid() )
             continue;
 #ifdef ENABLE_PROGRESS_OVERLAY
-        if ( Settings::slidesShowProgress() && r.intersects( m_overlayGeometry ) )
+        if ( KpdfSettings::slidesShowProgress() && r.intersects( m_overlayGeometry ) )
         {
             // backbuffer the overlay operation
             QPixmap backPixmap( r.size() );
@@ -368,7 +368,7 @@ void PresentationWidget::generatePage()
 
     // generate the top-right corner overlay
 #ifdef ENABLE_PROGRESS_OVERLAY
-    if ( Settings::slidesShowProgress() && m_frameIndex != -1 )
+    if ( KpdfSettings::slidesShowProgress() && m_frameIndex != -1 )
         generateOverlay();
 #endif
 
@@ -459,7 +459,7 @@ void PresentationWidget::generateContentsPage( int pageNum, QPainter & p )
     for ( uint i = 0; i < rects.count(); i++ )
     {
         const QRect & r = rects[i];
-        p.fillRect( r, Settings::slidesBackgroundColor() );
+        p.fillRect( r, KpdfSettings::slidesBackgroundColor() );
     }
 }
 
@@ -542,7 +542,7 @@ void PresentationWidget::generateOverlay()
 void PresentationWidget::slotNextPage()
 {
     // loop when configured
-    if ( m_frameIndex == (int)m_frames.count() - 1 && Settings::slidesLoop() )
+    if ( m_frameIndex == (int)m_frames.count() - 1 && KpdfSettings::slidesLoop() )
         m_frameIndex = -1;
 
     if ( m_frameIndex < (int)m_frames.count() - 1 )
@@ -560,8 +560,8 @@ void PresentationWidget::slotNextPage()
     setFocus();
 
     // auto advance to the next page if set
-    if ( Settings::slidesAdvance() )
-        QTimer::singleShot( Settings::slidesAdvanceTime() * 1000, this, SLOT( slotNextPage() ) );
+    if ( KpdfSettings::slidesAdvance() )
+        QTimer::singleShot( KpdfSettings::slidesAdvanceTime() * 1000, this, SLOT( slotNextPage() ) );
 }
 
 void PresentationWidget::slotPrevPage()
@@ -605,73 +605,73 @@ void PresentationWidget::slotTransitionStep()
 
 const KPDFPageTransition PresentationWidget::defaultTransition() const
 {
-    return defaultTransition( Settings::slidesTransition() );
+    return defaultTransition( KpdfSettings::slidesTransition() );
 }
 
 const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
 {
     switch ( type )
     {
-        case Settings::EnumSlidesTransition::BlindsHorizontal:
+        case KpdfSettings::EnumSlidesTransition::BlindsHorizontal:
         {
             KPDFPageTransition transition( KPDFPageTransition::Blinds );
             transition.setAlignment( KPDFPageTransition::Horizontal );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::BlindsVertical:
+        case KpdfSettings::EnumSlidesTransition::BlindsVertical:
         {
             KPDFPageTransition transition( KPDFPageTransition::Blinds );
             transition.setAlignment( KPDFPageTransition::Vertical );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::BoxIn:
+        case KpdfSettings::EnumSlidesTransition::BoxIn:
         {
             KPDFPageTransition transition( KPDFPageTransition::Box );
             transition.setDirection( KPDFPageTransition::Inward );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::BoxOut:
+        case KpdfSettings::EnumSlidesTransition::BoxOut:
         {
             KPDFPageTransition transition( KPDFPageTransition::Box );
             transition.setDirection( KPDFPageTransition::Outward );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::Dissolve:
+        case KpdfSettings::EnumSlidesTransition::Dissolve:
         {
             return KPDFPageTransition( KPDFPageTransition::Dissolve );
             break;
         }
-        case Settings::EnumSlidesTransition::GlitterDown:
+        case KpdfSettings::EnumSlidesTransition::GlitterDown:
         {
             KPDFPageTransition transition( KPDFPageTransition::Glitter );
             transition.setAngle( 270 );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::GlitterRight:
+        case KpdfSettings::EnumSlidesTransition::GlitterRight:
         {
             KPDFPageTransition transition( KPDFPageTransition::Glitter );
             transition.setAngle( 0 );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::GlitterRightDown:
+        case KpdfSettings::EnumSlidesTransition::GlitterRightDown:
         {
             KPDFPageTransition transition( KPDFPageTransition::Glitter );
             transition.setAngle( 315 );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::Random:
+        case KpdfSettings::EnumSlidesTransition::Random:
         {
             return defaultTransition( KApplication::random() % 18 );
             break;
         }
-        case Settings::EnumSlidesTransition::SplitHorizontalIn:
+        case KpdfSettings::EnumSlidesTransition::SplitHorizontalIn:
         {
             KPDFPageTransition transition( KPDFPageTransition::Split );
             transition.setAlignment( KPDFPageTransition::Horizontal );
@@ -679,7 +679,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::SplitHorizontalOut:
+        case KpdfSettings::EnumSlidesTransition::SplitHorizontalOut:
         {
             KPDFPageTransition transition( KPDFPageTransition::Split );
             transition.setAlignment( KPDFPageTransition::Horizontal );
@@ -687,7 +687,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::SplitVerticalIn:
+        case KpdfSettings::EnumSlidesTransition::SplitVerticalIn:
         {
             KPDFPageTransition transition( KPDFPageTransition::Split );
             transition.setAlignment( KPDFPageTransition::Vertical );
@@ -695,7 +695,7 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::SplitVerticalOut:
+        case KpdfSettings::EnumSlidesTransition::SplitVerticalOut:
         {
             KPDFPageTransition transition( KPDFPageTransition::Split );
             transition.setAlignment( KPDFPageTransition::Vertical );
@@ -703,35 +703,35 @@ const KPDFPageTransition PresentationWidget::defaultTransition( int type ) const
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::WipeDown:
+        case KpdfSettings::EnumSlidesTransition::WipeDown:
         {
             KPDFPageTransition transition( KPDFPageTransition::Wipe );
             transition.setAngle( 270 );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::WipeRight:
+        case KpdfSettings::EnumSlidesTransition::WipeRight:
         {
             KPDFPageTransition transition( KPDFPageTransition::Wipe );
             transition.setAngle( 0 );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::WipeLeft:
+        case KpdfSettings::EnumSlidesTransition::WipeLeft:
         {
             KPDFPageTransition transition( KPDFPageTransition::Wipe );
             transition.setAngle( 180 );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::WipeUp:
+        case KpdfSettings::EnumSlidesTransition::WipeUp:
         {
             KPDFPageTransition transition( KPDFPageTransition::Wipe );
             transition.setAngle( 90 );
             return transition;
             break;
         }
-        case Settings::EnumSlidesTransition::Replace:
+        case KpdfSettings::EnumSlidesTransition::Replace:
         default:
             return KPDFPageTransition( KPDFPageTransition::Replace );
             break;
