@@ -39,7 +39,7 @@ PMCameraEdit::PMCameraEdit( QWidget* parent, const char* name )
 void PMCameraEdit::createTopWidgets( )
 {
    Base::createTopWidgets( );
-   
+
    QGridLayout* layout;
    QLabel* label;
 
@@ -57,7 +57,7 @@ void PMCameraEdit::createTopWidgets( )
    m_pCylinderType->insertItem( i18n( "2: Horizontal, Fixed Viewpoint" ) );
    m_pCylinderType->insertItem( i18n( "3: Vertical, Variable Viewpoint" ) );
    m_pCylinderType->insertItem( i18n( "4: Horizontal, Variable Viewpoint" ) );
-   
+
    m_pLocation = new PMVectorEdit( "x", "y", "z", this );
    m_pSky = new PMVectorEdit( "x", "y", "z", this );
    m_pDirection = new PMVectorEdit( "x", "y", "z", this );
@@ -74,17 +74,17 @@ void PMCameraEdit::createTopWidgets( )
    m_pCylinderTypeLabel = new QLabel( i18n( "Cylinder type:" ), this );
    hl->addWidget( m_pCylinderTypeLabel );
    hl->addWidget( m_pCylinderType );
-   
+
    layout = new QGridLayout( topLayout( ), 7, 2 );
    layout->addWidget( new QLabel( i18n( "Location:" ), this ), 0, 0 );
    layout->addWidget( m_pLocation, 0, 1 );
-   
+
    layout->addWidget( new QLabel( i18n( "Sky:" ), this ), 1, 0 );
    layout->addWidget( m_pSky, 1, 1 );
 
    layout->addWidget( new QLabel( i18n( "Direction:" ), this ), 2, 0 );
    layout->addWidget( m_pDirection, 2, 1 );
-   
+
    layout->addWidget( new QLabel( i18n( "Right:" ), this ), 3, 0 );
    layout->addWidget( m_pRight, 3, 1 );
 
@@ -108,39 +108,39 @@ void PMCameraEdit::createTopWidgets( )
    m_pBlurSamples->setValidation( true, 0, false, 0 );
    m_focalWidgets.append( m_pBlurSamples );
    m_pFocalPoint = new PMVectorEdit( "x", "y", "z", this );
-   m_focalWidgets.append( m_pFocalPoint );   
+   m_focalWidgets.append( m_pFocalPoint );
    m_pConfidence = new PMFloatEdit( this );
    m_pConfidence->setValidation( true, 0, true, 1 );
    m_focalWidgets.append( m_pConfidence );
    m_pVariance = new PMFloatEdit( this );
    m_pVariance->setValidation( true, 0, false, 0 );
    m_focalWidgets.append( m_pVariance );
-   
+
    layout = new QGridLayout( topLayout( ), 5, 2 );
    label = new QLabel( i18n( "Aperture:" ), this );
-   m_focalWidgets.append( label );   
+   m_focalWidgets.append( label );
    layout->addWidget( label, 0, 0 );
    layout->addWidget( m_pAperture, 0, 1 );
    label = new QLabel( i18n( "Blur samples:" ), this );
-   m_focalWidgets.append( label );   
+   m_focalWidgets.append( label );
    layout->addWidget( label, 1, 0 );
    layout->addWidget( m_pBlurSamples, 1, 1 );
    label = new QLabel( i18n( "Focal point:" ), this );
-   m_focalWidgets.append( label );   
+   m_focalWidgets.append( label );
    layout->addWidget( label, 2, 0 );
    layout->addWidget( m_pFocalPoint, 2, 1 );
    label = new QLabel( i18n( "Confidence:" ), this );
-   m_focalWidgets.append( label );   
+   m_focalWidgets.append( label );
    layout->addWidget( label, 3, 0 );
    layout->addWidget( m_pConfidence, 3, 1 );
    label = new QLabel( i18n( "Variance:" ), this );
-   m_focalWidgets.append( label );   
+   m_focalWidgets.append( label );
    layout->addWidget( label, 4, 0 );
    layout->addWidget( m_pVariance, 4, 1 );
-   
-   m_pExport = new QCheckBox( i18n( "Export" ), this );
+
+   m_pExport = new QCheckBox( i18n( "Export to renderer" ), this );
    topLayout( )->addWidget( m_pExport );
-   
+
    connect( m_pLocation, SIGNAL( dataChanged( ) ), SIGNAL( dataChanged( ) ) );
    connect( m_pDirection, SIGNAL( dataChanged( ) ), SLOT( slotDirectionChanged( ) ) );
    connect( m_pRight, SIGNAL( dataChanged( ) ), SIGNAL( dataChanged( ) ) );
@@ -211,7 +211,7 @@ void PMCameraEdit::displayObject( PMObject* o )
       m_pConfidence->setReadOnly( readOnly );
       m_pVariance->setValue( m_pDisplayedObject->variance( ) );
       m_pVariance->setReadOnly( readOnly );
-      
+
       m_pExport->setChecked( m_pDisplayedObject->exportPovray( ) );
       m_pExport->setEnabled( !readOnly );
 
@@ -262,7 +262,7 @@ bool PMCameraEdit::isDataValid( )
       return false;
    if( approxZero( m_pSky->vector( ).abs( ) ) )
    {
-      KMessageBox::error( this, i18n( "The sky vector may not be a null vector" ),
+      KMessageBox::error( this, i18n( "The sky vector may not be a null vector." ),
                           i18n( "Error" ) );
       m_pSky->setFocus( );
       return false;
@@ -271,7 +271,7 @@ bool PMCameraEdit::isDataValid( )
       return false;
    if( approxZero( m_pDirection->vector( ).abs( ) ) )
    {
-      KMessageBox::error( this, i18n( "The direction vector may not be a null vector" ),
+      KMessageBox::error( this, i18n( "The direction vector may not be a null vector." ),
                           i18n( "Error" ) );
       m_pDirection->setFocus( );
       return false;
@@ -280,7 +280,7 @@ bool PMCameraEdit::isDataValid( )
       return false;
    if( approxZero( m_pRight->vector( ).abs( ) ) )
    {
-      KMessageBox::error( this, i18n( "The right vector may not be a null vector" ),
+      KMessageBox::error( this, i18n( "The right vector may not be a null vector." ),
                           i18n( "Error" ) );
       m_pRight->setFocus( );
       return false;
@@ -289,7 +289,7 @@ bool PMCameraEdit::isDataValid( )
       return false;
    if( approxZero( m_pUp->vector( ).abs( ) ) )
    {
-      KMessageBox::error( this, i18n( "The up vector may not be a null vector" ),
+      KMessageBox::error( this, i18n( "The up vector may not be a null vector." ),
                           i18n( "Error" ) );
       m_pDirection->setFocus( );
       return false;
@@ -305,7 +305,7 @@ bool PMCameraEdit::isDataValid( )
       if( angle >= 180.0 )
       {
          KMessageBox::error( this, i18n( "Angle has to be smaller than 180"
-                                         " degrees for that camera type" ),
+                                         " degrees for that camera type." ),
                              i18n( "Error" ) );
          m_pAngle->setFocus( );
          return false;
