@@ -32,6 +32,7 @@
 
 class PMObject;
 class PMPart;
+class PMCommandManager;
 
 /**
  * Constants for object changes
@@ -92,7 +93,7 @@ public:
    /**
     * Creates a command with command text text
     */
-   PMCommand( QString text )
+   PMCommand( const QString &text )
    { m_text = text; }
    /**
     * Deletes the command.
@@ -118,7 +119,7 @@ public:
     * Returns the error message
     */
    PMMessageList messages( ) { return m_errors; }
-   
+
 protected:
    /**
     * Executes the command and stores undo information.
@@ -132,7 +133,7 @@ protected:
     * The error messages
     */
    PMMessageList m_errors;
-   
+
 private:
    /**
     * The command text.
