@@ -41,12 +41,12 @@
 #include <X11/Xlib.h>
 #endif
 #else
-
+#include <qapplication.h>
 #include <qtoolbar.h>
 #include <qpopupmenu.h>
 #endif
 
-#include "pmglobals.h"
+#include "pmdebug.h"
 
 #include <kparts/event.h>
 #include <kparts/part.h>
@@ -56,8 +56,9 @@
 #include <kinstance.h>
 #include <khelpmenu.h>
 #include <kstandarddirs.h>
+#include <qapplication.h>
+#include <kdebug.h>
 #include <kxmlguifactory.h>
-#include <kapplication.h>
 
 #include <assert.h>
 
@@ -178,7 +179,7 @@ void PMDockMainWindow::createGUI( Part * part )
 
   if( !d->m_bShellGUIActivated )
   {
-    // loadPlugins( this, this, KGlobal::instance() );
+    loadPlugins( this, this, KGlobal::instance() );
     createShellGUI();
     d->m_bShellGUIActivated = true;
   }
@@ -2072,7 +2073,7 @@ void PMDockManager::writeConfig( KConfig* c, QString group )
         c->writeEntry( cname+":curTab", ((PMDockTabGroup*)obj->widget)->currentPageIndex() );
 
         nameList.append( obj->name() );
-        findList.append( obj->name() ); // not realy need !!!
+        findList.append( obj->name() ); // not really need !!!
         //debug("  Save %s", nList.current());
         nList.remove();
         nList.first();
