@@ -20,9 +20,6 @@
 #include "pmmaterial.h"
 #include "pmlinkedit.h"
 
-#include <kdebug.h>
-#include "pmglobals.h"
-
 #include <qlayout.h>
 #include <qlabel.h>
 #include <klocale.h>
@@ -36,7 +33,7 @@ PMMaterialEdit::PMMaterialEdit( QWidget* parent, const char* name )
 
 void PMMaterialEdit::displayObject( PMObject* o )
 {
-   if( o->isA( PMTMaterial ) )
+   if( o->isA( "Material" ) )
    {
       Base::displayObject( o );
    }
