@@ -20,7 +20,7 @@
 #include "pmxmlhelper.h"
 #include "pmmemento.h"
 
-PMDefinePropertyClass( PMNamedObject, PMProperty );
+PMDefinePropertyClass( PMNamedObject, PMNamedObjectProperty );
 
 PMMetaObject* PMNamedObject::s_pMetaObject = 0;
 
@@ -45,7 +45,7 @@ PMMetaObject* PMNamedObject::metaObject( ) const
    {
       s_pMetaObject = new PMMetaObject( "NamedObject", Base::metaObject( ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "name", &PMNamedObject::setName, &PMNamedObject::name ) );
+         new PMNamedObjectProperty( "name", &PMNamedObject::setName, &PMNamedObject::name ) );
    }
    return s_pMetaObject;
 }
