@@ -28,7 +28,7 @@
 
 #include <klocale.h>
 
-PMDefinePropertyClass( PMObjectLink, PMProperty );
+PMDefinePropertyClass( PMObjectLink, PMObjectLinkProperty );
 
 PMMetaObject* PMObjectLink::s_pMetaObject = 0;
 PMObject* createNewObjectLink( PMPart* part )
@@ -65,7 +65,7 @@ PMMetaObject* PMObjectLink::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "ObjectLink", Base::metaObject( ),
                                         createNewObjectLink );
       s_pMetaObject->addProperty(
-         new PMProperty( "linkedObject", &PMObjectLink::setLinkedObjectProperty,
+         new PMObjectLinkProperty( "linkedObject", &PMObjectLink::setLinkedObjectProperty,
                          &PMObjectLink::linkedObjectProperty ) );
    }
    return s_pMetaObject;
