@@ -33,6 +33,8 @@
 #include "pmsor.h"
 #include "pmprism.h"
 #include "pmsqe.h"
+#include "pmspheresweep.h"
+#include "pmheightfield.h"
 #include "pmtext.h"
 
 #include <qlayout.h>
@@ -57,8 +59,8 @@ PMObjectSettings::PMObjectSettings( QWidget* parent, const char* name )
    vlayout->addWidget( gb );
    gvl = new QVBoxLayout( gb, KDialog::marginHint( ), KDialog::spacingHint( ) );
    gvl->addSpacing( 10 );
-   grid = new QGridLayout( gvl, 11, 3 );
-   
+   grid = new QGridLayout( gvl, 13, 3 );
+
    grid->addWidget( new QLabel( i18n( "Sphere:" ), gb ), 0, 0 );
    hlayout = new QHBoxLayout( );
    grid->addLayout( hlayout, 0, 2 );
@@ -182,13 +184,34 @@ PMObjectSettings::PMObjectSettings( QWidget* parent, const char* name )
    m_pSqeVSteps->setValidation( true, 2, true, 8 );
    hlayout->addStretch( 1 );
 
+   grid->addWidget( new QLabel( i18n( "Sphere sweep:" ), gb ), 11, 0 );
+   hlayout = new QHBoxLayout( );
+   grid->addLayout( hlayout, 11, 2 );
+   grid->addWidget( new QLabel( "r", gb ), 11, 1 );
+   m_pSphereSweepRSteps = new PMIntEdit( gb );
+   hlayout->addWidget( m_pSphereSweepRSteps );
+   m_pSphereSweepRSteps->setValidation( true, 4, true, 64 );
+   hlayout->addWidget( new QLabel( "s", gb ) );
+   m_pSphereSweepSSteps = new PMIntEdit( gb );
+   hlayout->addWidget( m_pSphereSweepSSteps );
+   m_pSphereSweepSSteps->setValidation( true, 1, true, 16 );
+   hlayout->addStretch( 1 );
+
+   grid->addWidget( new QLabel( i18n( "Heightfield:" ), gb ), 12, 0 );
+   hlayout = new QHBoxLayout( );
+   grid->addLayout( hlayout, 12, 2 );
+   m_pHeightFieldVariance = new PMIntEdit( gb );
+   hlayout->addWidget( m_pHeightFieldVariance );
+   m_pHeightFieldVariance->setValidation( true, 1, true, 16 );
+   hlayout->addStretch( 1 );
+
    gb = new QGroupBox( i18n( "Sizes" ), this );
    vlayout->addWidget( gb );
    gvl = new QVBoxLayout( gb, KDialog::marginHint( ), KDialog::spacingHint( ) );
    gvl->addSpacing( 10 );
 
    grid = new QGridLayout( gvl, 1, 2 );
-   
+
    grid->addWidget( new QLabel( i18n( "Plane:" ), gb ), 0, 0 );
    hlayout = new QHBoxLayout( );
    grid->addLayout( hlayout, 0, 1 );
@@ -204,7 +227,7 @@ PMObjectSettings::PMObjectSettings( QWidget* parent, const char* name )
 
    m_pHighDetailCameraViews = new QCheckBox( i18n( "High detail for enhanced projections" ), gb );
    gvl->addWidget( m_pHighDetailCameraViews );
-   
+
    vlayout->addStretch( 1 );
 }
 
@@ -229,6 +252,9 @@ void PMObjectSettings::displaySettings( )
    m_pPrismSteps->setValue( PMPrism::sSteps( ) );
    m_pSqeUSteps->setValue( PMSuperquadricEllipsoid::uSteps( ) );
    m_pSqeVSteps->setValue( PMSuperquadricEllipsoid::vSteps( ) );
+   m_pSphereSweepRSteps->setValue( PMSphereSweep::rSteps( ) );
+   m_pSphereSweepSSteps->setValue( PMSphereSweep::sSteps( ) );
+   m_pHeightFieldVariance->setValue( PMHeightField::variance( ) );
    PMRenderManager* rm = PMRenderManager::theManager( );
    m_pHighDetailCameraViews->setChecked( rm->highDetailCameraViews( ) );
 }
@@ -253,6 +279,9 @@ void PMObjectSettings::displayDefaults( )
    m_pPrismSteps->setValue( c_defaultPrismSSteps );
    m_pSqeUSteps->setValue( c_defaultSuperquadricEllipsoidUSteps );
    m_pSqeVSteps->setValue( c_defaultSuperquadricEllipsoidVSteps );
+   m_pSphereSweepRSteps->setValue( c_defaultSphereSweepRSteps );
+   m_pSphereSweepSSteps->setValue( c_defaultSphereSweepSSteps );
+   m_pHeightFieldVariance->setValue( c_defaultHeightFieldVariance );
    m_pPlaneSize->setValue( c_defaultPlaneSize );
    m_pHighDetailCameraViews->setChecked( c_defaultHighDetailCameraView );
 }
@@ -311,19 +340,19 @@ bool PMObjectSettings::validateData( )
    {
       emit showMe( );
       m_pBlobSphereVSteps->setFocus( );
-      return false;      
+      return false;
    }
    if( !m_pBlobCylinderUSteps->isDataValid( ) )
    {
       emit showMe( );
       m_pBlobCylinderUSteps->setFocus( );
-      return false;      
+      return false;
    }
    if( !m_pBlobCylinderVSteps->isDataValid( ) )
    {
       emit showMe( );
       m_pBlobCylinderVSteps->setFocus( );
-      return false;      
+      return false;
    }
    if( !m_pLatheUSteps->isDataValid( ) )
    {
@@ -367,6 +396,24 @@ bool PMObjectSettings::validateData( )
       m_pSqeVSteps->setFocus( );
       return false;
    }
+   if( !m_pSphereSweepRSteps->isDataValid( ) )
+   {
+      emit showMe( );
+      m_pSphereSweepRSteps->setFocus( );
+      return false;
+   }
+   if( !m_pSphereSweepSSteps->isDataValid( ) )
+   {
+      emit showMe( );
+      m_pSphereSweepSSteps->setFocus( );
+      return false;
+   }
+   if( !m_pHeightFieldVariance->isDataValid( ) )
+   {
+      emit showMe( );
+      m_pHeightFieldVariance->setFocus( );
+      return false;
+   }
    if( !m_pPlaneSize->isDataValid( ) )
    {
       emit showMe( );
@@ -379,7 +426,7 @@ bool PMObjectSettings::validateData( )
 void PMObjectSettings::applySettings( )
 {
    bool repaint = false;
-   
+
    PMRenderManager* rm = PMRenderManager::theManager( );
    if( rm->highDetailCameraViews( ) != m_pHighDetailCameraViews->isChecked( ) )
    {
@@ -481,6 +528,21 @@ void PMObjectSettings::applySettings( )
       PMSuperquadricEllipsoid::setVSteps( m_pSqeVSteps->value( ) );
       repaint = true;
    }
+   if( PMSphereSweep::rSteps( ) != m_pSphereSweepRSteps->value( ) )
+   {
+      PMSphereSweep::setRSteps( m_pSphereSweepRSteps->value( ) );
+      repaint = true;
+   }
+   if( PMSphereSweep::sSteps( ) != m_pSphereSweepSSteps->value( ) )
+   {
+      PMSphereSweep::setSSteps( m_pSphereSweepSSteps->value( ) );
+      repaint = true;
+   }
+   if( PMHeightField::variance( ) != m_pHeightFieldVariance->value( ) );
+   {
+      PMHeightField::setVariance( m_pHeightFieldVariance->value( ) );
+      repaint = true;
+   }
    if( repaint )
       emit repaintViews( );
 }
