@@ -1014,7 +1014,7 @@ bool PMPart::setActiveObject( const QString& name )
    QString pathElem;
 
    // check if it's a absolute object name
-   if( name[0] = '/' )
+   if( name[0] == '/' )
    {
       tmpObj = m_pScene;
       objPath = name.mid( 1 );  // clear that first character
