@@ -38,6 +38,7 @@
 
 #include "pmobject.h"
 #include "pmcommandmanager.h"
+#include "pmpartiface.h"
 
 class PMView;
 class PMShell;
@@ -57,6 +58,7 @@ class PMIOManager;
 
 class QMimeSource;
 class KAction;
+class KSelectAction;
 class PMComboAction;
 class PMSpinBoxAction;
 class PMLabelAction;
@@ -65,7 +67,7 @@ class KProcess;
 /**
  * The part for kpovmodeler (povray document)
  */
-class PMPart : public KParts::ReadWritePart
+class PMPart : public KParts::ReadWritePart, virtual public PMPartIface
 {
    Q_OBJECT
 public:
@@ -128,6 +130,7 @@ public:
     * returns a reference to the list.
     */
    const PMObjectList& selectedObjects( );
+
    /**
     * Executes the command cmd.
     *
@@ -178,6 +181,34 @@ public:
     * The active object
     */
    PMObject* activeObject( ) const { return m_pActiveObject; }
+   /**
+    * The active object's name
+    */
+   virtual QString activeObjectName( );
+   /**
+    * Set the active object
+    */
+   virtual bool setActiveObject( const QString& name );
+   /**
+    * Get the valid properties of the currently active object
+    */
+   virtual QStringList getProperties( );
+   /**
+    * set a property on the active object
+    */
+   virtual bool setProperty( const QString& name, const PMVariant& value );
+   /**
+    * set a property on the active object
+    */
+   virtual bool setProperty( const QString& name, const QString& value );
+   /**
+    * get a property on the active object
+    */
+   virtual const PMVariant getProperty( const QString& name );
+   /**
+    * get a property on the active object
+    */
+   virtual const QString getPropertyStr( const QString& name );
    /**
     * List of control points of the active object
     */
@@ -266,11 +297,24 @@ public slots:
     * Inserts a new PMObject of type type
     */
    void slotNewObject( const QString& type );
+   /**
+    * Inserts a new PMObject of type type at position pos.
+    * pos can be one of:
+    *     FirstChild
+    *     LastChild
+    *     Sibling
+    */
+   void slotNewObject( const QString& type, const QString& pos );
    /**
     * Inserts the new PMObject. The object will be deleted if it can't be
     * inserted or the user aborts the action
     */
-   void slotNewObject( PMObject* newObject );
+   void slotNewObject( PMObject* newObject, int insertAs = 0 );
+
+   /**
+    * List the known object types
+    */
+   virtual QStringList getObjectTypes( );
 
    /**
     * Adds transformations to the object and calls slotNewObject
@@ -615,7 +659,7 @@ public slots:
    /**
     * Starts rendering with povray
     */
-   void slotRender( );
+   virtual void slotRender( );
    /**
     * Opens the render settings
     */
@@ -640,11 +684,11 @@ public slots:
     * Called when the visibility level action is plugged into the toolbar
     */
    void slotVisibilityActionPlugged( );
-
    /**
-    * Opens the Import library object dialog
+    * Called when the global detail level has changed
     */
-   void slotImportLibraryObject( );
+   void slotGlobalDetailLevelChanged( int level );
+
    /**
     * Opens the search library object dialog
     */
@@ -655,7 +699,7 @@ public slots:
    /** */
    virtual void setModified( bool modified );
 
-   /** Set the scene object. To be used with extreme care. */
+   /** Set the scene object. Must be used with extreme care. */
    void setScene( PMScene* scene );
 
 signals:
@@ -691,6 +735,7 @@ signals:
     * Views should ask the user to save pending changes.
     */
    void aboutToRender( );
+
 protected:
    /**
     * reimplemented from @ref KParts::ReadOnlyPart
@@ -948,8 +993,6 @@ private:
    KAction* m_pNewSphereSweepAction;
    KAction* m_pNewMeshAction;
 
-   KAction* m_pImportLibraryObjectAction;
-   KAction* m_pExportLibraryObjectAction;
    KAction* m_pSearchLibraryObjectAction;
 
    PMComboAction* m_pRenderComboAction;
@@ -958,6 +1001,8 @@ private:
    KAction* m_pRenderAction;
    PMSpinBoxAction* m_pVisibilityLevelAction;
    PMLabelAction* m_pVisibilityLabelAction;
+   KSelectAction* m_pGlobalDetailAction;
+   PMLabelAction* m_pGlobalDetailLabelAction;
 
    QPtrList<KAction> m_readWriteActions;
 
