@@ -24,7 +24,7 @@
 
 #include <klocale.h>
 
-PMDefinePropertyClass( PMPovrayMatrix, PMProperty );
+PMDefinePropertyClass( PMPovrayMatrix, PMPovrayMatrixProperty );
 
 PMMetaObject* PMPovrayMatrix::s_pMetaObject = 0;
 PMObject* createNewPovrayMatrix( PMPart* part )
@@ -79,7 +79,7 @@ PMMetaObject* PMPovrayMatrix::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "PovrayMatrix", Base::metaObject( ),
                                         createNewPovrayMatrix );
       s_pMetaObject->addProperty(
-         new PMProperty( "values", &PMPovrayMatrix::setValues, &PMPovrayMatrix::values ) );
+         new PMPovrayMatrixProperty( "values", &PMPovrayMatrix::setValues, &PMPovrayMatrix::values ) );
    }
    return s_pMetaObject;
 }
