@@ -29,6 +29,7 @@
 #include <qstringlist.h>
 
 #include "pmrendermode.h"
+#include "pmdragwidget.h"
 
 class KProcess;
 class KConfig;
@@ -39,7 +40,7 @@ class KTempFile;
  * Widget that calls povray to render a scene and
  * displays the output.
  */
-class PMPovrayRenderWidget : public QWidget
+class PMPovrayRenderWidget : public PMDragWidget
 {
    Q_OBJECT
 public:
@@ -91,6 +92,7 @@ public:
    { s_libraryPaths = slist; }
    virtual QSize sizeHint( ) const;
 
+   virtual void startDrag( );
 signals:
    /**
     * Emitted when rendering has finished
