@@ -553,7 +553,7 @@ void PMPrismEdit::slotAddSubPrism( )
    if( m_pSplineType->currentItem( ) == 3 )
    {
       KMessageBox::information( this, i18n( "Sub prisms do not work with "
-                                            "bezier splines in POV-Ray 3.1" ),
+                                            "bezier splines in POV-Ray 3.1." ),
                                 i18n( "Warning" ), "subPrismWithBezierSplines" );
    }
    
