@@ -41,6 +41,8 @@
 #include "pmunknownview.h"
 #include "pmviewlayoutmanager.h"
 
+//#define KPM_WITH_OBJECT_LIBRARY
+
 const int c_statusBarInfo = 0;
 const int c_statusBarControlPoints = 1;
 
@@ -49,20 +51,23 @@ PMShell::PMShell( const KURL& url )
 {
    setPluginLoadingMode( DoNotLoadPlugins );
    setInstance( PMFactory::instance( ), false );
-   
+
    m_pPart = new PMPart( this, "part", this, "part", true, this );
    m_pPart->setReadWrite( ); // read-write mode
    m_viewNumber = 0;
    m_objectsToDelete.setAutoDelete( true );
 
+   if (!initialGeometrySet())
+      resize(800,600);
+
    setupActions( );
-   
+
    restoreOptions( );
-   
+
    setupView( );
    setXMLFile( "kpovmodelershell.rc" );
    createGUI( m_pPart );
-   
+
    //guiFactory( )->addClient( m_pPart );
    m_pStatusBar = statusBar( );
    m_pStatusBar->insertItem( " ", c_statusBarInfo, 1 );
@@ -71,7 +76,7 @@ PMShell::PMShell( const KURL& url )
    KConfig* config = instance( )->config( );
    config->setGroup( "Appearance" );
    applyMainWindowSettings( config );
-   
+
    if( !url.isEmpty( ) )
       openURL( url );
 
@@ -106,17 +111,18 @@ void PMShell::setupActions( )
    m_pPathAction = new KToggleAction( i18n( "Show &Path" ), 0, this,
                                SLOT( slotShowPath( ) ), actionCollection( ),
                                "options_show_path" );
+   m_pPathAction->setCheckedState(i18n("Hide &Path"));
 
    m_pStatusbarAction = KStdAction::showStatusbar( this, SLOT( slotShowStatusbar( ) ),
                                                    actionCollection( ) );
 
    KStdAction::saveOptions( this, SLOT( saveOptions( ) ), actionCollection( ) );
-   
+
    KStdAction::keyBindings( this, SLOT( slotConfigureKeys( ) ),
                             actionCollection( ) );
    KStdAction::configureToolbars( this, SLOT( slotConfigureToolbars( ) ),
                                   actionCollection( ) );
-   KStdAction::preferences( this, SLOT( slotSettings( ) ), actionCollection( ) );   
+   KStdAction::preferences( this, SLOT( slotSettings( ) ), actionCollection( ) );
 
    m_pNewTopViewAction = new KAction( i18n( "New Top View" ), 0, this,
                                       SLOT( slotNewTopView( ) ),
@@ -139,16 +145,22 @@ void PMShell::setupActions( )
    m_pNewCameraViewAction = new KAction( i18n( "New Camera View" ), 0, this,
                                          SLOT( slotNewCameraView( ) ),
                                          actionCollection( ), "view_new_cameraview" );
-   
+
    m_pNewTreeViewAction = new KAction( i18n( "New Object Tree" ), 0, this,
                               SLOT( slotNewTreeView( ) ), actionCollection( ),
                               "view_new_treeview" );
    m_pNewDialogViewAction = new KAction( i18n( "New Properties View" ), 0, this,
                              SLOT( slotNewDialogView( ) ), actionCollection( ),
                              "view_new_dialogview" );
-   
+
+#ifdef KPM_WITH_OBJECT_LIBRARY
+   m_pNewLibraryBrowserAction = new KAction( i18n( "New Library Browser" ), 0, this,
+                                    SLOT( slotNewLibraryBrowserView( ) ), actionCollection( ),
+                                    "view_new_librarybrowser" );
+#endif
+
    // Creating the view layouts menu
-   m_pViewLayoutsAction = new KActionMenu( i18n( "View Layouts" ), 
+   m_pViewLayoutsAction = new KActionMenu( i18n( "View Layouts" ),
                                            actionCollection( ), "view_layouts_menu" );
    KPopupMenu* menu = m_pViewLayoutsAction->popupMenu( );
    connect( menu, SIGNAL( aboutToShow( ) ), SLOT( slotViewsMenuAboutToShow( ) ) );
@@ -171,13 +183,13 @@ PMDockWidget* PMShell::createView( const QString& t, PMViewOptions* o,
 {
    PMDockWidget* dock = 0;
    PMViewBase* contents = 0;
-   
+
    PMViewTypeFactory* factory =
       PMViewFactory::theFactory( )->viewFactory( t );
 
    m_viewNumber++;
    QString name = QString( "View (%1)" ).arg( m_viewNumber );
-   
+
    if( factory )
    {
       QString desc;
@@ -186,7 +198,7 @@ PMDockWidget* PMShell::createView( const QString& t, PMViewOptions* o,
          desc = factory->description( o );
       else
          desc = factory->description( );
-         
+
       dock = createDockWidget( name, SmallIcon( factory->iconName( ) ), 0L,
                                desc, desc );
       contents = factory->newInstance( dock, m_pPart );
@@ -204,7 +216,7 @@ PMDockWidget* PMShell::createView( const QString& t, PMViewOptions* o,
    dock->setWidget( contents );
    connect( dock, SIGNAL( headerCloseButtonClicked( ) ),
             SLOT( slotDockWidgetClosed( ) ) );
-   
+
    if( initPosition )
    {
       dock->resize( 300, 400 );
@@ -228,7 +240,7 @@ PMDockWidget* PMShell::createTreeView( )
 
    connect( dock, SIGNAL( headerCloseButtonClicked( ) ),
             SLOT( slotDockWidgetClosed( ) ) );
-   
+
    return dock;
 }
 
@@ -245,7 +257,7 @@ PMDockWidget* PMShell::createDialogView( )
 
    connect( dock, SIGNAL( headerCloseButtonClicked( ) ),
             SLOT( slotDockWidgetClosed( ) ) );
-   
+
    return dock;
 }
 
@@ -262,10 +274,10 @@ PMDockWidget* PMShell::create3DView( PMGLView::PMViewType t )
    connect( vgl, SIGNAL( viewTypeChanged( const QString& ) ),
             dock, SLOT( slotSetCaption( const QString& ) ) );
    dock->slotSetCaption( PMGLView::viewTypeAsString( t ) );
-   
+
    connect( dock, SIGNAL( headerCloseButtonClicked( ) ),
             SLOT( slotDockWidgetClosed( ) ) );
-   
+
    return dock;
 }
 */
@@ -322,6 +334,11 @@ void PMShell::slotNewTreeView( )
    createView( "treeview" );
 }
 
+void PMShell::slotNewLibraryBrowserView( )
+{
+   createView( "librarybrowserview" );
+}
+
 void PMShell::slotDockWidgetClosed( )
 {
    const QObject* o = sender( );
@@ -343,7 +360,7 @@ void PMShell::slotDeleteClosedObjects( )
 void PMShell::openURL( const KURL& url )
 {
    m_pRecent->addURL( url );
-   
+
    if( !m_pPart->isModified( ) && m_pPart->url( ).isEmpty( ) )
    {
       m_pPart->openURL( url );
@@ -354,7 +371,7 @@ void PMShell::openURL( const KURL& url )
       PMShell *shell = new PMShell( );
       shell->show( );
       shell->openURL( url );
-   }  
+   }
 }
 
 void PMShell::slotOpenRecent( const KURL& url )
@@ -379,7 +396,7 @@ void PMShell::slotFileNew( )
    {
       PMShell *shell = new PMShell( );
       shell->show( );
-   }  
+   }
 }
 
 void PMShell::slotFileOpen( )
@@ -424,7 +441,7 @@ void PMShell::slotFileSaveAs( )
       if( dlg.currentFilter( ) == QString( "*.kpm" ) )
          if( QFileInfo( url.path( ) ).extension( ).isEmpty( ) )
             url.setPath( url.path( ) + ".kpm" );
-      
+
       if( overwriteURL( url ) )
       {
          m_pRecent->addURL( url );
@@ -538,7 +555,7 @@ void PMShell::saveOptions( )
    // set group
    config->setGroup( "Appearance" );
    config->writeEntry( "ShowStatusbar", m_pStatusbarAction->isChecked( ) );
-   saveMainWindowSettings( config ); 
+   saveMainWindowSettings( config );
    m_pRecent->saveEntries( config );
 
    if( m_pPart )
@@ -596,6 +613,10 @@ bool PMShell::queryClose( )
    return m_pPart->closeURL( );
 }
 
+void PMShell::showEvent( QShowEvent* ){
+   activateDock( );
+}
+
 void PMShell::slotModified( )
 {
    setCaption( m_pPart->url( ).prettyURL( ) );
@@ -613,7 +634,7 @@ void PMShell::slotControlPointMsg( const QString& msg )
 bool PMShell::overwriteURL( const KURL& u )
 {
    int query = KMessageBox::Yes;
-   
+
    if( u.isLocalFile( ) )
    {
       QFileInfo info;
