@@ -21,7 +21,7 @@
 #include "pmmemento.h"
 
 
-PMDefinePropertyClass( PMSolidObject, PMProperty );
+PMDefinePropertyClass( PMSolidObject, PMSolidObjectProperty );
 
 PMMetaObject* PMSolidObject::s_pMetaObject = 0;
 
@@ -49,9 +49,9 @@ PMMetaObject* PMSolidObject::metaObject( ) const
    {
       s_pMetaObject = new PMMetaObject( "SolidObject", Base::metaObject( ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "inverse", &PMSolidObject::setInverse, &PMSolidObject::inverse ) );
+         new PMSolidObjectProperty( "inverse", &PMSolidObject::setInverse, &PMSolidObject::inverse ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "hollow", &PMSolidObject::setHollow, &PMSolidObject::hollow ) );
+         new PMSolidObjectProperty( "hollow", &PMSolidObject::setHollow, &PMSolidObject::hollow ) );
    }
    return s_pMetaObject;
 }
