@@ -2,7 +2,7 @@
 **************************************************************************
                                  description
                              --------------------
-    copyright            : (C) 2000-2002 by Andreas Zehender
+    copyright            : (C) 2000-2003 by Andreas Zehender
     email                : zehender@kde.org
 **************************************************************************
 
@@ -38,11 +38,23 @@
 #include "pmobjectdrag.h"
 
 
+PMTreeViewWidget::PMTreeViewWidget( PMPart* part, QWidget* parent /*= 0*/,
+                                    const char* name /*=0*/ )
+      : PMViewBase( parent, name )
+{
+   QHBoxLayout* hl = new QHBoxLayout( this );
+   PMTreeView* tv = new PMTreeView( part, this );
+   hl->addWidget( tv );
+}
 
+QString PMTreeViewWidget::description( ) const
+{
+   return i18n( "Object Tree" );
+}
 
 PMTreeView::PMTreeView( PMPart* part, QWidget* parent /*= 0*/,
                         const char* name /*= 0*/ )
-      :QListView( parent, name )
+      : QListView( parent, name )
 {
    addColumn( i18n( "Objects" ) );
    header( )->hide( );
@@ -69,15 +81,11 @@ PMTreeView::PMTreeView( PMPart* part, QWidget* parent /*= 0*/,
 
    connect( part, SIGNAL( refresh( ) ), SLOT( slotRefresh( ) ) );
    connect( part, SIGNAL( objectChanged( PMObject*, const int, QObject* ) ),
-            SLOT( slotObjectChanged( PMObject*, const int, QObject* ) ) );
+                  SLOT( slotObjectChanged( PMObject*, const int, QObject* ) ) );
    connect( part, SIGNAL( clear( ) ), SLOT( slotClear( ) ) );
    connect( this, SIGNAL( objectChanged( PMObject*, const int, QObject* ) ),
             part, SLOT( slotObjectChanged( PMObject*, const int, QObject* ) ) );
 
-   part->addTreeView( this );
-   connect( this, SIGNAL( destroyed( PMTreeView* ) ),
-            part, SLOT( removeTreeView( PMTreeView* ) ) );
-   
    slotRefresh( );
 }
 
@@ -92,7 +100,7 @@ void PMTreeView::slotObjectChanged( PMObject* obj, const int mode,
    PMTreeViewItem* pTreeItem = 0;
    bool as = m_acceptSelect;
    m_acceptSelect = true;
-   
+
    if( sender != this )
    {
       if( ( mode & PMCAdd ) && !( mode & PMCInsertError ) )
@@ -112,7 +120,7 @@ void PMTreeView::slotObjectChanged( PMObject* obj, const int mode,
                PMObject* hObj = obj->prevSibling( );
                QListViewItem* pSibling = 0;
                bool found = false;
-               
+
                if( hObj )
                {
                   // find the previous sibling
@@ -137,7 +145,7 @@ void PMTreeView::slotObjectChanged( PMObject* obj, const int mode,
                }
             }
          }
-      
+
          if( pTreeItem )
          {
             // add child items if necessary
@@ -176,7 +184,7 @@ void PMTreeView::slotObjectChanged( PMObject* obj, const int mode,
          {
             if( !pTreeItem )
                pTreeItem = findObject( obj );
-      
+
             if( pTreeItem )
             {
                PMTreeViewItem* p;
@@ -211,7 +219,7 @@ void PMTreeView::slotObjectChanged( PMObject* obj, const int mode,
          // special case for texture maps
          if( obj )
          {
-            if( obj->isA( PMTTextureMapBase ) )
+            if( obj->isA( "TextureMapBase" ) )
             {
                if( !pTreeItem )
                   pTreeItem = findObject( obj );
@@ -232,7 +240,7 @@ void PMTreeView::slotObjectChanged( PMObject* obj, const int mode,
 PMTreeViewItem* PMTreeView::findObject( const PMObject* obj )
 {
    PMTreeViewItem* pTreeItem = 0;
-   
+
    if( !obj->parent( ) )
    {
       // top level object
@@ -261,9 +269,9 @@ void PMTreeView::selectItem( QListViewItem* /*sitem*/ )
 /*   QListViewItem* pItem = 0;
    bool emitSig;
    emitSig = ( m_pSelectedObject != ( ( PMTreeViewItem* ) sitem )->object( ) );
-   
+
    m_pSelectedObject = ( ( PMTreeViewItem* ) sitem )->object( );
-   
+
    for( pItem = sitem->parent( ); pItem; pItem = pItem->parent( ) )
       pItem->setOpen( true );
    ensureItemVisible( sitem );
@@ -324,7 +332,7 @@ void PMTreeView::itemSelected( PMTreeViewItem* item, bool selected )
    if( m_event )
    {
       m_pLastSelected = item;
-      
+
       if( selected )
          m_itemSelected = true;
       else
@@ -345,9 +353,9 @@ void PMTreeView::contentsMousePressEvent( QMouseEvent * e )
    m_selectionCleared = false;
    m_selectOnReleaseEvent = false;
    bool specialAction = false;
-   
+
    QListViewItem* oldCurrent = currentItem( );
-   
+
    m_event = true;
    m_acceptSelect = true;
    QListView::contentsMousePressEvent( e );
@@ -371,7 +379,7 @@ void PMTreeView::contentsMousePressEvent( QMouseEvent * e )
          {
             clearSelection( );
             m_pLastSelected->setSelected( true );
-         
+
             emit objectChanged( m_pLastSelected->object( ), PMCNewSelection,
                                 this );
          }
@@ -395,7 +403,7 @@ void PMTreeView::contentsMousePressEvent( QMouseEvent * e )
             {
                bool down = oldCurrent->itemPos( ) < m_pLastSelected->itemPos( );
                QListViewItem* tmp;
-               
+
                if( down )
                {
                   for( tmp = oldCurrent; tmp; tmp = tmp->nextSibling( ) )
@@ -417,7 +425,7 @@ void PMTreeView::contentsMousePressEvent( QMouseEvent * e )
                      if( tmp == oldCurrent )
                         break;
                   }
-               }  
+               }
             }
             else
                m_pLastSelected->setSelected( false );
@@ -464,15 +472,18 @@ void PMTreeView::viewportMousePressEvent( QMouseEvent* e )
    m_acceptSelect = false;
 
    m_pressed = false;
-   
+
    QPoint p = e->pos( );
 
    if( e->button( ) & RightButton )
    {
-      QPopupMenu* m =
-         ( QPopupMenu* ) m_pPart->factory( )->container( "treeViewPopup", m_pPart );
-      if( m )
-         m->exec( QCursor::pos( ) );
+      if( m_pPart->factory( ) ) 
+      {
+         QPopupMenu* m =
+            ( QPopupMenu* ) m_pPart->factory( )->container( "treeViewPopup", m_pPart );
+         if( m )
+            m->exec( QCursor::pos( ) );
+      }
       return;
    }
 
@@ -486,15 +497,15 @@ void PMTreeView::viewportMousePressEvent( QMouseEvent* e )
              p.x( ) < header( )->cellPos( header( )->mapToActual( 0 ) ) ) )
          item = 0; // p is on the root decoration
    }
-   
+
    if( item )
    {
       if( e->button( ) == LeftButton || e->button( ) == MidButton )
-      {   
+      {
          m_pressed = true;
          m_pressedPos = e->pos( );
          m_pressedItem = item;
-         return;  
+         return;
       }
    }
 }
@@ -517,7 +528,7 @@ void PMTreeView::viewportMouseReleaseEvent( QMouseEvent* e )
          clearSelection( );
          m_pLastSelected->setSelected( true );
          m_acceptSelect = false;
-         
+
          emit objectChanged( m_pLastSelected->object( ), PMCNewSelection, this );
       }
    }
@@ -537,18 +548,18 @@ void PMTreeView::viewportMouseMoveEvent( QMouseEvent *e )
            abs( y - m_pressedPos.y( ) ) > KGlobalSettings::dndEventDelay( ) )
       {
          m_selectOnReleaseEvent = false;
-         
+
          // Calculate hotspot
          QPoint hotspot;
          PMObjectList sortedList = m_pPart->selectedObjects( );
-         
+
          // Do not handle more mouse move or mouse release events
          m_pressed = false;
 
          if( sortedList.count( ) > 0 )
          {
-            PMObjectDrag* d = new PMObjectDrag( sortedList, viewport( ) );
-         
+            PMObjectDrag* d = new PMObjectDrag( m_pPart, sortedList, viewport( ) );
+
             hotspot.setX( m_pressedItem->pixmap( 0 )->width( ) / 2 );
             hotspot.setY( m_pressedItem->pixmap( 0 )->height( ) / 2 );
             if( sortedList.count( ) == 1 )
@@ -556,7 +567,7 @@ void PMTreeView::viewportMouseMoveEvent( QMouseEvent *e )
                   sortedList.first( )->pixmap( ) ), hotspot );
             else
                d->setPixmap( SmallIcon( "pmdrag" ) );
-            
+
             if( d->drag( ) )
             {
                kdDebug( PMArea ) << "Drag returned true\n";
@@ -571,14 +582,14 @@ void PMTreeView::viewportMouseMoveEvent( QMouseEvent *e )
 void PMTreeView::viewportDragMoveEvent( QDragMoveEvent *e )
 {
    bool accept = false;
-   
+
    if( m_pPart->isReadWrite( ) )
    {
-      if( PMObjectDrag::canDecode( e ) )
+      if( PMObjectDrag::canDecode( e, m_pPart ) )
       {
          PMTreeViewItem *item = ( PMTreeViewItem* ) itemAt( e->pos( ) );
          PMObject* obj = 0;
-         
+
          if( !item )
          {
             accept = false;
@@ -642,14 +653,14 @@ void PMTreeView::viewportDragEnterEvent( QDragEnterEvent *e )
    m_pDragOverItem = 0L;
 
    if( m_pPart->isReadWrite( ) )
-      e->accept( PMObjectDrag::canDecode( e ) );
+      e->accept( PMObjectDrag::canDecode( e, m_pPart ) );
    else
       e->ignore( );
 }
 
 void PMTreeView::viewportDragLeaveEvent( QDragLeaveEvent* )
 {
-   m_pDragOverItem = 0L;   
+   m_pDragOverItem = 0L;
 }
 
 void PMTreeView::viewportDropEvent( QDropEvent* e )
@@ -663,10 +674,10 @@ void PMTreeView::viewportDropEvent( QDropEvent* e )
       else
          obj = m_pPart->scene( );
 
-      if( PMObjectDrag::canDecode( e ) )
+      if( PMObjectDrag::canDecode( e, m_pPart ) )
       {
          if( targetDisplaysPart( e->source( ) ) &&
-             ( e->action( ) == QDropEvent::Move ) ) 
+             ( e->action( ) == QDropEvent::Move ) )
          {
             if( m_pPart->dragMoveSelectionTo( obj ) )
                e->acceptAction( );
@@ -686,7 +697,7 @@ void PMTreeView::viewportDropEvent( QDropEvent* e )
    }
    else
       e->ignore( );
-   
+
    m_pDragOverItem = 0L;
 }
 
@@ -709,7 +720,9 @@ void PMTreeView::keyPressEvent( QKeyEvent* e )
    QListViewItem* current = currentItem( );
    QListViewItem* newSelection = 0;
    bool accept = false;
-   
+   bool deleteItem = false;
+   bool pasteItem = false;
+
    if( current )
    {
       switch( e->key( ) )
@@ -737,6 +750,15 @@ void PMTreeView::keyPressEvent( QKeyEvent* e )
          case Qt::Key_Minus:
             current->setOpen( false );
             accept = true;
+         case Qt::Key_Delete:
+            deleteItem = true;
+            accept = true;
+            break;
+         case Qt::CTRL+Qt::Key_V:
+         case Qt::SHIFT+Qt::Key_Insert:
+            pasteItem = true;
+            accept = true;
+            break;
       }
    }
 
@@ -752,7 +774,19 @@ void PMTreeView::keyPressEvent( QKeyEvent* e )
       emit objectChanged( ( ( PMTreeViewItem* ) newSelection )->object( ),
                           PMCNewSelection, this );
    }
+
+   if( deleteItem && m_pPart->isReadWrite( ) )
+   {
+      m_pPart->slotEditDelete( );
+      m_pPart->setModified( true );
+   }
    
+   if( pasteItem && m_pPart->isReadWrite( ) )
+   {
+      m_pPart->slotEditPaste( );
+      m_pPart->setModified( true );
+   }
+
    if( accept )
       e->accept( );
    else
@@ -769,13 +803,21 @@ bool PMTreeView::targetDisplaysPart( QWidget* target )
       result = true;
    else
    {
-      const QPtrList<PMTreeView>& views = m_pPart->treeViews( );
-      QPtrListIterator<PMTreeView> it( views );
-      for( ; it.current( ) && !result; ++it )
-         if( it.current( )->viewport( ) == target )
+      // Widget may be a view port
+      // find the tree view
+      QWidget* t = target;
+      while( t && !t->isA( "PMTreeView" ) )
+         t = t->parentWidget( );
+      if( t )
+         if( ( ( PMTreeView* ) t )->part( ) == m_pPart )
             result = true;
    }
    return result;
 }
 
+QString PMTreeViewFactory::description( ) const
+{
+   return i18n( "Object Tree" );
+}
+
 #include "pmtreeview.moc"
