@@ -22,6 +22,7 @@
 #include "pmvector.h"
 #include "pmdebug.h"
 
+inline const char* dcopTypeName( const PMVariant& ) { return "PMVariant"; }
 
 PMVariant::PMVariant( )
 {
@@ -736,3 +737,182 @@ bool PMVariant::convertTo( PMVariant::PMVariantDataType t )
 
    return success;
 }
+
+QString PMVariant::asString( ) const
+{
+   QString tmp;
+
+   switch( m_dataType )
+   {
+      case PMVariant::Integer:
+      {
+         int data = *( ( int* ) m_pData );
+
+         tmp.setNum( data );
+         break;
+      }
+      case PMVariant::Unsigned:
+      {
+         unsigned data = *( ( unsigned* ) m_pData );
+
+         tmp.setNum( data );
+         break;
+      }
+      case PMVariant::Double:
+      {
+         double data = *( ( double* ) m_pData );
+
+         tmp.setNum( data );
+         break;
+      }
+      case PMVariant::Bool:
+      {
+         bool data = *( ( bool* ) m_pData );
+
+         if( data )
+            tmp = "true";
+         else
+            tmp = "false";
+         break;
+      }
+      case PMVariant::ThreeState:
+      {
+         PMThreeState data = *( ( PMThreeState* ) m_pData );
+
+         if( data == PMTrue )
+            tmp = "true";
+         else if( data == PMFalse )
+            tmp = "false";
+         else
+            tmp = "unspecified";
+         break;
+      }
+      case PMVariant::String:
+      {
+         tmp = *( ( QString* ) m_pData );
+         break;
+      }
+      case PMVariant::Vector:
+      {
+         PMVector v = *( ( PMVector* ) m_pData );
+         tmp = v.serializeXML( );
+         break;
+      }
+
+      case PMVariant::Color:
+      {
+         PMColor c = *( ( PMColor* ) m_pData );
+         tmp = c.serializeXML( );
+         break;
+      }
+
+      case PMVariant::ObjectPointer:
+         tmp = "<object_pointer>";
+         break;
+
+      case PMVariant::None:
+         tmp = "<none>"; 
+         break;
+
+      default:
+         tmp = "<unknown>";
+         break;
+   }
+
+   return tmp;
+}
+
+bool PMVariant::fromString( const PMVariant::PMVariantDataType t, const QString& value )
+{
+   bool success;
+
+   switch( t )
+   {
+      case PMVariant::Integer:
+      { 
+         int i = value.toInt( &success );
+         if( success )
+            setInt( i );
+         break;
+      }
+      case PMVariant::Unsigned:
+      {
+         unsigned u = value.toUInt( &success );
+         if( success )
+            setUnsigned( u );
+         break;
+      }
+      case PMVariant::Double:
+      {
+         double d = value.toDouble( &success );
+         if( success )
+            setDouble( d );
+         break;
+      }
+      case PMVariant::Bool:
+         if( value == "true" || value == "on" || value == "yes" )
+            setBool( true );
+         else if( value == "false" || value == "off" || value == "no" )
+            setBool( false );
+         else
+            success = false;
+         break;
+      case PMVariant::ThreeState:
+         if( value == "true" || value == "on" || value == "yes" )
+            setThreeState( PMTrue );
+         else if( value == "false" || value == "off" || value == "no" )
+            setThreeState( PMFalse );
+         else if( value == "unspecified" )
+            setThreeState( PMUnspecified );
+         else
+            success = false;
+         break;
+      case PMVariant::String:
+         setString( value );
+         success = true;
+         break;
+      case PMVariant::Vector:
+         {
+            PMVector v;
+            v.loadXML( value );
+            setVector( v );
+            success = true;
+            break;
+         }
+      case PMVariant::Color:
+         {
+            PMColor c;
+            c.loadXML( value );
+            setColor( c );
+            success = true;
+            break;
+         }
+      default:
+         success = false;
+   }
+   return success;
+}
+
+QDataStream& operator<<( QDataStream& stream, const PMVariant& value )
+{
+   stream << (Q_INT8)value.dataType( );
+   stream << value.asString( );
+
+   return stream;
+}
+
+QDataStream& operator>>( QDataStream& stream, PMVariant& value ) 
+{
+   Q_INT8 type;
+   PMVariant::PMVariantDataType dataType;
+   QString str;
+
+   stream >> type;
+   dataType = (PMVariant::PMVariantDataType)type;
+
+   stream >> str;
+
+   value.fromString(dataType, str);
+
+   return stream;
+}
