@@ -20,6 +20,7 @@
 #ifndef PMVIEWSTRUCTURE_H
 #define PMVIEWSTRUCTURE_H
 
+#include "pmface.h"
 #include "pmpoint.h"
 #include "pmline.h"
 #include "pmmatrix.h"
@@ -42,15 +43,15 @@ public:
     */
    PMViewStructure( );
    /**
-    * Creates a view structure with n points and l lines
+    * Creates a view structure with n points, l lines and f faces.
     */
-   PMViewStructure( unsigned int n, unsigned int l );
+   PMViewStructure( unsigned int n, unsigned int l, unsigned int f = 0 );
    /**
-    * Creates a copy of the view structure. m_points and m_lines are shared
+    * Creates a copy of the view structure. m_points, m_lines and m_faces are shared
     */
    PMViewStructure( const PMViewStructure& vs );
    /**
-    * Creates a copy of the view structure. m_points and m_lines are shared
+    * Creates a copy of the view structure. m_points, m_lines anf m_faces are shared
     */
    PMViewStructure( const PMViewStructure* vs );
 
@@ -62,6 +63,10 @@ public:
     * Returns a reference to the array of lines
     */
    PMLineArray& lines( ) { return m_lines; }
+   /**
+    * Returns a refrence to the array of faces
+    */
+   PMFaceArray& faces( ) { return m_faces; }
    /**
     * Returns the parameter key
     */
@@ -98,6 +103,10 @@ protected:
     * Optimized for fast rendering.
     */
    PMLineArray m_lines;
+   /**
+    * Faces to display.
+    */
+   PMFaceArray m_faces;
    /**
     * View structure parameter key.
     *
