@@ -114,6 +114,7 @@ KSnapshot::KSnapshot(QWidget *parent, const char *name, bool grabCurrent)
     }
 
     connect( &grabTimer, SIGNAL( timeout() ), this, SLOT(  grabTimerDone() ) );
+    connect( &updateTimer, SIGNAL( timeout() ), this, SLOT(  updatePreview() ) );
     QTimer::singleShot( 0, this, SLOT( updateCaption() ) );
 
     KHelpMenu *helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), false);
@@ -151,6 +152,14 @@ KSnapshot::~KSnapshot()
 {
 }
 
+void KSnapshot::resizeEvent( QResizeEvent *event)
+{
+	if( !updateTimer.isActive() )
+		updateTimer.start(200, true);
+	else	
+		updateTimer.changeInterval(200);
+}
+
 bool KSnapshot::save( const QString &filename )
 {
     return save( KURL::fromPathOrURL( filename ));
@@ -377,7 +386,7 @@ void KSnapshot::autoincFilename()
     QRegExp numSearch("[0-9]+");
 
     // Does it have a number?
-    int start = numSearch.searchRev(name);
+    int start = numSearch.search(name);
     if (start != -1) {
         // It has a number, increment it
         int len = numSearch.matchedLength();
@@ -405,18 +414,7 @@ void KSnapshot::autoincFilename()
 
 void KSnapshot::updatePreview()
 {
-    QImage img = snapshot.convertToImage();
-    double r1 = ((double) snapshot.height() ) / snapshot.width();
-    if ( r1 * mainWidget->previewWidth()  < mainWidget->previewHeight() )
-	img = img.smoothScale( mainWidget->previewWidth(),
-        int( mainWidget->previewWidth() * r1 ));
-    else
-	img = img.smoothScale( (int) (((double)mainWidget->previewHeight()) / r1),
-        (mainWidget->previewHeight() ) );
-
-    QPixmap pm;
-    pm.convertFromImage( img );
-    mainWidget->setPreview( pm );
+    mainWidget->setPreview( snapshot );
 }
 
 void KSnapshot::grabTimerDone()
@@ -510,6 +508,18 @@ void KSnapshot::performGrab()
 	    }
 	}
 
+	XWindowAttributes rootAttributes;
+	if ( XGetWindowAttributes( qt_xdisplay(), root, &rootAttributes ) ) {
+	    if ( ( x + w ) > rootAttributes.width ) {
+		// then the window is partly off the screen
+		w = rootAttributes.width - x;
+	    }
+	    if ( ( y + h ) > rootAttributes.height ) {
+		// then the window is partly off the screen
+		h = rootAttributes.height - y;
+	    }
+	}
+
 	snapshot = QPixmap::grabWindow( qt_xrootwin(), x, y, w, h );
 
 #ifdef HAVE_X11_EXTENSIONS_SHAPE_H
@@ -575,6 +585,11 @@ void KSnapshot::setTime(int newTime)
     mainWidget->setDelay(newTime);
 }
 
+int KSnapshot::timeout()
+{
+    return mainWidget->delay();
+}
+
 void KSnapshot::setURL( const QString &url )
 {
     KURL newURL = KURL::fromPathOrURL( url );
@@ -587,7 +602,12 @@ void KSnapshot::setURL( const QString &url )
 
 void KSnapshot::setGrabMode( int m )
 {
-  mainWidget->setMode( m );
+    mainWidget->setMode( m );
+}
+
+int KSnapshot::grabMode()
+{
+    return mainWidget->mode();
 }
 
 void KSnapshot::updateCaption()
