@@ -201,22 +201,22 @@ SVGAnimatedLengthImpl *SVGSVGElementImpl::height()
 
 void SVGSVGElementImpl::setContentScriptType(const DOM::DOMString &contentScriptType)
 {
-	m_contentScriptType = contentScriptType;
+	setAttribute("contentScriptType", contentScriptType);
 }
 
 DOM::DOMString SVGSVGElementImpl::contentScriptType() const
 {
-	return m_contentScriptType;
+	return getAttribute("contentScriptType");
 }
 
 void SVGSVGElementImpl::setContentStyleType(const DOM::DOMString &contentStyleType)
 {
-	m_contentStyleType = contentStyleType;
+	setAttribute("contentStyleType", contentStyleType);
 }
 
 DOM::DOMString SVGSVGElementImpl::contentStyleType() const
 {
-	return m_contentStyleType;
+	return getAttribute("contentStyleType");
 }
 
 SVGRectImpl *SVGSVGElementImpl::viewport()
@@ -863,10 +863,10 @@ void SVGSVGElementImpl::putValueProperty(ExecState *exec, int token, const Value
 	switch(token)
 	{
 		case ContentScriptType:
-			m_contentScriptType = value.toString(exec).string();
+			setContentScriptType(value.toString(exec).string());
 			break;
 		case ContentStyleType:
-			m_contentStyleType = value.toString(exec).string();
+			setContentStyleType(value.toString(exec).string());
 			break;
 		case CurrentScale:
 			m_currentScale = value.toNumber(exec);
