@@ -54,15 +54,14 @@
 #include "SVGAnimatedTransformListImpl.h"
 #include "SVGTransformListImpl.h"
 #include "SVGUnitConverter.h"
-#include "SVGAngleImpl.h"
 
 #include "Glyph.h"
 #include "Converter.h"
 #include "KSVGTextChunk.h"
 
 #include "agg_rasterizer_scanline_aa.h"
-#include "agg_scanline_u8.h"
-#include "agg_scanline_p32.h"
+#include "agg_scanline_u.h"
+#include "agg_scanline_p.h"
 #include "agg_bounding_rect.h"
 #include "agg_ellipse.h"
 #include "agg_span_image_filter_rgba32.h"
@@ -101,21 +100,21 @@ using namespace KSVG;
 
 // agg2 helpers
 
-agg::gen_stroke::line_cap_e toAggLineCap(PathStrokeCapType cap)
+agg::vcgen_stroke::line_cap_e toAggLineCap(PathStrokeCapType cap)
 {
 	if(cap == PATH_STROKE_CAP_BUTT)
-		return agg::gen_stroke::butt_cap;
+		return agg::vcgen_stroke::butt_cap;
 	else if(cap == PATH_STROKE_CAP_ROUND)
-		return agg::gen_stroke::round_cap;
+		return agg::vcgen_stroke::round_cap;
 	else
-		return agg::gen_stroke::square_cap;
+		return agg::vcgen_stroke::square_cap;
 }
 
 template<class Source>
 stroke<Source>::stroke(Source& src, KSVG::SVGStylableImpl *style) : m_s(src)
 {
 	m_s.width(style->getStrokeWidth()->baseVal()->value());
-	m_s.line_join((agg::gen_stroke::line_join_e)style->getJoinStyle());
+	m_s.line_join((agg::vcgen_stroke::line_join_e)style->getJoinStyle());
 	m_s.miter_limit(style->getStrokeMiterlimit());
 	m_s.line_cap(toAggLineCap(style->getCapStyle()));
 }
@@ -131,7 +130,7 @@ dash_stroke<Source>::dash_stroke(Source& src, KSVG::SVGStylableImpl *style) : m_
 		 			 style->getDashArray()->baseVal()->getItem((i + 1) % dashLength)->value());
 	m_d.dash_start(style->getDashOffset()->baseVal()->value());
 	m_ds.width(style->getStrokeWidth()->baseVal()->value());
-	m_ds.line_join((agg::gen_stroke::line_join_e)style->getJoinStyle());
+	m_ds.line_join((agg::vcgen_stroke::line_join_e)style->getJoinStyle());
 	m_ds.miter_limit(style->getStrokeMiterlimit());
 	m_ds.line_cap(toAggLineCap(style->getCapStyle()));
 }
@@ -151,6 +150,37 @@ dash_stroke_simple<Source>::dash_stroke_simple(Source& src, KSVG::SVGStylableImp
 		//impl = 0;
 }
 
+void renderPathSolid(AggCanvas *canvas, const agg::rgba8 &color)
+{
+	agg::scanline_p8 sl;
+	if(canvas->nrChannels() == 3)
+	{
+		typedef agg::pixfmt_rgb24 pixfmt;
+        	typedef agg::renderer_base<pixfmt> renderer_base;
+        	typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
+
+		pixfmt pixf(canvas->buf());
+		renderer_base rb(pixf);
+		renderer_solid ren(rb);
+
+		ren.color(color);
+		canvas->m_ras.render(sl, ren);
+	}
+	else
+	{
+		typedef agg::pixfmt_rgba32 pixfmt;
+        	typedef agg::renderer_base<pixfmt> renderer_base;
+        	typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
+
+		pixfmt pixf(canvas->buf());
+		renderer_base rb(pixf);
+		renderer_solid ren(rb);
+
+		ren.color(color);
+		canvas->m_ras.render(sl, ren);
+	}
+}
+
 // #####
 
 BezierPathAggStroked::BezierPathAggStroked(SVGStylableImpl *style)
@@ -221,7 +251,7 @@ void AggShape::update(CanvasItemUpdate reason, int param1, int param2)
 		init();
 	else if(reason == UPDATE_PAN)
 	{
-		agg::affine_matrix mtx(1, 0, 0, 1, param1, param2);
+		agg::trans_affine mtx(1, 0, 0, 1, param1, param2);
 		m_transform *= mtx;
 	}
 	else if(reason == UPDATE_LINEWIDTH)
@@ -275,7 +305,7 @@ bool AggShape::isVisible(SVGShapeImpl *shape)
 void AggShape::calcSVPs(const SVGMatrixImpl *matrix)
 {
 	// transform
-	m_transform = agg::affine_matrix(matrix->a(), matrix->b(), matrix->c(), matrix->d(), matrix->e(), matrix->f());
+	m_transform = agg::trans_affine(matrix->a(), matrix->b(), matrix->c(), matrix->d(), matrix->e(), matrix->f());
 
 	double x1, y1, x2, y2;
 	agg::bounding_rect(m_curved_trans, *this, 0, 1, &x1, &y1, &x2, &y2);
@@ -363,34 +393,8 @@ void AggStrokePaintServer::draw(AggCanvas *canvas, VertexSource &vs, SVGStylable
 	}
 	else
 	{
-		agg::scanline_p8 sl;
 		canvas->m_ras.add_path(vs);
-		if(canvas->nrChannels() == 3)
-		{
-			typedef agg::pixfmt_rgb24 pixfmt;
-	        	typedef agg::renderer_base<pixfmt> renderer_base;
-	        	typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
-
-			pixfmt pixf(canvas->buf());
-			renderer_base rb(pixf);
-			renderer_solid ren(rb);
-
-			ren.color(m_color);
-			canvas->m_ras.render(sl, ren);
-		}
-		else
-		{
-			typedef agg::pixfmt_rgba32 pixfmt;
-	        	typedef agg::renderer_base<pixfmt> renderer_base;
-	        	typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
-
-			pixfmt pixf(canvas->buf());
-			renderer_base rb(pixf);
-			renderer_solid ren(rb);
-
-			ren.color(m_color);
-			canvas->m_ras.render(sl, ren);
-		}
+		renderPathSolid(canvas, m_color);
 	}
 }
 
@@ -438,35 +442,9 @@ void AggFillPaintServer::draw(AggCanvas *canvas, VertexSource &vs, SVGStylableIm
 	}
 	else
 	{
-		agg::scanline_p8 sl;
 		canvas->m_ras.filling_rule(style->getFillRule() == RULE_EVENODD ? agg::fill_even_odd : agg::fill_non_zero);
 		canvas->m_ras.add_path(vs);
-		if(canvas->nrChannels() == 3)
-		{
-			typedef agg::pixfmt_rgb24 pixfmt;
-	        	typedef agg::renderer_base<pixfmt> renderer_base;
-	        	typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
-
-			pixfmt pixf(canvas->buf());
-			renderer_base rb(pixf);
-			renderer_solid ren(rb);
-
-			ren.color(m_color);
-			canvas->m_ras.render(sl, ren);
-		}
-		else
-		{
-			typedef agg::pixfmt_rgba32 pixfmt;
-	        	typedef agg::renderer_base<pixfmt> renderer_base;
-	        	typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
-
-			pixfmt pixf(canvas->buf());
-			renderer_base rb(pixf);
-			renderer_solid ren(rb);
-
-			ren.color(m_color);
-			canvas->m_ras.render(sl, ren);
-		}
+		renderPathSolid(canvas, m_color);
 	}
 }
 
@@ -690,11 +668,9 @@ void AggLine::draw()
 {
 	if(isVisible())
 	{
-		agg::scanline_p8 sl;
-
 		// transform ( zoom?)
-		//agg::affine_matrix transform = m_transform;
-		//agg::affine_matrix mtx(m_canvas->zoom(), 0, 0, m_canvas->zoom(), m_canvas->pan().x(), m_canvas->pan().y());
+		//agg::trans_affine transform = m_transform;
+		//agg::trans_affine mtx(m_canvas->zoom(), 0, 0, m_canvas->zoom(), m_canvas->pan().x(), m_canvas->pan().y());
 		//m_transform *= mtx;
 		//m_curved.approximation_scale(pow(m_transform.scale(), 0.75));
 
@@ -709,30 +685,7 @@ void AggLine::draw()
 				qcolor = m_style->getStrokeColor()->rgbColor().color();
 			agg::rgba8 color(qcolor.red(), qcolor.green(), qcolor.blue());
 			color.opacity(m_style->getStrokeOpacity() * m_style->getOpacity());
-			if(m_canvas->nrChannels() == 3)
-			{
-				typedef agg::pixfmt_rgb24 pixfmt;
-			        typedef agg::renderer_base<pixfmt> renderer_base;
-			        typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
-
-				pixfmt pixf(m_canvas->buf());
-				renderer_base rb(pixf);
-				renderer_solid ren(rb);
-				ren.color(color);
-				m_canvas->m_ras.render(sl, ren);
-			}
-			else
-			{
-				typedef agg::pixfmt_rgba32 pixfmt;
-			        typedef agg::renderer_base<pixfmt> renderer_base;
-			        typedef agg::renderer_scanline_p_solid<renderer_base> renderer_solid;
-
-				pixfmt pixf(m_canvas->buf());
-				renderer_base rb(pixf);
-				renderer_solid ren(rb);
-				ren.color(color);
-				m_canvas->m_ras.render(sl, ren);
-			}
+			renderPathSolid(m_canvas, color);
 		}
 		//m_transform = transform;
 
@@ -768,7 +721,15 @@ void AggLine::init(const SVGMatrixImpl *screenCTM)
 	if(m_storage.total_vertices() == 0)
 	{
 		m_storage.move_to(m_line->x1()->baseVal()->value(), m_line->y1()->baseVal()->value());
-		m_storage.line_to(m_line->x2()->baseVal()->value(), m_line->y2()->baseVal()->value());
+		// A subpath consisting of a moveto and lineto to the same exact location or a subpath consisting of a moveto
+		// and a closepath will be stroked only if the 'stroke-linecap' property is set to "round", producing a circle
+		// centered at the given point.
+		double x2 = m_line->x2()->baseVal()->value();
+		double y2 = m_line->y2()->baseVal()->value();
+		if(x2 == m_line->x1()->baseVal()->value() && y2 == m_line->y1()->baseVal()->value() && m_line->getCapStyle() == PATH_STROKE_CAP_ROUND)
+				m_storage.line_to(x2 + .5, y2);
+		else
+				m_storage.line_to(x2, y2);
 	}
 	//if(m_context == NORMAL)
 		calcSVPs(screenCTM);
@@ -830,9 +791,24 @@ void AggPolyline::init(const SVGMatrixImpl *screenCTM)
 
 		m_storage.move_to(m_poly->points()->getItem(0)->x(), m_poly->points()->getItem(0)->y());
 
-		unsigned int index;
-		for(index = 1; index < numberOfPoints; index++)
-			m_storage.line_to(m_poly->points()->getItem(index)->x(), m_poly->points()->getItem(index)->y());
+		// A subpath consisting of a moveto and lineto to the same exact location or a subpath consisting of a moveto
+		// and a closepath will be stroked only if the 'stroke-linecap' property is set to "round", producing a circle
+		// centered at the given point.
+		if(numberOfPoints == 2)
+		{
+			double x1 = m_poly->points()->getItem(1)->x();
+			double y1 = m_poly->points()->getItem(1)->y();
+			if(x1 == m_poly->points()->getItem(0)->x() && y1 == m_poly->points()->getItem(0)->y() && m_poly->getCapStyle() == PATH_STROKE_CAP_ROUND)
+				m_storage.line_to(m_poly->points()->getItem(1)->x() + .5, m_poly->points()->getItem(1)->y());
+			else
+				m_storage.line_to(m_poly->points()->getItem(1)->x(), m_poly->points()->getItem(1)->y());
+		}
+		else
+		{
+			unsigned int index;
+			for(index = 1; index < numberOfPoints; index++)
+				m_storage.line_to(m_poly->points()->getItem(index)->x(), m_poly->points()->getItem(index)->y());
+		}
 	}
 	//if(m_context == NORMAL)
 		calcSVPs(screenCTM);
@@ -932,6 +908,18 @@ void AggPath::init(const SVGMatrixImpl *screenCTM)
 			m_storage.start_new_path();
 			parseSVG(m_path->getAttribute("d").string(), true);
 
+			// A subpath consisting of a moveto and lineto to the same exact location or a subpath consisting of a moveto
+			// and a closepath will be stroked only if the 'stroke-linecap' property is set to "round", producing a circle
+			// centered at the given point.
+			if(m_storage.total_vertices() == 2 && agg::is_line_to(m_storage.command(1)))
+			{
+				double x1, y1;
+				double x2, y2;
+				m_storage.vertex(0, &x1, &y1);
+				m_storage.vertex(1, &x2, &y2);
+				if(x1 == x2 && y1 == y2 && m_path->getCapStyle() == PATH_STROKE_CAP_ROUND)
+					m_storage.modify_vertex(1, x2 + .5, y2);
+			}
 			// TODO : handle filled paths that are not closed explicitly
 		}
 	}
@@ -986,7 +974,7 @@ void AggMarker::draw()
 {
 }
 
-void AggMarker::draw(SVGShapeImpl *obj, int x, int y, float lwidth, double angle)
+void AggMarker::draw(SVGShapeImpl * /*obj*/, int  /*x*/, int  /*y*/, float  /*lwidth*/, double  /*angle*/)
 {
 }
 
@@ -1023,7 +1011,7 @@ void AggImage::draw()
 		typedef agg::span_image_filter_rgba32_bilinear<agg::order_bgra32, interpolator_type> span_gen_type;
 		typedef agg::renderer_scanline_u<renderer_base, span_gen_type> renderer_type;
 		SVGMatrixImpl *ctm = m_image->scaledImageMatrix();
-		agg::affine_matrix img_mtx(ctm->a(), ctm->b(), ctm->c(), ctm->d(), ctm->e(), ctm->f());
+		agg::trans_affine img_mtx(ctm->a(), ctm->b(), ctm->c(), ctm->d(), ctm->e(), ctm->f());
 		kdDebug() << "ctm->e() : " << ctm->e() << endl;
 		kdDebug() << "ctm->f() : " << ctm->f() << endl;
 		double x1 = 0;
@@ -1200,7 +1188,7 @@ void AggText::update(CanvasItemUpdate reason, int param1, int param2)
 		while(svpelement)
 		{
 			bpath = svpelement->svp;
-			agg::affine_matrix mtx(1, 0, 0, 1, param1, param2);
+			agg::trans_affine mtx(1, 0, 0, 1, param1, param2);
 			bpath->m_transform *= mtx;
 
 			svpelement = ++it;
@@ -1275,9 +1263,9 @@ void AggText::renderCallback(SVGTextContentElementImpl *element, const SVGMatrix
 
 		// text-anchor/baseline-shift support
 		if(!params->tb())
-			bpath->m_transform = agg::affine_matrix(screenCTM->a(), screenCTM->b(), screenCTM->c(), screenCTM->d(), screenCTM->e() - anchor * screenCTM->a(), screenCTM->f());
+			bpath->m_transform = agg::trans_affine(screenCTM->a(), screenCTM->b(), screenCTM->c(), screenCTM->d(), screenCTM->e() - anchor * screenCTM->a(), screenCTM->f());
 		else
-			bpath->m_transform = agg::affine_matrix(screenCTM->a(), screenCTM->b(), screenCTM->c(), screenCTM->d(), screenCTM->e(), screenCTM->f() - anchor * screenCTM->d());
+			bpath->m_transform = agg::trans_affine(screenCTM->a(), screenCTM->b(), screenCTM->c(), screenCTM->d(), screenCTM->e(), screenCTM->f() - anchor * screenCTM->d());
 
 		SVPElement *svpelement = new SVPElement();
 		svpelement->svp = new BezierPathAggStroked(*bpath, element);
@@ -1322,7 +1310,7 @@ void AggText::addTextDecoration(SVGTextContentElementImpl *element, double x, do
 		bpath->m_storage.line_to(x, y + height);
 
 		const SVGMatrixImpl *mat = m_text->screenCTM();
-		bpath->m_transform = agg::affine_matrix(mat->a(), mat->b(), mat->c(), mat->d(), mat->e(), mat->f());
+		bpath->m_transform = agg::trans_affine(mat->a(), mat->b(), mat->c(), mat->d(), mat->e(), mat->f());
 
 		SVPElement *svpelement = new SVPElement();
 		svpelement->svp = bpath;
@@ -1350,8 +1338,6 @@ AggText::SVPElement::~SVPElement()
 
 AggGradient::AggGradient(SVGGradientElementImpl *gradient) : m_gradient(gradient)
 {
-        for(int i = 0; i < 256; i++)
-		m_gamma[i] = i;
 }
 
 void AggGradient::parseGradientStops(SVGGradientElementImpl *gradient)
@@ -1470,7 +1456,7 @@ void AggGradient::finalizePaintServer()
 	setFinalized();
 }
 
-void AggGradient::reference(const QString &href)
+void AggGradient::reference(const QString &/*href*/)
 {
 }
 
@@ -1496,7 +1482,7 @@ void AggLinearGradient::render(AggCanvas *c)
 	}
 
 	// Get the basic bbox that will be the rendering area
-	SVGRectImpl *bbox = getBBoxTarget()->getBBoxInternal();
+	SVGRectImpl *userBBox = getBBoxTarget()->getBBox();
 
 	// Compute x1, y1, x2 and y2
 	bool objectbbox = (linear->gradientUnits()->baseVal() == SVGUnitTypes::SVG_UNIT_TYPE_OBJECTBOUNDINGBOX);
@@ -1509,18 +1495,13 @@ void AggLinearGradient::render(AggCanvas *c)
 
 	if(objectbbox)
 	{
-		_x1 = _x1 * matrix->a() + bbox->x();
-		_y1 = _y1 * matrix->d() + bbox->y();
-		_x2 = _x2 * matrix->a() + bbox->x();
-		_y2 = _y2 * matrix->d() + bbox->y();
-	}
-	else
-	{
-		matrix->qmatrix().map(_x1, _y1, &_x1, &_y1);
-		matrix->qmatrix().map(_x2, _y2, &_x2, &_y2);
+		_x1 += userBBox->x();
+		_y1 += userBBox->y();
+		_x2 += userBBox->x();
+		_y2 += userBBox->y();
 	}
 
-	bbox->deref();
+	userBBox->deref();
 
 	gradient_polymorphic_wrapper_base* gr_ptr = &m_linPad;
 	if(linear->spreadMethod()->baseVal() == SVG_SPREADMETHOD_REPEAT)
@@ -1528,12 +1509,13 @@ void AggLinearGradient::render(AggCanvas *c)
 	else if(linear->spreadMethod()->baseVal() == SVG_SPREADMETHOD_REFLECT)
 		gr_ptr = &m_linReflect;
 
-	agg::affine_matrix mtx_g1;
+	agg::trans_affine mtx_g1;
 	double dx = _x2 - _x1;
 	double dy = _y2 - _y1;
 	double angle = (atan2(dy, dx));
-	mtx_g1 *= agg::rotation_matrix(angle);
-	mtx_g1 *= agg::translation_matrix(_x1, _y1);
+	mtx_g1 *= agg::trans_affine_rotation(angle);
+	mtx_g1 *= agg::trans_affine_translation(_x1, _y1);
+	mtx_g1 *= agg::trans_affine(matrix->a(), matrix->b(), matrix->c(), matrix->d(), matrix->e(), matrix->f());
 	mtx_g1.invert();
 
 	double len = sqrt(dx * dx + dy * dy);
@@ -1606,6 +1588,8 @@ void AggRadialGradient::render(AggCanvas *c)
 	bool objectbbox = (radial->gradientUnits()->baseVal() == SVGUnitTypes::SVG_UNIT_TYPE_OBJECTBOUNDINGBOX);
 
 	SVGRectImpl *userBBox = getBBoxTarget()->getBBox();
+	float width = userBBox->width();
+	float height = userBBox->height();
 
 	if(objectbbox)
 	{
@@ -1621,23 +1605,20 @@ void AggRadialGradient::render(AggCanvas *c)
 	else if(radial->spreadMethod()->baseVal() == SVG_SPREADMETHOD_REFLECT)
 		gr_ptr = &m_radialReflect;
 
-	agg::affine_matrix mtx_g1;
+	agg::trans_affine mtx_g1;
 
-	mtx_g1 *= agg::translation_matrix(_cx, _cy);
 
 	// Adjust to gradient transform
 	SVGMatrixImpl *gradTrans = radial->gradientTransform()->baseVal()->concatenate();
 	if(gradTrans)
 	{
-		agg::affine_matrix mtx;
+		agg::trans_affine mtx;
 		QWMatrix m = gradTrans->qmatrix();
-		mtx = agg::affine_matrix(m.m11(), m.m12(), m.m21(), m.m22(), m.dx(), m.dy());
+		mtx = agg::trans_affine(m.m11(), m.m12(), m.m21(), m.m22(), m.dx(), m.dy());
 		gradTrans->deref();
 		mtx_g1 *= mtx;
 	}
 
-	float width = userBBox->width();
-	float height = userBBox->height();
 	userBBox->deref();
 
 	int diff = int(width - height); // allow slight tolerance
@@ -1646,9 +1627,11 @@ void AggRadialGradient::render(AggCanvas *c)
 		// make elliptical or circular depending on bbox aspect ratio
 		float ratioX = (width / height) * sqrt(2);
 		float ratioY = (height / width) * sqrt(2);
-		mtx_g1 *= agg::scaling_matrix((width > height) ? sqrt(2) : ratioX, (width > height) ? ratioY :sqrt(2));
+		mtx_g1 *= agg::trans_affine_scaling((width > height) ? sqrt(2) : ratioX, (width > height) ? ratioY :sqrt(2));
 	}
 
+	mtx_g1 *= agg::trans_affine_translation(_cx, _cy);
+
 	// Respect current transformation matrix (so gradients zoom with...)
 	SVGTransformableImpl *transformable = dynamic_cast<SVGTransformableImpl *>(getBBoxTarget());
 	const SVGMatrixImpl *matrix = 0;
@@ -1658,7 +1641,7 @@ void AggRadialGradient::render(AggCanvas *c)
 	if(!matrix)
 		return;
 
-	mtx_g1 *= agg::affine_matrix(matrix->a(), matrix->b(), matrix->c(), matrix->d(), matrix->e(), matrix->f());
+	mtx_g1 *= agg::trans_affine(matrix->a(), matrix->b(), matrix->c(), matrix->d(), matrix->e(), matrix->f());
 
 	mtx_g1.invert();
 
@@ -1738,20 +1721,20 @@ void AggPattern::render(AggCanvas *c)
 		pixfmt pixf(c->buf());
 		renderer_base rb(pixf);
 		renderer_solid rs(rb);
-		double width = c->buf().width();
-		double height = c->buf().height();
+		//double width = c->buf().width();
+		//double height = c->buf().height();
 
 		typedef agg::span_pattern_rgba32<agg::order_rgba32> span_gen_type;
 		typedef agg::renderer_scanline_u<renderer_base, span_gen_type> renderer_type;
 
 		SVGRectImpl *screenBBox = getBBoxTarget()->getBBoxInternal();
-		unsigned offset_x = affine[4];
-		unsigned offset_y = affine[5];
+		double offset_x = affine[4];
+		double offset_y = affine[5];
 		screenBBox->deref();
 		agg::rendering_buffer m_pattern_rbuf;
 		m_pattern_rbuf.attach(tile.image().bits(), tile.image().width(), tile.image().height(), tile.image().width() * 4);
 		agg::span_allocator<agg::rgba8> sa;
-	        span_gen_type sg(sa, m_pattern_rbuf, offset_x, offset_y);
+	        span_gen_type sg(sa, m_pattern_rbuf, unsigned(offset_x), unsigned(offset_y));
 
 		renderer_type rp(rb, sg);
 
