@@ -15,7 +15,7 @@ using namespace KSVG;
 
 static KCmdLineOptions options[] =
 {
-	{ "+URL",   I18N_NOOP("SVG file to open."), 0 },
+	{ "+URL",   I18N_NOOP("SVG file to open"), 0 },
 	KCmdLineLastOption
 };
 
