@@ -215,22 +215,30 @@ void ImageWindow::setupActions()
     new KAction( i18n("Scroll Right"), Key_Right,
                  this, SLOT( scrollRight() ),
                  m_actions, "scroll_right" );
+    // --------
+    KAction *pause = new KAction( i18n("Pause Slideshow"), Key_P,
+				  this, SLOT( pauseSlideShow() ),
+				  m_actions, "kuick_slideshow_pause" );
 
-    KShortcut cut(Key_Return);
-    cut.append(KStdAccel::shortcut(KStdAccel::FullScreen));
-
-    KAction *action = KStdAction::fullScreen(this, SLOT( toggleFullscreen() ), m_actions, 0 );
-    action->setShortcut(cut);
+    KAction *fullscreenAction = KStdAction::fullScreen(this, SLOT( toggleFullscreen() ), m_actions, 0 );
 
     new KAction( i18n("Reload Image"), Key_Enter,
                  this, SLOT( reload() ),
                  m_actions, "reload_image" );
 
-    new KAction( i18n("Properties..."), ALT + Key_Return,
+    new KAction( i18n("Properties"), ALT + Key_Return,
                  this, SLOT( slotProperties() ),
                  m_actions, "properties" );
 
     m_actions->readShortcutSettings();
+
+    // Unfortunately there is no KAction::setShortcutDefault() :-/
+    // so add Key_Return as fullscreen shortcut _after_ readShortcutSettings()
+    KShortcut cut( fullscreenAction->shortcut() );
+    if ( cut == fullscreenAction->shortcutDefault() ) {
+	cut.append(KKey(Key_Return));
+	fullscreenAction->setShortcut(cut);
+    }
 }
 
 
@@ -271,7 +279,7 @@ void ImageWindow::updateGeometry( int imWidth, int imHeight )
     }
 
     updateCursor();
-
+	
     QString caption = i18n( "Filename (Imagewidth x Imageheight)",
                             "%3 (%1 x %2)" );
     caption = caption.arg( m_kuim->originalWidth() ).
@@ -389,6 +397,11 @@ void ImageWindow::reload()
     showNextImage( filename() );
 }
 
+void ImageWindow::pauseSlideShow()
+{
+    emit pauseSlideShowSignal();
+}
+
 void ImageWindow::addBrightness( int factor )
 {
     if ( factor == 0 )
@@ -516,7 +529,7 @@ void ImageWindow::keyPressEvent( QKeyEvent *e )
 
     if ( key == Key_Shift )
         updateCursor( ZoomCursor );
-
+	
     if ( key == Key_Escape || KStdAccel::close().contains( KKey( e ) ) )
         close( true );
     else if ( KStdAccel::save().contains( KKey( e ) ) )
@@ -601,7 +614,7 @@ void ImageWindow::mouseMoveEvent( QMouseEvent *e )
     }
 
     if ( e->state() & ShiftButton ) {
-
+	
 	if ( !transWidget ) {
 	    transWidget = new QWidget( this );
 	    transWidget->setGeometry( 0, 0, width(), height() );
@@ -614,10 +627,10 @@ void ImageWindow::mouseMoveEvent( QMouseEvent *e )
  	p.eraseRect( transWidget->rect() );
 	transWidget->show();
 	qApp->processOneEvent();
-
+	
 	int width  = e->x() - xposPress;
 	int height = e->y() - yposPress;
-
+	
 	if ( width < 0 ) {
 	    width = abs( width );
 	    xzoom = e->x();
@@ -680,7 +693,7 @@ void ImageWindow::mouseReleaseEvent( QMouseEvent *e )
     }
 
     if ( yposPress > y ) {
-	topY = y;
+	topY = y;	
 	botY = yposPress;
     }
     else {
@@ -1085,4 +1098,5 @@ void ImageWindow::slotProperties()
     (void) new KPropertiesDialog( url, this, "props dialog", true );
 }
 
+
 #include "imagewindow.moc"
