@@ -26,12 +26,14 @@
 #include <qcolor.h>
 #include <qfile.h>
 #include <qglobal.h>
+#include <qimage.h>
 #include <qobject.h>
 #include <qpalette.h>
 
 #include <kcursor.h>
 #include <kdebug.h>
 #include <kfilemetainfo.h>
+#include <kimageio.h>
 
 #include "imlibwidget.h"
 
@@ -52,15 +54,18 @@ ImlibWidget::ImlibWidget( ImData *_idata, QWidget *parent, const char *name ) :
     ImlibInitParams par;
 
     // PARAMS_PALETTEOVERRIDE taken out because of segfault in imlib :o(
-    par.flags = ( PARAMS_REMAP |
+    par.flags = ( PARAMS_REMAP | PARAMS_VISUALID |
 		  PARAMS_FASTRENDER | PARAMS_HIQUALITY | PARAMS_DITHER |
 		  PARAMS_IMAGECACHESIZE | PARAMS_PIXMAPCACHESIZE );
 
+    Visual* defaultvis = DefaultVisual(x11Display(), x11Screen());
+
     par.paletteoverride = idata->ownPalette ? 1 : 0;
     par.remap           = idata->fastRemap ? 1 : 0;
     par.fastrender      = idata->fastRender ? 1 : 0;
     par.hiquality       = idata->dither16bit ? 1 : 0;
     par.dither          = idata->dither8bit ? 1 : 0;
+    par.visualid        = defaultvis->visualid;
     uint maxcache       = idata->maxCache;
 
     // 0 == no cache
@@ -754,8 +759,11 @@ KuickImage * ImageCache::getKuimage( const QString& file,
 // #endif	
 
         slotIdle();
-	if ( !im )
-	    return 0L;
+	if ( !im ) {
+	    im = loadImageWithQt( file );
+	    if ( !im )
+		return 0L;
+	}
 
 	Imlib_set_image_modifier( myId, im, &mod );
 	kuim = new KuickImage( file, im, myId );
@@ -776,6 +784,51 @@ KuickImage * ImageCache::getKuimage( const QString& file,
 }
 
 
+// Note: the returned image's filename will not be the real filename (which it usually
+// isn't anyway, according to Imlib's sources).
+ImlibImage * ImageCache::loadImageWithQt( const QString& fileName ) const
+{
+    kdDebug() << "Trying to load " << fileName << " with KImageIO..." << endl;
+
+    KImageIO::registerFormats();
+
+    QImage image( fileName );
+    if ( image.isNull() )
+	return 0L;
+    if ( image.depth() != 32 ) {
+	image.setAlphaBuffer(false);
+	image = image.convertDepth(32);
+    }
+    if ( image.isNull() )
+	return 0L;
+
+    // convert to 24 bpp (discard alpha)
+    int numPixels = image.width() * image.height();
+    const int NUM_BYTES_NEW  = 3; // 24 bpp
+    uchar *newImageData = new uchar[numPixels * NUM_BYTES_NEW];
+    uchar *newData = newImageData;
+    
+    int w = image.width();
+    int h = image.height();
+    
+    for (int y = 0; y < h; y++) {
+	QRgb *scanLine = reinterpret_cast<QRgb *>( image.scanLine(y) );
+	for (int x = 0; x < w; x++) {
+	    const QRgb& pixel = scanLine[x];
+	    *(newData++) = qRed(pixel);
+	    *(newData++) = qGreen(pixel);
+	    *(newData++) = qBlue(pixel);
+	}
+    }
+    
+    ImlibImage *im = Imlib_create_image_from_data( myId, newImageData, NULL,
+                                                   image.width(), image.height() );
+		    
+    delete[] newImageData;
+
+    return im;
+}
+
 /*
 KuickImage * ImageCache::find( const QString& file )
 {
