@@ -96,7 +96,8 @@ KuickShow::KuickShow( const char *name )
       m_viewer( 0L ),
       oneWindowAction( 0L ),
       m_accel( 0L ),
-      m_delayedRepeatItem( 0L )
+      m_delayedRepeatItem( 0L ),
+      m_slideShowStopped(false)
 {
     aboutWidget = 0L;
     kdata = new KuickData;
@@ -144,12 +145,13 @@ KuickShow::KuickShow( const char *name )
         {
             KMimeType::Ptr mime = KMimeType::findByURL( url );
             QString name = mime->name();
-#if KDE_VERSION >= 310
             if ( name == "application/octet-stream" ) // unknown -> stat()
                 name = KIO::NetAccess::mimetype( url, this );
-#endif
 
-            if ( name.startsWith( "image/" ) )
+	    // text/* is a hack for bugs.kde.org-attached-images urls.
+	    // The real problem here is that NetAccess::mimetype does a HTTP HEAD, which doesn't
+	    // always return the right mimetype. The rest of KDE start a get() instead....
+            if ( name.startsWith( "image/" ) || name.startsWith( "text/" ) )
             {
                 FileWidget::setImage( item, true );
                 showImage( &item, true, false, true );
@@ -193,6 +195,7 @@ KuickShow::~KuickShow()
     delete kdata;
 }
 
+// TODO convert to use xmlui file
 void KuickShow::initGUI( const KURL& startDir )
 {
     fileWidget = new FileWidget( startDir, this, "MainWidget" );
@@ -239,7 +242,8 @@ void KuickShow::initGUI( const KURL& startDir )
                                          KShortcut( CTRL+Key_N ), coll,
                                          "kuick_one window" );
 
-    m_toggleBrowserAction = new KToggleAction( i18n("Show/Hide File Browser"), KShortcut( Key_Space ), coll, "toggleBrowser" );
+    m_toggleBrowserAction = new KToggleAction( i18n("Show File Browser"), KShortcut( Key_Space ), coll, "toggleBrowser" );
+    m_toggleBrowserAction->setCheckedState(i18n("Hide File Browser"));
     connect( m_toggleBrowserAction, SIGNAL( toggled( bool ) ),
              SLOT( toggleBrowser() ));
 
@@ -250,6 +254,9 @@ void KuickShow::initGUI( const KURL& startDir )
                                        KShortcut(),
                                        this, SLOT( slotShowInSameWindow() ),
                                        coll, "kuick_showInSameWindow" );
+    KAction *showFullscreen = new KAction( i18n("Show Image in Fullscreen Mode"),
+					   KShortcut(), this, SLOT( slotShowFullscreen() ),
+					   coll, "kuick_showFullscreen" );
 
     KAction *quit = KStdAction::quit( this, SLOT(slotQuit()), coll, "quit");
 
@@ -263,6 +270,7 @@ void KuickShow::initGUI( const KURL& startDir )
     open->plug( fileMenu );
     showInOther->plug( fileMenu );
     showInSame->plug( fileMenu );
+    showFullscreen->plug( fileMenu );
     fileMenu->insertSeparator();
     slide->plug( fileMenu );
     print->plug( fileMenu );
@@ -369,7 +377,8 @@ void KuickShow::initGUI( const KURL& startDir )
     dirSelected( fileWidget->url() );
 
     setCentralWidget( fileWidget );
-    setAutoSaveSettings();
+
+    setupGUI( KMainWindow::Save );
 
     coll->action( "reload" )->setShortcut( KStdAccel::reload() );
     coll->action( "short view" )->setShortcut(Key_F6);
@@ -378,11 +387,6 @@ void KuickShow::initGUI( const KURL& startDir )
     coll->action( "mkdir" )->setShortcut(Key_F10);
     coll->action( "preview" )->setShortcut(Key_F11);
     coll->action( "separate dirs" )->setShortcut(Key_F12);
-
-    // ### somehow the filewidget isn't resized at all sometimes, when initGUI
-    // is called lazily, not from this c'tor. (just a tiny little widget in
-    // the upper left corner of the mainwindow. Work around that.
-    fileWidget->resize( size() );
 }
 
 void KuickShow::slotSetURL( const KURL& url )
@@ -451,6 +455,7 @@ void KuickShow::slotHighlighted( const KFileItem *fi )
     fileWidget->actionCollection()->action("kuick_print")->setEnabled( image );
     fileWidget->actionCollection()->action("kuick_showInSameWindow")->setEnabled( image );
     fileWidget->actionCollection()->action("kuick_showInOtherWindow")->setEnabled( image );
+    fileWidget->actionCollection()->action("kuick_showFullscreen")->setEnabled( image );
 }
 
 void KuickShow::dirSelected( const KURL& url )
@@ -494,6 +499,8 @@ void KuickShow::showImage( const KFileItem *fi,
                      this, SLOT( messageCantLoadImage(const QString &) ));
             connect( m_viewer, SIGNAL( requestImage( ImageWindow *, int )),
                      this, SLOT( slotAdvanceImage( ImageWindow *, int )));
+	    connect( m_viewer, SIGNAL( pauseSlideShowSignal() ), 
+		     this, SLOT( pauseSlideShow() ) );
             if ( s_viewers.count() == 1 && moveToTopLeft ) {
                 // we have to move to 0x0 before showing _and_
                 // after showing, otherwise we get some bogus geometry()
@@ -558,6 +565,18 @@ void KuickShow::startSlideShow()
     }
 }
 
+void KuickShow::pauseSlideShow()
+{
+    if(m_slideShowStopped) {
+	m_slideTimer->start( kdata->slideDelay );
+	m_slideShowStopped = false;
+    }
+    else {
+	m_slideTimer->stop();
+	m_slideShowStopped = true;
+    }
+}
+
 void KuickShow::nextSlide()
 {
     if ( !m_viewer ) {
@@ -624,6 +643,11 @@ void KuickShow::slotShowInSameWindow()
     showImage( fileWidget->getCurrentItem( false ), false );
 }
 
+void KuickShow::slotShowFullscreen()
+{
+    showImage( fileWidget->getCurrentItem( false ), false, true );
+}
+
 void KuickShow::slotDropped( const KFileItem *, QDropEvent *, const KURL::List &urls)
 {
     KURL::List::ConstIterator it = urls.begin();
@@ -747,9 +771,11 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 
             // Key_Shift shouldn't load the browser in nobrowser mode, it
             // is used for zooming in the imagewindow
+            // Key_Alt shouldn't either - otherwise Alt+F4 doesn't work, the
+            // F4 gets eaten (by NetAccess' modal dialog maybe?)
             if ( !fileWidget )
             {
-                if ( key != Key_Escape && key != Key_Shift )
+                if ( key != Key_Escape && key != Key_Shift && key != Key_Alt )
                 {
                     KURL start;
                     QFileInfo fi( m_viewer->filename() );
@@ -893,7 +919,7 @@ void KuickShow::configuration()
     if ( !m_accel ) {
         KURL start;
         start.setPath( QDir::homeDirPath() );
-        initGUI( QDir::homeDirPath() );
+        initGUI( KURL::fromPathOrURL( QDir::homeDirPath() ) );
     }
 
     dialog = new KuickConfigDialog( fileWidget->actionCollection(), 0L,
@@ -968,14 +994,14 @@ void KuickShow::readProperties( KConfig *kc )
     assert( fileWidget ); // from SM, we should always have initGUI on startup
     QString dir = kc->readPathEntry( "CurrentDirectory" );
     if ( !dir.isEmpty() ) {
-        fileWidget->setURL( dir, true );
+        fileWidget->setURL( KURL::fromPathOrURL( dir ), true );
         fileWidget->clearHistory();
     }
 
     QStringList images = kc->readPathListEntry( "Images shown" );
     QStringList::Iterator it;
     for ( it = images.begin(); it != images.end(); ++it ) {
-        KFileItem item( KFileItem::Unknown, KFileItem::Unknown, *it, false );
+        KFileItem item( KFileItem::Unknown, KFileItem::Unknown, KURL::fromPathOrURL( *it ), false );
         if ( item.isReadable() )
             showImage( &item, true );
     }
@@ -1064,15 +1090,18 @@ void KuickShow::initImlib()
 
 void KuickShow::initImlibParams( ImData *idata, ImlibInitParams *par )
 {
-    par->flags = ( PARAMS_REMAP |
+    par->flags = ( PARAMS_REMAP | PARAMS_VISUALID |
                    PARAMS_FASTRENDER | PARAMS_HIQUALITY | PARAMS_DITHER |
                    PARAMS_IMAGECACHESIZE | PARAMS_PIXMAPCACHESIZE );
 
+    Visual* defaultvis = DefaultVisual(x11Display(), x11Screen());
+
     par->paletteoverride = idata->ownPalette  ? 1 : 0;
     par->remap           = idata->fastRemap   ? 1 : 0;
     par->fastrender      = idata->fastRender  ? 1 : 0;
     par->hiquality       = idata->dither16bit ? 1 : 0;
     par->dither          = idata->dither8bit  ? 1 : 0;
+    par->visualid	 = defaultvis->visualid;
     uint maxcache        = idata->maxCache;
 
     // 0 == no cache
