@@ -106,6 +106,8 @@ KView::KView()
 		connect( m_pCanvas->widget(), SIGNAL( cursorPos( const QPoint & ) ), SLOT( cursorPos( const QPoint & ) ) );
 
 		m_paRecent->loadEntries( KGlobal::config() );
+		if (!initialGeometrySet())
+			resize(500, 350);
 		readSettings();
 		m_pViewer->widget()->installEventFilter( this );
 
