@@ -200,7 +200,7 @@ bool KViewViewer::saveAs( const KURL & kurl )
 	{
 		kdDebug( 4610 ) << "copy image from " << m_file << " to " << kurl.prettyURL() << endl;
 
-		KIO::Job * job = KIO::copy( m_file, kurl, isProgressInfoEnabled() );
+		KIO::Job * job = KIO::copy( KURL( m_file ), kurl, isProgressInfoEnabled() );
 		emit started( job );
 		connect( job, SIGNAL( result( KIO::Job * ) ),
 				this, SLOT( slotResultSaveAs( KIO::Job * ) ) );
@@ -340,7 +340,7 @@ bool KViewViewer::eventFilter( QObject * o, QEvent * e )
 				QStringList l;
 				QImage image;
 				if( KURLDrag::decodeToUnicodeUris( ev, l ) )
-					openURL( l.first() );
+					openURL( KURL( l.first() ) );
 				else if( QImageDrag::decode( ev, image ) )
 					newImage( image );
 				return true;
@@ -391,7 +391,10 @@ bool KViewViewer::openFile()
 		delete m_pBuffer;
 		m_pBuffer = 0;
 		if( ! image.isNull() )
-			m_pCanvas->setImage( image );
+		{
+			QSize size = image.size();
+			m_pCanvas->setImage( image, size );
+		}
 		else
 		{
 			emit setStatusBarText( i18n( "Unknown image format: %1" ).arg( m_url.prettyURL() ) );
@@ -420,7 +423,8 @@ bool KViewViewer::openFile()
 
 		//load from file
 		QImage image( m_file );
-		m_pCanvas->setImage( image );
+		QSize size = image.size();
+		m_pCanvas->setImage( image, size );
 	}
 	m_pFileWatch->addFile( m_file );
 	emit imageOpened( m_url );
@@ -452,7 +456,7 @@ bool KViewViewer::saveFile()
 	kdDebug( 4610 ) << "save m_pCanvas->image() to " << m_file << " as " << type << endl;
 	int quality = 100; // TODO: ask user for quality. Keep it at 100 so that our
 	// users don't lose quality when working with KView.
-	
+
 	m_pFileWatch->removeFile( m_file );
 	bool ret = image->save( m_file, type.latin1(), quality );
 	m_pFileWatch->addFile( m_file );
@@ -461,9 +465,9 @@ bool KViewViewer::saveFile()
 
 void KViewViewer::setupActions()
 {
-	m_paZoomIn = new KAction( i18n( "Zoom In 10%" ), "viewmag+", KStdAccel::shortcut( KStdAccel::ZoomIn ), this,
+	m_paZoomIn = new KAction( i18n( "Zoom In" ), "viewmag+", KStdAccel::shortcut( KStdAccel::ZoomIn ), this,
 			SLOT( slotZoomIn() ), actionCollection(), "zoomin" );
-	m_paZoomOut = new KAction( i18n( "Zoom Out 10%" ), "viewmag-", KStdAccel::shortcut( KStdAccel::ZoomOut ), this,
+	m_paZoomOut = new KAction( i18n( "Zoom Out" ), "viewmag-", KStdAccel::shortcut( KStdAccel::ZoomOut ), this,
 			SLOT( slotZoomOut() ), actionCollection(), "zoomout" );
 
 	m_paZoom = new KSelectAction( i18n( "Zoom" ), "viewmag", 0, actionCollection(), "view_zoom" );
@@ -510,7 +514,9 @@ void KViewViewer::setupActions()
 	connect( widget(), SIGNAL( hasImage( bool ) ), m_paFlipV, SLOT( setEnabled( bool ) ) );
 	connect( widget(), SIGNAL( hasImage( bool ) ), m_paFlipH, SLOT( setEnabled( bool ) ) );
 
-	m_paShowScrollbars = new KToggleAction( i18n( "Show Scrollbars" ), 0, this, SLOT( slotToggleScrollbars() ), actionCollection(), "show_scrollbars" );
+	m_paShowScrollbars = new KToggleAction( i18n( "Show Scrollbars" ), 0, this, SLOT( slotToggleScrollbars() ),
+	 actionCollection(), "show_scrollbars" );
+	m_paShowScrollbars->setCheckedState(i18n("Hide Scrollbars"));
 }
 
 void KViewViewer::guiActivateEvent( KParts::GUIActivateEvent * event )
@@ -866,7 +872,7 @@ void KViewViewer::hasImage( bool b )
 	emit m_pExtension->enableAction( "print", b );
 	if( ! b )
 	{
-		m_sCaption = i18n( "Title caption when no image loaded", "no image loaded" );
+		m_sCaption = i18n( "Title caption when no image loaded", "No Image Loaded" );
 		emit setWindowCaption( m_sCaption );
 	}
 }
