@@ -25,6 +25,7 @@
 
 #include <qvaluevector.h>
 #include "kviewvieweriface.h"
+#include <kdemacros.h>
 
 namespace KImageViewer { class Canvas; }
 namespace KIO { class Job; }
@@ -41,7 +42,7 @@ class KDirWatch;
 template<class T>
 class QCache;
 
-class KViewViewer : public KImageViewer::Viewer, public KViewViewerIface
+class KDE_EXPORT KViewViewer : public KImageViewer::Viewer, public KViewViewerIface
 {
 	Q_OBJECT
 	friend class KViewKonqExtension;
