@@ -4,14 +4,14 @@
 #include <kcmdlineargs.h>
 #include <klocale.h>
 
-static const char *description =
+static const char description[] =
     I18N_NOOP("KView Viewer Part Test");
 
-static const char *version = "v0.1";
+static const char version[] = "v0.1";
 
 static KCmdLineOptions options[] =
 {
-    { "+[URL]", I18N_NOOP( "Image to open." ), 0 },
+    { "+[URL]", I18N_NOOP( "Image to open" ), 0 },
     KCmdLineLastOption
 };
 
