@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2001 Wilco Greven <greven@kde.org>
    Copyright (C) 2002-2004 Stefan Kebekus <kebekus@kde.org>
+   Copyright (C) 2004-2005 Wilfried Huss <Wilfried.Huss@gmx.at>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,7 +30,7 @@
 #include "centeringScrollview.h"
 
 CenteringScrollview::CenteringScrollview( QWidget* parent, const char* name )
-  : QScrollView( parent, name)
+  : QScrollView( parent, name, WStaticContents | WNoAutoErase)
 {
   widgetList = 0;
   setFocusPolicy( QWidget::StrongFocus );
@@ -40,11 +41,12 @@ CenteringScrollview::CenteringScrollview( QWidget* parent, const char* name )
   setVScrollBarMode(QScrollView::Auto);
   setHScrollBarMode(QScrollView::Auto);
 
-  viewport()->setBackgroundMode(QWidget::PaletteMid);
+  viewport()->setBackgroundMode(Qt::NoBackground);
+
+  setResizePolicy(Manual);
+  setAcceptDrops(true);
+  setDragAutoScroll(false);
 
-  URShadow.resize(4,4);
-  BRShadow.resize(4,4);
-  BLShadow.resize(4,4);
   enableClipper(true);
   nrCols = 2;
   nrRows = 1;
@@ -61,8 +63,10 @@ void CenteringScrollview::addChild( QPtrVector<QWidget> *wdgList )
   }
 
   widgetList = wdgList;
+
   for(Q_UINT16 i=0; i<widgetList->size(); i++) 
-    connect(widgetList->at(i), SIGNAL(resized()), this, SLOT(centerContents()));
+    connect(widgetList->at(i), SIGNAL(showMe(QWidget *, Q_UINT16)), this, SLOT(slotShowWidget(QWidget *, Q_UINT16)) );
+
   centerContents();
 }
 
@@ -216,7 +220,6 @@ void CenteringScrollview::setNrRows( Q_UINT8 rows )
 void CenteringScrollview::setContinuousViewMode(bool continuous)
 {
   continuousViewmode = continuous;
-  kdDebug(1223) << "ScrollView cont = " << continuous << endl;
 }
 
 bool CenteringScrollview::singlePageFullScreenMode()
@@ -232,7 +235,7 @@ void CenteringScrollview::slotShowScrollbars(bool status)
   } else {
     setVScrollBarMode(QScrollView::AlwaysOff);
     setHScrollBarMode(QScrollView::AlwaysOff);
-  }  
+  }
 
   // Remember the state of the scrollbars so that we can restore
   // scrollbar visibility when we switch back from fullscreen mode to
@@ -254,9 +257,8 @@ void CenteringScrollview::setFullScreenMode(bool fullScreen)
     {
       viewport()->setPaletteBackgroundColor( Qt::black ) ;
     }
-    // repaintContents(true);
-  } 
-  else 
+  }
+  else
   {
     viewport()->setPaletteBackgroundColor( backgroundColor ) ;
     slotShowScrollbars(showScrollBars);
@@ -264,7 +266,7 @@ void CenteringScrollview::setFullScreenMode(bool fullScreen)
   }
 }
 
-void CenteringScrollview::centerContents()
+void CenteringScrollview::centerContents(bool zoomChanged)
 {
   // Paranoid safety check
   if (widgetList == 0)
@@ -273,20 +275,9 @@ void CenteringScrollview::centerContents()
   // If there are no widgets, e.g. because the last widget has been
   // removed, the matter is easy: set the contents size to 0. If there
   // are no widgets because previously existing widgets were removed
-  // (we detect that by looking at the contentsWidth and -Height), we
-  // make sure to update the viewport so that old shadows will be
-  // removed.
   if (widgetList->isEmpty()) {
     if ((contentsWidth() != 0) || (contentsHeight() != 0)) {
       QScrollView::resizeContents(0,0);
-      viewport()->update();
-      // Process pending events. In particular, re-draw the the
-      // viewport now. This is useful as this method is often called
-      // when widgets are removed, because a new file is
-      // loaded. Loading a file may take a second, and we make sure
-      // here that the user is not left with a garbled looking
-      // viewport meanwhile.
-      qApp->processEvents();
     }
     return;
   }
@@ -333,8 +324,11 @@ void CenteringScrollview::centerContents()
       row = (i+nrCols) / nrCols - 1;
     }
 
-    colWidth[col] = QMAX(colWidth[col], (Q_UINT32)widgetList->at(i)->width());
-    rowHeight[row] = QMAX(rowHeight[row], (Q_UINT32)widgetList->at(i)->height());
+    // Substract 4 pixels from the widgets width and height to take the page shadow into account.
+    // It would be much cleaner to just call documentWidget::pageSize(), but then we would have to
+    // link documentWidget etc. to the kviewpart. (This has already been changed in HEAD)
+    colWidth[col] = QMAX(colWidth[col], (Q_UINT32)widgetList->at(i)->width()-4);
+    rowHeight[row] = QMAX(rowHeight[row], (Q_UINT32)widgetList->at(i)->height()-4);
   }
 
   // Calculate the total width and height of the display
@@ -388,9 +382,28 @@ void CenteringScrollview::centerContents()
 
   // Re-draw the viewport background so that old shadows are removed
   if (((Q_UINT32)contentsWidth() != totalWidth) || ((Q_UINT32)contentsHeight() != totalHeight))
+  {
+    // Calculate the point in the coordinates of the contents which is currently at the center of the viewport.
+    QPoint midPoint = QPoint(visibleWidth() / 2 + contentsX(), visibleHeight() / 2 + contentsY()); 
+    double midPointRatioX = (double)(midPoint.x()) / contentsWidth();
+    double midPointRatioY = (double)(midPoint.y()) / contentsHeight();
+
     resizeContents(totalWidth,totalHeight);
 
-  viewport()->update();
+    // If the zoom changed recenter the former midPoint
+    if (zoomChanged)
+      center((int)(contentsWidth() * midPointRatioX), (int)(contentsHeight() * midPointRatioY));
+
+  }
+}
+
+
+void CenteringScrollview::slotShowWidget(QWidget *wdg, Q_UINT16 y)
+{
+  if (wdg == 0)
+    return;
+
+  ensureVisible(childY(wdg)+wdg->width()/2, childY(wdg)+y, 50, 100);
 }
 
 
@@ -400,91 +413,51 @@ void CenteringScrollview::contentsWheelEvent ( QWheelEvent * e )
 }
 
 
-// The following tables store grey values for roundish shadow
-// corners. They were shamelessly stolen from kdelibs/kdefx/kstyle.cpp
-
-const int bottom_right_corner[16] =
-  { 61, 71, 85, 95,
-    71, 78, 89, 96,
-    85, 89, 95, 98,
-    95, 97, 98, 99 };
-const int bottom_left_corner[16] =
-  { 95, 85, 71, 61,
-    97, 89, 78, 71,
-    98, 95, 89, 85,
-    99, 98, 96, 95 };
-const int shadow_strip[4] =
-  { 56, 67, 83, 94 };
-
-
-void CenteringScrollview::drawContents( QPainter *p, int, int, int, int )
-{
-  // Safety check
-  if ((widgetList == 0) ||  (widgetList->isEmpty()))
-    return;
-
-  // Shadows are only drawn if a child widget exists, is shown and not
-  // 0x0 size, and if whe are not in single page fullscreen mode
-  if ( (widgetList != 0) && (!singlePageFullScreenMode()) ) {
-    QColor backgroundColor = viewport()->paletteBackgroundColor();
-
-    // (Re-)generate the Pixmaps for the shadow corners, if necessary
-    if (backgroundColor != viewportBackgroundColorForCorners) {
-      viewportBackgroundColorForCorners = backgroundColor;
-      QImage tmp(4, 4, 32);
-
-      for(int x=0; x<4; x++)
-        for(int y=0; y<4; y++)
-          tmp.setPixel(x, y, backgroundColor.light(bottom_right_corner[x+4*y]).rgb() );
-      BRShadow.convertFromImage(tmp);
-
-      for(int x=0; x<4; x++)
-        for(int y=0; y<4; y++)
-          tmp.setPixel(x, y, backgroundColor.light(bottom_left_corner[x+4*y]).rgb() );
-      BLShadow.convertFromImage(tmp);
-
-      URShadow.convertFromImage(tmp.mirror(true, true));
-    }
-
-    // Go through all widgets, but draw frames only about those that
-    // are visible.
-    QRect visiblRect(contentsX(), contentsY(), visibleWidth(), visibleHeight());
-    for(Q_UINT16 widgetNr=0; widgetNr<widgetList->size(); widgetNr++) {
-      QWidget *pagePtr = widgetList->at(widgetNr);
-
-      // Paranoid safety check
-      if (pagePtr == 0) {
-        kdError(4300) << "Safety check failed in void CenteringScrollview::drawContents( QPainter *p, int, int, int, int )" << endl;
-        continue;
-      }
-      Q_INT32 X = childX(pagePtr);
-      Q_INT32 Y = childY(pagePtr);
-      Q_INT32 W = pagePtr->width();
-      Q_INT32 H = pagePtr->height();
-
-      QRect widgetRect(X, Y, W, H );
-      if (widgetRect.intersects(visiblRect)) {
-        // Draw right and bottom shadows
-        for(Q_INT32 i=0; i<4; i++) {
-          p->setPen(backgroundColor.light(shadow_strip[i]));
-          // Right shadow
-          p->drawLine(X+W+i, Y+8, X+W+i, Y+H);
-          // Bottom shadow
-          p->drawLine(X+8, Y+H+i, X+W, Y+H+i );
-        }
-        // Draw shadow corners
-        p->drawPixmap(X+W, Y+H, BRShadow);
-        p->drawPixmap(X+4, Y+H, BLShadow);
-        p->drawPixmap(X+W, Y+4, URShadow);
-      }
-    }
-  }
-}
-
 void CenteringScrollview::moveViewportToWidget(QWidget* widget)
 {
   setContentsPos(childX(widget) - distanceBetweenWidgets, 
                  childY(widget) - distanceBetweenWidgets);
 }
 
+
+void CenteringScrollview::viewportPaintEvent(QPaintEvent* e)
+{
+  // Region from which rectangles occupied by child widgets will by substracted.
+  QRegion backgroundArea(e->rect());
+
+  if (widgetList != 0)
+  {
+    for (unsigned int i = 0; i < widgetList->count(); i++)
+    {
+      QWidget* item = widgetList->at(i);
+
+      // Check if the Widget needs to be updated.
+      if (!item->geometry().intersects(e->rect()))
+        continue;
+
+      QRect widgetGeometry = item->geometry();
+
+      // Draw the widget.
+      if (e->rect().intersects(widgetGeometry))
+      {
+        QRect widgetRect = e->rect().intersect(widgetGeometry);
+        widgetRect.moveBy(-widgetGeometry.left(), -widgetGeometry.top());
+
+        item->update(widgetRect);
+      }
+
+      // Substract the painted area.
+      backgroundArea -= widgetGeometry.intersect(e->rect());
+    }
+  }
+
+  // Paint the background.
+  QPainter p(viewport());
+
+  QMemArray<QRect> backgroundRects = backgroundArea.rects();
+
+  for (unsigned int i = 0; i < backgroundRects.count(); i++)
+    p.fillRect(backgroundRects[i], colorGroup().mid());
+}
+
 #include "centeringScrollview.moc"
