@@ -158,7 +158,7 @@ protected:
       enableActions(true) should be called whenever a file is
       successfully loaded.  enableActions(false) is called when the
       file is closed. */
-  virtual void enableActions(bool) {};
+  virtual void enableActions(bool);
 
   /** Initializes all data structures that need to know the renderer.
       This function must be called in the constructor of multipage
