@@ -4,19 +4,20 @@
 
 #include <kparts/part.h>
 #include <kparts/browserextension.h>
-#include <kparts/factory.h>
 #include <kdirwatch.h>
 #include <qtimer.h>
 
+class KAboutDialog;
 class KAccel;
 class KAction;
 class KSelectAction;
 class KTempFile;
 class KToggleAction;
 class KViewPartExtension;
-class MarkList;
 class KInstance;
+class KURL;
 class QSize;
+class QHBoxLayout;
 class pageSizeDialog;
 
 #include "kviewpart_iface.h"
@@ -25,31 +26,17 @@ class pageSizeDialog;
 #include "zoom.h"
 #include "zoomlimits.h"
 
-class KViewPartFactory : public KParts::Factory
-{
-  Q_OBJECT
-
-public:
-  KViewPartFactory();
-  virtual ~KViewPartFactory();
-
-  virtual KParts::Part *createPartObject( QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name, const char *classname, const QStringList &args );
-  
-  static KInstance *instance();
-
-private:
-  static KInstance *s_instance;
-};
-
-
 class KViewPart : public KViewPart_Iface
 {
   Q_OBJECT
 
 public:
-  KViewPart(QString partname, QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name);
+  KViewPart(QWidget *parentWidget, const char *widgetName, QObject *parent,
+            const char *name, const QStringList& args);
   virtual ~KViewPart();
 
+  static KAboutData* createAboutData();
+
   bool isValid() { return multiPage; }
 
   // Returns a description of the current page size, for use in the
@@ -61,23 +48,25 @@ signals:
   void pageChanged(const QString &);
   void sizeChanged(const QString &);
   void scrollbarStatusChanged(bool);
+  void fileOpened();
 
 public slots:
   void slotSetFullPage(bool fullpage);
+
+  virtual void slotFileOpen();
   virtual bool closeURL();
   virtual QStringList fileFormats();
   void setStatusBarTextFromMultiPage(const QString &);
   /** Calling this slot will cause the kmultipage to reload the file */
   void reload(void);
 
+  void restoreDocument(const KURL &url, int page);
+  void saveDocumentRestoreInfo(KConfig* config);
+
 protected slots:
-  void slotShowMarkList();
+  void slotShowSidebar();
   void slotMedia (int);
 
-  void prevPage();
-  void nextPage();
-  void firstPage();
-  void lastPage();
   void goToPage();
 
   void zoomIn();
@@ -85,28 +74,15 @@ protected slots:
 
   void disableZoomFit();
   void updateZoomLevel();
-  
+
   void enableFitToPage(bool);
   void enableFitToHeight(bool);
   void enableFitToWidth(bool);
-  
+
   void fitToPage();
   void fitToHeight();
   void fitToWidth();
 
-  void scrollUp();
-  void scrollDown();
-  void scrollLeft();
-  void scrollRight();
-
-  void scrollUpPage();
-  void scrollDownPage();
-  void scrollLeftPage();
-  void scrollRightPage();
-
-  void readUp();
-  void readDown();
-
   void slotPrint();
 
   void fileChanged(const QString&);
@@ -116,38 +92,18 @@ protected slots:
 
 
 protected:
-  KToggleAction *showmarklist, *scrollbarHandling;
+  KToggleAction *showSidebar, *scrollbarHandling;
   KSelectAction *orientation, *media, *zoom_action;
 
   virtual bool openFile();
 
-  int page() const { return _currentPage; };
-  int pages() const { return _numberOfPages; };
-  void setPage(int page);
-
-  bool eventFilter(QObject *obj, QEvent *ev);
   void connectNotify ( const char * );
 
   void partActivateEvent( KParts::PartActivateEvent *ev );
   void guiActivateEvent( KParts::GUIActivateEvent *ev );
 
-  /** Scrolls the main scrollview by deltaInPixel (positive values
-      scroll DOWN). If the user tries to scroll past the beginning or
-      the end of a page, then the method either returns without doing
-      anything (if the current page is the first or last page, resp,
-      or if the method is called within 200ms after the beg. or end of
-      the page was reached), or goes the the next/previous page. The
-      delay makes it a little easier for the user to scroll with the
-      mouse wheel or the keyboard without involuntarily moving to
-      another page. */
-  void scroll(Q_INT32 deltaInPixel);
-
-
 private slots:
-  void numberOfPages(int nr);
   void pageInfo(int numpages, int currentpage);
-  void pageSelected(int nr);
-  void scrollTo(int x, int y);
   void checkActions();
 
   /** This is the slot where mouseWheel events are processed that come
@@ -156,34 +112,45 @@ private slots:
       scrolls by two 'lines'. */
   void wheelEvent(QWheelEvent *);
 
-  // This slot is connected to userRequestedPaperSize. Whenever the
-  // size changes, this slot is called. It checks if the
-  // userRequestedPaperSize has an orientation and
-  // enables/set/disables the menu entries accordingly. It also sets
-  // the media menu entries. Finally, the slot sets the _paperSize, if
-  // appropriate, and initiates an update of the GUI, if necessary.
-  void slotUserPreferredSizeChanged(float, float);
-
-  // This slot is connected to the useDocumentSpecifiedSize action,
-  // and is called when the user checks/unchecks the "use document
-  // specified paper size" menu entry
-  void slotUseDocumentSpecifiedSize(bool);
-
-  // This slot is connected to _paperSize: whenever the paper size
-  // changes, this slot is called and the necessary upates in the GUI
-  // are performed
-  void setPaperSize(float width_in_mm, float height_in_mm);
-
-  // Reacts to page size requests of the multipage
-  void slotPageSizeRequests(const pageSize &size);
-  
   void slotStartFitTimer();
-  
+
+  void doSettings();
+  void preferencesChanged();
+
+  void aboutKViewShell();
+
+  // Relay signals to the multipage. We cannot connect to the
+  // slots of the multipage directly because than we would have
+  // to recreate the whole interface whenever a new multipage is loaded.
+  void mp_prevPage();
+  void mp_nextPage();
+  void mp_firstPage();
+  void mp_lastPage();
+
+  void mp_readUp();
+  void mp_readDown();
+
+  void mp_scrollUp();
+  void mp_scrollDown();
+  void mp_scrollLeft();
+  void mp_scrollRight();
+  void mp_scrollUpPage();
+  void mp_scrollDownPage();
+  void mp_scrollLeftPage();
+  void mp_scrollRightPage();
+
+  void mp_slotSave();
+  void mp_slotSave_defaultFilename();
+
+  void mp_doGoBack();
+  void mp_doGoForward();
+
 private:
+  void initializeMultiPage();
+
   // This method reads the configuration file. It should only be
   // called when no document is loaded.
   void readSettings();
-
   void writeSettings();
 
   // The method openFile of this kviewpart can be called even if
@@ -193,32 +160,29 @@ private:
   KTempFile *tmpUnzipped;
 
   KDirWatch *watch;
-  QString _partname;
-  QSize sizeOfPage();
   KAccel *accel;
   KAction *zoomInAct, *zoomOutAct, *backAct, *forwardAct,
     *startAct, *endAct, *endDocAct, *markAct, *gotoAct,
     *saveAction, *saveAsAction, *printAction, *readUpAct, *readDownAct;
+  KAction *backAction;
+  KAction *forwardAction;
+  KAction *settingsAction;
+  KAction* aboutAction;
   KToggleAction *watchAct,*useDocumentSpecifiedSize,
     *fitPageAct, *fitHeightAct, *fitWidthAct;
+  KSelectAction* viewModeAction;
 
   KMultiPage *multiPage;
-  MarkList  *markList;
+  // Name of the library of the currently loaded multiPage.
+  // Is used to check if it is really necessary to load a new MultiPage.
+  QString multiPageLibrary;
+
   KViewPartExtension *m_extension;
 
-  int _numberOfPages, _currentPage;
   bool pageChangeIsConnected;
 
   QWidget *mainWidget;
-
-  pageSize  _paperSize;
-
-  /** Some documents specify the paper size. In that case, the
-      kmultipage implementation will call the slotPageSizeRequests()
-      method. The method will then set this flag to 'true' and store
-      the requested size in 'documentRequestedPaperSize'. */
-  bool      documentHasRequestedPaperSize;
-  pageSize  documentRequestedPaperSize;
+  QHBoxLayout* mainLayout;
 
   /** This entry stores the paper size that the user has requested in
       the preferences dialog. If that paper size is actually used or
@@ -227,24 +191,13 @@ private:
       specified paper size if available" */
   pageSize  userRequestedPaperSize;
 
-
-  class zoom      _zoomVal; // stores the current zoom value
+  /** stores the current zoom value */
+  class zoom      _zoomVal;
   pageSizeDialog *_pageSizeDialog;
 
-  /** Stores the mouse position between two mouse events. This is used
-      to implement the "grab and drag the scrollview contents"
-      feature. */
-  QPoint mousePos;
-
-  /** This timer is used to implement a brief delay when the user
-      scrolls past the beginning or the end of the page before a the
-      program moves to a new page. That way, it is a little easier for
-      the user to scroll with the mouse wheel or the keyboard without
-      involuntarily moving to another page. The timer is used in the
-      scroll() method. */
-  QTimer changePageDelayTimer;
-  
   QTimer fitTimer;
+
+  KAboutDialog* aboutDialog;
 };
 
 
