@@ -8,6 +8,7 @@
  */
  
 
+#include <qfileinfo.h>
 #include <qtimer.h>
 #include <qregexp.h>
 
@@ -15,14 +16,13 @@
 #include <kstandarddirs.h>
 #include <kapplication.h>
 #include <kaction.h>
+#include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <kmenubar.h>
 #include <klibloader.h>
 #include <kstdaction.h>
-#include <khelpmenu.h>
 #include <kedittoolbar.h>
 #include <kurldrag.h>
 
@@ -43,17 +43,26 @@
 #define StatusBar_ID_Zoom 3
 
 
-KViewShell::KViewShell(QString partname, KAboutData *about)
-  : KParts::MainWindow(), _partname(partname)
+KViewShell::KViewShell(QString defaultMimeType)
+  : KParts::MainWindow()
 {
   // create the viewer part
 
   // Try to load
   KLibFactory *factory = KLibLoader::self()->factory("kviewerpart");
   if (factory) {
-    QStringList args;
-    args << _partname;
-    view = (KViewPart_Iface*) factory->create(this, "kviewerpart", "KViewPart", args);
+    if (defaultMimeType == QString::null)
+    {
+      view = (KViewPart_Iface*) factory->create(this, "kviewerpart", "KViewPart");
+    }
+    else
+    {
+      QStringList args;
+      args << defaultMimeType;
+      view = (KViewPart_Iface*) factory->create(this, "kviewerpart", "KViewPart", args);
+    }
+    if (!view)
+      ::exit(-1);
   } else {
     KMessageBox::error(this, i18n("No viewing component found"));
     ::exit(-1);
@@ -62,12 +71,14 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
   setCentralWidget(view->widget());
 
   // file menu
-  KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
+  KStdAction::open(view, SLOT(slotFileOpen()), actionCollection());
   recent = KStdAction::openRecent (this, SLOT(openURL(const KURL &)), actionCollection());
   reloadAction = new KAction(i18n("Reload"), "reload", CTRL + Key_R, view, SLOT(reload(void)), actionCollection(), "reload");
   closeAction = KStdAction::close(this, SLOT(slotFileClose()), actionCollection());
   KStdAction::quit (this, SLOT(slotQuit()), actionCollection());
 
+  connect(view, SIGNAL(fileOpened()), this, SLOT(addRecentFile()));
+
   // view menu
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,1,90)
   fullScreenAction = KStdAction::fullScreen(this, SLOT(slotFullScreen()), actionCollection(), this, "fullscreen" );
@@ -86,7 +97,9 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
   connect( view, SIGNAL( pageChanged(const QString &) ), this,SLOT( slotChangePageText(const QString &) ) );
   connect( view, SIGNAL( sizeChanged(const QString &) ), this,SLOT( slotChangeSizeText(const QString &) ) );
 
-  m_helpMenu = new KHelpMenu( this, about, true, actionCollection() );
+  // Setup session management
+  connect( this, SIGNAL( restoreDocument(const KURL &, int) ), view, SLOT( restoreDocument(const KURL &, int)));
+  connect( this, SIGNAL( saveDocumentRestoreInfo(KConfig*) ), view, SLOT( saveDocumentRestoreInfo(KConfig*)));
 
   setXMLFile( "kviewshell.rc" );
   createGUI(view);
@@ -104,6 +117,7 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
   // Add statusbar-widgets for zoom, pagenr and format
   statusBar()->insertItem("", StatusBar_ID_PageNr, 0, true);
   statusBar()->insertFixedItem("XXXX%", StatusBar_ID_Zoom, true);
+  statusBar()->changeItem("", StatusBar_ID_Zoom);
   statusBar()->insertItem(view->pageSizeDescription(), StatusBar_ID_PageSize, 0, true);
 }
 
@@ -149,15 +163,13 @@ void KViewShell::slotQuit()
 
 void KViewShell::readSettings()
 {
-  // Hmm using kapp->config() here means all kviewshell-based apps share the same setings... (DF)
-
   resize(600, 300); // default size if the config file specifies no size
   setAutoSaveSettings( "General" ); // apply mainwindow settings (size, toolbars, etc.)
 
   KConfig *config = kapp->config();
   config->setGroup("General");
 
-  recent->loadEntries(config, QString("%1-RecentFiles").arg(_partname));
+  recent->loadEntries(config, "Recent Files");
 
   // Constant source of annoyance in KDVI < 1.0: the 'recent-files'
   // menu contains lots of files which don't exist (any longer). Thus,
@@ -168,7 +180,7 @@ void KViewShell::readSettings()
     if (url.isLocalFile()) {
       QFileInfo info(url.path());
       if (!info.exists())
-	recent->removeURL(url);
+        recent->removeURL(url);
     }
   }
 
@@ -179,36 +191,51 @@ void KViewShell::writeSettings()
 {
   KConfig *config = kapp->config();
   config->setGroup( "General" );
-  recent->saveEntries(config, QString("%1-RecentFiles").arg(_partname));
+  recent->saveEntries(config, "Recent Files");
 
   config->sync();
 }
 
 
-void KViewShell::openURL(const KURL &url)
+void KViewShell::saveProperties(KConfig* config)
 {
-  if (view->openURL(url)) {
-    // The URL which we passed as an argument may have been incomplete
-    // (e.g. "test" instead of "test.dvi"). Thus, we use the completed
-    // version from the kviewpart here.
-    KURL actualURL = view->url();
-    // To store the URL in the list of recent files, we remove the
-    // reference part.
-    actualURL.setRef(QString::null);
-    recent->addURL(actualURL);
-    checkActions();
+  // the 'config' object points to the session managed
+  // config file.  anything you write here will be available
+  // later when this app is restored
+  emit saveDocumentRestoreInfo(config);
+}
+
+
+void KViewShell::readProperties(KConfig* config)
+{
+  // the 'config' object points to the session managed
+  // config file.  this function is automatically called whenever
+  // the app is being restored.  read in here whatever you wrote
+  // in 'saveProperties'
+  if (view)
+  {
+    KURL url (config->readPathEntry("URL"));
+    if (url.isValid())
+      emit restoreDocument(url, config->readNumEntry("Page", 1));
   }
 }
 
 
-void KViewShell::slotFileOpen()
+void KViewShell::addRecentFile()
 {
-  KURL url = KFileDialog::getOpenURL(QString::null, view->fileFormats().join("\n"));
-
-  if (!url.isEmpty())
-    openURL(url);
+  // Get the URL of the opened file from the kviewpart.
+  KURL actualURL = view->url();
+  // To store the URL in the list of recent files, we remove the
+  // reference part.
+  actualURL.setRef(QString::null);
+  recent->addURL(actualURL);
+  checkActions();
 }
 
+void KViewShell::openURL(const KURL& url)
+{
+  view->openURL(url);
+}
 
 void KViewShell::slotFullScreen()
 {
@@ -273,29 +300,16 @@ void KViewShell::slotNewToolbarConfig()
 
 void KViewShell::dragEnterEvent(QDragEnterEvent *event)
 {
-  if (KURLDrag::canDecode(event)) {
+  if (KURLDrag::canDecode(event)) 
+  {
     KURL::List urls;
     KURLDrag::decode(event, urls);
-    if (urls.count() > 0) {
-      const KURL &url = urls.first();
-      // look if the extension is right
-      QStringList list = view->fileFormats();
-      QStringList::Iterator it;
-      for (it = list.begin(); it != list.end(); ++it) {
-	QString ext = (*it);
-	int pos = ext.find('|');
-	if (pos >= 0)
-	  ext = ext.left(pos);
-
-	QRegExp re(ext, false, true);
-	if (re.search(url.fileName()) >= 0) {
-	  event->accept(true);
-	  return;
-	}
-      }
-    }
+    if (urls.isEmpty())
+      event->ignore();
+    else
+      event->accept();
+    //TODO: check for supported mime-types.
   }
-  event->accept(false);
 }
 
 
@@ -303,7 +317,7 @@ void KViewShell::dropEvent(QDropEvent *event)
 {
   KURL::List urls;
   if (KURLDrag::decode(event, urls) && !urls.isEmpty())
-    openURL(urls.first());
+    view->openURL(urls.first());
 }
 
 
