@@ -23,7 +23,7 @@ public:
 
 public slots:
   // Sets the size.
-  void setSize(float width, float height);
+  void setSize(float width_mm, float height_mm);
 
   // or = 0 means "Portrait", anything else means "Landscape"
   void setOrientation(int ori); 
