@@ -1,5 +1,5 @@
 /* This file is part of the KDE Project
-   Copyright (C) 1999 Klaas Freitag <freitag@suse.de>  
+   Copyright (C) 1999 Klaas Freitag <freitag@suse.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -15,13 +15,9 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
-
-   $Id: img_canvas.cpp,v 1.17 2002/09/19 10:24:10 freitag Exp $
 */
 
 #include <qapplication.h>
-#include <iostream.h>
-
 #include <qfiledialog.h>
 #include <qstring.h>
 #include <qmessagebox.h>
@@ -29,6 +25,9 @@
 #include <kpopupmenu.h>
 #include <qlabel.h>
 #include <qdict.h>
+#include <qimage.h>
+#include <qpainter.h>
+
 #include <klocale.h>
 #include <kstyle.h>
 #include <kapplication.h>
@@ -37,6 +36,7 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <kcmenumngr.h>
+#include <qpixmap.h>
 
 #define __IMG_CANVAS_CPP__
 
@@ -54,86 +54,117 @@ inline void debug_rect( const char *name, QRect *r )
 }
 
 
+class ImageCanvas::ImageCanvasPrivate
+{
+public:
+    ImageCanvasPrivate()
+        : keepZoom(false),
+	  readOnly(false),
+          scaleKind( UNSPEC ),
+          defaultScaleKind( FIT_ORIG )
+        {}
+
+    bool         keepZoom;  /* keep the zoom settings if images change */
+    bool         readOnly;
+    ScaleKinds   scaleKind;
+    ScaleKinds   defaultScaleKind;
+
+    QValueList<QRect> highlightRects;
+};
 
 ImageCanvas::ImageCanvas(QWidget *parent,
 			 const QImage *start_image,
 			 const char *name 	):
    QScrollView( parent, name ),
    m_contextMenu(0)
-
 {
-  scale_factor     = 100; // means orignal size
-  maintain_aspect  = true;
-  selected         = new QRect;
-  timer_id         = 0;
-  pmScaled         = 0;
+    d = new ImageCanvasPrivate();
 
-  image            = start_image;
-  moving 	   = MOVE_NONE;
+    scale_factor     = 100; // means original size
+    maintain_aspect  = true;
+    selected         = new QRect;
+    selected->setWidth(0);
+    selected->setHeight(0);
 
-  QSize img_size;
+    timer_id         = 0;
+    pmScaled         = 0;
 
-  if( image && ! image->isNull() )
-  {
-    img_size = image->size();
-    pmScaled = new QPixmap( img_size );
+    image            = start_image;
+    moving 	   = MOVE_NONE;
+
+    QSize img_size;
+
+    if( image && ! image->isNull() )
+    {
+        img_size = image->size();
+        pmScaled = new QPixmap( img_size );
 
 #ifdef USE_KPIXMAPIO
-    *pmScaled = pixIO.convertToPixmap(*image);
+        *pmScaled = pixIO.convertToPixmap(*image);
 #else
-    pmScaled->convertFromImage( *image );
+        pmScaled->convertFromImage( *image );
 #endif
 
-    acquired = true;
-  } else {
-    img_size = size();
-  }
+        acquired = true;
+    } else {
+        img_size = size();
+    }
 
-  
-  // createContextMenu();
-  update_scaled_pixmap();
 
-  // timer-Start and stop
-  connect( this, SIGNAL( newRect()), SLOT( newRectSlot()));
-  connect( this, SIGNAL( noRect()),  SLOT( noRectSlot()));
+    update_scaled_pixmap();
 
-  //zoomOut();scrollview/scrollview
-  viewport()->setCursor( crossCursor );
-  cr1 = 0;
-  cr2 = 0;
-  viewport()->setMouseTracking(TRUE);
-  viewport()->setBackgroundMode(PaletteBackground);
-  show();
+    // timer-Start and stop
+    connect( this, SIGNAL( newRect()), SLOT( newRectSlot()));
+    connect( this, SIGNAL( noRect()),  SLOT( noRectSlot()));
+
+    //zoomOut();scrollview/scrollview
+    viewport()->setCursor( crossCursor );
+    cr1 = 0;
+    cr2 = 0;
+    viewport()->setMouseTracking(TRUE);
+    viewport()->setBackgroundMode(PaletteBackground);
+    show();
 
 }
 
 ImageCanvas::~ImageCanvas()
 {
-   kdDebug(28000) << "Destructor of ImageCanvas" << endl;
+   kdDebug(29000) << "Destructor of ImageCanvas" << endl;
     noRectSlot();
     if( selected ) delete selected;
     selected = 0;
     if( pmScaled ) delete pmScaled;
     pmScaled = 0;
+    delete d;
 }
 
 void ImageCanvas::deleteView( QImage *delimage )
 {
    const QImage *img = rootImage();
-   
+
    if( delimage == img )
    {
-      kdDebug(28000) << "ImageCanvas -> emiting newImage(0L)" << endl;
+      kdDebug(29000) << "ImageCanvas -> emiting newImage(0L)" << endl;
       newImage( 0L );
       noRectSlot();
    }
-	 
+
+}
+
+void ImageCanvas::newImageHoldZoom( QImage *new_image )
+{
+    bool holdZ = d->keepZoom;
+
+    d->keepZoom = true;
+    newImage( new_image );
+    d->keepZoom = holdZ;
 }
 
 void ImageCanvas::newImage( QImage *new_image )
 {
-   // dont free old image -> not yours
 
+    /** do cleanups **/
+   // dont free old image -> not yours
    image = new_image;
 
    if( ! image || image->isNull())
@@ -152,27 +183,40 @@ void ImageCanvas::newImage( QImage *new_image )
       noRectSlot();
    }
 
+   /* throw away all highlights */
+   d->highlightRects.clear();
+
+   /** handle the new image **/
    if( image )
-   {						
+   {
       if( image->depth() == 1 ) {
 	 pmScaled = new QPixmap( image->size(), 1 );
       } else {
 	 int i = QPixmap::defaultDepth();
 	 pmScaled = new QPixmap( image->size(), i);
       }
-	
-      image->convertDepth(32);
+
+      // image->convertDepth(32);
 #ifdef USE_KPIXMAPIO
-	
+
       *pmScaled = pixIO.convertToPixmap(*image);
 #else
       pmScaled->convertFromImage( *image );
       // *pmScaled = image->convertToPixmap( );
 #endif
-    	
+
       acquired = true;
-      if( scale_factor != 0 )
-	 scale_factor = 100;
+
+      if( d->keepZoom )
+      {
+          kdDebug(29000) << "Preserving Zoom settings!" << endl;
+      }
+      else
+      {
+          kdDebug(29000) << "Resetting Zoom to original size!" << endl;
+          setScaleKind( defaultScaleKind() );
+      }
+
       update_scaled_pixmap();
       setContentsPos(0,0);
    } else {
@@ -198,9 +242,9 @@ void ImageCanvas::enableContextMenu( bool wantContextMenu )
    {
       if( ! m_contextMenu )
       {
-	 m_contextMenu = new KPopupMenu( this );
+	 m_contextMenu = new KPopupMenu(this, "IMG_CANVAS");
 
-	 KContextMenuManager::insert( this, m_contextMenu );
+	 KContextMenuManager::insert( viewport(), m_contextMenu );
       }
    }
    else
@@ -211,21 +255,16 @@ void ImageCanvas::enableContextMenu( bool wantContextMenu )
        * it from the contextMenuManager
        */
    }
-   
+
 }
 
 void ImageCanvas::handle_popup( int item )
 {
    if( item < ID_POP_ZOOM || item > ID_ORIG_SIZE ) return;
-   double scale;
-   
+
    if( ! image ) return;
    ImgScaleDialog *zoomDia  = 0;
-   const int sbWidth = kapp->style().pixelMetric( QStyle::PM_ScrollBarExtent );
-   const QSize noSBSize = size(); /* Size of complete scrollbar */
-   
-   kdDebug(29000)<< "Size of viewport: " << noSBSize.width() << " and " << noSBSize.height() << endl;
-   
+
    switch( item )
    {
       case ID_POP_ZOOM:
@@ -234,55 +273,20 @@ void ImageCanvas::handle_popup( int item )
           if( zoomDia->exec() )
           {
               int sf = zoomDia->getSelected();
-	      QApplication::setOverrideCursor(waitCursor);
+	      setScaleKind(ZOOM);
               setScaleFactor( sf );
-              repaint( true);
           }
           delete zoomDia;
 	  zoomDia = 0;
-	  QApplication::restoreOverrideCursor();
-
 	 break;
       case ID_ORIG_SIZE:
-	 QApplication::setOverrideCursor(waitCursor);
-	 setScaleFactor(100);
-	 QApplication::restoreOverrideCursor();
-      break;
+	 setScaleKind( FIT_ORIG );
+         break;
       case ID_FIT_WIDTH:
-	 QApplication::setOverrideCursor(waitCursor);
-	 
-	 scale = 100.0 * noSBSize.width() / image->width();
-	 kdDebug(29000) << "Scale ist " << scale << endl;
-
-	 if( (scale/100.0 * image->height()) >= noSBSize.height() )
-	 {
-	    /* substract for scrollbar */
-	    scale = 100 * (noSBSize.width() - sbWidth) / image->width();
-	    kdDebug(29000) << "FIT WIDTH scrollbar to substract: " << sbWidth << endl;
-	 }
-
-	 kdDebug(29000)<< "Sale Factor double: " << scale << endl;
-	 setScaleFactor( static_cast<int>(scale-0.5) );
-	 repaint( true );
-	 QApplication::restoreOverrideCursor();
-      break;
+          setScaleKind( FIT_WIDTH );
+          break;
       case ID_FIT_HEIGHT:
-	 QApplication::setOverrideCursor(waitCursor);
-
-	 scale = 100.0 * noSBSize.height() / image->height();
-	 kdDebug(29000) << "Scale ist " << scale << endl;
-
-	 if( (scale/100.0 * image->width()) >= width() )
-	 {
-	    /* substract for scrollbar */
-	    kdDebug(29000) << "FIT HEIGHT scrollbar to substract: " << sbWidth << endl;
-	    scale = 100.0*(noSBSize.height() -sbWidth) / image->height();
-	 }
-
-	 kdDebug(29000)<< "Sale Factor double: " << scale << endl;
-	 setScaleFactor( static_cast<int>(scale-0.5) );
-	 repaint( true );
-	 QApplication::restoreOverrideCursor();
+          setScaleKind( FIT_HEIGHT );
 	 break;
       case ID_POP_CLOSE:
 	 emit( closingRequested());
@@ -290,7 +294,8 @@ void ImageCanvas::handle_popup( int item )
 
       default: break;
    }
-
+   update_scaled_pixmap();
+   repaint();
 }
 
 
@@ -302,27 +307,29 @@ void ImageCanvas::handle_popup( int item )
 QRect ImageCanvas::sel( void )
 {
     QRect retval;
-	
-    if( selected && image )
+    retval.setCoords(0, 0, 0, 0);
+
+    if( selected && image && selected->width()>MIN_AREA_WIDTH
+        && selected->height()>MIN_AREA_HEIGHT )
     {
 	/* Get the size in real image pixels */
-		
+
 	// debug_rect( "PRE map", selected );
    	QRect mapped = inv_scale_matrix.map( (const QRect) *selected );
    	// debug_rect( "Postmap", &mapped );
    	if( mapped.x() > 0 )
 	    retval.setLeft((int) (1000.0/( (double)image->width() / (double)mapped.x())));
-	
+
 	if( mapped.y() > 0 )
 	    retval.setTop((int) (1000.0/( (double)image->height() / (double)mapped.y())));
-	
+
 	if( mapped.width() > 0 )
 	    retval.setWidth((int) (1000.0/( (double)image->width() / (double)mapped.width())));
-	
-	if( mapped.height() > 0 )	
+
+	if( mapped.height() > 0 )
 	    retval.setHeight((int)(1000.0/( (double)image->height() / (double)mapped.height())));
-	
-     }   	
+
+     }
    	// debug_rect( "sel() return", &retval );
      return( retval );
 
@@ -361,7 +368,7 @@ void ImageCanvas::drawContents( QPainter * p, int clipx, int clipy, int clipw, i
     int y1 = 0;
 
     int x2 = pmScaled->width();
-    int y2 = pmScaled->height();	
+    int y2 = pmScaled->height();
 
     if (x1 < clipx) x1=clipx;
     if (y1 < clipy) y1=clipy;
@@ -378,7 +385,7 @@ void ImageCanvas::drawContents( QPainter * p, int clipx, int clipy, int clipw, i
     }
 
         // p->fillRect(x1, y1, x2-x1+1, y2-y1+1, red);
- 	
+
 }
 
 void ImageCanvas::timerEvent(QTimerEvent *)
@@ -392,27 +399,34 @@ void ImageCanvas::timerEvent(QTimerEvent *)
 
 void ImageCanvas::newRectSlot( QRect newSel )
 {
-   if( ! selected ) selected = new QRect;
    QRect to_map;
    QPainter p(viewport());
    drawAreaBorder(&p,TRUE);
-
    selected->setWidth(0);
    selected->setHeight(0);
+
    emit( noRect() );
 
-   if ( image ) 
+   if ( image )
    {
-       int h = image->width();
-       //kdDebug(29000) << "ImageCanvas got selection Rect: W=" << newSel.width() << ", H=" << newSel.height() << endl;
-       to_map.setWidth(static_cast<int>(h * newSel.width() / 1000.0));
-       to_map.setX( static_cast<int>(h * newSel.x() / 1000.0 ));
+       int rx, ry, rw, rh;
+       int w = image->width();
+       int h = image->height();
 
-       h = image->height();
-       to_map.setHeight( static_cast<int>(h * newSel.height() / 1000.0 ));
-       to_map.setY( static_cast<int>(h * newSel.y() / 1000.0 ));
+       kdDebug(29000) << "ImageCanvas: Image size is " << w << "x" << h << endl;
+       kdDebug(29000) << "ImageCanvas got selection Rect: W=" << newSel.width() << ", H=" << newSel.height() << endl;
+       // to_map.setWidth(static_cast<int>(w * newSel.width() / 1000.0));
+       rw = static_cast<int>(w * newSel.width()  / 1000.0);
+       rx = static_cast<int>(w * newSel.x()      / 1000.0);
+       ry = static_cast<int>(h * newSel.y()      / 1000.0);
+       rh = static_cast<int>(h * newSel.height() / 1000.0);
+       kdDebug(29000) << "ImageCanvas: scaled Height is " << rh << endl;
 
+       to_map.setRect( rx, ry, rw, rh );
+
+       kdDebug(29000) << "ImageCanvas Selection: W=" << to_map.width() << " H=" << to_map.height() << endl;
        *selected = scale_matrix.map( to_map );
+       kdDebug(29000) << "ImageCanvas Selection: W=" << selected->width() << " H=" << selected->height() << endl;
        emit( newRect( sel() ));
        newRectSlot();
    }
@@ -442,7 +456,7 @@ void ImageCanvas::noRectSlot( void )
 void ImageCanvas::viewportMousePressEvent(QMouseEvent *ev)
 {
    if( ! acquired || ! image ) return;
-	
+
    if(ev->button()==LeftButton )
    {
 
@@ -493,7 +507,7 @@ void ImageCanvas::viewportMouseReleaseEvent(QMouseEvent *ev)
     drawAreaBorder(&p);
     emit newRect( sel() );
     emit newRect( );
-  } 
+  }
 }
 
 
@@ -607,12 +621,12 @@ void ImageCanvas::viewportMouseMoveEvent(QMouseEvent *ev)
     			kdDebug(29000) << "runs out !" << endl;
     		}
 
-    		/* Check if rectangle would run out of the image on left and top */    			    			
+    		/* Check if rectangle would run out of the image on left and top */
     		if( selected->x() +mx < 0 )
     			mx =  -selected->x();
     		if( selected->y()+ +my < 0 )
     			my =  -selected->y();
-			    		
+
     		x = mx+lx; y = my+ly;
 
     		selected->moveBy( mx, my );
@@ -630,6 +644,10 @@ void ImageCanvas::setScaleFactor( int i )
 {
    kdDebug(29000) <<  "Setting Scalefactor to " << i << endl;
    scale_factor = i;
+   if( i == 0 ){
+       kdDebug(29000) << "Setting Dynamic Scaling!" << endl;
+       setScaleKind(DYNAMIC);
+   }
    update_scaled_pixmap();
 }
 
@@ -638,79 +656,121 @@ void ImageCanvas::resizeEvent( QResizeEvent * event )
 {
 	QScrollView::resizeEvent( event );
 	update_scaled_pixmap();
-	
+
 }
 
 void ImageCanvas::update_scaled_pixmap( void )
 {
-
-  if( !pmScaled || !image)
-  { 	// debug( "Pixmap px is null in Update_scaled" );
+    resizeContents( 0,0 );
+    updateScrollBars();
+    if( !pmScaled || !image)
+    { 	// debug( "Pixmap px is null in Update_scaled" );
 	return;
-  }
+    }
 
-  int scale = scale_factor;
-  // debug( "Rescaling with Factor %d", scale );
-  if( scale == 0 )
-  {
-     // do scaling to window-size
-     used_yscaler = ((float)viewport()-> height()) / ((float)image->height());
-     used_xscaler = ((float)viewport()-> width())  / ((float)image->width());
-  }
-  else
-  {
-     // scale as in scale in percent given (eg 100 = original size )
-     used_xscaler = (double) scale / 100;
-     used_yscaler = (double) scale / 100;
-  }
+    QApplication::setOverrideCursor(waitCursor);
 
-  // reconvert the selection to orig size
-  if( selected ) {
-     *selected = inv_scale_matrix.map( (const QRect) *selected );
-  }
+    kdDebug(28000) << "Updating scaled_pixmap" << endl;
+    if( scaleKind() == DYNAMIC )
+        kdDebug(28000) << "Scaling DYNAMIC" << endl;
+    QSize noSBSize( visibleWidth(), visibleHeight());
+    const int sbWidth = kapp->style().pixelMetric( QStyle::PM_ScrollBarExtent );
 
-  scale_matrix.reset();                         // transformation matrix
-  inv_scale_matrix.reset();
+    // if( verticalScrollBar()->visible() ) noSBSize.width()+=sbWidth;
+    // if( horizontalScrollBar()->visible() ) noSBSize.height()+=sbWidth;
+
+    switch( scaleKind() )
+    {
+    case DYNAMIC:
+        // do scaling to window-size
+        used_yscaler = ((double)viewport()-> height()) / ((double)image->height());
+        used_xscaler = ((double)viewport()-> width())  / ((double)image->width());
+        scale_factor = 0;
+        break;
+    case FIT_ORIG:
+        used_yscaler = used_xscaler = 1.0;
+        scale_factor = 100;
+        break;
+    case FIT_WIDTH:
+        used_xscaler = used_yscaler = double(noSBSize.width()) / double(image->width());
+        if( used_xscaler * image->height() >= noSBSize.height() )
+        {
+            /* substract for scrollbar */
+            used_xscaler = used_yscaler = double(noSBSize.width() - sbWidth) /
+                           double(image->width());
+            kdDebug(29000) << "FIT WIDTH scrollbar to substract: " << sbWidth << endl;
+        }
+        scale_factor = 100*used_xscaler;
+        break;
+    case FIT_HEIGHT:
+        used_yscaler = used_xscaler = double(noSBSize.height())/double(image->height());
+
+        // scale = int(100.0 * noSBSize.height() / image->height());
+        if( used_xscaler * image->width() >= noSBSize.width() )
+        {
+            /* substract for scrollbar */
+            used_xscaler = used_yscaler = double(noSBSize.height() - sbWidth) /
+                           double(image->height());
+
+            kdDebug(29000) << "FIT HEIGHT scrollbar to substract: " << sbWidth << endl;
+            // scale = int(100.0*(noSBSize.height() -sbWidth) / image->height());
+        }
+        scale_factor = 100*used_xscaler;
+
+        break;
+    case ZOOM:
+        used_xscaler = used_yscaler = double(getScaleFactor())/100.0;
+        scale_factor = 100*used_xscaler;
+        break;
+    default:
+        break;
+    }
+
+    // reconvert the selection to orig size
+    if( selected ) {
+        *selected = inv_scale_matrix.map( (const QRect) *selected );
+    }
+
+    scale_matrix.reset();                         // transformation matrix
+    inv_scale_matrix.reset();
 
 
-  if( !scale && maintain_aspect  ) {
-     // printf( "Skaler: x: %f, y: %f\n", x_scaler, y_scaler );
-     used_xscaler = used_yscaler <  used_xscaler ?
-		used_yscaler : used_xscaler;
-     used_yscaler = used_xscaler;
-  }
+    if( scaleKind() == DYNAMIC && maintain_aspect  ) {
+        // printf( "Skaler: x: %f, y: %f\n", x_scaler, y_scaler );
+        used_xscaler = used_yscaler <  used_xscaler ?
+                       used_yscaler : used_xscaler;
+        used_yscaler = used_xscaler;
+    }
 
-  scale_matrix.scale( used_xscaler, used_yscaler );  // define scale factors
-  inv_scale_matrix = scale_matrix.invert();	// for redraw of selection
+    scale_matrix.scale( used_xscaler, used_yscaler );  // define scale factors
+    inv_scale_matrix = scale_matrix.invert();	// for redraw of selection
 
-  if( selected ) {
-     *selected = scale_matrix.map( (const QRect )*selected );
-  }
+    if( selected ) {
+        *selected = scale_matrix.map( (const QRect )*selected );
+    }
 
 #ifdef USE_KPIXMAPIO
-  *pmScaled = pixIO.convertToPixmap(*image);
+    *pmScaled = pixIO.convertToPixmap(*image);
 #else
-  pmScaled->convertFromImage( *image );
+    pmScaled->convertFromImage( *image );
 #endif
 
-  *pmScaled = pmScaled->xForm( scale_matrix );  // create scaled pixmap
+    *pmScaled = pmScaled->xForm( scale_matrix );  // create scaled pixmap
 
-  /* Resizing to 0,0 never may be dropped, otherwise there are problems
-   * with redrawing of new images.
-   */
-  resizeContents( 0,0 );
-  resizeContents( static_cast<int>(image->width() * used_xscaler),
-                  static_cast<int>(image->height() * used_yscaler ) );
+    /* Resizing to 0,0 never may be dropped, otherwise there are problems
+     * with redrawing of new images.
+     */
+    resizeContents( static_cast<int>(image->width() * used_xscaler),
+                    static_cast<int>(image->height() * used_yscaler ) );
 
+    QApplication::restoreOverrideCursor();
 }
 
 
-
-
 void ImageCanvas::drawHAreaBorder(QPainter &p,int x1,int x2,int y,int r)
 {
 	if( ! acquired || !image ) return;
-	
+
   if(moving!=MOVE_NONE) cr2 = 0;
   int inc = 1;
   int cx = contentsX(), cy = contentsY();
@@ -730,7 +790,7 @@ void ImageCanvas::drawHAreaBorder(QPainter &p,int x1,int x2,int y,int r)
 	re_y = MIN( image->height()-1, re_y );
 
 	p.setPen( QPen( QColor( image->pixel(re_x1, re_y))));
-      }	
+      }
       p.drawPoint(x1,y);
     }
     if(!r) {
@@ -891,6 +951,17 @@ const QImage *ImageCanvas::rootImage( )
    return( image );
 }
 
+void ImageCanvas::setReadOnly( bool ro )
+{
+    d->readOnly = ro;
+    emit( imageReadOnly(ro) );
+}
+
+bool ImageCanvas::readOnly()
+{
+    return d->readOnly;
+}
+
 void ImageCanvas::setBrightness(int b)
 {
    brightness = b;
@@ -906,6 +977,138 @@ void ImageCanvas::setGamma(int c)
    gamma = c;
 }
 
+void ImageCanvas::setKeepZoom( bool k )
+{
+    d->keepZoom = k;
+}
+
+ImageCanvas::ScaleKinds ImageCanvas::scaleKind()
+{
+    if( d->scaleKind == UNSPEC )
+        return defaultScaleKind();
+    else
+        return d->scaleKind;
+}
+
+ImageCanvas::ScaleKinds ImageCanvas::defaultScaleKind()
+{
+    return d->defaultScaleKind;
+}
+
+void ImageCanvas::setScaleKind( ScaleKinds k )
+{
+    if( k == d->scaleKind ) return; // no change, return
+    d->scaleKind = k;
+
+    emit scalingChanged(scaleKindString());
+}
+
+void ImageCanvas::setDefaultScaleKind( ScaleKinds k )
+{
+    d->defaultScaleKind = k;
+}
+
+const QString ImageCanvas::imageInfoString( int w, int h, int d )
+{
+    if( w == 0 && h == 0 && d == 0 )
+    {
+        if( image )
+        {
+            w = image->width();
+            h = image->height();
+            d = image->depth();
+        }
+        else
+            return QString("-");
+    }
+    return i18n("%1x%2 pixel, %3 bit").arg(w).arg(h).arg(d);
+}
+
+
+const QString ImageCanvas::scaleKindString()
+{
+    switch( scaleKind() )
+    {
+    case DYNAMIC:
+        return i18n("Fit window best");
+        break;
+    case FIT_ORIG:
+        return i18n("Original size");
+        break;
+    case FIT_WIDTH:
+        return i18n("Fit Width");
+        break;
+    case FIT_HEIGHT:
+        return i18n("Fit Height");
+        break;
+    case ZOOM:
+        return i18n("Zoom to %1 %%").arg( QString::number(getScaleFactor()));
+        break;
+    default:
+        return i18n("Unknown scaling!");
+        break;
+    }
+}
+
+
+int ImageCanvas::highlight( const QRect& rect, const QPen& pen, const QBrush&, bool ensureVis  )
+{
+    QRect saveRect;
+    saveRect.setRect( rect.x()-2, rect.y()-2, rect.width()+4, rect.height()+4 );
+    d->highlightRects.append( saveRect );
+
+    int idx = d->highlightRects.findIndex(saveRect);
+
+    QRect targetRect = scale_matrix.map( rect );
+
+    QPainter p( pmScaled );
+
+    p.setPen(pen);
+    p.drawLine( targetRect.x(), targetRect.y()+targetRect.height(),
+                targetRect.x()+targetRect.width(), targetRect.y()+targetRect.height() );
+
+    p.flush();
+    updateContents(targetRect.x()-1, targetRect.y()-1,
+                   targetRect.width()+2, targetRect.height()+2 );
+
+    if( ensureVis )
+    {
+        QPoint p = targetRect.center();
+        ensureVisible( p.x(), p.y(), 10+targetRect.width()/2, 10+targetRect.height()/2 );
+    }
+
+    return idx;
+}
+
+void ImageCanvas::removeHighlight( int idx )
+{
+    if( (unsigned) idx >= d->highlightRects.count() )
+    {
+        kdDebug(28000) << "removeHighlight: Not a valid index" << endl;
+        return;
+    }
+
+    /* take the rectangle from the stored highlight rects and map it to the viewer scaling */
+    QRect r = d->highlightRects[idx];
+    d->highlightRects.remove(r);
+    QRect targetRect = scale_matrix.map( r );
+
+    /* create a small pixmap with a copy of the region in question of the original image */
+    QPixmap origPix;
+    origPix.convertFromImage( image->copy(r) );
+    /* and scale it */
+    QPixmap scaledPix = origPix.xForm( scale_matrix );
+    /* and finally draw it */
+    QPainter p( pmScaled );
+    p.drawPixmap( targetRect, scaledPix );
+    p.flush();
+
+    /* update the viewers contents */
+    updateContents(targetRect.x()-1, targetRect.y()-1,
+                   targetRect.width()+2, targetRect.height()+2 );
+
+
+}
 
 
 #include "img_canvas.moc"
