@@ -1,22 +1,21 @@
-/***************************************************************************
-	     kscanoption.h - Scanner option class
-                             -------------------
-    begin                : Wed Oct 13 2000
-    copyright            : (C) 2000 by Klaas Freitag
-    email                : Klaas.Freitag@SuSE.de
+/* This file is part of the KDE Project
+   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>  
 
-    $Id: kscanoption.h,v 1.10 2002/01/17 16:09:48 hausmann Exp $
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef _KSCANOPTION_H_
 #define _KSCANOPTION_H_
@@ -161,6 +160,7 @@ public:
    
   // Possible Values
   QStrList    getList() const;
+  bool        getRangeFromList( double*, double*, double* ) const;
   bool        getRange( double*, double*, double* ) const;
 
   QCString    getName() const { return( name ); }
@@ -248,7 +248,7 @@ private:
   bool       buffer_untouched;
   size_t     buffer_size;
 
-  /* For gamma-Tables remeber gamma, brightness, contrast */
+  /* For gamma-Tables remember gamma, brightness, contrast */
   int        gamma, brightness, contrast;
 
    class KScanOptionPrivate;
