@@ -1,37 +1,38 @@
-/***************************************************************************
-              kscanslider.h - some helpfull widgets for kooka
-                             -------------------
-    begin                : Wed Jan 5 2000
-    copyright            : (C) 2000 by Klaas Freitag
-    email                : freitag@suse.de
- ***************************************************************************/
+/* This file is part of the KDE Project
+   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef KSCANSLIDER_H
 #define KSCANSLIDER_H
 
 #include <qframe.h>
+#include <qstrlist.h>
+#include <qhbox.h>
+#include <qcombobox.h>
 #include <qslider.h>
 #include <qlineedit.h>
-#include <qstrlist.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qhbox.h>
 /**
   *@author Klaas Freitag
   */
 
 class QPushButton;
 class QSpinBox;
+class QLabel;
 
 /**
  * a kind of extended slider which has a spinbox beside the slider offering
@@ -45,7 +46,7 @@ class KScanSlider : public QFrame
 {
    Q_OBJECT
    Q_PROPERTY( int slider_val READ value WRITE slSetSlider )
-   
+
 public:
    /**
     * Create the slider.
@@ -72,7 +73,7 @@ public:
     */
    int value( ) const
       { return( slider->value()); }
-   
+
 public slots:
   /**
    * sets the slider value
@@ -88,14 +89,14 @@ protected slots:
     /**
      * reverts the slider back to the standard value given in the constructor
      */
-     void         slRevertValue(); 
+     void         slRevertValue();
 
    signals:
     /**
      * emitted if the slider value changes
      */
      void	  valueChanged( int );
-		
+
 private slots:
    void		slSliderChange( int );
 
@@ -107,7 +108,7 @@ private:
    QPushButton  *m_stdButt;
    class KScanSliderPrivate;
    KScanSliderPrivate *d;
-   
+
 };
 
 /**
@@ -117,7 +118,7 @@ class KScanEntry : public QFrame
 {
    Q_OBJECT
    Q_PROPERTY( QString text READ text WRITE slSetEntry )
-      
+
 public:
    /**
     * create a new entry field prepended by text.
@@ -143,7 +144,7 @@ public slots:
     * @param b set enabled if true, else disabled.
     */
    void		setEnabled( bool b ){ if( entry) entry->setEnabled( b ); }
-      
+
 protected slots:
    void         slReturnPressed( void );
 
@@ -153,13 +154,13 @@ signals:
 
 private slots:
    void		slEntryChange( const QString& );
- 
+
 private:
    QLineEdit 	*entry;
 
    class KScanEntryPrivate;
    KScanEntryPrivate *d;
-	
+
 };
 
 
@@ -170,7 +171,7 @@ class KScanCombo : public QHBox
 {
    Q_OBJECT
    Q_PROPERTY( QString cbEntry READ currentText WRITE slSetEntry )
-      
+
 public:
    /**
     * create a combobox with prepended text.
@@ -180,6 +181,7 @@ public:
     * @param list a stringlist with values the list should contain.
     */
    KScanCombo( QWidget *parent, const QString& text, const QStrList& list );
+   KScanCombo( QWidget *parent, const QString& text, const QStringList& list );
    // ~KScanCombo();
 
    /**
@@ -231,6 +233,7 @@ signals:
    void         activated(int);
 
 private:
+    void createCombo( const QString& text );
    QComboBox	*combo;
    QStrList	combolist;
 
