@@ -16,8 +16,6 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
-
-   $Id: previewer.cpp,v 1.20 2003/11/19 09:05:50 freitag Exp $
 */
 
 #include <qlabel.h>
@@ -25,7 +23,6 @@
 #include <qhbox.h>
 #include <qtooltip.h>
 #include <qpopupmenu.h>
-#include <qregexp.h>
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qcombobox.h>
@@ -144,11 +141,11 @@ Previewer::Previewer(QWidget *parent, const char *name )
     /* Actions for the previewer zoom */
     KAction *act;
     act =  new KAction(i18n("Scale to W&idth"), "scaletowidth", CTRL+Key_I,
-		       this, SLOT( slScaleToWidth()), this );
+		       this, SLOT( slScaleToWidth()), this, "preview_scaletowidth" );
     act->plug( img_canvas->contextMenu());
 
     act = new KAction(i18n("Scale to &Height"), "scaletoheight", CTRL+Key_H,
-		      this, SLOT( slScaleToHeight()), this );
+		      this, SLOT( slScaleToHeight()), this, "preview_scaletoheight" );
     act->plug( img_canvas->contextMenu());
 
     /*Signals: Control the custom-field and show size of selection */
@@ -206,8 +203,8 @@ Previewer::Previewer(QWidget *parent, const char *name )
 
     /* combobox to select if black or white background */
     d->m_cbBackground = new QComboBox( hbox );
-    d->m_cbBackground->insertItem(i18n("black"), BG_ITEM_BLACK );
-    d->m_cbBackground->insertItem(i18n("white"), BG_ITEM_WHITE );
+    d->m_cbBackground->insertItem(i18n("Black"), BG_ITEM_BLACK );
+    d->m_cbBackground->insertItem(i18n("White"), BG_ITEM_WHITE );
     connect( d->m_cbBackground, SIGNAL(activated(int) ),
              this, SLOT( slScanBackgroundChanged( int )));
 
@@ -289,38 +286,22 @@ Previewer::~Previewer()
     delete d;
 }
 
-bool Previewer::loadPreviewImage( const QString forScanner )
+bool Previewer::setPreviewImage( const QImage &image )
 {
-   const QString prevFile = previewFile( forScanner );
-   kdDebug(29000) << "Loading preview for " << forScanner << " from file " << prevFile << endl;
+   if ( image.isNull() )
+	return false;
 
-   bool re = m_previewImage.load( prevFile );
-   if( re )
-   {
-      img_canvas->newImage( &m_previewImage );
-   }
-   return re;
-}
+   m_previewImage = image;
+   img_canvas->newImage( &m_previewImage );
 
-/* extension needs to be added */
-QString Previewer::previewFile( const QString& scanner )
-{
-   QString fname = galleryRoot() + QString::fromLatin1(".previews/");
-   QRegExp rx( "/" );
-   QString sname( scanner );
-   sname.replace( rx, "_");
-
-   fname += sname;
-
-   kdDebug(29000) << "ImgSaver: returning preview file without extension: " << fname << endl;
-   return( fname );
+   return true;
 }
 
 QString Previewer::galleryRoot()
 {
    QString dir = (KGlobal::dirs())->saveLocation( "data", "ScanImages", true );
 
-   if( dir.right(1) != "/" )
+   if( !dir.endsWith("/") )
       dir += "/";
 
    return( dir );
@@ -437,7 +418,6 @@ void Previewer::slFormatChange( int id )
       bgroup->setButton( portrait_id );
       format_id = portrait_id;
    }
-
    /* Convert the new dimension to a new QRect and call slot in canvas */
    if( setSelection )
    {
