@@ -1,6 +1,6 @@
 /* This file is part of the KDE Project
    Copyright (C) 2001 Nikolas Zimmermann <wildfox@kde.org>
-                      Klaas Freitag <freitag@suse.de>  
+                      Klaas Freitag <freitag@suse.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -16,8 +16,6 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
-
-   $Id: scandialog.cpp,v 1.25 2002/09/19 10:24:10 freitag Exp $
 */
 
 #include <qlabel.h>
@@ -25,8 +23,9 @@
 #include <qstringlist.h>
 #include <qstrlist.h>
 #include <qtooltip.h>
-#include <qsizepolicy.h> 
+#include <qsizepolicy.h>
 #include <qapplication.h>
+#include <qcheckbox.h>
 
 #include <kglobal.h>
 #include <klocale.h>
@@ -34,6 +33,8 @@
 #include <kconfig.h>
 #include <ksimpleconfig.h>
 #include <kled.h>
+#include <kglobalsettings.h>
+#include <kscandevice.h>
 
 // libkscan stuff
 #include "scanparams.h"
@@ -72,14 +73,14 @@ ScanDialog::ScanDialog( QWidget *parent, const char *name, bool modal )
      good_scan_connect(false)
 {
     QVBox *page = addVBoxPage( i18n("&Scanning") );
-    
+
     splitter = new QSplitter( Horizontal, page, "splitter" );
     Q_CHECK_PTR( splitter );
-    
-    m_scanParams = 0; 
+
+    m_scanParams = 0;
     m_device = new KScanDevice( this );
-    connect(m_device, SIGNAL(sigNewImage(QImage *)),
-            this, SLOT(slotFinalImage(QImage *)));
+    connect(m_device, SIGNAL(sigNewImage(QImage *, ImgScanInfo*)),
+            this, SLOT(slotFinalImage(QImage *, ImgScanInfo *)));
 
     connect( m_device, SIGNAL(sigScanStart()), this, SLOT(slotScanStart()));
     connect( m_device, SIGNAL(sigScanFinished(KScanStat)),
@@ -88,10 +89,11 @@ ScanDialog::ScanDialog( QWidget *parent, const char *name, bool modal )
     /* Create a preview widget to the right side of the splitter */
     m_previewer = new Previewer( splitter );
     Q_CHECK_PTR(m_previewer );
+
     /* ... and connect to the selector-slots. They communicate user's
      * selection to the scanner parameter engine */
     /* a new preview signal */
-    connect( m_device, SIGNAL( sigNewPreview( QImage* )),
+    connect( m_device, SIGNAL( sigNewPreview( QImage*, ImgScanInfo* )),
              this, SLOT( slotNewPreview( QImage* )));
 
     m_previewer->setEnabled( false ); // will be enabled in setup()
@@ -106,13 +108,13 @@ void ScanDialog::createOptionsTab( void )
 {
 
    QVBox *page = addVBoxPage( i18n("&Options"));
-   setMainWidget(page);	   
+   setMainWidget(page);
 
    QGroupBox *gb = new QGroupBox( 1, Qt::Horizontal, i18n("Startup Options"), page, "GB_STARTUP" );
    QLabel *label = new QLabel( i18n( "Note: changing these options will affect the scan plugin on next start." ),
 			       gb );
    label->setSizePolicy( QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed ) );
-   
+
    /* Checkbox for asking for scanner on startup */
    cb_askOnStart = new QCheckBox( i18n( "&Ask for the scan device on plugin startup"), gb );
    QToolTip::add( cb_askOnStart,
@@ -127,19 +129,19 @@ void ScanDialog::createOptionsTab( void )
 
 
    /* Read settings for startup behavior */
-   KConfig *gcfg = KGlobal::config(); 
+   KConfig *gcfg = KGlobal::config();
    gcfg->setGroup(QString::fromLatin1(GROUP_STARTUP));
-   bool skipDialog  = gcfg->readBoolEntry( STARTUP_SKIP_ASK, false );	
+   bool skipDialog  = gcfg->readBoolEntry( STARTUP_SKIP_ASK, false );
    bool onlyLocal   = gcfg->readBoolEntry( STARTUP_ONLY_LOCAL, false );
-   
+
    /* Note: flag must be inverted because of question is 'the other way round' */
    cb_askOnStart->setChecked( !skipDialog );
    connect( cb_askOnStart, SIGNAL(toggled(bool)), this, SLOT(slotAskOnStartToggle(bool)));
 
    cb_network->setChecked( !onlyLocal );
    connect( cb_network, SIGNAL(toggled(bool)), this, SLOT(slotNetworkToggle(bool)));
-   
-   
+
+
    QWidget *spaceEater = new QWidget( page );
    Q_CHECK_PTR( spaceEater );
    spaceEater->setSizePolicy( QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding) );
@@ -159,7 +161,7 @@ void ScanDialog::slotNetworkToggle( bool state)
 void ScanDialog::slotAskOnStartToggle(bool state)
 {
    bool writestate = !state;
-   
+
    kdDebug(29000) << "slotAskOnStartToggle: Writing state " << writestate << endl;
    KConfig *c = KGlobal::config();
    c->setGroup(QString::fromLatin1(GROUP_STARTUP));
@@ -196,7 +198,7 @@ void ScanDialog::slotAcquireStart( )
 
 void ScanDialog::slotScanFinished( KScanStat status )
 {
-   kdDebug(28000) << "Scan finished with status " << status << endl;
+   kdDebug(29000) << "Scan finished with status " << status << endl;
    if( m_scanParams )
    {
       m_scanParams->setEnabled( true );
@@ -206,7 +208,7 @@ void ScanDialog::slotScanFinished( KScanStat status )
 	 led->setColor( Qt::green );
 	 led->setState( KLed::Off );
       }
-      
+
    }
 }
 
@@ -219,19 +221,19 @@ bool ScanDialog::setup()
    }
    // The scan device is now closed on closing the scan dialog. That means
    // that more work to open it needs to be done in the setup slot like opening
-   // the selector if neccessary etc.
+   // the selector if necessary etc.
 
    if( m_scanParams )
    {
       /* if m_scanParams exist it means, that the dialog is already open */
       return true;
    }
-   
+
    m_scanParams = new ScanParams( splitter );
    connect( m_previewer->getImageCanvas(), SIGNAL( newRect(QRect)),
 	    m_scanParams, SLOT(slCustomScanSize(QRect)));
    connect( m_previewer->getImageCanvas(), SIGNAL( noRect()),
-	    m_scanParams, SLOT(slMaximalScanSize()));	
+	    m_scanParams, SLOT(slMaximalScanSize()));
 
    connect( m_scanParams, SIGNAL( scanResolutionChanged( int, int )),
 	    m_previewer, SLOT( slNewScanResolutions( int, int )));
@@ -242,7 +244,7 @@ bool ScanDialog::setup()
    QStringList scannerNames;
    QStrList backends = m_device->getDevices();;
    QStrListIterator it( backends );
-   
+
    while ( it.current() ) {
       scannerNames.append( m_device->getScannerName( it.current() ));
       ++it;
@@ -298,7 +300,8 @@ bool ScanDialog::setup()
    if( good_scan_connect )
    {
       m_previewer->setEnabled( true );
-      m_previewer->loadPreviewImage( configDevice );
+      m_previewer->setPreviewImage( m_device->loadPreviewImage() );
+      m_previewer->slConnectScanner( m_device );
    }
 
     /* set initial sizes */
@@ -307,16 +310,15 @@ bool ScanDialog::setup()
     KConfig *kfg = KGlobal::config();
     if( kfg )
     {
-       int scnum = QApplication::desktop()->screenNumber(this);
-       QRect desk = QApplication::desktop()->screenGeometry(scnum);
+       QRect r = KGlobalSettings::desktopGeometry(this);
 
        kfg->setGroup( GROUP_STARTUP );
        /* Since this is a vertical splitter, only the width is important */
-       QString key = QString::fromLatin1( SCANDIA_SPLITTER_SIZES ).arg( desk.width());
+       QString key = QString::fromLatin1( SCANDIA_SPLITTER_SIZES ).arg( r.width());
        kdDebug(29000) << "Read Splitter-Sizes " << key  << endl;
        splitter->setSizes( kfg->readIntListEntry( key ));
     }
-   
+
    return true;
 }
 
@@ -330,12 +332,11 @@ void ScanDialog::slotClose()
       KConfig *kfg = KGlobal::config();
       if( kfg )
       {
-         int scnum = QApplication::desktop()->screenNumber(this);
-	 QRect desk = QApplication::desktop()->screenGeometry(scnum);
+         QRect r = KGlobalSettings::desktopGeometry(this);
 
 	 kfg->setGroup( GROUP_STARTUP );
 	 /* Since this is a vertical splitter, only the width is important */
-	 QString key = QString::fromLatin1( SCANDIA_SPLITTER_SIZES ).arg( desk.width());
+	 QString key = QString::fromLatin1( SCANDIA_SPLITTER_SIZES ).arg( r.width());
 	 kfg->writeEntry( key, splitter->sizes(), true, true);
       }
    }
@@ -358,7 +359,7 @@ void ScanDialog::slotNewPreview( QImage *image )
     if( image )
     {
         m_previewImage = *image;
-        // hmmm - dont know, if conversion of the bit-depth is neccessary.
+        // hmmm - dont know, if conversion of the bit-depth is necessary.
         // m_previewImage.convertDepth(32);
 
         /* The previewer does not copy the image data ! */
@@ -371,7 +372,7 @@ ScanDialog::~ScanDialog()
 {
 }
 
-void ScanDialog::slotFinalImage(QImage *image)
+void ScanDialog::slotFinalImage(QImage *image, ImgScanInfo *)
 {
     emit finalImage(*image, nextId());
 }
